/// autogenerated analytical inverse kinematics code from ikfast program part of OpenRAVE
/// \author Rosen Diankov
///
/// Licensed under the Apache License, Version 2.0 (the "License");
/// you may not use this file except in compliance with the License.
/// You may obtain a copy of the License at
///     http://www.apache.org/licenses/LICENSE-2.0
/// 
/// Unless required by applicable law or agreed to in writing, software
/// distributed under the License is distributed on an "AS IS" BASIS,
/// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
/// See the License for the specific language governing permissions and
/// limitations under the License.
///
/// ikfast version 61 generated on 2013-10-08 17:29:42.298650
/// To compile with gcc:
///     gcc -lstdc++ ik.cpp
/// To compile without any main function as a shared object (might need -llapack):
///     gcc -fPIC -lstdc++ -DIKFAST_NO_MAIN -DIKFAST_CLIBRARY -shared -Wl,-soname,libik.so -o libik.so ik.cpp
#define IKFAST_HAS_LIBRARY
#include "baxter_ikfast_right_arm_plugin/ikfast.h" // found inside share/openrave-X.Y/python/ikfast.h
using namespace ikfast;

// check if the included ikfast version matches what this file was compiled with
#define IKFAST_COMPILE_ASSERT(x) extern int __dummy[(int)x]
IKFAST_COMPILE_ASSERT(IKFAST_VERSION==61);

#include <cmath>
#include <vector>
#include <limits>
#include <algorithm>
#include <complex>

#define IKFAST_STRINGIZE2(s) #s
#define IKFAST_STRINGIZE(s) IKFAST_STRINGIZE2(s)

#ifndef IKFAST_ASSERT
#include <stdexcept>
#include <sstream>
#include <iostream>

#ifdef _MSC_VER
#ifndef __PRETTY_FUNCTION__
#define __PRETTY_FUNCTION__ __FUNCDNAME__
#endif
#endif

#ifndef __PRETTY_FUNCTION__
#define __PRETTY_FUNCTION__ __func__
#endif

#define IKFAST_ASSERT(b) { if( !(b) ) { std::stringstream ss; ss << "ikfast exception: " << __FILE__ << ":" << __LINE__ << ": " <<__PRETTY_FUNCTION__ << ": Assertion '" << #b << "' failed"; throw std::runtime_error(ss.str()); } }

#endif

#if defined(_MSC_VER)
#define IKFAST_ALIGNED16(x) __declspec(align(16)) x
#else
#define IKFAST_ALIGNED16(x) x __attribute((aligned(16)))
#endif

#define IK2PI  ((IkReal)6.28318530717959)
#define IKPI  ((IkReal)3.14159265358979)
#define IKPI_2  ((IkReal)1.57079632679490)

#ifdef _MSC_VER
#ifndef isnan
#define isnan _isnan
#endif
#endif // _MSC_VER

// lapack routines
extern "C" {
  void dgetrf_ (const int* m, const int* n, double* a, const int* lda, int* ipiv, int* info);
  void zgetrf_ (const int* m, const int* n, std::complex<double>* a, const int* lda, int* ipiv, int* info);
  void dgetri_(const int* n, const double* a, const int* lda, int* ipiv, double* work, const int* lwork, int* info);
  void dgesv_ (const int* n, const int* nrhs, double* a, const int* lda, int* ipiv, double* b, const int* ldb, int* info);
  void dgetrs_(const char *trans, const int *n, const int *nrhs, double *a, const int *lda, int *ipiv, double *b, const int *ldb, int *info);
  void dgeev_(const char *jobvl, const char *jobvr, const int *n, double *a, const int *lda, double *wr, double *wi,double *vl, const int *ldvl, double *vr, const int *ldvr, double *work, const int *lwork, int *info);
}

using namespace std; // necessary to get std math routines

#ifdef IKFAST_NAMESPACE
namespace IKFAST_NAMESPACE {
#endif

inline float IKabs(float f) { return fabsf(f); }
inline double IKabs(double f) { return fabs(f); }

inline float IKsqr(float f) { return f*f; }
inline double IKsqr(double f) { return f*f; }

inline float IKlog(float f) { return logf(f); }
inline double IKlog(double f) { return log(f); }

// allows asin and acos to exceed 1
#ifndef IKFAST_SINCOS_THRESH
#define IKFAST_SINCOS_THRESH ((IkReal)0.000001)
#endif

// used to check input to atan2 for degenerate cases
#ifndef IKFAST_ATAN2_MAGTHRESH
#define IKFAST_ATAN2_MAGTHRESH ((IkReal)2e-6)
#endif

// minimum distance of separate solutions
#ifndef IKFAST_SOLUTION_THRESH
#define IKFAST_SOLUTION_THRESH ((IkReal)1e-6)
#endif

inline float IKasin(float f)
{
IKFAST_ASSERT( f > -1-IKFAST_SINCOS_THRESH && f < 1+IKFAST_SINCOS_THRESH ); // any more error implies something is wrong with the solver
if( f <= -1 ) return float(-IKPI_2);
else if( f >= 1 ) return float(IKPI_2);
return asinf(f);
}
inline double IKasin(double f)
{
IKFAST_ASSERT( f > -1-IKFAST_SINCOS_THRESH && f < 1+IKFAST_SINCOS_THRESH ); // any more error implies something is wrong with the solver
if( f <= -1 ) return -IKPI_2;
else if( f >= 1 ) return IKPI_2;
return asin(f);
}

// return positive value in [0,y)
inline float IKfmod(float x, float y)
{
    while(x < 0) {
        x += y;
    }
    return fmodf(x,y);
}

// return positive value in [0,y)
inline double IKfmod(double x, double y)
{
    while(x < 0) {
        x += y;
    }
    return fmod(x,y);
}

inline float IKacos(float f)
{
IKFAST_ASSERT( f > -1-IKFAST_SINCOS_THRESH && f < 1+IKFAST_SINCOS_THRESH ); // any more error implies something is wrong with the solver
if( f <= -1 ) return float(IKPI);
else if( f >= 1 ) return float(0);
return acosf(f);
}
inline double IKacos(double f)
{
IKFAST_ASSERT( f > -1-IKFAST_SINCOS_THRESH && f < 1+IKFAST_SINCOS_THRESH ); // any more error implies something is wrong with the solver
if( f <= -1 ) return IKPI;
else if( f >= 1 ) return 0;
return acos(f);
}
inline float IKsin(float f) { return sinf(f); }
inline double IKsin(double f) { return sin(f); }
inline float IKcos(float f) { return cosf(f); }
inline double IKcos(double f) { return cos(f); }
inline float IKtan(float f) { return tanf(f); }
inline double IKtan(double f) { return tan(f); }
inline float IKsqrt(float f) { if( f <= 0.0f ) return 0.0f; return sqrtf(f); }
inline double IKsqrt(double f) { if( f <= 0.0 ) return 0.0; return sqrt(f); }
inline float IKatan2(float fy, float fx) {
    if( isnan(fy) ) {
        IKFAST_ASSERT(!isnan(fx)); // if both are nan, probably wrong value will be returned
        return float(IKPI_2);
    }
    else if( isnan(fx) ) {
        return 0;
    }
    return atan2f(fy,fx);
}
inline double IKatan2(double fy, double fx) {
    if( isnan(fy) ) {
        IKFAST_ASSERT(!isnan(fx)); // if both are nan, probably wrong value will be returned
        return IKPI_2;
    }
    else if( isnan(fx) ) {
        return 0;
    }
    return atan2(fy,fx);
}

inline float IKsign(float f) {
    if( f > 0 ) {
        return float(1);
    }
    else if( f < 0 ) {
        return float(-1);
    }
    return 0;
}

inline double IKsign(double f) {
    if( f > 0 ) {
        return 1.0;
    }
    else if( f < 0 ) {
        return -1.0;
    }
    return 0;
}

/// solves the forward kinematics equations.
/// \param pfree is an array specifying the free joints of the chain.
IKFAST_API void ComputeFk(const IkReal* j, IkReal* eetrans, IkReal* eerot) {
IkReal x0,x1,x2,x3,x4,x5,x6,x7,x8,x9,x10,x11,x12,x13,x14,x15,x16,x17,x18,x19,x20,x21,x22,x23,x24,x25,x26,x27,x28,x29,x30,x31,x32,x33,x34,x35,x36,x37,x38,x39,x40,x41,x42,x43,x44,x45,x46,x47,x48,x49,x50,x51,x52,x53,x54,x55,x56,x57,x58,x59,x60,x61,x62,x63,x64,x65,x66,x67,x68,x69,x70,x71,x72,x73;
x0=IKcos(j[0]);
x1=IKcos(j[2]);
x2=IKsin(j[1]);
x3=IKsin(j[0]);
x4=IKsin(j[2]);
x5=IKsin(j[3]);
x6=IKcos(j[1]);
x7=IKcos(j[3]);
x8=IKsin(j[4]);
x9=IKcos(j[4]);
x10=IKcos(j[6]);
x11=IKsin(j[6]);
x12=IKsin(j[5]);
x13=IKcos(j[5]);
x14=((IkReal(0.0690000000000000))*(x0));
x15=((IkReal(0.0100000000000000))*(x7));
x16=((IkReal(1.00000000000000))*(x3));
x17=((IkReal(0.279525000000000))*(x5));
x18=((IkReal(1.00000000000000))*(x9));
x19=((IkReal(0.279525000000000))*(x9));
x20=((IkReal(1.00000000000000))*(x5));
x21=((IkReal(0.374290000000000))*(x3));
x22=((IkReal(0.374290000000000))*(x0));
x23=((IkReal(1.00000000000000))*(x0));
x24=((IkReal(0.0100000000000000))*(x2));
x25=((IkReal(1.00000000000000))*(x8));
x26=((IkReal(0.279525000000000))*(x8));
x27=((IkReal(0.0690000000000000))*(x3));
x28=((IkReal(0.0100000000000000))*(x0));
x29=((IkReal(-1.00000000000000))*(x9));
x30=((x2)*(x7));
x31=((x1)*(x6));
x32=((IkReal(-1.00000000000000))*(x12));
x33=((x1)*(x2));
x34=((x0)*(x4));
x35=((x5)*(x6));
x36=((x3)*(x6));
x37=((x6)*(x7));
x38=((IkReal(-1.00000000000000))*(x8));
x39=((x1)*(x3));
x40=((x4)*(x6));
x41=((IkReal(-1.00000000000000))*(x13));
x42=((x2)*(x23)*(x4));
x43=((x23)*(x37));
x44=((x16)*(x33));
x45=((x16)*(x37));
x46=((x18)*(x40));
x47=((x39)+(((IkReal(-1.00000000000000))*(x42))));
x48=((((IkReal(-1.00000000000000))*(x44)))+(x34));
x49=((((IkReal(-1.00000000000000))*(x31)*(x7)))+(((x2)*(x5))));
x50=((((x31)*(x5)))+(x30));
x51=((x42)+(((IkReal(-1.00000000000000))*(x1)*(x16))));
x52=((x44)+(((IkReal(-1.00000000000000))*(x23)*(x4))));
x53=((((x23)*(x33)))+(((x16)*(x4))));
x54=((IkReal(-1.00000000000000))*(x53));
x55=((((x1)*(x23)))+(((x16)*(x2)*(x4))));
x56=((x48)*(x7));
x57=((x5)*(x52));
x58=((x51)*(x8));
x59=((x54)*(x7));
x60=((x55)*(x8));
x61=((x5)*(x53));
x62=((x56)+(((IkReal(-1.00000000000000))*(x16)*(x35))));
x63=((((x40)*(x8)))+(((x49)*(x9))));
x64=((x57)+(((IkReal(-1.00000000000000))*(x45))));
x65=((x59)+(((IkReal(-1.00000000000000))*(x0)*(x20)*(x6))));
x66=((x61)+(((IkReal(-1.00000000000000))*(x43))));
x67=((x13)*(x63));
x68=((x12)*(x64));
x69=((x60)+(((x62)*(x9))));
x70=((x58)+(((x65)*(x9))));
x71=((x13)*(x69));
x72=((((IkReal(-1.00000000000000))*(x29)*(x55)))+(((x38)*(x62))));
x73=((x13)*(x70));
eerot[0]=((((x10)*(((((x12)*(x66)))+(x73)))))+(((x11)*(((((x38)*(x65)))+(((x29)*(x47))))))));
eerot[1]=((((x10)*(((((IkReal(-1.00000000000000))*(x25)*(x65)))+(((IkReal(-1.00000000000000))*(x18)*(x47)))))))+(((x11)*(((((x32)*(x66)))+(((x41)*(x70))))))));
eerot[2]=((((x13)*(((x43)+(((IkReal(-1.00000000000000))*(x20)*(x53)))))))+(((x12)*(x70))));
IkReal x74=((IkReal(1.00000000000000))*(x35));
IkReal x75=((IkReal(1.00000000000000))*(x4));
IkReal x76=((IkReal(1.00000000000000))*(x33));
eetrans[0]=((IkReal(0.0556950000000000))+(((x12)*(((((x26)*(x51)))+(((x19)*(((x59)+(((IkReal(-1.00000000000000))*(x0)*(x74)))))))))))+(((IkReal(-1.00000000000000))*(x27)*(x75)))+(x14)+(((IkReal(-1.00000000000000))*(x14)*(x76)))+(((x22)*(x37)))+(((x5)*(((((IkReal(-1.00000000000000))*(x22)*(x76)))+(((IkReal(-1.00000000000000))*(x21)*(x75)))))))+(((x9)*(((((x15)*(x54)))+(((IkReal(-1.00000000000000))*(x28)*(x74)))))))+(((x13)*(((((IkReal(0.279525000000000))*(x0)*(x37)))+(((IkReal(-1.00000000000000))*(x17)*(x53)))))))+(((IkReal(0.364420000000000))*(x0)*(x6)))+(((x8)*(((((x24)*(x34)))+(((IkReal(-0.0100000000000000))*(x39))))))));
eerot[3]=((((x10)*(((x68)+(x71)))))+(((x11)*(x72))));
eerot[4]=((((x10)*(x72)))+(((x11)*(((((IkReal(-1.00000000000000))*(x71)))+(((IkReal(-1.00000000000000))*(x68))))))));
eerot[5]=((((x12)*(x69)))+(((x13)*(((((IkReal(-1.00000000000000))*(x20)*(x52)))+(x45))))));
IkReal x77=((x3)*(x35));
IkReal x78=((IkReal(1.00000000000000))*(x33));
eetrans[1]=((((x12)*(((((x26)*(x55)))+(((x19)*(((x56)+(((IkReal(-1.00000000000000))*(x77)))))))))))+(((IkReal(-1.00000000000000))*(x27)*(x78)))+(x27)+(((x8)*(((((x24)*(x3)*(x4)))+(((x1)*(x28)))))))+(((x9)*(((((x15)*(x48)))+(((IkReal(-0.0100000000000000))*(x77)))))))+(((x21)*(x37)))+(((x13)*(((((IkReal(-1.00000000000000))*(x17)*(x52)))+(((IkReal(0.279525000000000))*(x36)*(x7)))))))+(((x5)*(((((x22)*(x4)))+(((IkReal(-1.00000000000000))*(x21)*(x78)))))))+(((IkReal(0.364420000000000))*(x36)))+(((x14)*(x4))));
eerot[6]=((((x11)*(((x46)+(((x38)*(x49)))))))+(((x10)*(((((x12)*(x50)))+(x67))))));
eerot[7]=((((x10)*(((x46)+(((IkReal(-1.00000000000000))*(x25)*(x49)))))))+(((x11)*(((((x32)*(x50)))+(((x41)*(x63))))))));
eerot[8]=((((x13)*(((((IkReal(-1.00000000000000))*(x30)))+(((IkReal(-1.00000000000000))*(x20)*(x31)))))))+(((x12)*(x63))));
IkReal x79=((IkReal(1.00000000000000))*(x31));
eetrans[2]=((IkReal(0.281388000000000))+(((IkReal(-0.0690000000000000))*(x31)))+(((IkReal(0.0100000000000000))*(x40)*(x8)))+(((IkReal(-0.374290000000000))*(x30)))+(((IkReal(-0.364420000000000))*(x2)))+(((x12)*(((((x19)*(x49)))+(((x26)*(x40)))))))+(((x13)*(((((IkReal(-0.279525000000000))*(x30)))+(((IkReal(-1.00000000000000))*(x17)*(x79)))))))+(((x9)*(((((IkReal(-1.00000000000000))*(x15)*(x79)))+(((x24)*(x5)))))))+(((IkReal(-0.374290000000000))*(x31)*(x5))));
}

IKFAST_API int GetNumFreeParameters() { return 1; }
IKFAST_API int* GetFreeParameters() { static int freeparams[] = {5}; return freeparams; }
IKFAST_API int GetNumJoints() { return 7; }

IKFAST_API int GetIkRealSize() { return sizeof(IkReal); }

IKFAST_API int GetIkType() { return 0x67000001; }

class IKSolver {
public:
IkReal j0,cj0,sj0,htj0,j1,cj1,sj1,htj1,j2,cj2,sj2,htj2,j3,cj3,sj3,htj3,j4,cj4,sj4,htj4,j6,cj6,sj6,htj6,j5,cj5,sj5,htj5,new_r00,r00,rxp0_0,new_r01,r01,rxp0_1,new_r02,r02,rxp0_2,new_r10,r10,rxp1_0,new_r11,r11,rxp1_1,new_r12,r12,rxp1_2,new_r20,r20,rxp2_0,new_r21,r21,rxp2_1,new_r22,r22,rxp2_2,new_px,px,npx,new_py,py,npy,new_pz,pz,npz,pp;
unsigned char _ij0[2], _nj0,_ij1[2], _nj1,_ij2[2], _nj2,_ij3[2], _nj3,_ij4[2], _nj4,_ij6[2], _nj6,_ij5[2], _nj5;

bool ComputeIk(const IkReal* eetrans, const IkReal* eerot, const IkReal* pfree, IkSolutionListBase<IkReal>& solutions) {
j0=numeric_limits<IkReal>::quiet_NaN(); _ij0[0] = -1; _ij0[1] = -1; _nj0 = -1; j1=numeric_limits<IkReal>::quiet_NaN(); _ij1[0] = -1; _ij1[1] = -1; _nj1 = -1; j2=numeric_limits<IkReal>::quiet_NaN(); _ij2[0] = -1; _ij2[1] = -1; _nj2 = -1; j3=numeric_limits<IkReal>::quiet_NaN(); _ij3[0] = -1; _ij3[1] = -1; _nj3 = -1; j4=numeric_limits<IkReal>::quiet_NaN(); _ij4[0] = -1; _ij4[1] = -1; _nj4 = -1; j6=numeric_limits<IkReal>::quiet_NaN(); _ij6[0] = -1; _ij6[1] = -1; _nj6 = -1;  _ij5[0] = -1; _ij5[1] = -1; _nj5 = 0; 
for(int dummyiter = 0; dummyiter < 1; ++dummyiter) {
    solutions.Clear();
j5=pfree[0]; cj5=cos(pfree[0]); sj5=sin(pfree[0]);
r00 = eerot[0*3+0];
r01 = eerot[0*3+1];
r02 = eerot[0*3+2];
r10 = eerot[1*3+0];
r11 = eerot[1*3+1];
r12 = eerot[1*3+2];
r20 = eerot[2*3+0];
r21 = eerot[2*3+1];
r22 = eerot[2*3+2];
px = eetrans[0]; py = eetrans[1]; pz = eetrans[2];

new_r00=((IkReal(-1.00000000000000))*(r01));
new_r01=r00;
new_r02=r02;
new_px=((IkReal(-0.0556950000000000))+(((IkReal(-0.279525000000000))*(r02)))+(px));
new_r10=((IkReal(-1.00000000000000))*(r11));
new_r11=r10;
new_r12=r12;
new_py=((((IkReal(-0.279525000000000))*(r12)))+(py));
new_r20=((IkReal(-1.00000000000000))*(r21));
new_r21=r20;
new_r22=r22;
new_pz=((IkReal(-0.281388000000000))+(((IkReal(-0.279525000000000))*(r22)))+(pz));
r00 = new_r00; r01 = new_r01; r02 = new_r02; r10 = new_r10; r11 = new_r11; r12 = new_r12; r20 = new_r20; r21 = new_r21; r22 = new_r22; px = new_px; py = new_py; pz = new_pz;
pp=(((px)*(px))+((pz)*(pz))+((py)*(py)));
npx=((((py)*(r10)))+(((pz)*(r20)))+(((px)*(r00))));
npy=((((px)*(r01)))+(((pz)*(r21)))+(((py)*(r11))));
npz=((((py)*(r12)))+(((pz)*(r22)))+(((px)*(r02))));
rxp0_0=((((IkReal(-1.00000000000000))*(py)*(r20)))+(((pz)*(r10))));
rxp0_1=((((px)*(r20)))+(((IkReal(-1.00000000000000))*(pz)*(r00))));
rxp0_2=((((py)*(r00)))+(((IkReal(-1.00000000000000))*(px)*(r10))));
rxp1_0=((((pz)*(r11)))+(((IkReal(-1.00000000000000))*(py)*(r21))));
rxp1_1=((((IkReal(-1.00000000000000))*(pz)*(r01)))+(((px)*(r21))));
rxp1_2=((((py)*(r01)))+(((IkReal(-1.00000000000000))*(px)*(r11))));
rxp2_0=((((IkReal(-1.00000000000000))*(py)*(r22)))+(((pz)*(r12))));
rxp2_1=((((px)*(r22)))+(((IkReal(-1.00000000000000))*(pz)*(r02))));
rxp2_2=((((py)*(r02)))+(((IkReal(-1.00000000000000))*(px)*(r12))));
IkReal op[72], zeror[48];
int numroots;
IkReal x80=((IkReal(0.138000000000000))*(px));
IkReal x81=((IkReal(0.748580000000000))*(py));
IkReal x82=((IkReal(0.0200000000000000))*(rxp0_1));
IkReal x83=((IkReal(0.00866840000000000))*(r20));
IkReal x84=((IkReal(0.00728840000000000))*(r00));
IkReal x85=((IkReal(0.0400000000000000))*(rxp1_1));
IkReal x86=((IkReal(0.00590840000000000))*(r20));
IkReal x87=((IkReal(0.276000000000000))*(py));
IkReal x88=((IkReal(1.49716000000000))*(px));
IkReal x89=((IkReal(0.0400000000000000))*(rxp0_0));
IkReal x90=((IkReal(0.0145768000000000))*(r10));
IkReal x91=((IkReal(0.0800000000000000))*(rxp1_0));
IkReal x92=((IkReal(0.0173368000000000))*(r21));
IkReal x93=((IkReal(0.0118168000000000))*(r21));
IkReal x94=((cj5)*(r00));
IkReal x95=((IkReal(0.0959180554000000))*(sj5));
IkReal x96=((cj5)*(r12));
IkReal x97=((cj5)*(r02));
IkReal x98=((r11)*(sj5));
IkReal x99=((r12)*(sj5));
IkReal x100=((r02)*(sj5));
IkReal x101=((rxp1_2)*(sj5));
IkReal x102=((cj5)*(rxp2_2));
IkReal x103=((r00)*(sj5));
IkReal x104=((npx)*(sj5));
IkReal x105=((r10)*(sj5));
IkReal x106=((IkReal(2.00000000000000))*(pp));
IkReal x107=((rxp0_2)*(sj5));
IkReal x108=((IkReal(1.45768000000000))*(sj5));
IkReal x109=((cj5)*(r01));
IkReal x110=((IkReal(1.00000000000000))*(pp));
IkReal x111=((cj5)*(npz));
IkReal x112=((IkReal(4.00000000000000))*(px));
IkReal x113=((r01)*(sj5));
IkReal x114=((cj5)*(r10));
IkReal x115=((npy)*(sj5));
IkReal x116=((IkReal(2.00000000000000))*(py));
IkReal x117=((cj5)*(r11));
IkReal x118=((IkReal(0.0516520200000000))*(x97));
IkReal x119=((IkReal(0.0200000000000000))*(cj5)*(npy));
IkReal x120=((IkReal(0.00138000000000000))*(x100));
IkReal x121=((IkReal(0.0516520200000000))*(x113));
IkReal x122=((IkReal(0.748580000000000))*(x111));
IkReal x123=((IkReal(0.00138000000000000))*(x109));
IkReal x124=((IkReal(0.748580000000000))*(x115));
IkReal x125=((IkReal(0.0200000000000000))*(npz)*(sj5));
IkReal x126=((IkReal(0.0526208923000000))*(x98));
IkReal x127=((IkReal(0.0526208923000000))*(x96));
IkReal x128=((IkReal(0.00748580000000000))*(x117));
IkReal x129=((IkReal(0.866840000000000))*(x102));
IkReal x130=((pp)*(x96));
IkReal x131=((IkReal(0.866840000000000))*(x101));
IkReal x132=((IkReal(0.00748580000000000))*(x99));
IkReal x133=((IkReal(0.728840000000000))*(cj5)*(rxp2_0));
IkReal x134=((IkReal(0.728840000000000))*(rxp1_0)*(sj5));
IkReal x135=((IkReal(0.0149716000000000))*(x114));
IkReal x136=((pp)*(x98));
IkReal x137=((IkReal(0.0479590277000000))*(x98));
IkReal x138=((IkReal(0.0479590277000000))*(x96));
IkReal x139=((IkReal(0.590840000000000))*(x102));
IkReal x140=((IkReal(0.590840000000000))*(x101));
IkReal x141=((IkReal(0.103304040000000))*(x96));
IkReal x142=((IkReal(0.103304040000000))*(x98));
IkReal x143=((IkReal(0.00276000000000000))*(x99));
IkReal x144=((IkReal(0.00276000000000000))*(x117));
IkReal x145=((IkReal(0.0149716000000000))*(x100));
IkReal x146=((IkReal(0.105241784600000))*(x97));
IkReal x147=((IkReal(0.105241784600000))*(x113));
IkReal x148=((IkReal(0.0149716000000000))*(x109));
IkReal x149=((IkReal(1.45768000000000))*(cj5)*(rxp2_1));
IkReal x150=((rxp1_1)*(x108));
IkReal x151=((IkReal(0.0299432000000000))*(x94));
IkReal x152=((IkReal(0.0959180554000000))*(x97));
IkReal x153=((r01)*(x95));
IkReal x154=((IkReal(0.103304040000000))*(x103));
IkReal x155=((IkReal(1.49716000000000))*(x104));
IkReal x156=((IkReal(0.0400000000000000))*(cj5)*(npx));
IkReal x157=((IkReal(0.00276000000000000))*(x94));
IkReal x158=((IkReal(0.105241784600000))*(x105));
IkReal x159=((IkReal(1.73368000000000))*(x107));
IkReal x160=((IkReal(1.18168000000000))*(x107));
IkReal x161=((r10)*(x95));
IkReal x162=((x115)*(x116));
IkReal x163=((x111)*(x116));
IkReal x164=((x110)*(x98));
IkReal x165=((IkReal(4.00000000000000))*(py)*(x104));
IkReal x166=((x105)*(x106));
IkReal x167=((x112)*(x115));
IkReal x168=((x111)*(x112));
IkReal x169=((x106)*(x113));
IkReal x170=((x106)*(x97));
IkReal x171=((IkReal(4.00000000000000))*(pp)*(x103));
IkReal x172=((IkReal(8.00000000000000))*(px)*(x104));
IkReal x173=((x110)*(x96));
IkReal x174=((((IkReal(-1.00000000000000))*(rxp0_0)*(x108)))+(((IkReal(-0.0145768000000000))*(r01))));
IkReal x175=((((IkReal(0.00552000000000000))*(x114)))+(((IkReal(-0.206608080000000))*(x105))));
IkReal x176=((((IkReal(-0.0291536000000000))*(r11)))+(((IkReal(-2.91536000000000))*(rxp0_1)*(sj5))));
IkReal x177=((x133)+(x84));
IkReal x178=((((IkReal(0.0145768000000000))*(r01)))+(((rxp0_0)*(x108))));
IkReal x179=((x129)+(x83));
IkReal x180=((x130)+(x81));
IkReal x181=((x159)+(x92));
IkReal x182=((IkReal(0.00739106770000000))+(x123)+(pp));
IkReal x183=((x119)+(x80));
IkReal x184=((x124)+(x80));
IkReal x185=((IkReal(0.00739106770000000))+(x121)+(pp));
IkReal x186=((x160)+(x93));
IkReal x187=((x134)+(x133));
IkReal x188=((x173)+(x81));
IkReal x189=((x139)+(x140));
IkReal x190=((x170)+(x88));
IkReal x191=((x126)+(x131));
IkReal x192=((x125)+(x122));
IkReal x193=((x172)+(x91));
IkReal x194=((x165)+(x85));
IkReal x195=((x141)+(x143));
IkReal x196=((x177)+(((IkReal(-1.00000000000000))*(x134))));
IkReal x197=((x187)+(((IkReal(-1.00000000000000))*(x84))));
IkReal x198=((((IkReal(-1.00000000000000))*(x150)))+(x149)+(x90));
IkReal x199=((x150)+(((IkReal(-1.00000000000000))*(x90)))+(x149));
IkReal x200=((((IkReal(-1.00000000000000))*(x177)))+(x134));
IkReal x201=((((IkReal(-1.00000000000000))*(x187)))+(x84));
IkReal x202=((x163)+(x132));
IkReal x203=((x127)+(x162));
IkReal x204=((x153)+(x167));
IkReal x205=((x168)+(x145));
IkReal x206=((x171)+(x151));
IkReal x207=((x166)+(x135));
IkReal x208=((x162)+(x137));
IkReal x209=((x128)+(x136)+(x82));
IkReal x210=((x128)+(x164)+(x82));
IkReal x211=((x169)+(x148)+(x89));
IkReal x212=((x124)+(x120)+(x118));
IkReal x213=((x208)+(x86));
IkReal x214=((x194)+(x161));
IkReal x215=((x120)+(x119)+(x118));
IkReal x216=((x158)+(x207));
IkReal x217=((x152)+(x205));
IkReal x218=((((IkReal(-1.00000000000000))*(x154)))+(x157)+(x155)+(((IkReal(-1.00000000000000))*(x156))));
IkReal x219=((x155)+(x154)+(((IkReal(-1.00000000000000))*(x157)))+(((IkReal(-1.00000000000000))*(x156))));
IkReal x220=((((IkReal(-1.00000000000000))*(x142)))+(x195)+(x144)+(((IkReal(-1.00000000000000))*(x87))));
IkReal x221=((x195)+(x142)+(((IkReal(-1.00000000000000))*(x144)))+(((IkReal(-1.00000000000000))*(x87))));
IkReal x222=((((IkReal(-1.00000000000000))*(x192)))+(((IkReal(-1.00000000000000))*(x183)))+(x212)+(x182)+(((IkReal(-1.00000000000000))*(x121))));
IkReal x223=((((IkReal(-1.00000000000000))*(x192)))+(x215)+(x185)+(((IkReal(-1.00000000000000))*(x184)))+(((IkReal(-1.00000000000000))*(x123))));
IkReal x224=((((IkReal(-1.00000000000000))*(x192)))+(((IkReal(-1.00000000000000))*(x215)))+(x184)+(x185)+(((IkReal(-1.00000000000000))*(x123))));
IkReal x225=((((IkReal(-1.00000000000000))*(x192)))+(((IkReal(-1.00000000000000))*(x212)))+(x182)+(x183)+(((IkReal(-1.00000000000000))*(x121))));
op[0]=x222;
op[1]=IkReal(0);
op[2]=x218;
op[3]=IkReal(0);
op[4]=x223;
op[5]=IkReal(0);
op[6]=IkReal(0);
op[7]=x222;
op[8]=IkReal(0);
op[9]=x218;
op[10]=IkReal(0);
op[11]=x223;
op[12]=((((IkReal(-1.00000000000000))*(x210)))+(x179)+(((IkReal(-1.00000000000000))*(x191)))+(((IkReal(-1.00000000000000))*(x202)))+(x180)+(x203));
op[13]=x196;
op[14]=((x194)+(((IkReal(-1.00000000000000))*(x181)))+(((IkReal(-1.00000000000000))*(x216))));
op[15]=x174;
op[16]=((((IkReal(-1.00000000000000))*(x202)))+(x191)+(x180)+(x127)+(x129)+(x209)+(((IkReal(-1.00000000000000))*(x83)))+(((IkReal(-1.00000000000000))*(x162))));
op[17]=x197;
op[18]=x196;
op[19]=((((IkReal(-1.00000000000000))*(x86)))+(((IkReal(-1.00000000000000))*(x210)))+(((IkReal(-1.00000000000000))*(x202)))+(((IkReal(-1.00000000000000))*(x139)))+(((IkReal(-1.00000000000000))*(x138)))+(x180)+(x208)+(x140));
op[20]=x174;
op[21]=((x214)+(x186)+(((IkReal(-1.00000000000000))*(x207))));
op[22]=x197;
op[23]=((((IkReal(-1.00000000000000))*(x189)))+(((IkReal(-1.00000000000000))*(x202)))+(((IkReal(-1.00000000000000))*(x138)))+(x180)+(x209)+(x86)+(((IkReal(-1.00000000000000))*(x208))));
op[24]=x220;
op[25]=IkReal(0);
op[26]=x175;
op[27]=IkReal(0);
op[28]=x221;
op[29]=IkReal(0);
op[30]=IkReal(0);
op[31]=x220;
op[32]=IkReal(0);
op[33]=x175;
op[34]=IkReal(0);
op[35]=x221;
op[36]=((((IkReal(-1.00000000000000))*(x167)))+(x211)+(((IkReal(-1.00000000000000))*(x146)))+(x205)+(((IkReal(-1.00000000000000))*(x190)))+(x147));
op[37]=x198;
op[38]=((((IkReal(-1.00000000000000))*(x193)))+(x206)+(((IkReal(0.210483569200000))*(x103))));
op[39]=x176;
op[40]=((((IkReal(-1.00000000000000))*(x146)))+(x167)+(x205)+(((IkReal(-1.00000000000000))*(x147)))+(((IkReal(-1.00000000000000))*(x190)))+(((IkReal(-1.00000000000000))*(x211))));
op[41]=x199;
op[42]=x198;
op[43]=((((IkReal(-1.00000000000000))*(x204)))+(x211)+(x217)+(((IkReal(-1.00000000000000))*(x190))));
op[44]=x176;
op[45]=((((IkReal(-1.00000000000000))*(x193)))+(x206)+(((IkReal(-0.191836110800000))*(x103))));
op[46]=x199;
op[47]=((x217)+(x204)+(((IkReal(-1.00000000000000))*(x190)))+(((IkReal(-1.00000000000000))*(x211))));
op[48]=x224;
op[49]=IkReal(0);
op[50]=x219;
op[51]=IkReal(0);
op[52]=x225;
op[53]=IkReal(0);
op[54]=IkReal(0);
op[55]=x224;
op[56]=IkReal(0);
op[57]=x219;
op[58]=IkReal(0);
op[59]=x225;
op[60]=((x179)+(((IkReal(-1.00000000000000))*(x188)))+(((IkReal(-1.00000000000000))*(x203)))+(((IkReal(-1.00000000000000))*(x131)))+(x126)+(x202)+(x209));
op[61]=x200;
op[62]=((x216)+(((IkReal(-1.00000000000000))*(x181)))+(((IkReal(-1.00000000000000))*(x194))));
op[63]=x178;
op[64]=((((IkReal(-1.00000000000000))*(x210)))+(((IkReal(-1.00000000000000))*(x188)))+(((IkReal(-1.00000000000000))*(x126)))+(((IkReal(-1.00000000000000))*(x127)))+(x129)+(x162)+(x202)+(((IkReal(-1.00000000000000))*(x83)))+(x131));
op[65]=x201;
op[66]=x200;
op[67]=((((IkReal(-1.00000000000000))*(x188)))+(((IkReal(-1.00000000000000))*(x139)))+(((IkReal(-1.00000000000000))*(x213)))+(x202)+(x209)+(x138)+(x140));
op[68]=x178;
op[69]=((((IkReal(-1.00000000000000))*(x214)))+(x186)+(x207));
op[70]=x201;
op[71]=((((IkReal(-1.00000000000000))*(x210)))+(((IkReal(-1.00000000000000))*(x188)))+(((IkReal(-1.00000000000000))*(x189)))+(x213)+(x202)+(x138));
solvedialyticpoly8qep(op,zeror,numroots);
IkReal j0array[16], cj0array[16], sj0array[16], j6array[16], cj6array[16], sj6array[16], j1array[16], cj1array[16], sj1array[16];
int numsolutions = 0;
for(int ij0 = 0; ij0 < numroots; ij0 += 3)
{
IkReal htj0 = zeror[ij0+0], htj6 = zeror[ij0+1], htj1 = zeror[ij0+2];
j0array[numsolutions]=((IkReal(2.00000000000000))*(atan(htj0)));
j6array[numsolutions]=((IkReal(2.00000000000000))*(atan(htj6)));
j1array[numsolutions]=((IkReal(2.00000000000000))*(atan(htj1)));
IkReal x226=(htj0)*(htj0);
IkReal x227=(htj6)*(htj6);
IkReal x228=(htj1)*(htj1);
cj0array[numsolutions]=((((IKabs(((IkReal(1.00000000000000))+(x226))) != 0)?((IkReal)1/(((IkReal(1.00000000000000))+(x226)))):(IkReal)1.0e30))*(((IkReal(1.00000000000000))+(((IkReal(-1.00000000000000))*(x226))))));
cj6array[numsolutions]=((((IKabs(((IkReal(1.00000000000000))+(x227))) != 0)?((IkReal)1/(((IkReal(1.00000000000000))+(x227)))):(IkReal)1.0e30))*(((IkReal(1.00000000000000))+(((IkReal(-1.00000000000000))*(x227))))));
cj1array[numsolutions]=((((IKabs(((IkReal(1.00000000000000))+(x228))) != 0)?((IkReal)1/(((IkReal(1.00000000000000))+(x228)))):(IkReal)1.0e30))*(((IkReal(1.00000000000000))+(((IkReal(-1.00000000000000))*(x228))))));
sj0array[numsolutions]=((IkReal(2.00000000000000))*(htj0)*(((IKabs(((IkReal(1.00000000000000))+((htj0)*(htj0)))) != 0)?((IkReal)1/(((IkReal(1.00000000000000))+((htj0)*(htj0))))):(IkReal)1.0e30)));
sj6array[numsolutions]=((IkReal(2.00000000000000))*(htj6)*(((IKabs(((IkReal(1.00000000000000))+((htj6)*(htj6)))) != 0)?((IkReal)1/(((IkReal(1.00000000000000))+((htj6)*(htj6))))):(IkReal)1.0e30)));
sj1array[numsolutions]=((IkReal(2.00000000000000))*(htj1)*(((IKabs(((IkReal(1.00000000000000))+((htj1)*(htj1)))) != 0)?((IkReal)1/(((IkReal(1.00000000000000))+((htj1)*(htj1))))):(IkReal)1.0e30)));
if( j0array[numsolutions] > IKPI )
{
    j0array[numsolutions]-=IK2PI;
}
else if( j0array[numsolutions] < -IKPI )
{
    j0array[numsolutions]+=IK2PI;
}
if( j6array[numsolutions] > IKPI )
{
    j6array[numsolutions]-=IK2PI;
}
else if( j6array[numsolutions] < -IKPI )
{
    j6array[numsolutions]+=IK2PI;
}
if( j1array[numsolutions] > IKPI )
{
    j1array[numsolutions]-=IK2PI;
}
else if( j1array[numsolutions] < -IKPI )
{
    j1array[numsolutions]+=IK2PI;
}
numsolutions++;
}
bool j0valid[16]={true,true,true,true,true,true,true,true,true,true,true,true,true,true,true,true};
_nj0 = 16;
_nj6 = 1;
_nj1 = 1;
for(int ij0 = 0; ij0 < numsolutions; ++ij0)
    {
if( !j0valid[ij0] )
{
    continue;
}
_ij0[0] = ij0; _ij0[1] = -1;
_ij6[0] = 0; _ij6[1] = -1;
_ij1[0] = 0; _ij1[1] = -1;
for(int iij0 = ij0+1; iij0 < numsolutions; ++iij0)
{
if( !j0valid[iij0] ) { continue; }
if( IKabs(cj0array[ij0]-cj0array[iij0]) < IKFAST_SOLUTION_THRESH && IKabs(sj0array[ij0]-sj0array[iij0]) < IKFAST_SOLUTION_THRESH && IKabs(cj6array[ij0]-cj6array[iij0]) < IKFAST_SOLUTION_THRESH && IKabs(sj6array[ij0]-sj6array[iij0]) < IKFAST_SOLUTION_THRESH && IKabs(cj1array[ij0]-cj1array[iij0]) < IKFAST_SOLUTION_THRESH && IKabs(sj1array[ij0]-sj1array[iij0]) < IKFAST_SOLUTION_THRESH &&  1 )
{
    j0valid[iij0]=false; _ij0[1] = iij0; _ij6[1] = 0; _ij1[1] = 0;  break; 
}
}
    j0 = j0array[ij0]; cj0 = cj0array[ij0]; sj0 = sj0array[ij0];

    j6 = j6array[ij0]; cj6 = cj6array[ij0]; sj6 = sj6array[ij0];

    j1 = j1array[ij0]; cj1 = cj1array[ij0]; sj1 = sj1array[ij0];

{
IkReal dummyeval[1];
dummyeval[0]=cj1;
if( IKabs(dummyeval[0]) < 0.0000010000000000  )
{
{
IkReal dummyeval[1];
dummyeval[0]=sj1;
if( IKabs(dummyeval[0]) < 0.0000010000000000  )
{
{
IkReal evalcond[2];
IkReal x229=((cj0)*(cj5));
IkReal x230=((IkReal(0.374290000000000))*(sj0));
IkReal x231=((cj6)*(r11));
IkReal x232=((IkReal(0.0100000000000000))*(sj6));
IkReal x233=((cj6)*(r01));
IkReal x234=((IkReal(0.0100000000000000))*(sj0));
IkReal x235=((cj0)*(sj5));
evalcond[0]=((IkReal(-3.14159265358979))+(IKfmod(((IkReal(3.14159265358979))+(j1)), IkReal(6.28318530717959))));
evalcond[1]=((IkReal(0.433420000000000))+(((cj5)*(r10)*(sj0)*(x232)))+(((IkReal(-1.00000000000000))*(r10)*(sj5)*(sj6)*(x230)))+(((IkReal(-1.00000000000000))*(cj0)*(px)))+(((IkReal(-0.374290000000000))*(r00)*(sj6)*(x235)))+(((IkReal(-1.00000000000000))*(sj5)*(x230)*(x231)))+(((IkReal(0.0100000000000000))*(r02)*(x235)))+(((IkReal(-0.374290000000000))*(x233)*(x235)))+(((r12)*(sj5)*(x234)))+(((r00)*(x229)*(x232)))+(((IkReal(0.0100000000000000))*(x229)*(x233)))+(((cj5)*(x231)*(x234)))+(((cj5)*(r12)*(x230)))+(((IkReal(-1.00000000000000))*(py)*(sj0)))+(((IkReal(0.374290000000000))*(r02)*(x229))));
if( IKabs(evalcond[0]) < 0.0000010000000000  && IKabs(evalcond[1]) < 0.0000010000000000  )
{
{
IkReal j2array[1], cj2array[1], sj2array[1];
bool j2valid[1]={false};
_nj2 = 1;
IkReal x236=((cj0)*(r11));
IkReal x237=((r01)*(sj0));
IkReal x238=((cj0)*(r10));
IkReal x239=((IkReal(0.144927536231884))*(sj5));
IkReal x240=((IkReal(5.42449275362319))*(cj5));
IkReal x241=((r00)*(sj0));
IkReal x242=((cj0)*(r12));
IkReal x243=((r02)*(sj0));
IkReal x244=((IkReal(5.42449275362319))*(cj6)*(sj5));
IkReal x245=((IkReal(5.42449275362319))*(sj5)*(sj6));
IkReal x246=((IkReal(0.144927536231884))*(cj5)*(sj6));
IkReal x247=((IkReal(0.144927536231884))*(cj5)*(cj6));
if( IKabs(((((IkReal(-1.00000000000000))*(x238)*(x246)))+(((x241)*(x246)))+(((x240)*(x243)))+(((IkReal(-1.00000000000000))*(x236)*(x247)))+(((IkReal(14.4927536231884))*(cj0)*(py)))+(((IkReal(-14.4927536231884))*(px)*(sj0)))+(((IkReal(-1.00000000000000))*(x239)*(x242)))+(((x236)*(x244)))+(((x238)*(x245)))+(((IkReal(-1.00000000000000))*(x241)*(x245)))+(((IkReal(-1.00000000000000))*(x240)*(x242)))+(((IkReal(-1.00000000000000))*(x237)*(x244)))+(((x239)*(x243)))+(((x237)*(x247))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(((((r22)*(x240)))+(((IkReal(-14.4927536231884))*(pz)))+(((IkReal(-1.00000000000000))*(r20)*(x245)))+(((r22)*(x239)))+(((r21)*(x247)))+(((IkReal(-1.00000000000000))*(r21)*(x244)))+(((r20)*(x246))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(IKsqr(((((IkReal(-1.00000000000000))*(x238)*(x246)))+(((x241)*(x246)))+(((x240)*(x243)))+(((IkReal(-1.00000000000000))*(x236)*(x247)))+(((IkReal(14.4927536231884))*(cj0)*(py)))+(((IkReal(-14.4927536231884))*(px)*(sj0)))+(((IkReal(-1.00000000000000))*(x239)*(x242)))+(((x236)*(x244)))+(((x238)*(x245)))+(((IkReal(-1.00000000000000))*(x241)*(x245)))+(((IkReal(-1.00000000000000))*(x240)*(x242)))+(((IkReal(-1.00000000000000))*(x237)*(x244)))+(((x239)*(x243)))+(((x237)*(x247)))))+IKsqr(((((r22)*(x240)))+(((IkReal(-14.4927536231884))*(pz)))+(((IkReal(-1.00000000000000))*(r20)*(x245)))+(((r22)*(x239)))+(((r21)*(x247)))+(((IkReal(-1.00000000000000))*(r21)*(x244)))+(((r20)*(x246)))))-1) <= IKFAST_SINCOS_THRESH )
    continue;
j2array[0]=IKatan2(((((IkReal(-1.00000000000000))*(x238)*(x246)))+(((x241)*(x246)))+(((x240)*(x243)))+(((IkReal(-1.00000000000000))*(x236)*(x247)))+(((IkReal(14.4927536231884))*(cj0)*(py)))+(((IkReal(-14.4927536231884))*(px)*(sj0)))+(((IkReal(-1.00000000000000))*(x239)*(x242)))+(((x236)*(x244)))+(((x238)*(x245)))+(((IkReal(-1.00000000000000))*(x241)*(x245)))+(((IkReal(-1.00000000000000))*(x240)*(x242)))+(((IkReal(-1.00000000000000))*(x237)*(x244)))+(((x239)*(x243)))+(((x237)*(x247)))), ((((r22)*(x240)))+(((IkReal(-14.4927536231884))*(pz)))+(((IkReal(-1.00000000000000))*(r20)*(x245)))+(((r22)*(x239)))+(((r21)*(x247)))+(((IkReal(-1.00000000000000))*(r21)*(x244)))+(((r20)*(x246)))));
sj2array[0]=IKsin(j2array[0]);
cj2array[0]=IKcos(j2array[0]);
if( j2array[0] > IKPI )
{
    j2array[0]-=IK2PI;
}
else if( j2array[0] < -IKPI )
{    j2array[0]+=IK2PI;
}
j2valid[0] = true;
for(int ij2 = 0; ij2 < 1; ++ij2)
{
if( !j2valid[ij2] )
{
    continue;
}
_ij2[0] = ij2; _ij2[1] = -1;
for(int iij2 = ij2+1; iij2 < 1; ++iij2)
{
if( j2valid[iij2] && IKabs(cj2array[ij2]-cj2array[iij2]) < IKFAST_SOLUTION_THRESH && IKabs(sj2array[ij2]-sj2array[iij2]) < IKFAST_SOLUTION_THRESH )
{
    j2valid[iij2]=false; _ij2[1] = iij2; break; 
}
}
j2 = j2array[ij2]; cj2 = cj2array[ij2]; sj2 = sj2array[ij2];
{
IkReal evalcond[2];
IkReal x248=((cj6)*(r11));
IkReal x249=((IkReal(0.374290000000000))*(sj0));
IkReal x250=((IkReal(0.0100000000000000))*(cj5));
IkReal x251=((cj6)*(r21));
IkReal x252=((r10)*(sj6));
IkReal x253=((IkReal(0.374290000000000))*(sj5));
IkReal x254=((IkReal(0.0100000000000000))*(sj5));
IkReal x255=((cj6)*(r01));
IkReal x256=((r20)*(sj6));
IkReal x257=((IkReal(0.374290000000000))*(cj5));
IkReal x258=((cj0)*(r12));
IkReal x259=((r00)*(sj6));
IkReal x260=((cj0)*(x253));
evalcond[0]=((((IkReal(-1.00000000000000))*(r22)*(x254)))+(((x253)*(x256)))+(((IkReal(0.0690000000000000))*(IKcos(j2))))+(((IkReal(-1.00000000000000))*(x250)*(x256)))+(((IkReal(-1.00000000000000))*(x250)*(x251)))+(pz)+(((x251)*(x253)))+(((IkReal(-1.00000000000000))*(r22)*(x257))));
evalcond[1]=((((IkReal(-1.00000000000000))*(r02)*(sj0)*(x254)))+(((IkReal(-1.00000000000000))*(sj0)*(x250)*(x255)))+(((IkReal(-1.00000000000000))*(sj0)*(x250)*(x259)))+(((IkReal(-1.00000000000000))*(cj0)*(py)))+(((IkReal(-1.00000000000000))*(x252)*(x260)))+(((cj0)*(x248)*(x250)))+(((sj5)*(x249)*(x259)))+(((IkReal(-1.00000000000000))*(x248)*(x260)))+(((IkReal(-1.00000000000000))*(cj5)*(r02)*(x249)))+(((x254)*(x258)))+(((IkReal(0.0690000000000000))*(IKsin(j2))))+(((sj5)*(x249)*(x255)))+(((cj0)*(x250)*(x252)))+(((x257)*(x258)))+(((px)*(sj0))));
if( IKabs(evalcond[0]) > 0.000001  || IKabs(evalcond[1]) > 0.000001  )
{
continue;
}
}

{
IkReal dummyeval[1];
IkReal gconst40;
IkReal x261=(sj6)*(sj6);
IkReal x262=(cj6)*(cj6);
IkReal x263=((r10)*(sj0));
IkReal x264=((r22)*(sj5));
IkReal x265=((cj0)*(cj5));
IkReal x266=((IkReal(1.00000000000000))*(r20));
IkReal x267=((cj0)*(sj6));
IkReal x268=((r21)*(sj5));
IkReal x269=((sj0)*(sj6));
IkReal x270=((cj6)*(sj5));
IkReal x271=((r21)*(x262));
IkReal x272=((cj5)*(r11)*(sj0));
IkReal x273=((r21)*(x261));
gconst40=IKsign(((((IkReal(-1.00000000000000))*(cj0)*(r02)*(x266)*(x270)))+(((cj5)*(x263)*(x271)))+(((cj6)*(x263)*(x264)))+(((IkReal(-1.00000000000000))*(r01)*(x264)*(x267)))+(((cj0)*(cj6)*(r00)*(x264)))+(((IkReal(-1.00000000000000))*(r01)*(x262)*(x265)*(x266)))+(((IkReal(-1.00000000000000))*(r12)*(sj0)*(x266)*(x270)))+(((IkReal(-1.00000000000000))*(x261)*(x266)*(x272)))+(((IkReal(-1.00000000000000))*(r11)*(x264)*(x269)))+(((cj5)*(x263)*(x273)))+(((r02)*(x267)*(x268)))+(((r00)*(x265)*(x271)))+(((r00)*(x265)*(x273)))+(((r12)*(x268)*(x269)))+(((IkReal(-1.00000000000000))*(x262)*(x266)*(x272)))+(((IkReal(-1.00000000000000))*(r01)*(x261)*(x265)*(x266)))));
IkReal x274=(sj6)*(sj6);
IkReal x275=(cj6)*(cj6);
IkReal x276=((r10)*(sj0));
IkReal x277=((r22)*(sj5));
IkReal x278=((cj0)*(cj5));
IkReal x279=((IkReal(1.00000000000000))*(r20));
IkReal x280=((cj0)*(sj6));
IkReal x281=((r21)*(sj5));
IkReal x282=((sj0)*(sj6));
IkReal x283=((cj6)*(sj5));
IkReal x284=((r21)*(x275));
IkReal x285=((cj5)*(r11)*(sj0));
IkReal x286=((r21)*(x274));
dummyeval[0]=((((cj5)*(x276)*(x284)))+(((IkReal(-1.00000000000000))*(r01)*(x275)*(x278)*(x279)))+(((r12)*(x281)*(x282)))+(((IkReal(-1.00000000000000))*(x275)*(x279)*(x285)))+(((cj0)*(cj6)*(r00)*(x277)))+(((IkReal(-1.00000000000000))*(r01)*(x274)*(x278)*(x279)))+(((cj5)*(x276)*(x286)))+(((r02)*(x280)*(x281)))+(((IkReal(-1.00000000000000))*(r11)*(x277)*(x282)))+(((IkReal(-1.00000000000000))*(x274)*(x279)*(x285)))+(((IkReal(-1.00000000000000))*(r01)*(x277)*(x280)))+(((cj6)*(x276)*(x277)))+(((IkReal(-1.00000000000000))*(r12)*(sj0)*(x279)*(x283)))+(((IkReal(-1.00000000000000))*(cj0)*(r02)*(x279)*(x283)))+(((r00)*(x278)*(x286)))+(((r00)*(x278)*(x284))));
if( IKabs(dummyeval[0]) < 0.0000010000000000  )
{
{
IkReal dummyeval[1];
IkReal gconst39;
IkReal x287=(cj6)*(cj6);
IkReal x288=(sj6)*(sj6);
IkReal x289=((IkReal(1.00000000000000))*(r01));
IkReal x290=((sj0)*(sj5));
IkReal x291=((cj6)*(r22));
IkReal x292=((r21)*(sj6));
IkReal x293=((r00)*(r21));
IkReal x294=((cj0)*(sj5));
IkReal x295=((cj6)*(r20));
IkReal x296=((r22)*(sj6));
IkReal x297=((cj0)*(cj5));
IkReal x298=((IkReal(1.00000000000000))*(r10));
IkReal x299=((cj5)*(sj0));
IkReal x300=((r20)*(x288));
IkReal x301=((x287)*(x299));
gconst39=IKsign(((((IkReal(-1.00000000000000))*(x289)*(x299)*(x300)))+(((IkReal(-1.00000000000000))*(x291)*(x294)*(x298)))+(((IkReal(-1.00000000000000))*(r02)*(x290)*(x295)))+(((r11)*(x297)*(x300)))+(((r12)*(x294)*(x295)))+(((IkReal(-1.00000000000000))*(r21)*(x288)*(x297)*(x298)))+(((IkReal(-1.00000000000000))*(x289)*(x290)*(x296)))+(((x293)*(x301)))+(((r11)*(r20)*(x287)*(x297)))+(((IkReal(-1.00000000000000))*(r21)*(x287)*(x297)*(x298)))+(((r02)*(x290)*(x292)))+(((IkReal(-1.00000000000000))*(r20)*(x289)*(x301)))+(((x288)*(x293)*(x299)))+(((r11)*(x294)*(x296)))+(((IkReal(-1.00000000000000))*(r12)*(x292)*(x294)))+(((r00)*(x290)*(x291)))));
IkReal x302=(cj6)*(cj6);
IkReal x303=(sj6)*(sj6);
IkReal x304=((IkReal(1.00000000000000))*(r01));
IkReal x305=((sj0)*(sj5));
IkReal x306=((cj6)*(r22));
IkReal x307=((r21)*(sj6));
IkReal x308=((r00)*(r21));
IkReal x309=((cj0)*(sj5));
IkReal x310=((cj6)*(r20));
IkReal x311=((r22)*(sj6));
IkReal x312=((cj0)*(cj5));
IkReal x313=((IkReal(1.00000000000000))*(r10));
IkReal x314=((cj5)*(sj0));
IkReal x315=((r20)*(x303));
IkReal x316=((x302)*(x314));
dummyeval[0]=((((x303)*(x308)*(x314)))+(((x308)*(x316)))+(((IkReal(-1.00000000000000))*(x304)*(x314)*(x315)))+(((r00)*(x305)*(x306)))+(((IkReal(-1.00000000000000))*(x304)*(x305)*(x311)))+(((IkReal(-1.00000000000000))*(r21)*(x302)*(x312)*(x313)))+(((r11)*(x312)*(x315)))+(((IkReal(-1.00000000000000))*(r21)*(x303)*(x312)*(x313)))+(((r02)*(x305)*(x307)))+(((IkReal(-1.00000000000000))*(x306)*(x309)*(x313)))+(((IkReal(-1.00000000000000))*(r12)*(x307)*(x309)))+(((IkReal(-1.00000000000000))*(r02)*(x305)*(x310)))+(((r11)*(r20)*(x302)*(x312)))+(((r11)*(x309)*(x311)))+(((r12)*(x309)*(x310)))+(((IkReal(-1.00000000000000))*(r20)*(x304)*(x316))));
if( IKabs(dummyeval[0]) < 0.0000010000000000  )
{
{
IkReal dummyeval[1];
dummyeval[0]=cj2;
if( IKabs(dummyeval[0]) < 0.0000010000000000  )
{
{
IkReal evalcond[5];
IkReal x317=((cj5)*(r22));
IkReal x318=((IkReal(0.374290000000000))*(sj5));
IkReal x319=((cj0)*(sj6));
IkReal x320=((cj6)*(r21));
IkReal x321=((IkReal(0.0100000000000000))*(sj5));
IkReal x322=((cj0)*(r02));
IkReal x323=((IkReal(0.0100000000000000))*(cj5));
IkReal x324=((IkReal(1.00000000000000))*(py));
IkReal x325=((r01)*(sj0));
IkReal x326=((r20)*(sj6));
IkReal x327=((r11)*(sj0));
IkReal x328=((IkReal(0.374290000000000))*(cj5));
IkReal x329=((cj0)*(r12));
IkReal x330=((sj0)*(x328));
IkReal x331=((cj6)*(x323));
IkReal x332=((r10)*(sj0)*(sj6));
IkReal x333=((r00)*(sj0)*(sj6));
IkReal x334=((cj0)*(cj6)*(x318));
evalcond[0]=((IkReal(-3.14159265358979))+(IKfmod(((IkReal(1.57079632679490))+(j2)), IkReal(6.28318530717959))));
evalcond[1]=((((IkReal(-1.00000000000000))*(x317)))+(((sj5)*(x320)))+(((sj5)*(x326))));
evalcond[2]=((((IkReal(-1.00000000000000))*(x320)*(x323)))+(((x318)*(x326)))+(((IkReal(-1.00000000000000))*(r22)*(x321)))+(((IkReal(-0.374290000000000))*(x317)))+(((x318)*(x320)))+(pz)+(((IkReal(-1.00000000000000))*(x323)*(x326))));
evalcond[3]=((IkReal(0.0690000000000000))+(((IkReal(-1.00000000000000))*(r11)*(x334)))+(((IkReal(-1.00000000000000))*(x323)*(x333)))+(((r10)*(x319)*(x323)))+(((IkReal(-1.00000000000000))*(r02)*(x330)))+(((x328)*(x329)))+(((cj6)*(x318)*(x325)))+(((x321)*(x329)))+(((IkReal(-1.00000000000000))*(cj0)*(x324)))+(((IkReal(-1.00000000000000))*(r02)*(sj0)*(x321)))+(((x318)*(x333)))+(((cj0)*(r11)*(x331)))+(((IkReal(-1.00000000000000))*(x325)*(x331)))+(((IkReal(-1.00000000000000))*(r10)*(x318)*(x319)))+(((px)*(sj0))));
evalcond[4]=((IkReal(0.433420000000000))+(((r00)*(x319)*(x323)))+(((IkReal(-1.00000000000000))*(cj0)*(px)))+(((x323)*(x332)))+(((x322)*(x328)))+(((r12)*(sj0)*(x321)))+(((cj0)*(r01)*(x331)))+(((x321)*(x322)))+(((IkReal(-1.00000000000000))*(r01)*(x334)))+(((IkReal(-1.00000000000000))*(r00)*(x318)*(x319)))+(((IkReal(-1.00000000000000))*(sj0)*(x324)))+(((r12)*(x330)))+(((x327)*(x331)))+(((IkReal(-1.00000000000000))*(x318)*(x332)))+(((IkReal(-1.00000000000000))*(cj6)*(x318)*(x327))));
if( IKabs(evalcond[0]) < 0.0000010000000000  && IKabs(evalcond[1]) < 0.0000010000000000  && IKabs(evalcond[2]) < 0.0000010000000000  && IKabs(evalcond[3]) < 0.0000010000000000  && IKabs(evalcond[4]) < 0.0000010000000000  )
{
{
IkReal j3array[1], cj3array[1], sj3array[1];
bool j3valid[1]={false};
_nj3 = 1;
IkReal x335=((cj0)*(cj5));
IkReal x336=((IkReal(1.00000000000000))*(cj0));
IkReal x337=((cj6)*(r11));
IkReal x338=((r10)*(sj6));
IkReal x339=((cj5)*(sj0));
IkReal x340=((r00)*(sj5)*(sj6));
IkReal x341=((cj6)*(r01)*(sj5));
IkReal x342=((IkReal(1.00000000000000))*(sj0)*(sj5));
if( IKabs(((((IkReal(-1.00000000000000))*(sj5)*(x336)*(x338)))+(((IkReal(-1.00000000000000))*(r02)*(x339)))+(((r12)*(x335)))+(((sj0)*(x341)))+(((IkReal(-1.00000000000000))*(sj5)*(x336)*(x337)))+(((sj0)*(x340))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(((((r12)*(x339)))+(((r02)*(x335)))+(((IkReal(-1.00000000000000))*(x336)*(x340)))+(((IkReal(-1.00000000000000))*(x336)*(x341)))+(((IkReal(-1.00000000000000))*(x337)*(x342)))+(((IkReal(-1.00000000000000))*(x338)*(x342))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(IKsqr(((((IkReal(-1.00000000000000))*(sj5)*(x336)*(x338)))+(((IkReal(-1.00000000000000))*(r02)*(x339)))+(((r12)*(x335)))+(((sj0)*(x341)))+(((IkReal(-1.00000000000000))*(sj5)*(x336)*(x337)))+(((sj0)*(x340)))))+IKsqr(((((r12)*(x339)))+(((r02)*(x335)))+(((IkReal(-1.00000000000000))*(x336)*(x340)))+(((IkReal(-1.00000000000000))*(x336)*(x341)))+(((IkReal(-1.00000000000000))*(x337)*(x342)))+(((IkReal(-1.00000000000000))*(x338)*(x342)))))-1) <= IKFAST_SINCOS_THRESH )
    continue;
j3array[0]=IKatan2(((((IkReal(-1.00000000000000))*(sj5)*(x336)*(x338)))+(((IkReal(-1.00000000000000))*(r02)*(x339)))+(((r12)*(x335)))+(((sj0)*(x341)))+(((IkReal(-1.00000000000000))*(sj5)*(x336)*(x337)))+(((sj0)*(x340)))), ((((r12)*(x339)))+(((r02)*(x335)))+(((IkReal(-1.00000000000000))*(x336)*(x340)))+(((IkReal(-1.00000000000000))*(x336)*(x341)))+(((IkReal(-1.00000000000000))*(x337)*(x342)))+(((IkReal(-1.00000000000000))*(x338)*(x342)))));
sj3array[0]=IKsin(j3array[0]);
cj3array[0]=IKcos(j3array[0]);
if( j3array[0] > IKPI )
{
    j3array[0]-=IK2PI;
}
else if( j3array[0] < -IKPI )
{    j3array[0]+=IK2PI;
}
j3valid[0] = true;
for(int ij3 = 0; ij3 < 1; ++ij3)
{
if( !j3valid[ij3] )
{
    continue;
}
_ij3[0] = ij3; _ij3[1] = -1;
for(int iij3 = ij3+1; iij3 < 1; ++iij3)
{
if( j3valid[iij3] && IKabs(cj3array[ij3]-cj3array[iij3]) < IKFAST_SOLUTION_THRESH && IKabs(sj3array[ij3]-sj3array[iij3]) < IKFAST_SOLUTION_THRESH )
{
    j3valid[iij3]=false; _ij3[1] = iij3; break; 
}
}
j3 = j3array[ij3]; cj3 = cj3array[ij3]; sj3 = sj3array[ij3];
{
IkReal evalcond[2];
IkReal x343=((cj0)*(cj5));
IkReal x344=((IkReal(1.00000000000000))*(cj0));
IkReal x345=((cj6)*(r11));
IkReal x346=((r10)*(sj6));
IkReal x347=((cj5)*(sj0));
IkReal x348=((r00)*(sj5)*(sj6));
IkReal x349=((cj6)*(r01)*(sj5));
IkReal x350=((IkReal(1.00000000000000))*(sj0)*(sj5));
evalcond[0]=((((IkReal(-1.00000000000000))*(sj5)*(x344)*(x346)))+(((IkReal(-1.00000000000000))*(r02)*(x347)))+(((r12)*(x343)))+(((sj0)*(x348)))+(((sj0)*(x349)))+(((IkReal(-1.00000000000000))*(IKsin(j3))))+(((IkReal(-1.00000000000000))*(sj5)*(x344)*(x345))));
evalcond[1]=((((r12)*(x347)))+(((IkReal(-1.00000000000000))*(IKcos(j3))))+(((IkReal(-1.00000000000000))*(x344)*(x348)))+(((IkReal(-1.00000000000000))*(x346)*(x350)))+(((IkReal(-1.00000000000000))*(x344)*(x349)))+(((IkReal(-1.00000000000000))*(x345)*(x350)))+(((r02)*(x343))));
if( IKabs(evalcond[0]) > 0.000001  || IKabs(evalcond[1]) > 0.000001  )
{
continue;
}
}

{
IkReal dummyeval[1];
IkReal gconst46;
IkReal x351=(cj5)*(cj5);
IkReal x352=(r20)*(r20);
IkReal x353=(sj6)*(sj6);
IkReal x354=(cj6)*(cj6);
IkReal x355=(r21)*(r21);
IkReal x356=((cj6)*(r21));
IkReal x357=((IkReal(2.00000000000000))*(r20)*(sj6));
IkReal x358=((cj5)*(r22)*(sj5));
gconst46=IKsign((((((r22)*(r22))*((sj5)*(sj5))))+(((x353)*(x355)))+(((IkReal(2.00000000000000))*(x356)*(x358)))+(((x357)*(x358)))+(((IkReal(-1.00000000000000))*(x356)*(x357)))+(((x351)*(x356)*(x357)))+(((x351)*(x352)*(x353)))+(((x351)*(x354)*(x355)))+(((x352)*(x354)))));
IkReal x359=(cj5)*(cj5);
IkReal x360=(r20)*(r20);
IkReal x361=(sj6)*(sj6);
IkReal x362=(cj6)*(cj6);
IkReal x363=(r21)*(r21);
IkReal x364=((cj6)*(r21));
IkReal x365=((IkReal(2.00000000000000))*(r20)*(sj6));
IkReal x366=((cj5)*(r22)*(sj5));
dummyeval[0]=((((x359)*(x364)*(x365)))+(((x365)*(x366)))+((((r22)*(r22))*((sj5)*(sj5))))+(((IkReal(-1.00000000000000))*(x364)*(x365)))+(((x359)*(x360)*(x361)))+(((x360)*(x362)))+(((x359)*(x362)*(x363)))+(((IkReal(2.00000000000000))*(x364)*(x366)))+(((x361)*(x363))));
if( IKabs(dummyeval[0]) < 0.0000010000000000  )
{
{
IkReal dummyeval[1];
IkReal gconst47;
IkReal x367=(cj6)*(cj6);
IkReal x368=(sj6)*(sj6);
IkReal x369=((IkReal(1.00000000000000))*(r21));
IkReal x370=((cj6)*(r20));
IkReal x371=((r22)*(sj5));
IkReal x372=((r01)*(sj0));
IkReal x373=((r00)*(sj0));
IkReal x374=((cj0)*(r10));
IkReal x375=((r02)*(sj0)*(sj5));
IkReal x376=((cj5)*(x367));
IkReal x377=((cj0)*(r12)*(sj5));
IkReal x378=((IkReal(1.00000000000000))*(cj0)*(r11));
IkReal x379=((cj5)*(x368));
IkReal x380=((r20)*(x379));
gconst47=IKsign(((((IkReal(-1.00000000000000))*(cj6)*(x371)*(x373)))+(((IkReal(-1.00000000000000))*(sj6)*(x369)*(x375)))+(((sj6)*(x371)*(x372)))+(((r21)*(x374)*(x376)))+(((IkReal(-1.00000000000000))*(r20)*(x376)*(x378)))+(((IkReal(-1.00000000000000))*(sj6)*(x371)*(x378)))+(((IkReal(-1.00000000000000))*(x369)*(x373)*(x376)))+(((IkReal(-1.00000000000000))*(x378)*(x380)))+(((r21)*(x374)*(x379)))+(((r21)*(sj6)*(x377)))+(((IkReal(-1.00000000000000))*(x369)*(x373)*(x379)))+(((IkReal(-1.00000000000000))*(x370)*(x377)))+(((cj6)*(x371)*(x374)))+(((r20)*(x372)*(x376)))+(((x372)*(x380)))+(((x370)*(x375)))));
IkReal x381=(cj6)*(cj6);
IkReal x382=(sj6)*(sj6);
IkReal x383=((IkReal(1.00000000000000))*(r21));
IkReal x384=((cj6)*(r20));
IkReal x385=((r22)*(sj5));
IkReal x386=((r01)*(sj0));
IkReal x387=((r00)*(sj0));
IkReal x388=((cj0)*(r10));
IkReal x389=((r02)*(sj0)*(sj5));
IkReal x390=((cj5)*(x381));
IkReal x391=((cj0)*(r12)*(sj5));
IkReal x392=((IkReal(1.00000000000000))*(cj0)*(r11));
IkReal x393=((cj5)*(x382));
IkReal x394=((r20)*(x393));
dummyeval[0]=((((IkReal(-1.00000000000000))*(x383)*(x387)*(x390)))+(((x384)*(x389)))+(((r20)*(x386)*(x390)))+(((IkReal(-1.00000000000000))*(r20)*(x390)*(x392)))+(((x386)*(x394)))+(((IkReal(-1.00000000000000))*(cj6)*(x385)*(x387)))+(((IkReal(-1.00000000000000))*(x383)*(x387)*(x393)))+(((IkReal(-1.00000000000000))*(sj6)*(x383)*(x389)))+(((sj6)*(x385)*(x386)))+(((IkReal(-1.00000000000000))*(sj6)*(x385)*(x392)))+(((IkReal(-1.00000000000000))*(x392)*(x394)))+(((IkReal(-1.00000000000000))*(x384)*(x391)))+(((r21)*(x388)*(x393)))+(((r21)*(sj6)*(x391)))+(((r21)*(x388)*(x390)))+(((cj6)*(x385)*(x388))));
if( IKabs(dummyeval[0]) < 0.0000010000000000  )
{
continue;

} else
{
{
IkReal j4array[1], cj4array[1], sj4array[1];
bool j4valid[1]={false};
_nj4 = 1;
IkReal x395=((sj0)*(sj6));
IkReal x396=((cj0)*(r10));
IkReal x397=((IkReal(1.00000000000000))*(cj5));
IkReal x398=((cj6)*(sj0));
IkReal x399=((cj0)*(r11));
if( IKabs(((gconst47)*(((((IkReal(-1.00000000000000))*(r00)*(x398)))+(((cj6)*(x396)))+(((r01)*(x395)))+(((IkReal(-1.00000000000000))*(sj6)*(x399))))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(((gconst47)*(((((cj5)*(sj6)*(x396)))+(((IkReal(-1.00000000000000))*(r01)*(x397)*(x398)))+(((cj0)*(r12)*(sj5)))+(((IkReal(-1.00000000000000))*(r02)*(sj0)*(sj5)))+(((cj5)*(cj6)*(x399)))+(((IkReal(-1.00000000000000))*(r00)*(x395)*(x397))))))) < IKFAST_ATAN2_MAGTHRESH )
    continue;
j4array[0]=IKatan2(((gconst47)*(((((IkReal(-1.00000000000000))*(r00)*(x398)))+(((cj6)*(x396)))+(((r01)*(x395)))+(((IkReal(-1.00000000000000))*(sj6)*(x399)))))), ((gconst47)*(((((cj5)*(sj6)*(x396)))+(((IkReal(-1.00000000000000))*(r01)*(x397)*(x398)))+(((cj0)*(r12)*(sj5)))+(((IkReal(-1.00000000000000))*(r02)*(sj0)*(sj5)))+(((cj5)*(cj6)*(x399)))+(((IkReal(-1.00000000000000))*(r00)*(x395)*(x397)))))));
sj4array[0]=IKsin(j4array[0]);
cj4array[0]=IKcos(j4array[0]);
if( j4array[0] > IKPI )
{
    j4array[0]-=IK2PI;
}
else if( j4array[0] < -IKPI )
{    j4array[0]+=IK2PI;
}
j4valid[0] = true;
for(int ij4 = 0; ij4 < 1; ++ij4)
{
if( !j4valid[ij4] )
{
    continue;
}
_ij4[0] = ij4; _ij4[1] = -1;
for(int iij4 = ij4+1; iij4 < 1; ++iij4)
{
if( j4valid[iij4] && IKabs(cj4array[ij4]-cj4array[iij4]) < IKFAST_SOLUTION_THRESH && IKabs(sj4array[ij4]-sj4array[iij4]) < IKFAST_SOLUTION_THRESH )
{
    j4valid[iij4]=false; _ij4[1] = iij4; break; 
}
}
j4 = j4array[ij4]; cj4 = cj4array[ij4]; sj4 = sj4array[ij4];
{
IkReal evalcond[6];
IkReal x400=IKsin(j4);
IkReal x401=IKcos(j4);
IkReal x402=((r22)*(sj5));
IkReal x403=((IkReal(1.00000000000000))*(cj6));
IkReal x404=((IkReal(1.00000000000000))*(cj0));
IkReal x405=((cj5)*(r11));
IkReal x406=((cj5)*(cj6));
IkReal x407=((r11)*(sj6));
IkReal x408=((IkReal(1.00000000000000))*(sj6));
IkReal x409=((cj6)*(r00));
IkReal x410=((r12)*(sj5));
IkReal x411=((r02)*(sj5));
IkReal x412=((cj6)*(r10));
IkReal x413=((cj5)*(sj6));
IkReal x414=((cj5)*(r01));
IkReal x415=((sj0)*(x400));
IkReal x416=((r00)*(x413));
IkReal x417=((cj0)*(x400));
IkReal x418=((sj0)*(x401));
IkReal x419=((r20)*(x401));
IkReal x420=((cj0)*(x401));
IkReal x421=((r21)*(x400));
IkReal x422=((r21)*(x401));
IkReal x423=((r20)*(x400));
IkReal x424=((x401)*(x410));
IkReal x425=((r01)*(sj6)*(x401));
IkReal x426=((cj5)*(r10)*(x408));
evalcond[0]=((IkReal(-1.00000000000000))+(((IkReal(-1.00000000000000))*(x403)*(x419)))+(((x413)*(x423)))+(((x406)*(x421)))+(((x400)*(x402)))+(((sj6)*(x422))));
evalcond[1]=((((x413)*(x419)))+(((IkReal(-1.00000000000000))*(x408)*(x421)))+(((x406)*(x422)))+(((cj6)*(x423)))+(((x401)*(x402))));
evalcond[2]=((((x412)*(x420)))+(((x415)*(x416)))+(((IkReal(-1.00000000000000))*(r10)*(x400)*(x404)*(x413)))+(((IkReal(-1.00000000000000))*(x401)*(x404)*(x407)))+(((IkReal(-1.00000000000000))*(r00)*(x403)*(x418)))+(((IkReal(-1.00000000000000))*(x400)*(x404)*(x410)))+(((r01)*(sj6)*(x418)))+(((IkReal(-1.00000000000000))*(x403)*(x405)*(x417)))+(((x411)*(x415)))+(((r01)*(x406)*(x415))));
evalcond[3]=((((x409)*(x415)))+(((x411)*(x418)))+(((x416)*(x418)))+(((IkReal(-1.00000000000000))*(r10)*(x403)*(x417)))+(((IkReal(-1.00000000000000))*(r10)*(x401)*(x404)*(x413)))+(cj3)+(((x407)*(x417)))+(((IkReal(-1.00000000000000))*(x403)*(x405)*(x420)))+(((IkReal(-1.00000000000000))*(x404)*(x424)))+(((r01)*(x406)*(x418)))+(((IkReal(-1.00000000000000))*(r01)*(x408)*(x415))));
evalcond[4]=((((IkReal(-1.00000000000000))*(x403)*(x405)*(x415)))+(((IkReal(-1.00000000000000))*(x400)*(x404)*(x416)))+(((IkReal(-1.00000000000000))*(x407)*(x418)))+(((IkReal(-1.00000000000000))*(x400)*(x404)*(x411)))+(((IkReal(-1.00000000000000))*(x403)*(x414)*(x417)))+(((IkReal(-1.00000000000000))*(x415)*(x426)))+(((x412)*(x418)))+(((IkReal(-1.00000000000000))*(x410)*(x415)))+(((IkReal(-1.00000000000000))*(x404)*(x425)))+(((x409)*(x420))));
evalcond[5]=((((IkReal(-1.00000000000000))*(x418)*(x426)))+(((IkReal(-1.00000000000000))*(x410)*(x418)))+(((IkReal(-1.00000000000000))*(x401)*(x404)*(x416)))+(((IkReal(-1.00000000000000))*(x403)*(x405)*(x418)))+(((IkReal(-1.00000000000000))*(x403)*(x414)*(x420)))+(((r01)*(sj6)*(x417)))+(((IkReal(-1.00000000000000))*(r00)*(x403)*(x417)))+(((IkReal(-1.00000000000000))*(sj3)))+(((x407)*(x415)))+(((IkReal(-1.00000000000000))*(r10)*(x403)*(x415)))+(((IkReal(-1.00000000000000))*(x401)*(x404)*(x411))));
if( IKabs(evalcond[0]) > 0.000001  || IKabs(evalcond[1]) > 0.000001  || IKabs(evalcond[2]) > 0.000001  || IKabs(evalcond[3]) > 0.000001  || IKabs(evalcond[4]) > 0.000001  || IKabs(evalcond[5]) > 0.000001  )
{
continue;
}
}

{
std::vector<IkSingleDOFSolutionBase<IkReal> > vinfos(7);
vinfos[0].jointtype = 1;
vinfos[0].foffset = j0;
vinfos[0].indices[0] = _ij0[0];
vinfos[0].indices[1] = _ij0[1];
vinfos[0].maxsolutions = _nj0;
vinfos[1].jointtype = 1;
vinfos[1].foffset = j1;
vinfos[1].indices[0] = _ij1[0];
vinfos[1].indices[1] = _ij1[1];
vinfos[1].maxsolutions = _nj1;
vinfos[2].jointtype = 1;
vinfos[2].foffset = j2;
vinfos[2].indices[0] = _ij2[0];
vinfos[2].indices[1] = _ij2[1];
vinfos[2].maxsolutions = _nj2;
vinfos[3].jointtype = 1;
vinfos[3].foffset = j3;
vinfos[3].indices[0] = _ij3[0];
vinfos[3].indices[1] = _ij3[1];
vinfos[3].maxsolutions = _nj3;
vinfos[4].jointtype = 1;
vinfos[4].foffset = j4;
vinfos[4].indices[0] = _ij4[0];
vinfos[4].indices[1] = _ij4[1];
vinfos[4].maxsolutions = _nj4;
vinfos[5].jointtype = 1;
vinfos[5].foffset = j5;
vinfos[5].indices[0] = _ij5[0];
vinfos[5].indices[1] = _ij5[1];
vinfos[5].maxsolutions = _nj5;
vinfos[6].jointtype = 1;
vinfos[6].foffset = j6;
vinfos[6].indices[0] = _ij6[0];
vinfos[6].indices[1] = _ij6[1];
vinfos[6].maxsolutions = _nj6;
std::vector<int> vfree(0);
solutions.AddSolution(vinfos,vfree);
}
}
}

}

}

} else
{
{
IkReal j4array[1], cj4array[1], sj4array[1];
bool j4valid[1]={false};
_nj4 = 1;
if( IKabs(((gconst46)*(((((cj5)*(r20)*(sj6)))+(((r22)*(sj5)))+(((cj5)*(cj6)*(r21))))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(((gconst46)*(((((r21)*(sj6)))+(((IkReal(-1.00000000000000))*(cj6)*(r20))))))) < IKFAST_ATAN2_MAGTHRESH )
    continue;
j4array[0]=IKatan2(((gconst46)*(((((cj5)*(r20)*(sj6)))+(((r22)*(sj5)))+(((cj5)*(cj6)*(r21)))))), ((gconst46)*(((((r21)*(sj6)))+(((IkReal(-1.00000000000000))*(cj6)*(r20)))))));
sj4array[0]=IKsin(j4array[0]);
cj4array[0]=IKcos(j4array[0]);
if( j4array[0] > IKPI )
{
    j4array[0]-=IK2PI;
}
else if( j4array[0] < -IKPI )
{    j4array[0]+=IK2PI;
}
j4valid[0] = true;
for(int ij4 = 0; ij4 < 1; ++ij4)
{
if( !j4valid[ij4] )
{
    continue;
}
_ij4[0] = ij4; _ij4[1] = -1;
for(int iij4 = ij4+1; iij4 < 1; ++iij4)
{
if( j4valid[iij4] && IKabs(cj4array[ij4]-cj4array[iij4]) < IKFAST_SOLUTION_THRESH && IKabs(sj4array[ij4]-sj4array[iij4]) < IKFAST_SOLUTION_THRESH )
{
    j4valid[iij4]=false; _ij4[1] = iij4; break; 
}
}
j4 = j4array[ij4]; cj4 = cj4array[ij4]; sj4 = sj4array[ij4];
{
IkReal evalcond[6];
IkReal x427=IKsin(j4);
IkReal x428=IKcos(j4);
IkReal x429=((r22)*(sj5));
IkReal x430=((IkReal(1.00000000000000))*(cj6));
IkReal x431=((IkReal(1.00000000000000))*(cj0));
IkReal x432=((cj5)*(r11));
IkReal x433=((cj5)*(cj6));
IkReal x434=((r11)*(sj6));
IkReal x435=((IkReal(1.00000000000000))*(sj6));
IkReal x436=((cj6)*(r00));
IkReal x437=((r12)*(sj5));
IkReal x438=((r02)*(sj5));
IkReal x439=((cj6)*(r10));
IkReal x440=((cj5)*(sj6));
IkReal x441=((cj5)*(r01));
IkReal x442=((sj0)*(x427));
IkReal x443=((r00)*(x440));
IkReal x444=((cj0)*(x427));
IkReal x445=((sj0)*(x428));
IkReal x446=((r20)*(x428));
IkReal x447=((cj0)*(x428));
IkReal x448=((r21)*(x427));
IkReal x449=((r21)*(x428));
IkReal x450=((r20)*(x427));
IkReal x451=((x428)*(x437));
IkReal x452=((r01)*(sj6)*(x428));
IkReal x453=((cj5)*(r10)*(x435));
evalcond[0]=((IkReal(-1.00000000000000))+(((IkReal(-1.00000000000000))*(x430)*(x446)))+(((x433)*(x448)))+(((x427)*(x429)))+(((x440)*(x450)))+(((sj6)*(x449))));
evalcond[1]=((((x433)*(x449)))+(((cj6)*(x450)))+(((x428)*(x429)))+(((IkReal(-1.00000000000000))*(x435)*(x448)))+(((x440)*(x446))));
evalcond[2]=((((r01)*(x433)*(x442)))+(((x439)*(x447)))+(((IkReal(-1.00000000000000))*(r00)*(x430)*(x445)))+(((x442)*(x443)))+(((x438)*(x442)))+(((IkReal(-1.00000000000000))*(r10)*(x427)*(x431)*(x440)))+(((r01)*(sj6)*(x445)))+(((IkReal(-1.00000000000000))*(x430)*(x432)*(x444)))+(((IkReal(-1.00000000000000))*(x428)*(x431)*(x434)))+(((IkReal(-1.00000000000000))*(x427)*(x431)*(x437))));
evalcond[3]=((((r01)*(x433)*(x445)))+(((IkReal(-1.00000000000000))*(r10)*(x428)*(x431)*(x440)))+(((x436)*(x442)))+(((IkReal(-1.00000000000000))*(r01)*(x435)*(x442)))+(((x438)*(x445)))+(((IkReal(-1.00000000000000))*(x431)*(x451)))+(cj3)+(((IkReal(-1.00000000000000))*(x430)*(x432)*(x447)))+(((IkReal(-1.00000000000000))*(r10)*(x430)*(x444)))+(((x443)*(x445)))+(((x434)*(x444))));
evalcond[4]=((((x436)*(x447)))+(((IkReal(-1.00000000000000))*(x430)*(x432)*(x442)))+(((IkReal(-1.00000000000000))*(x427)*(x431)*(x443)))+(((IkReal(-1.00000000000000))*(x434)*(x445)))+(((IkReal(-1.00000000000000))*(x431)*(x452)))+(((IkReal(-1.00000000000000))*(x430)*(x441)*(x444)))+(((IkReal(-1.00000000000000))*(x437)*(x442)))+(((IkReal(-1.00000000000000))*(x427)*(x431)*(x438)))+(((IkReal(-1.00000000000000))*(x442)*(x453)))+(((x439)*(x445))));
evalcond[5]=((((IkReal(-1.00000000000000))*(x437)*(x445)))+(((IkReal(-1.00000000000000))*(x430)*(x432)*(x445)))+(((IkReal(-1.00000000000000))*(x445)*(x453)))+(((IkReal(-1.00000000000000))*(r10)*(x430)*(x442)))+(((IkReal(-1.00000000000000))*(x428)*(x431)*(x443)))+(((IkReal(-1.00000000000000))*(x428)*(x431)*(x438)))+(((IkReal(-1.00000000000000))*(x430)*(x441)*(x447)))+(((x434)*(x442)))+(((IkReal(-1.00000000000000))*(sj3)))+(((r01)*(sj6)*(x444)))+(((IkReal(-1.00000000000000))*(r00)*(x430)*(x444))));
if( IKabs(evalcond[0]) > 0.000001  || IKabs(evalcond[1]) > 0.000001  || IKabs(evalcond[2]) > 0.000001  || IKabs(evalcond[3]) > 0.000001  || IKabs(evalcond[4]) > 0.000001  || IKabs(evalcond[5]) > 0.000001  )
{
continue;
}
}

{
std::vector<IkSingleDOFSolutionBase<IkReal> > vinfos(7);
vinfos[0].jointtype = 1;
vinfos[0].foffset = j0;
vinfos[0].indices[0] = _ij0[0];
vinfos[0].indices[1] = _ij0[1];
vinfos[0].maxsolutions = _nj0;
vinfos[1].jointtype = 1;
vinfos[1].foffset = j1;
vinfos[1].indices[0] = _ij1[0];
vinfos[1].indices[1] = _ij1[1];
vinfos[1].maxsolutions = _nj1;
vinfos[2].jointtype = 1;
vinfos[2].foffset = j2;
vinfos[2].indices[0] = _ij2[0];
vinfos[2].indices[1] = _ij2[1];
vinfos[2].maxsolutions = _nj2;
vinfos[3].jointtype = 1;
vinfos[3].foffset = j3;
vinfos[3].indices[0] = _ij3[0];
vinfos[3].indices[1] = _ij3[1];
vinfos[3].maxsolutions = _nj3;
vinfos[4].jointtype = 1;
vinfos[4].foffset = j4;
vinfos[4].indices[0] = _ij4[0];
vinfos[4].indices[1] = _ij4[1];
vinfos[4].maxsolutions = _nj4;
vinfos[5].jointtype = 1;
vinfos[5].foffset = j5;
vinfos[5].indices[0] = _ij5[0];
vinfos[5].indices[1] = _ij5[1];
vinfos[5].maxsolutions = _nj5;
vinfos[6].jointtype = 1;
vinfos[6].foffset = j6;
vinfos[6].indices[0] = _ij6[0];
vinfos[6].indices[1] = _ij6[1];
vinfos[6].maxsolutions = _nj6;
std::vector<int> vfree(0);
solutions.AddSolution(vinfos,vfree);
}
}
}

}

}
}
}

} else
{
IkReal x454=((cj5)*(r22));
IkReal x455=((IkReal(0.374290000000000))*(sj5));
IkReal x456=((cj0)*(sj6));
IkReal x457=((cj6)*(r21));
IkReal x458=((IkReal(0.0100000000000000))*(sj5));
IkReal x459=((cj0)*(r02));
IkReal x460=((IkReal(0.0100000000000000))*(cj5));
IkReal x461=((IkReal(1.00000000000000))*(py));
IkReal x462=((r01)*(sj0));
IkReal x463=((r20)*(sj6));
IkReal x464=((r11)*(sj0));
IkReal x465=((IkReal(0.374290000000000))*(cj5));
IkReal x466=((cj0)*(r12));
IkReal x467=((sj0)*(x465));
IkReal x468=((cj6)*(x460));
IkReal x469=((r10)*(sj0)*(sj6));
IkReal x470=((r00)*(sj0)*(sj6));
IkReal x471=((cj0)*(cj6)*(x455));
evalcond[0]=((IkReal(-3.14159265358979))+(IKfmod(((IkReal(4.71238898038469))+(j2)), IkReal(6.28318530717959))));
evalcond[1]=((((IkReal(-1.00000000000000))*(x454)))+(((sj5)*(x457)))+(((sj5)*(x463))));
evalcond[2]=((((IkReal(-0.374290000000000))*(x454)))+(((x455)*(x457)))+(((IkReal(-1.00000000000000))*(x460)*(x463)))+(((IkReal(-1.00000000000000))*(x457)*(x460)))+(((x455)*(x463)))+(pz)+(((IkReal(-1.00000000000000))*(r22)*(x458))));
evalcond[3]=((IkReal(-0.0690000000000000))+(((r10)*(x456)*(x460)))+(((x465)*(x466)))+(((IkReal(-1.00000000000000))*(cj0)*(x461)))+(((IkReal(-1.00000000000000))*(x460)*(x470)))+(((IkReal(-1.00000000000000))*(x462)*(x468)))+(((x455)*(x470)))+(((IkReal(-1.00000000000000))*(r10)*(x455)*(x456)))+(((IkReal(-1.00000000000000))*(r02)*(x467)))+(((cj0)*(r11)*(x468)))+(((px)*(sj0)))+(((IkReal(-1.00000000000000))*(r11)*(x471)))+(((cj6)*(x455)*(x462)))+(((IkReal(-1.00000000000000))*(r02)*(sj0)*(x458)))+(((x458)*(x466))));
evalcond[4]=((IkReal(0.433420000000000))+(((IkReal(-1.00000000000000))*(cj0)*(px)))+(((r00)*(x456)*(x460)))+(((IkReal(-1.00000000000000))*(r00)*(x455)*(x456)))+(((x458)*(x459)))+(((x460)*(x469)))+(((cj0)*(r01)*(x468)))+(((x464)*(x468)))+(((r12)*(sj0)*(x458)))+(((IkReal(-1.00000000000000))*(cj6)*(x455)*(x464)))+(((IkReal(-1.00000000000000))*(x455)*(x469)))+(((r12)*(x467)))+(((IkReal(-1.00000000000000))*(sj0)*(x461)))+(((x459)*(x465)))+(((IkReal(-1.00000000000000))*(r01)*(x471))));
if( IKabs(evalcond[0]) < 0.0000010000000000  && IKabs(evalcond[1]) < 0.0000010000000000  && IKabs(evalcond[2]) < 0.0000010000000000  && IKabs(evalcond[3]) < 0.0000010000000000  && IKabs(evalcond[4]) < 0.0000010000000000  )
{
{
IkReal j3array[1], cj3array[1], sj3array[1];
bool j3valid[1]={false};
_nj3 = 1;
IkReal x472=((cj5)*(r02));
IkReal x473=((cj0)*(sj5));
IkReal x474=((r10)*(sj6));
IkReal x475=((IkReal(1.00000000000000))*(cj6));
IkReal x476=((sj0)*(sj5));
IkReal x477=((cj5)*(r12));
IkReal x478=((IkReal(1.00000000000000))*(r00)*(sj6));
if( IKabs(((((IkReal(-1.00000000000000))*(x476)*(x478)))+(((IkReal(-1.00000000000000))*(cj0)*(x477)))+(((IkReal(-1.00000000000000))*(r01)*(x475)*(x476)))+(((sj0)*(x472)))+(((x473)*(x474)))+(((cj6)*(r11)*(x473))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(((((IkReal(-1.00000000000000))*(x473)*(x478)))+(((cj0)*(x472)))+(((IkReal(-1.00000000000000))*(r11)*(x475)*(x476)))+(((IkReal(-1.00000000000000))*(r01)*(x473)*(x475)))+(((IkReal(-1.00000000000000))*(x474)*(x476)))+(((sj0)*(x477))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(IKsqr(((((IkReal(-1.00000000000000))*(x476)*(x478)))+(((IkReal(-1.00000000000000))*(cj0)*(x477)))+(((IkReal(-1.00000000000000))*(r01)*(x475)*(x476)))+(((sj0)*(x472)))+(((x473)*(x474)))+(((cj6)*(r11)*(x473)))))+IKsqr(((((IkReal(-1.00000000000000))*(x473)*(x478)))+(((cj0)*(x472)))+(((IkReal(-1.00000000000000))*(r11)*(x475)*(x476)))+(((IkReal(-1.00000000000000))*(r01)*(x473)*(x475)))+(((IkReal(-1.00000000000000))*(x474)*(x476)))+(((sj0)*(x477)))))-1) <= IKFAST_SINCOS_THRESH )
    continue;
j3array[0]=IKatan2(((((IkReal(-1.00000000000000))*(x476)*(x478)))+(((IkReal(-1.00000000000000))*(cj0)*(x477)))+(((IkReal(-1.00000000000000))*(r01)*(x475)*(x476)))+(((sj0)*(x472)))+(((x473)*(x474)))+(((cj6)*(r11)*(x473)))), ((((IkReal(-1.00000000000000))*(x473)*(x478)))+(((cj0)*(x472)))+(((IkReal(-1.00000000000000))*(r11)*(x475)*(x476)))+(((IkReal(-1.00000000000000))*(r01)*(x473)*(x475)))+(((IkReal(-1.00000000000000))*(x474)*(x476)))+(((sj0)*(x477)))));
sj3array[0]=IKsin(j3array[0]);
cj3array[0]=IKcos(j3array[0]);
if( j3array[0] > IKPI )
{
    j3array[0]-=IK2PI;
}
else if( j3array[0] < -IKPI )
{    j3array[0]+=IK2PI;
}
j3valid[0] = true;
for(int ij3 = 0; ij3 < 1; ++ij3)
{
if( !j3valid[ij3] )
{
    continue;
}
_ij3[0] = ij3; _ij3[1] = -1;
for(int iij3 = ij3+1; iij3 < 1; ++iij3)
{
if( j3valid[iij3] && IKabs(cj3array[ij3]-cj3array[iij3]) < IKFAST_SOLUTION_THRESH && IKabs(sj3array[ij3]-sj3array[iij3]) < IKFAST_SOLUTION_THRESH )
{
    j3valid[iij3]=false; _ij3[1] = iij3; break; 
}
}
j3 = j3array[ij3]; cj3 = cj3array[ij3]; sj3 = sj3array[ij3];
{
IkReal evalcond[2];
IkReal x479=((cj0)*(cj5));
IkReal x480=((IkReal(1.00000000000000))*(cj0));
IkReal x481=((cj6)*(r11));
IkReal x482=((r10)*(sj6));
IkReal x483=((cj5)*(sj0));
IkReal x484=((r00)*(sj5)*(sj6));
IkReal x485=((cj6)*(r01)*(sj5));
IkReal x486=((IkReal(1.00000000000000))*(sj0)*(sj5));
evalcond[0]=((((sj0)*(x484)))+(((r12)*(x479)))+(IKsin(j3))+(((IkReal(-1.00000000000000))*(sj5)*(x480)*(x481)))+(((IkReal(-1.00000000000000))*(sj5)*(x480)*(x482)))+(((IkReal(-1.00000000000000))*(r02)*(x483)))+(((sj0)*(x485))));
evalcond[1]=((((IkReal(-1.00000000000000))*(x480)*(x484)))+(((r12)*(x483)))+(((r02)*(x479)))+(((IkReal(-1.00000000000000))*(IKcos(j3))))+(((IkReal(-1.00000000000000))*(x482)*(x486)))+(((IkReal(-1.00000000000000))*(x481)*(x486)))+(((IkReal(-1.00000000000000))*(x480)*(x485))));
if( IKabs(evalcond[0]) > 0.000001  || IKabs(evalcond[1]) > 0.000001  )
{
continue;
}
}

{
IkReal dummyeval[1];
IkReal gconst50;
IkReal x487=(r21)*(r21);
IkReal x488=(cj5)*(cj5);
IkReal x489=(sj6)*(sj6);
IkReal x490=(cj6)*(cj6);
IkReal x491=(r20)*(r20);
IkReal x492=((cj6)*(r21));
IkReal x493=((IkReal(2.00000000000000))*(r20)*(sj6));
IkReal x494=((cj5)*(r22)*(sj5));
IkReal x495=((IkReal(1.00000000000000))*(x489));
IkReal x496=((IkReal(1.00000000000000))*(x490));
gconst50=IKsign(((((IkReal(-1.00000000000000))*(x487)*(x488)*(x496)))+(((IkReal(-1.00000000000000))*(x488)*(x492)*(x493)))+(((x492)*(x493)))+(((IkReal(-1.00000000000000))*(x491)*(x496)))+(((IkReal(-2.00000000000000))*(x492)*(x494)))+(((IkReal(-1.00000000000000))*((r22)*(r22))*((sj5)*(sj5))))+(((IkReal(-1.00000000000000))*(x488)*(x491)*(x495)))+(((IkReal(-1.00000000000000))*(x487)*(x495)))+(((IkReal(-1.00000000000000))*(x493)*(x494)))));
IkReal x497=(r21)*(r21);
IkReal x498=(cj5)*(cj5);
IkReal x499=(sj6)*(sj6);
IkReal x500=(cj6)*(cj6);
IkReal x501=(r20)*(r20);
IkReal x502=((cj6)*(r21));
IkReal x503=((IkReal(2.00000000000000))*(r20)*(sj6));
IkReal x504=((cj5)*(r22)*(sj5));
IkReal x505=((IkReal(1.00000000000000))*(x499));
IkReal x506=((IkReal(1.00000000000000))*(x500));
dummyeval[0]=((((IkReal(-1.00000000000000))*((r22)*(r22))*((sj5)*(sj5))))+(((IkReal(-1.00000000000000))*(x497)*(x505)))+(((IkReal(-1.00000000000000))*(x503)*(x504)))+(((IkReal(-1.00000000000000))*(x498)*(x502)*(x503)))+(((IkReal(-1.00000000000000))*(x498)*(x501)*(x505)))+(((x502)*(x503)))+(((IkReal(-1.00000000000000))*(x501)*(x506)))+(((IkReal(-2.00000000000000))*(x502)*(x504)))+(((IkReal(-1.00000000000000))*(x497)*(x498)*(x506))));
if( IKabs(dummyeval[0]) < 0.0000010000000000  )
{
{
IkReal dummyeval[1];
IkReal gconst51;
IkReal x507=(cj6)*(cj6);
IkReal x508=(sj6)*(sj6);
IkReal x509=((IkReal(1.00000000000000))*(r01));
IkReal x510=((sj0)*(sj5));
IkReal x511=((cj6)*(r22));
IkReal x512=((r21)*(sj6));
IkReal x513=((r00)*(r21));
IkReal x514=((cj0)*(sj5));
IkReal x515=((cj6)*(r20));
IkReal x516=((r22)*(sj6));
IkReal x517=((cj0)*(cj5));
IkReal x518=((IkReal(1.00000000000000))*(r10));
IkReal x519=((cj5)*(sj0));
IkReal x520=((r20)*(x508));
IkReal x521=((x507)*(x519));
gconst51=IKsign(((((r11)*(x514)*(x516)))+(((IkReal(-1.00000000000000))*(r20)*(x509)*(x521)))+(((IkReal(-1.00000000000000))*(r12)*(x512)*(x514)))+(((r00)*(x510)*(x511)))+(((IkReal(-1.00000000000000))*(r21)*(x508)*(x517)*(x518)))+(((x513)*(x521)))+(((x508)*(x513)*(x519)))+(((IkReal(-1.00000000000000))*(x509)*(x510)*(x516)))+(((r11)*(x517)*(x520)))+(((r11)*(r20)*(x507)*(x517)))+(((IkReal(-1.00000000000000))*(r21)*(x507)*(x517)*(x518)))+(((r02)*(x510)*(x512)))+(((IkReal(-1.00000000000000))*(x511)*(x514)*(x518)))+(((IkReal(-1.00000000000000))*(x509)*(x519)*(x520)))+(((IkReal(-1.00000000000000))*(r02)*(x510)*(x515)))+(((r12)*(x514)*(x515)))));
IkReal x522=(cj6)*(cj6);
IkReal x523=(sj6)*(sj6);
IkReal x524=((IkReal(1.00000000000000))*(r01));
IkReal x525=((sj0)*(sj5));
IkReal x526=((cj6)*(r22));
IkReal x527=((r21)*(sj6));
IkReal x528=((r00)*(r21));
IkReal x529=((cj0)*(sj5));
IkReal x530=((cj6)*(r20));
IkReal x531=((r22)*(sj6));
IkReal x532=((cj0)*(cj5));
IkReal x533=((IkReal(1.00000000000000))*(r10));
IkReal x534=((cj5)*(sj0));
IkReal x535=((r20)*(x523));
IkReal x536=((x522)*(x534));
dummyeval[0]=((((r11)*(x529)*(x531)))+(((r12)*(x529)*(x530)))+(((r00)*(x525)*(x526)))+(((r02)*(x525)*(x527)))+(((IkReal(-1.00000000000000))*(r21)*(x522)*(x532)*(x533)))+(((IkReal(-1.00000000000000))*(r20)*(x524)*(x536)))+(((IkReal(-1.00000000000000))*(x526)*(x529)*(x533)))+(((IkReal(-1.00000000000000))*(r21)*(x523)*(x532)*(x533)))+(((IkReal(-1.00000000000000))*(r02)*(x525)*(x530)))+(((IkReal(-1.00000000000000))*(r12)*(x527)*(x529)))+(((IkReal(-1.00000000000000))*(x524)*(x525)*(x531)))+(((r11)*(x532)*(x535)))+(((x528)*(x536)))+(((r11)*(r20)*(x522)*(x532)))+(((IkReal(-1.00000000000000))*(x524)*(x534)*(x535)))+(((x523)*(x528)*(x534))));
if( IKabs(dummyeval[0]) < 0.0000010000000000  )
{
continue;

} else
{
{
IkReal j4array[1], cj4array[1], sj4array[1];
bool j4valid[1]={false};
_nj4 = 1;
IkReal x537=((sj0)*(sj6));
IkReal x538=((cj0)*(r10));
IkReal x539=((IkReal(1.00000000000000))*(cj5));
IkReal x540=((cj6)*(sj0));
IkReal x541=((cj0)*(r11));
if( IKabs(((gconst51)*(((((r01)*(x537)))+(((IkReal(-1.00000000000000))*(r00)*(x540)))+(((IkReal(-1.00000000000000))*(sj6)*(x541)))+(((cj6)*(x538))))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(((gconst51)*(((((cj0)*(r12)*(sj5)))+(((IkReal(-1.00000000000000))*(r00)*(x537)*(x539)))+(((IkReal(-1.00000000000000))*(r02)*(sj0)*(sj5)))+(((cj5)*(cj6)*(x541)))+(((cj5)*(sj6)*(x538)))+(((IkReal(-1.00000000000000))*(r01)*(x539)*(x540))))))) < IKFAST_ATAN2_MAGTHRESH )
    continue;
j4array[0]=IKatan2(((gconst51)*(((((r01)*(x537)))+(((IkReal(-1.00000000000000))*(r00)*(x540)))+(((IkReal(-1.00000000000000))*(sj6)*(x541)))+(((cj6)*(x538)))))), ((gconst51)*(((((cj0)*(r12)*(sj5)))+(((IkReal(-1.00000000000000))*(r00)*(x537)*(x539)))+(((IkReal(-1.00000000000000))*(r02)*(sj0)*(sj5)))+(((cj5)*(cj6)*(x541)))+(((cj5)*(sj6)*(x538)))+(((IkReal(-1.00000000000000))*(r01)*(x539)*(x540)))))));
sj4array[0]=IKsin(j4array[0]);
cj4array[0]=IKcos(j4array[0]);
if( j4array[0] > IKPI )
{
    j4array[0]-=IK2PI;
}
else if( j4array[0] < -IKPI )
{    j4array[0]+=IK2PI;
}
j4valid[0] = true;
for(int ij4 = 0; ij4 < 1; ++ij4)
{
if( !j4valid[ij4] )
{
    continue;
}
_ij4[0] = ij4; _ij4[1] = -1;
for(int iij4 = ij4+1; iij4 < 1; ++iij4)
{
if( j4valid[iij4] && IKabs(cj4array[ij4]-cj4array[iij4]) < IKFAST_SOLUTION_THRESH && IKabs(sj4array[ij4]-sj4array[iij4]) < IKFAST_SOLUTION_THRESH )
{
    j4valid[iij4]=false; _ij4[1] = iij4; break; 
}
}
j4 = j4array[ij4]; cj4 = cj4array[ij4]; sj4 = sj4array[ij4];
{
IkReal evalcond[6];
IkReal x542=IKsin(j4);
IkReal x543=IKcos(j4);
IkReal x544=((r22)*(sj5));
IkReal x545=((IkReal(1.00000000000000))*(cj6));
IkReal x546=((IkReal(1.00000000000000))*(cj0));
IkReal x547=((cj5)*(r11));
IkReal x548=((cj5)*(cj6));
IkReal x549=((r11)*(sj6));
IkReal x550=((IkReal(1.00000000000000))*(sj6));
IkReal x551=((cj6)*(r00));
IkReal x552=((r12)*(sj5));
IkReal x553=((r02)*(sj5));
IkReal x554=((cj6)*(r10));
IkReal x555=((cj5)*(sj6));
IkReal x556=((cj5)*(r01));
IkReal x557=((sj0)*(x542));
IkReal x558=((r00)*(x555));
IkReal x559=((cj0)*(x542));
IkReal x560=((sj0)*(x543));
IkReal x561=((r20)*(x543));
IkReal x562=((cj0)*(x543));
IkReal x563=((r21)*(x542));
IkReal x564=((r21)*(x543));
IkReal x565=((r20)*(x542));
IkReal x566=((x543)*(x552));
IkReal x567=((r01)*(sj6)*(x543));
IkReal x568=((cj5)*(r10)*(x550));
evalcond[0]=((IkReal(1.00000000000000))+(((sj6)*(x564)))+(((x542)*(x544)))+(((IkReal(-1.00000000000000))*(x545)*(x561)))+(((x548)*(x563)))+(((x555)*(x565))));
evalcond[1]=((((cj6)*(x565)))+(((x555)*(x561)))+(((IkReal(-1.00000000000000))*(x550)*(x563)))+(((x548)*(x564)))+(((x543)*(x544))));
evalcond[2]=((((IkReal(-1.00000000000000))*(r10)*(x542)*(x546)*(x555)))+(((IkReal(-1.00000000000000))*(x542)*(x546)*(x552)))+(((r01)*(x548)*(x557)))+(((IkReal(-1.00000000000000))*(x543)*(x546)*(x549)))+(((IkReal(-1.00000000000000))*(r00)*(x545)*(x560)))+(((IkReal(-1.00000000000000))*(x545)*(x547)*(x559)))+(((r01)*(sj6)*(x560)))+(((x557)*(x558)))+(((x554)*(x562)))+(((x553)*(x557))));
evalcond[3]=((((r01)*(x548)*(x560)))+(((x553)*(x560)))+(((x549)*(x559)))+(((IkReal(-1.00000000000000))*(r10)*(x545)*(x559)))+(((IkReal(-1.00000000000000))*(r01)*(x550)*(x557)))+(((IkReal(-1.00000000000000))*(r10)*(x543)*(x546)*(x555)))+(((IkReal(-1.00000000000000))*(cj3)))+(((IkReal(-1.00000000000000))*(x545)*(x547)*(x562)))+(((x551)*(x557)))+(((IkReal(-1.00000000000000))*(x546)*(x566)))+(((x558)*(x560))));
evalcond[4]=((((IkReal(-1.00000000000000))*(x542)*(x546)*(x553)))+(((IkReal(-1.00000000000000))*(x542)*(x546)*(x558)))+(((IkReal(-1.00000000000000))*(x546)*(x567)))+(((IkReal(-1.00000000000000))*(x557)*(x568)))+(((IkReal(-1.00000000000000))*(x545)*(x547)*(x557)))+(((IkReal(-1.00000000000000))*(x549)*(x560)))+(((IkReal(-1.00000000000000))*(x545)*(x556)*(x559)))+(((x554)*(x560)))+(((x551)*(x562)))+(((IkReal(-1.00000000000000))*(x552)*(x557))));
evalcond[5]=((((IkReal(-1.00000000000000))*(x560)*(x568)))+(((r01)*(sj6)*(x559)))+(((IkReal(-1.00000000000000))*(r00)*(x545)*(x559)))+(((IkReal(-1.00000000000000))*(x545)*(x556)*(x562)))+(((IkReal(-1.00000000000000))*(r10)*(x545)*(x557)))+(((IkReal(-1.00000000000000))*(x545)*(x547)*(x560)))+(((IkReal(-1.00000000000000))*(x543)*(x546)*(x558)))+(((IkReal(-1.00000000000000))*(x552)*(x560)))+(((IkReal(-1.00000000000000))*(x543)*(x546)*(x553)))+(((IkReal(-1.00000000000000))*(sj3)))+(((x549)*(x557))));
if( IKabs(evalcond[0]) > 0.000001  || IKabs(evalcond[1]) > 0.000001  || IKabs(evalcond[2]) > 0.000001  || IKabs(evalcond[3]) > 0.000001  || IKabs(evalcond[4]) > 0.000001  || IKabs(evalcond[5]) > 0.000001  )
{
continue;
}
}

{
std::vector<IkSingleDOFSolutionBase<IkReal> > vinfos(7);
vinfos[0].jointtype = 1;
vinfos[0].foffset = j0;
vinfos[0].indices[0] = _ij0[0];
vinfos[0].indices[1] = _ij0[1];
vinfos[0].maxsolutions = _nj0;
vinfos[1].jointtype = 1;
vinfos[1].foffset = j1;
vinfos[1].indices[0] = _ij1[0];
vinfos[1].indices[1] = _ij1[1];
vinfos[1].maxsolutions = _nj1;
vinfos[2].jointtype = 1;
vinfos[2].foffset = j2;
vinfos[2].indices[0] = _ij2[0];
vinfos[2].indices[1] = _ij2[1];
vinfos[2].maxsolutions = _nj2;
vinfos[3].jointtype = 1;
vinfos[3].foffset = j3;
vinfos[3].indices[0] = _ij3[0];
vinfos[3].indices[1] = _ij3[1];
vinfos[3].maxsolutions = _nj3;
vinfos[4].jointtype = 1;
vinfos[4].foffset = j4;
vinfos[4].indices[0] = _ij4[0];
vinfos[4].indices[1] = _ij4[1];
vinfos[4].maxsolutions = _nj4;
vinfos[5].jointtype = 1;
vinfos[5].foffset = j5;
vinfos[5].indices[0] = _ij5[0];
vinfos[5].indices[1] = _ij5[1];
vinfos[5].maxsolutions = _nj5;
vinfos[6].jointtype = 1;
vinfos[6].foffset = j6;
vinfos[6].indices[0] = _ij6[0];
vinfos[6].indices[1] = _ij6[1];
vinfos[6].maxsolutions = _nj6;
std::vector<int> vfree(0);
solutions.AddSolution(vinfos,vfree);
}
}
}

}

}

} else
{
{
IkReal j4array[1], cj4array[1], sj4array[1];
bool j4valid[1]={false};
_nj4 = 1;
if( IKabs(((gconst50)*(((((cj5)*(r20)*(sj6)))+(((r22)*(sj5)))+(((cj5)*(cj6)*(r21))))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(((gconst50)*(((((r21)*(sj6)))+(((IkReal(-1.00000000000000))*(cj6)*(r20))))))) < IKFAST_ATAN2_MAGTHRESH )
    continue;
j4array[0]=IKatan2(((gconst50)*(((((cj5)*(r20)*(sj6)))+(((r22)*(sj5)))+(((cj5)*(cj6)*(r21)))))), ((gconst50)*(((((r21)*(sj6)))+(((IkReal(-1.00000000000000))*(cj6)*(r20)))))));
sj4array[0]=IKsin(j4array[0]);
cj4array[0]=IKcos(j4array[0]);
if( j4array[0] > IKPI )
{
    j4array[0]-=IK2PI;
}
else if( j4array[0] < -IKPI )
{    j4array[0]+=IK2PI;
}
j4valid[0] = true;
for(int ij4 = 0; ij4 < 1; ++ij4)
{
if( !j4valid[ij4] )
{
    continue;
}
_ij4[0] = ij4; _ij4[1] = -1;
for(int iij4 = ij4+1; iij4 < 1; ++iij4)
{
if( j4valid[iij4] && IKabs(cj4array[ij4]-cj4array[iij4]) < IKFAST_SOLUTION_THRESH && IKabs(sj4array[ij4]-sj4array[iij4]) < IKFAST_SOLUTION_THRESH )
{
    j4valid[iij4]=false; _ij4[1] = iij4; break; 
}
}
j4 = j4array[ij4]; cj4 = cj4array[ij4]; sj4 = sj4array[ij4];
{
IkReal evalcond[6];
IkReal x569=IKsin(j4);
IkReal x570=IKcos(j4);
IkReal x571=((r22)*(sj5));
IkReal x572=((IkReal(1.00000000000000))*(cj6));
IkReal x573=((IkReal(1.00000000000000))*(cj0));
IkReal x574=((cj5)*(r11));
IkReal x575=((cj5)*(cj6));
IkReal x576=((r11)*(sj6));
IkReal x577=((IkReal(1.00000000000000))*(sj6));
IkReal x578=((cj6)*(r00));
IkReal x579=((r12)*(sj5));
IkReal x580=((r02)*(sj5));
IkReal x581=((cj6)*(r10));
IkReal x582=((cj5)*(sj6));
IkReal x583=((cj5)*(r01));
IkReal x584=((sj0)*(x569));
IkReal x585=((r00)*(x582));
IkReal x586=((cj0)*(x569));
IkReal x587=((sj0)*(x570));
IkReal x588=((r20)*(x570));
IkReal x589=((cj0)*(x570));
IkReal x590=((r21)*(x569));
IkReal x591=((r21)*(x570));
IkReal x592=((r20)*(x569));
IkReal x593=((x570)*(x579));
IkReal x594=((r01)*(sj6)*(x570));
IkReal x595=((cj5)*(r10)*(x577));
evalcond[0]=((IkReal(1.00000000000000))+(((sj6)*(x591)))+(((x582)*(x592)))+(((x575)*(x590)))+(((IkReal(-1.00000000000000))*(x572)*(x588)))+(((x569)*(x571))));
evalcond[1]=((((IkReal(-1.00000000000000))*(x577)*(x590)))+(((x575)*(x591)))+(((x570)*(x571)))+(((cj6)*(x592)))+(((x582)*(x588))));
evalcond[2]=((((r01)*(sj6)*(x587)))+(((IkReal(-1.00000000000000))*(x572)*(x574)*(x586)))+(((x584)*(x585)))+(((IkReal(-1.00000000000000))*(r10)*(x569)*(x573)*(x582)))+(((IkReal(-1.00000000000000))*(r00)*(x572)*(x587)))+(((r01)*(x575)*(x584)))+(((IkReal(-1.00000000000000))*(x570)*(x573)*(x576)))+(((x580)*(x584)))+(((IkReal(-1.00000000000000))*(x569)*(x573)*(x579)))+(((x581)*(x589))));
evalcond[3]=((((x580)*(x587)))+(((IkReal(-1.00000000000000))*(r01)*(x577)*(x584)))+(((r01)*(x575)*(x587)))+(((x585)*(x587)))+(((IkReal(-1.00000000000000))*(x572)*(x574)*(x589)))+(((IkReal(-1.00000000000000))*(x573)*(x593)))+(((IkReal(-1.00000000000000))*(cj3)))+(((IkReal(-1.00000000000000))*(r10)*(x572)*(x586)))+(((x578)*(x584)))+(((IkReal(-1.00000000000000))*(r10)*(x570)*(x573)*(x582)))+(((x576)*(x586))));
evalcond[4]=((((IkReal(-1.00000000000000))*(x572)*(x583)*(x586)))+(((x578)*(x589)))+(((x581)*(x587)))+(((IkReal(-1.00000000000000))*(x573)*(x594)))+(((IkReal(-1.00000000000000))*(x584)*(x595)))+(((IkReal(-1.00000000000000))*(x569)*(x573)*(x580)))+(((IkReal(-1.00000000000000))*(x579)*(x584)))+(((IkReal(-1.00000000000000))*(x569)*(x573)*(x585)))+(((IkReal(-1.00000000000000))*(x576)*(x587)))+(((IkReal(-1.00000000000000))*(x572)*(x574)*(x584))));
evalcond[5]=((((IkReal(-1.00000000000000))*(x572)*(x583)*(x589)))+(((IkReal(-1.00000000000000))*(r00)*(x572)*(x586)))+(((IkReal(-1.00000000000000))*(x587)*(x595)))+(((IkReal(-1.00000000000000))*(x572)*(x574)*(x587)))+(((IkReal(-1.00000000000000))*(x570)*(x573)*(x580)))+(((IkReal(-1.00000000000000))*(x579)*(x587)))+(((IkReal(-1.00000000000000))*(x570)*(x573)*(x585)))+(((r01)*(sj6)*(x586)))+(((x576)*(x584)))+(((IkReal(-1.00000000000000))*(sj3)))+(((IkReal(-1.00000000000000))*(r10)*(x572)*(x584))));
if( IKabs(evalcond[0]) > 0.000001  || IKabs(evalcond[1]) > 0.000001  || IKabs(evalcond[2]) > 0.000001  || IKabs(evalcond[3]) > 0.000001  || IKabs(evalcond[4]) > 0.000001  || IKabs(evalcond[5]) > 0.000001  )
{
continue;
}
}

{
std::vector<IkSingleDOFSolutionBase<IkReal> > vinfos(7);
vinfos[0].jointtype = 1;
vinfos[0].foffset = j0;
vinfos[0].indices[0] = _ij0[0];
vinfos[0].indices[1] = _ij0[1];
vinfos[0].maxsolutions = _nj0;
vinfos[1].jointtype = 1;
vinfos[1].foffset = j1;
vinfos[1].indices[0] = _ij1[0];
vinfos[1].indices[1] = _ij1[1];
vinfos[1].maxsolutions = _nj1;
vinfos[2].jointtype = 1;
vinfos[2].foffset = j2;
vinfos[2].indices[0] = _ij2[0];
vinfos[2].indices[1] = _ij2[1];
vinfos[2].maxsolutions = _nj2;
vinfos[3].jointtype = 1;
vinfos[3].foffset = j3;
vinfos[3].indices[0] = _ij3[0];
vinfos[3].indices[1] = _ij3[1];
vinfos[3].maxsolutions = _nj3;
vinfos[4].jointtype = 1;
vinfos[4].foffset = j4;
vinfos[4].indices[0] = _ij4[0];
vinfos[4].indices[1] = _ij4[1];
vinfos[4].maxsolutions = _nj4;
vinfos[5].jointtype = 1;
vinfos[5].foffset = j5;
vinfos[5].indices[0] = _ij5[0];
vinfos[5].indices[1] = _ij5[1];
vinfos[5].maxsolutions = _nj5;
vinfos[6].jointtype = 1;
vinfos[6].foffset = j6;
vinfos[6].indices[0] = _ij6[0];
vinfos[6].indices[1] = _ij6[1];
vinfos[6].maxsolutions = _nj6;
std::vector<int> vfree(0);
solutions.AddSolution(vinfos,vfree);
}
}
}

}

}
}
}

} else
{
if( 1 )
{
continue;

} else
{
}
}
}
}

} else
{
{
IkReal j3array[1], cj3array[1], sj3array[1];
bool j3valid[1]={false};
_nj3 = 1;
IkReal x596=((sj5)*(sj6));
IkReal x597=((IkReal(1.00000000000000))*(cj6)*(sj5));
if( IKabs(((((IKabs(cj2) != 0)?((IkReal)1/(cj2)):(IkReal)1.0e30))*(((((cj6)*(r21)*(sj5)))+(((r20)*(x596)))+(((IkReal(-1.00000000000000))*(cj5)*(r22))))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(((((cj0)*(cj5)*(r02)))+(((IkReal(-1.00000000000000))*(r11)*(sj0)*(x597)))+(((IkReal(-1.00000000000000))*(cj0)*(r00)*(x596)))+(((cj5)*(r12)*(sj0)))+(((IkReal(-1.00000000000000))*(cj0)*(r01)*(x597)))+(((IkReal(-1.00000000000000))*(r10)*(sj0)*(x596))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(IKsqr(((((IKabs(cj2) != 0)?((IkReal)1/(cj2)):(IkReal)1.0e30))*(((((cj6)*(r21)*(sj5)))+(((r20)*(x596)))+(((IkReal(-1.00000000000000))*(cj5)*(r22)))))))+IKsqr(((((cj0)*(cj5)*(r02)))+(((IkReal(-1.00000000000000))*(r11)*(sj0)*(x597)))+(((IkReal(-1.00000000000000))*(cj0)*(r00)*(x596)))+(((cj5)*(r12)*(sj0)))+(((IkReal(-1.00000000000000))*(cj0)*(r01)*(x597)))+(((IkReal(-1.00000000000000))*(r10)*(sj0)*(x596)))))-1) <= IKFAST_SINCOS_THRESH )
    continue;
j3array[0]=IKatan2(((((IKabs(cj2) != 0)?((IkReal)1/(cj2)):(IkReal)1.0e30))*(((((cj6)*(r21)*(sj5)))+(((r20)*(x596)))+(((IkReal(-1.00000000000000))*(cj5)*(r22)))))), ((((cj0)*(cj5)*(r02)))+(((IkReal(-1.00000000000000))*(r11)*(sj0)*(x597)))+(((IkReal(-1.00000000000000))*(cj0)*(r00)*(x596)))+(((cj5)*(r12)*(sj0)))+(((IkReal(-1.00000000000000))*(cj0)*(r01)*(x597)))+(((IkReal(-1.00000000000000))*(r10)*(sj0)*(x596)))));
sj3array[0]=IKsin(j3array[0]);
cj3array[0]=IKcos(j3array[0]);
if( j3array[0] > IKPI )
{
    j3array[0]-=IK2PI;
}
else if( j3array[0] < -IKPI )
{    j3array[0]+=IK2PI;
}
j3valid[0] = true;
for(int ij3 = 0; ij3 < 1; ++ij3)
{
if( !j3valid[ij3] )
{
    continue;
}
_ij3[0] = ij3; _ij3[1] = -1;
for(int iij3 = ij3+1; iij3 < 1; ++iij3)
{
if( j3valid[iij3] && IKabs(cj3array[ij3]-cj3array[iij3]) < IKFAST_SOLUTION_THRESH && IKabs(sj3array[ij3]-sj3array[iij3]) < IKFAST_SOLUTION_THRESH )
{
    j3valid[iij3]=false; _ij3[1] = iij3; break; 
}
}
j3 = j3array[ij3]; cj3 = cj3array[ij3]; sj3 = sj3array[ij3];
{
IkReal evalcond[3];
IkReal x598=IKsin(j3);
IkReal x599=((sj5)*(sj6));
IkReal x600=((cj0)*(cj5));
IkReal x601=((IkReal(1.00000000000000))*(cj0));
IkReal x602=((IkReal(1.00000000000000))*(sj0));
IkReal x603=((IkReal(1.00000000000000))*(x598));
IkReal x604=((cj6)*(r01)*(sj5));
IkReal x605=((cj6)*(r11)*(sj5));
evalcond[0]=((((r20)*(x599)))+(((IkReal(-1.00000000000000))*(cj2)*(x603)))+(((cj6)*(r21)*(sj5)))+(((IkReal(-1.00000000000000))*(cj5)*(r22))));
evalcond[1]=((((IkReal(-1.00000000000000))*(cj5)*(r02)*(x602)))+(((r00)*(sj0)*(x599)))+(((IkReal(-1.00000000000000))*(sj2)*(x603)))+(((IkReal(-1.00000000000000))*(x601)*(x605)))+(((IkReal(-1.00000000000000))*(r10)*(x599)*(x601)))+(((sj0)*(x604)))+(((r12)*(x600))));
evalcond[2]=((((cj5)*(r12)*(sj0)))+(((IkReal(-1.00000000000000))*(IKcos(j3))))+(((IkReal(-1.00000000000000))*(r10)*(x599)*(x602)))+(((IkReal(-1.00000000000000))*(r00)*(x599)*(x601)))+(((r02)*(x600)))+(((IkReal(-1.00000000000000))*(x602)*(x605)))+(((IkReal(-1.00000000000000))*(x601)*(x604))));
if( IKabs(evalcond[0]) > 0.000001  || IKabs(evalcond[1]) > 0.000001  || IKabs(evalcond[2]) > 0.000001  )
{
continue;
}
}

{
IkReal dummyeval[1];
IkReal gconst41;
IkReal x606=(r21)*(r21);
IkReal x607=(cj5)*(cj5);
IkReal x608=(sj6)*(sj6);
IkReal x609=(cj6)*(cj6);
IkReal x610=(r20)*(r20);
IkReal x611=((cj6)*(r21));
IkReal x612=((IkReal(2.00000000000000))*(r20)*(sj6));
IkReal x613=((cj5)*(r22)*(sj5));
IkReal x614=((IkReal(1.00000000000000))*(x608));
IkReal x615=((IkReal(1.00000000000000))*(x609));
gconst41=IKsign(((((IkReal(-1.00000000000000))*(x606)*(x614)))+(((IkReal(-1.00000000000000))*(x610)*(x615)))+(((IkReal(-1.00000000000000))*(x607)*(x610)*(x614)))+(((IkReal(-1.00000000000000))*((r22)*(r22))*((sj5)*(sj5))))+(((IkReal(-1.00000000000000))*(x612)*(x613)))+(((IkReal(-2.00000000000000))*(x611)*(x613)))+(((IkReal(-1.00000000000000))*(x606)*(x607)*(x615)))+(((IkReal(-1.00000000000000))*(x607)*(x611)*(x612)))+(((x611)*(x612)))));
IkReal x616=(r21)*(r21);
IkReal x617=(cj5)*(cj5);
IkReal x618=(sj6)*(sj6);
IkReal x619=(cj6)*(cj6);
IkReal x620=(r20)*(r20);
IkReal x621=((cj6)*(r21));
IkReal x622=((IkReal(2.00000000000000))*(r20)*(sj6));
IkReal x623=((cj5)*(r22)*(sj5));
IkReal x624=((IkReal(1.00000000000000))*(x618));
IkReal x625=((IkReal(1.00000000000000))*(x619));
dummyeval[0]=((((IkReal(-1.00000000000000))*(x616)*(x617)*(x625)))+(((IkReal(-1.00000000000000))*(x616)*(x624)))+(((IkReal(-1.00000000000000))*(x620)*(x625)))+(((IkReal(-2.00000000000000))*(x621)*(x623)))+(((IkReal(-1.00000000000000))*((r22)*(r22))*((sj5)*(sj5))))+(((x621)*(x622)))+(((IkReal(-1.00000000000000))*(x622)*(x623)))+(((IkReal(-1.00000000000000))*(x617)*(x620)*(x624)))+(((IkReal(-1.00000000000000))*(x617)*(x621)*(x622))));
if( IKabs(dummyeval[0]) < 0.0000010000000000  )
{
{
IkReal dummyeval[1];
IkReal gconst42;
IkReal x626=(cj6)*(cj6);
IkReal x627=(sj6)*(sj6);
IkReal x628=((IkReal(1.00000000000000))*(r01));
IkReal x629=((sj0)*(sj5));
IkReal x630=((cj6)*(r22));
IkReal x631=((r21)*(sj6));
IkReal x632=((r00)*(r21));
IkReal x633=((cj0)*(sj5));
IkReal x634=((cj6)*(r20));
IkReal x635=((r22)*(sj6));
IkReal x636=((cj0)*(cj5));
IkReal x637=((IkReal(1.00000000000000))*(r10));
IkReal x638=((cj5)*(sj0));
IkReal x639=((r20)*(x627));
IkReal x640=((x626)*(x638));
gconst42=IKsign(((((r00)*(x629)*(x630)))+(((r02)*(x629)*(x631)))+(((IkReal(-1.00000000000000))*(r12)*(x631)*(x633)))+(((IkReal(-1.00000000000000))*(x628)*(x638)*(x639)))+(((r12)*(x633)*(x634)))+(((IkReal(-1.00000000000000))*(x630)*(x633)*(x637)))+(((IkReal(-1.00000000000000))*(r21)*(x626)*(x636)*(x637)))+(((IkReal(-1.00000000000000))*(r21)*(x627)*(x636)*(x637)))+(((r11)*(x633)*(x635)))+(((IkReal(-1.00000000000000))*(x628)*(x629)*(x635)))+(((IkReal(-1.00000000000000))*(r02)*(x629)*(x634)))+(((r11)*(r20)*(x626)*(x636)))+(((IkReal(-1.00000000000000))*(r20)*(x628)*(x640)))+(((x632)*(x640)))+(((r11)*(x636)*(x639)))+(((x627)*(x632)*(x638)))));
IkReal x641=(cj6)*(cj6);
IkReal x642=(sj6)*(sj6);
IkReal x643=((IkReal(1.00000000000000))*(r01));
IkReal x644=((sj0)*(sj5));
IkReal x645=((cj6)*(r22));
IkReal x646=((r21)*(sj6));
IkReal x647=((r00)*(r21));
IkReal x648=((cj0)*(sj5));
IkReal x649=((cj6)*(r20));
IkReal x650=((r22)*(sj6));
IkReal x651=((cj0)*(cj5));
IkReal x652=((IkReal(1.00000000000000))*(r10));
IkReal x653=((cj5)*(sj0));
IkReal x654=((r20)*(x642));
IkReal x655=((x641)*(x653));
dummyeval[0]=((((IkReal(-1.00000000000000))*(r02)*(x644)*(x649)))+(((IkReal(-1.00000000000000))*(r21)*(x642)*(x651)*(x652)))+(((r02)*(x644)*(x646)))+(((x642)*(x647)*(x653)))+(((IkReal(-1.00000000000000))*(x643)*(x644)*(x650)))+(((IkReal(-1.00000000000000))*(r20)*(x643)*(x655)))+(((IkReal(-1.00000000000000))*(x643)*(x653)*(x654)))+(((IkReal(-1.00000000000000))*(x645)*(x648)*(x652)))+(((r11)*(r20)*(x641)*(x651)))+(((r00)*(x644)*(x645)))+(((x647)*(x655)))+(((IkReal(-1.00000000000000))*(r21)*(x641)*(x651)*(x652)))+(((IkReal(-1.00000000000000))*(r12)*(x646)*(x648)))+(((r11)*(x648)*(x650)))+(((r12)*(x648)*(x649)))+(((r11)*(x651)*(x654))));
if( IKabs(dummyeval[0]) < 0.0000010000000000  )
{
continue;

} else
{
{
IkReal j4array[1], cj4array[1], sj4array[1];
bool j4valid[1]={false};
_nj4 = 1;
IkReal x656=((r01)*(sj0));
IkReal x657=((cj2)*(sj6));
IkReal x658=((IkReal(1.00000000000000))*(cj0));
IkReal x659=((r10)*(sj2));
IkReal x660=((sj2)*(sj5));
IkReal x661=((cj5)*(sj6));
IkReal x662=((sj2)*(sj6));
IkReal x663=((cj2)*(cj6));
IkReal x664=((cj5)*(cj6)*(sj2));
IkReal x665=((r00)*(sj0)*(sj2));
if( IKabs(((gconst42)*(((((cj6)*(x665)))+(((r20)*(x663)))+(((cj0)*(r11)*(x662)))+(((IkReal(-1.00000000000000))*(r21)*(x657)))+(((IkReal(-1.00000000000000))*(cj6)*(x658)*(x659)))+(((IkReal(-1.00000000000000))*(x656)*(x662))))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(((gconst42)*(((((cj2)*(r22)*(sj5)))+(((x656)*(x664)))+(((x661)*(x665)))+(((IkReal(-1.00000000000000))*(x658)*(x659)*(x661)))+(((cj5)*(r21)*(x663)))+(((IkReal(-1.00000000000000))*(r11)*(x658)*(x664)))+(((r02)*(sj0)*(x660)))+(((cj5)*(r20)*(x657)))+(((IkReal(-1.00000000000000))*(r12)*(x658)*(x660))))))) < IKFAST_ATAN2_MAGTHRESH )
    continue;
j4array[0]=IKatan2(((gconst42)*(((((cj6)*(x665)))+(((r20)*(x663)))+(((cj0)*(r11)*(x662)))+(((IkReal(-1.00000000000000))*(r21)*(x657)))+(((IkReal(-1.00000000000000))*(cj6)*(x658)*(x659)))+(((IkReal(-1.00000000000000))*(x656)*(x662)))))), ((gconst42)*(((((cj2)*(r22)*(sj5)))+(((x656)*(x664)))+(((x661)*(x665)))+(((IkReal(-1.00000000000000))*(x658)*(x659)*(x661)))+(((cj5)*(r21)*(x663)))+(((IkReal(-1.00000000000000))*(r11)*(x658)*(x664)))+(((r02)*(sj0)*(x660)))+(((cj5)*(r20)*(x657)))+(((IkReal(-1.00000000000000))*(r12)*(x658)*(x660)))))));
sj4array[0]=IKsin(j4array[0]);
cj4array[0]=IKcos(j4array[0]);
if( j4array[0] > IKPI )
{
    j4array[0]-=IK2PI;
}
else if( j4array[0] < -IKPI )
{    j4array[0]+=IK2PI;
}
j4valid[0] = true;
for(int ij4 = 0; ij4 < 1; ++ij4)
{
if( !j4valid[ij4] )
{
    continue;
}
_ij4[0] = ij4; _ij4[1] = -1;
for(int iij4 = ij4+1; iij4 < 1; ++iij4)
{
if( j4valid[iij4] && IKabs(cj4array[ij4]-cj4array[iij4]) < IKFAST_SOLUTION_THRESH && IKabs(sj4array[ij4]-sj4array[iij4]) < IKFAST_SOLUTION_THRESH )
{
    j4valid[iij4]=false; _ij4[1] = iij4; break; 
}
}
j4 = j4array[ij4]; cj4 = cj4array[ij4]; sj4 = sj4array[ij4];
{
IkReal evalcond[6];
IkReal x666=IKsin(j4);
IkReal x667=IKcos(j4);
IkReal x668=((r00)*(sj6));
IkReal x669=((IkReal(1.00000000000000))*(r12));
IkReal x670=((IkReal(1.00000000000000))*(cj6));
IkReal x671=((cj6)*(r01));
IkReal x672=((r11)*(sj6));
IkReal x673=((r01)*(sj6));
IkReal x674=((IkReal(1.00000000000000))*(cj5));
IkReal x675=((IkReal(1.00000000000000))*(sj6));
IkReal x676=((cj5)*(sj6));
IkReal x677=((cj5)*(r11));
IkReal x678=((cj6)*(r00));
IkReal x679=((cj5)*(cj6));
IkReal x680=((r02)*(sj5));
IkReal x681=((cj6)*(r10));
IkReal x682=((r10)*(sj6));
IkReal x683=((cj5)*(r01));
IkReal x684=((sj5)*(x666));
IkReal x685=((cj0)*(x667));
IkReal x686=((cj0)*(x666));
IkReal x687=((sj0)*(x667));
IkReal x688=((sj0)*(x666));
IkReal x689=((r20)*(x667));
IkReal x690=((r21)*(x666));
IkReal x691=((r21)*(x667));
IkReal x692=((r20)*(x666));
IkReal x693=((cj5)*(x688));
evalcond[0]=((((sj6)*(x691)))+(((IkReal(-1.00000000000000))*(sj2)))+(((IkReal(-1.00000000000000))*(x670)*(x689)))+(((r22)*(x684)))+(((x679)*(x690)))+(((x676)*(x692))));
evalcond[1]=((((cj6)*(x692)))+(((x679)*(x691)))+(((cj2)*(cj3)))+(((r22)*(sj5)*(x667)))+(((x676)*(x689)))+(((IkReal(-1.00000000000000))*(x675)*(x690))));
evalcond[2]=((((IkReal(-1.00000000000000))*(cj0)*(x669)*(x684)))+(((x681)*(x685)))+(((x680)*(x688)))+(((x668)*(x693)))+(((IkReal(-1.00000000000000))*(r00)*(x670)*(x687)))+(((x673)*(x687)))+(((IkReal(-1.00000000000000))*(x670)*(x677)*(x686)))+(((x671)*(x693)))+(cj2)+(((IkReal(-1.00000000000000))*(x674)*(x682)*(x686)))+(((IkReal(-1.00000000000000))*(x672)*(x685))));
evalcond[3]=((((x680)*(x687)))+(((cj5)*(x668)*(x687)))+(((IkReal(-1.00000000000000))*(x673)*(x688)))+(((IkReal(-1.00000000000000))*(x670)*(x677)*(x685)))+(((IkReal(-1.00000000000000))*(r10)*(x670)*(x686)))+(((x678)*(x688)))+(((x672)*(x686)))+(((IkReal(-1.00000000000000))*(sj5)*(x669)*(x685)))+(((cj5)*(x671)*(x687)))+(((IkReal(-1.00000000000000))*(x674)*(x682)*(x685)))+(((cj3)*(sj2))));
evalcond[4]=((((IkReal(-1.00000000000000))*(x680)*(x686)))+(((IkReal(-1.00000000000000))*(x668)*(x674)*(x686)))+(((IkReal(-1.00000000000000))*(x670)*(x677)*(x688)))+(((IkReal(-1.00000000000000))*(x670)*(x683)*(x686)))+(((IkReal(-1.00000000000000))*(sj0)*(x669)*(x684)))+(((IkReal(-1.00000000000000))*(x672)*(x687)))+(((x681)*(x687)))+(((IkReal(-1.00000000000000))*(x674)*(x682)*(x688)))+(((IkReal(-1.00000000000000))*(x673)*(x685)))+(((x678)*(x685))));
evalcond[5]=((((IkReal(-1.00000000000000))*(x674)*(x682)*(x687)))+(((IkReal(-1.00000000000000))*(x680)*(x685)))+(((IkReal(-1.00000000000000))*(sj5)*(x669)*(x687)))+(((x673)*(x686)))+(((IkReal(-1.00000000000000))*(r00)*(x670)*(x686)))+(((IkReal(-1.00000000000000))*(x670)*(x677)*(x687)))+(((IkReal(-1.00000000000000))*(x668)*(x674)*(x685)))+(((x672)*(x688)))+(((IkReal(-1.00000000000000))*(x670)*(x683)*(x685)))+(((IkReal(-1.00000000000000))*(sj3)))+(((IkReal(-1.00000000000000))*(r10)*(x670)*(x688))));
if( IKabs(evalcond[0]) > 0.000001  || IKabs(evalcond[1]) > 0.000001  || IKabs(evalcond[2]) > 0.000001  || IKabs(evalcond[3]) > 0.000001  || IKabs(evalcond[4]) > 0.000001  || IKabs(evalcond[5]) > 0.000001  )
{
continue;
}
}

{
std::vector<IkSingleDOFSolutionBase<IkReal> > vinfos(7);
vinfos[0].jointtype = 1;
vinfos[0].foffset = j0;
vinfos[0].indices[0] = _ij0[0];
vinfos[0].indices[1] = _ij0[1];
vinfos[0].maxsolutions = _nj0;
vinfos[1].jointtype = 1;
vinfos[1].foffset = j1;
vinfos[1].indices[0] = _ij1[0];
vinfos[1].indices[1] = _ij1[1];
vinfos[1].maxsolutions = _nj1;
vinfos[2].jointtype = 1;
vinfos[2].foffset = j2;
vinfos[2].indices[0] = _ij2[0];
vinfos[2].indices[1] = _ij2[1];
vinfos[2].maxsolutions = _nj2;
vinfos[3].jointtype = 1;
vinfos[3].foffset = j3;
vinfos[3].indices[0] = _ij3[0];
vinfos[3].indices[1] = _ij3[1];
vinfos[3].maxsolutions = _nj3;
vinfos[4].jointtype = 1;
vinfos[4].foffset = j4;
vinfos[4].indices[0] = _ij4[0];
vinfos[4].indices[1] = _ij4[1];
vinfos[4].maxsolutions = _nj4;
vinfos[5].jointtype = 1;
vinfos[5].foffset = j5;
vinfos[5].indices[0] = _ij5[0];
vinfos[5].indices[1] = _ij5[1];
vinfos[5].maxsolutions = _nj5;
vinfos[6].jointtype = 1;
vinfos[6].foffset = j6;
vinfos[6].indices[0] = _ij6[0];
vinfos[6].indices[1] = _ij6[1];
vinfos[6].maxsolutions = _nj6;
std::vector<int> vfree(0);
solutions.AddSolution(vinfos,vfree);
}
}
}

}

}

} else
{
{
IkReal j4array[1], cj4array[1], sj4array[1];
bool j4valid[1]={false};
_nj4 = 1;
IkReal x694=((IkReal(1.00000000000000))*(sj2));
IkReal x695=((r22)*(sj5));
IkReal x696=((cj5)*(sj6));
IkReal x697=((cj2)*(cj3));
IkReal x698=((r21)*(sj6));
IkReal x699=((r20)*(x697));
IkReal x700=((cj5)*(cj6)*(r21));
if( IKabs(((gconst41)*(((((cj6)*(x699)))+(((IkReal(-1.00000000000000))*(x697)*(x698)))+(((IkReal(-1.00000000000000))*(r20)*(x694)*(x696)))+(((IkReal(-1.00000000000000))*(x694)*(x695)))+(((IkReal(-1.00000000000000))*(x694)*(x700))))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(((gconst41)*(((((x697)*(x700)))+(((cj6)*(r20)*(sj2)))+(((IkReal(-1.00000000000000))*(x694)*(x698)))+(((x696)*(x699)))+(((x695)*(x697))))))) < IKFAST_ATAN2_MAGTHRESH )
    continue;
j4array[0]=IKatan2(((gconst41)*(((((cj6)*(x699)))+(((IkReal(-1.00000000000000))*(x697)*(x698)))+(((IkReal(-1.00000000000000))*(r20)*(x694)*(x696)))+(((IkReal(-1.00000000000000))*(x694)*(x695)))+(((IkReal(-1.00000000000000))*(x694)*(x700)))))), ((gconst41)*(((((x697)*(x700)))+(((cj6)*(r20)*(sj2)))+(((IkReal(-1.00000000000000))*(x694)*(x698)))+(((x696)*(x699)))+(((x695)*(x697)))))));
sj4array[0]=IKsin(j4array[0]);
cj4array[0]=IKcos(j4array[0]);
if( j4array[0] > IKPI )
{
    j4array[0]-=IK2PI;
}
else if( j4array[0] < -IKPI )
{    j4array[0]+=IK2PI;
}
j4valid[0] = true;
for(int ij4 = 0; ij4 < 1; ++ij4)
{
if( !j4valid[ij4] )
{
    continue;
}
_ij4[0] = ij4; _ij4[1] = -1;
for(int iij4 = ij4+1; iij4 < 1; ++iij4)
{
if( j4valid[iij4] && IKabs(cj4array[ij4]-cj4array[iij4]) < IKFAST_SOLUTION_THRESH && IKabs(sj4array[ij4]-sj4array[iij4]) < IKFAST_SOLUTION_THRESH )
{
    j4valid[iij4]=false; _ij4[1] = iij4; break; 
}
}
j4 = j4array[ij4]; cj4 = cj4array[ij4]; sj4 = sj4array[ij4];
{
IkReal evalcond[6];
IkReal x701=IKsin(j4);
IkReal x702=IKcos(j4);
IkReal x703=((r00)*(sj6));
IkReal x704=((IkReal(1.00000000000000))*(r12));
IkReal x705=((IkReal(1.00000000000000))*(cj6));
IkReal x706=((cj6)*(r01));
IkReal x707=((r11)*(sj6));
IkReal x708=((r01)*(sj6));
IkReal x709=((IkReal(1.00000000000000))*(cj5));
IkReal x710=((IkReal(1.00000000000000))*(sj6));
IkReal x711=((cj5)*(sj6));
IkReal x712=((cj5)*(r11));
IkReal x713=((cj6)*(r00));
IkReal x714=((cj5)*(cj6));
IkReal x715=((r02)*(sj5));
IkReal x716=((cj6)*(r10));
IkReal x717=((r10)*(sj6));
IkReal x718=((cj5)*(r01));
IkReal x719=((sj5)*(x701));
IkReal x720=((cj0)*(x702));
IkReal x721=((cj0)*(x701));
IkReal x722=((sj0)*(x702));
IkReal x723=((sj0)*(x701));
IkReal x724=((r20)*(x702));
IkReal x725=((r21)*(x701));
IkReal x726=((r21)*(x702));
IkReal x727=((r20)*(x701));
IkReal x728=((cj5)*(x723));
evalcond[0]=((((sj6)*(x726)))+(((r22)*(x719)))+(((IkReal(-1.00000000000000))*(sj2)))+(((x711)*(x727)))+(((x714)*(x725)))+(((IkReal(-1.00000000000000))*(x705)*(x724))));
evalcond[1]=((((x714)*(x726)))+(((cj2)*(cj3)))+(((IkReal(-1.00000000000000))*(x710)*(x725)))+(((r22)*(sj5)*(x702)))+(((x711)*(x724)))+(((cj6)*(x727))));
evalcond[2]=((((x715)*(x723)))+(((x703)*(x728)))+(((x708)*(x722)))+(((x706)*(x728)))+(((x716)*(x720)))+(cj2)+(((IkReal(-1.00000000000000))*(x705)*(x712)*(x721)))+(((IkReal(-1.00000000000000))*(cj0)*(x704)*(x719)))+(((IkReal(-1.00000000000000))*(r00)*(x705)*(x722)))+(((IkReal(-1.00000000000000))*(x709)*(x717)*(x721)))+(((IkReal(-1.00000000000000))*(x707)*(x720))));
evalcond[3]=((((x715)*(x722)))+(((IkReal(-1.00000000000000))*(r10)*(x705)*(x721)))+(((x707)*(x721)))+(((cj5)*(x706)*(x722)))+(((cj5)*(x703)*(x722)))+(((IkReal(-1.00000000000000))*(x709)*(x717)*(x720)))+(((x713)*(x723)))+(((IkReal(-1.00000000000000))*(x705)*(x712)*(x720)))+(((cj3)*(sj2)))+(((IkReal(-1.00000000000000))*(sj5)*(x704)*(x720)))+(((IkReal(-1.00000000000000))*(x708)*(x723))));
evalcond[4]=((((IkReal(-1.00000000000000))*(x709)*(x717)*(x723)))+(((IkReal(-1.00000000000000))*(x703)*(x709)*(x721)))+(((IkReal(-1.00000000000000))*(sj0)*(x704)*(x719)))+(((IkReal(-1.00000000000000))*(x715)*(x721)))+(((IkReal(-1.00000000000000))*(x708)*(x720)))+(((x713)*(x720)))+(((x716)*(x722)))+(((IkReal(-1.00000000000000))*(x705)*(x718)*(x721)))+(((IkReal(-1.00000000000000))*(x707)*(x722)))+(((IkReal(-1.00000000000000))*(x705)*(x712)*(x723))));
evalcond[5]=((((IkReal(-1.00000000000000))*(x715)*(x720)))+(((IkReal(-1.00000000000000))*(r00)*(x705)*(x721)))+(((IkReal(-1.00000000000000))*(r10)*(x705)*(x723)))+(((x707)*(x723)))+(((IkReal(-1.00000000000000))*(x705)*(x718)*(x720)))+(((IkReal(-1.00000000000000))*(x703)*(x709)*(x720)))+(((IkReal(-1.00000000000000))*(x705)*(x712)*(x722)))+(((IkReal(-1.00000000000000))*(x709)*(x717)*(x722)))+(((IkReal(-1.00000000000000))*(sj3)))+(((x708)*(x721)))+(((IkReal(-1.00000000000000))*(sj5)*(x704)*(x722))));
if( IKabs(evalcond[0]) > 0.000001  || IKabs(evalcond[1]) > 0.000001  || IKabs(evalcond[2]) > 0.000001  || IKabs(evalcond[3]) > 0.000001  || IKabs(evalcond[4]) > 0.000001  || IKabs(evalcond[5]) > 0.000001  )
{
continue;
}
}

{
std::vector<IkSingleDOFSolutionBase<IkReal> > vinfos(7);
vinfos[0].jointtype = 1;
vinfos[0].foffset = j0;
vinfos[0].indices[0] = _ij0[0];
vinfos[0].indices[1] = _ij0[1];
vinfos[0].maxsolutions = _nj0;
vinfos[1].jointtype = 1;
vinfos[1].foffset = j1;
vinfos[1].indices[0] = _ij1[0];
vinfos[1].indices[1] = _ij1[1];
vinfos[1].maxsolutions = _nj1;
vinfos[2].jointtype = 1;
vinfos[2].foffset = j2;
vinfos[2].indices[0] = _ij2[0];
vinfos[2].indices[1] = _ij2[1];
vinfos[2].maxsolutions = _nj2;
vinfos[3].jointtype = 1;
vinfos[3].foffset = j3;
vinfos[3].indices[0] = _ij3[0];
vinfos[3].indices[1] = _ij3[1];
vinfos[3].maxsolutions = _nj3;
vinfos[4].jointtype = 1;
vinfos[4].foffset = j4;
vinfos[4].indices[0] = _ij4[0];
vinfos[4].indices[1] = _ij4[1];
vinfos[4].maxsolutions = _nj4;
vinfos[5].jointtype = 1;
vinfos[5].foffset = j5;
vinfos[5].indices[0] = _ij5[0];
vinfos[5].indices[1] = _ij5[1];
vinfos[5].maxsolutions = _nj5;
vinfos[6].jointtype = 1;
vinfos[6].foffset = j6;
vinfos[6].indices[0] = _ij6[0];
vinfos[6].indices[1] = _ij6[1];
vinfos[6].maxsolutions = _nj6;
std::vector<int> vfree(0);
solutions.AddSolution(vinfos,vfree);
}
}
}

}

}
}
}

}

}

} else
{
{
IkReal j4array[1], cj4array[1], sj4array[1];
bool j4valid[1]={false};
_nj4 = 1;
IkReal x729=((r01)*(sj0));
IkReal x730=((IkReal(1.00000000000000))*(cj0));
IkReal x731=((r10)*(sj2));
IkReal x732=((sj2)*(sj5));
IkReal x733=((IkReal(1.00000000000000))*(sj6));
IkReal x734=((cj2)*(r21));
IkReal x735=((cj5)*(sj6));
IkReal x736=((cj2)*(r20));
IkReal x737=((cj5)*(cj6)*(sj2));
IkReal x738=((r00)*(sj0)*(sj2));
if( IKabs(((gconst39)*(((((cj6)*(x736)))+(((cj6)*(x738)))+(((cj0)*(r11)*(sj2)*(sj6)))+(((IkReal(-1.00000000000000))*(x733)*(x734)))+(((IkReal(-1.00000000000000))*(sj2)*(x729)*(x733)))+(((IkReal(-1.00000000000000))*(cj6)*(x730)*(x731))))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(((gconst39)*(((((cj2)*(r22)*(sj5)))+(((x729)*(x737)))+(((IkReal(-1.00000000000000))*(r12)*(x730)*(x732)))+(((x735)*(x738)))+(((IkReal(-1.00000000000000))*(r11)*(x730)*(x737)))+(((x735)*(x736)))+(((r02)*(sj0)*(x732)))+(((IkReal(-1.00000000000000))*(x730)*(x731)*(x735)))+(((cj5)*(cj6)*(x734))))))) < IKFAST_ATAN2_MAGTHRESH )
    continue;
j4array[0]=IKatan2(((gconst39)*(((((cj6)*(x736)))+(((cj6)*(x738)))+(((cj0)*(r11)*(sj2)*(sj6)))+(((IkReal(-1.00000000000000))*(x733)*(x734)))+(((IkReal(-1.00000000000000))*(sj2)*(x729)*(x733)))+(((IkReal(-1.00000000000000))*(cj6)*(x730)*(x731)))))), ((gconst39)*(((((cj2)*(r22)*(sj5)))+(((x729)*(x737)))+(((IkReal(-1.00000000000000))*(r12)*(x730)*(x732)))+(((x735)*(x738)))+(((IkReal(-1.00000000000000))*(r11)*(x730)*(x737)))+(((x735)*(x736)))+(((r02)*(sj0)*(x732)))+(((IkReal(-1.00000000000000))*(x730)*(x731)*(x735)))+(((cj5)*(cj6)*(x734)))))));
sj4array[0]=IKsin(j4array[0]);
cj4array[0]=IKcos(j4array[0]);
if( j4array[0] > IKPI )
{
    j4array[0]-=IK2PI;
}
else if( j4array[0] < -IKPI )
{    j4array[0]+=IK2PI;
}
j4valid[0] = true;
for(int ij4 = 0; ij4 < 1; ++ij4)
{
if( !j4valid[ij4] )
{
    continue;
}
_ij4[0] = ij4; _ij4[1] = -1;
for(int iij4 = ij4+1; iij4 < 1; ++iij4)
{
if( j4valid[iij4] && IKabs(cj4array[ij4]-cj4array[iij4]) < IKFAST_SOLUTION_THRESH && IKabs(sj4array[ij4]-sj4array[iij4]) < IKFAST_SOLUTION_THRESH )
{
    j4valid[iij4]=false; _ij4[1] = iij4; break; 
}
}
j4 = j4array[ij4]; cj4 = cj4array[ij4]; sj4 = sj4array[ij4];
{
IkReal evalcond[3];
IkReal x739=IKsin(j4);
IkReal x740=IKcos(j4);
IkReal x741=((r00)*(sj6));
IkReal x742=((cj6)*(r01));
IkReal x743=((IkReal(1.00000000000000))*(cj0));
IkReal x744=((IkReal(1.00000000000000))*(sj0));
IkReal x745=((r10)*(sj6));
IkReal x746=((sj5)*(x739));
IkReal x747=((IkReal(1.00000000000000))*(cj6)*(r11));
IkReal x748=((cj5)*(x739));
IkReal x749=((cj6)*(x740));
IkReal x750=((sj0)*(x748));
IkReal x751=((r01)*(sj6)*(x740));
IkReal x752=((r11)*(sj6)*(x740));
evalcond[0]=((((r20)*(sj6)*(x748)))+(((IkReal(-1.00000000000000))*(sj2)))+(((r21)*(sj6)*(x740)))+(((r22)*(x746)))+(((IkReal(-1.00000000000000))*(r20)*(x749)))+(((cj6)*(r21)*(x748))));
evalcond[1]=((((IkReal(-1.00000000000000))*(r12)*(x743)*(x746)))+(((sj0)*(x751)))+(((IkReal(-1.00000000000000))*(x743)*(x752)))+(((IkReal(-1.00000000000000))*(x743)*(x745)*(x748)))+(cj2)+(((x742)*(x750)))+(((x741)*(x750)))+(((IkReal(-1.00000000000000))*(cj6)*(r11)*(x743)*(x748)))+(((IkReal(-1.00000000000000))*(r00)*(x744)*(x749)))+(((cj0)*(r10)*(x749)))+(((r02)*(sj0)*(x746))));
evalcond[2]=((((IkReal(-1.00000000000000))*(x744)*(x745)*(x748)))+(((IkReal(-1.00000000000000))*(x742)*(x743)*(x748)))+(((IkReal(-1.00000000000000))*(r02)*(x743)*(x746)))+(((IkReal(-1.00000000000000))*(x744)*(x752)))+(((cj0)*(r00)*(x749)))+(((IkReal(-1.00000000000000))*(r12)*(x744)*(x746)))+(((IkReal(-1.00000000000000))*(cj6)*(r11)*(x744)*(x748)))+(((IkReal(-1.00000000000000))*(x741)*(x743)*(x748)))+(((r10)*(sj0)*(x749)))+(((IkReal(-1.00000000000000))*(x743)*(x751))));
if( IKabs(evalcond[0]) > 0.000001  || IKabs(evalcond[1]) > 0.000001  || IKabs(evalcond[2]) > 0.000001  )
{
continue;
}
}

{
IkReal dummyeval[1];
IkReal gconst43;
gconst43=IKsign(cj2);
dummyeval[0]=cj2;
if( IKabs(dummyeval[0]) < 0.0000010000000000  )
{
{
IkReal dummyeval[1];
dummyeval[0]=cj2;
if( IKabs(dummyeval[0]) < 0.0000010000000000  )
{
{
IkReal dummyeval[1];
dummyeval[0]=sj2;
if( IKabs(dummyeval[0]) < 0.0000010000000000  )
{
{
IkReal evalcond[9];
IkReal x753=((cj5)*(sj4));
IkReal x754=((IkReal(1.00000000000000))*(sj6));
IkReal x755=((r10)*(sj0));
IkReal x756=((sj4)*(sj5));
IkReal x757=((cj5)*(cj6));
IkReal x758=((r01)*(sj0));
IkReal x759=((IkReal(1.00000000000000))*(r02));
IkReal x760=((IkReal(0.374290000000000))*(cj0));
IkReal x761=((cj5)*(r12));
IkReal x762=((cj6)*(sj5));
IkReal x763=((cj0)*(r11));
IkReal x764=((cj5)*(sj0));
IkReal x765=((r20)*(sj6));
IkReal x766=((IkReal(1.00000000000000))*(sj0));
IkReal x767=((cj4)*(cj5));
IkReal x768=((IkReal(1.00000000000000))*(cj6));
IkReal x769=((IkReal(0.0100000000000000))*(sj5));
IkReal x770=((sj5)*(sj6));
IkReal x771=((cj0)*(r10));
IkReal x772=((cj4)*(cj6));
IkReal x773=((cj0)*(r01));
IkReal x774=((IkReal(1.00000000000000))*(cj4));
IkReal x775=((cj0)*(r00));
IkReal x776=((IkReal(0.374290000000000))*(sj0));
IkReal x777=((cj0)*(r12));
IkReal x778=((IkReal(0.374290000000000))*(sj5));
IkReal x779=((cj4)*(sj6));
IkReal x780=((IkReal(1.00000000000000))*(cj0));
IkReal x781=((r02)*(sj0));
IkReal x782=((IkReal(0.0100000000000000))*(cj5));
IkReal x783=((r11)*(sj0));
IkReal x784=((r00)*(sj0)*(sj6));
IkReal x785=((r00)*(x772));
IkReal x786=((sj6)*(x782));
evalcond[0]=((IkReal(-3.14159265358979))+(IKfmod(((IkReal(3.14159265358979))+(j2)), IkReal(6.28318530717959))));
evalcond[1]=((((r22)*(x756)))+(((cj6)*(r21)*(x753)))+(((x753)*(x765)))+(((IkReal(-1.00000000000000))*(cj4)*(r20)*(x768)))+(((r21)*(x779))));
evalcond[2]=((IkReal(0.0690000000000000))+(((IkReal(-1.00000000000000))*(r22)*(x769)))+(((IkReal(-0.0100000000000000))*(r21)*(x757)))+(((IkReal(-1.00000000000000))*(x765)*(x782)))+(((IkReal(0.374290000000000))*(r21)*(x762)))+(((IkReal(-0.374290000000000))*(cj5)*(r22)))+(pz)+(((x765)*(x778))));
evalcond[3]=((((cj0)*(x761)))+(((x758)*(x762)))+(((IkReal(-1.00000000000000))*(x762)*(x763)))+(((IkReal(-1.00000000000000))*(x759)*(x764)))+(((IkReal(-1.00000000000000))*(sj5)*(x754)*(x771)))+(((r00)*(sj0)*(x770))));
evalcond[4]=((IkReal(1.00000000000000))+(((IkReal(-1.00000000000000))*(x753)*(x763)*(x768)))+(((x753)*(x784)))+(((IkReal(-1.00000000000000))*(cj4)*(x754)*(x763)))+(((cj6)*(x753)*(x758)))+(((IkReal(-1.00000000000000))*(x753)*(x754)*(x771)))+(((x756)*(x781)))+(((IkReal(-1.00000000000000))*(x766)*(x785)))+(((x771)*(x772)))+(((x758)*(x779)))+(((IkReal(-1.00000000000000))*(x756)*(x777))));
evalcond[5]=((((sj4)*(sj6)*(x763)))+(((IkReal(-1.00000000000000))*(sj4)*(x754)*(x758)))+(((IkReal(-1.00000000000000))*(sj5)*(x774)*(x777)))+(((r00)*(x764)*(x779)))+(((cj6)*(r00)*(sj0)*(sj4)))+(((cj4)*(sj5)*(x781)))+(((IkReal(-1.00000000000000))*(sj4)*(x768)*(x771)))+(((IkReal(-1.00000000000000))*(x754)*(x767)*(x771)))+(((cj4)*(x757)*(x758)))+(((IkReal(-1.00000000000000))*(x757)*(x763)*(x774))));
evalcond[6]=((((x755)*(x772)))+(((IkReal(-1.00000000000000))*(x753)*(x754)*(x775)))+(((IkReal(-1.00000000000000))*(cj6)*(r11)*(x753)*(x766)))+(((x772)*(x775)))+(((IkReal(-1.00000000000000))*(cj4)*(x754)*(x783)))+(((IkReal(-1.00000000000000))*(x753)*(x768)*(x773)))+(((IkReal(-1.00000000000000))*(x753)*(x754)*(x755)))+(((IkReal(-1.00000000000000))*(cj0)*(x756)*(x759)))+(((IkReal(-1.00000000000000))*(cj4)*(x754)*(x773)))+(((IkReal(-1.00000000000000))*(r12)*(x756)*(x766))));
evalcond[7]=((((IkReal(-0.0100000000000000))*(x757)*(x758)))+(((IkReal(0.374290000000000))*(x758)*(x762)))+(((x769)*(x777)))+(((IkReal(-1.00000000000000))*(r11)*(x760)*(x762)))+(((IkReal(-0.0100000000000000))*(r00)*(sj6)*(x764)))+(((IkReal(-1.00000000000000))*(py)*(x780)))+(((IkReal(-1.00000000000000))*(x769)*(x781)))+(((x760)*(x761)))+(((r00)*(x770)*(x776)))+(((x771)*(x786)))+(((IkReal(0.0100000000000000))*(x757)*(x763)))+(((IkReal(-1.00000000000000))*(r10)*(x760)*(x770)))+(((px)*(sj0)))+(((IkReal(-0.374290000000000))*(r02)*(x764))));
evalcond[8]=((IkReal(0.433420000000000))+(((x755)*(x786)))+(((x775)*(x786)))+(((IkReal(-0.374290000000000))*(x755)*(x770)))+(((IkReal(-1.00000000000000))*(r11)*(x762)*(x776)))+(((IkReal(-1.00000000000000))*(py)*(x766)))+(((IkReal(0.0100000000000000))*(x757)*(x773)))+(((x761)*(x776)))+(((cj0)*(r02)*(x769)))+(((IkReal(0.0100000000000000))*(x757)*(x783)))+(((IkReal(-1.00000000000000))*(r01)*(x760)*(x762)))+(((IkReal(-1.00000000000000))*(px)*(x780)))+(((cj5)*(r02)*(x760)))+(((r12)*(sj0)*(x769)))+(((IkReal(-1.00000000000000))*(r00)*(x760)*(x770))));
if( IKabs(evalcond[0]) < 0.0000010000000000  && IKabs(evalcond[1]) < 0.0000010000000000  && IKabs(evalcond[2]) < 0.0000010000000000  && IKabs(evalcond[3]) < 0.0000010000000000  && IKabs(evalcond[4]) < 0.0000010000000000  && IKabs(evalcond[5]) < 0.0000010000000000  && IKabs(evalcond[6]) < 0.0000010000000000  && IKabs(evalcond[7]) < 0.0000010000000000  && IKabs(evalcond[8]) < 0.0000010000000000  )
{
{
IkReal j3array[1], cj3array[1], sj3array[1];
bool j3valid[1]={false};
_nj3 = 1;
IkReal x787=((IkReal(1.00000000000000))*(cj4));
IkReal x788=((cj6)*(r21));
IkReal x789=((r20)*(sj6));
if( IKabs(((((IkReal(-1.00000000000000))*(cj5)*(r22)))+(((sj5)*(x788)))+(((sj5)*(x789))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(((((IkReal(-1.00000000000000))*(cj5)*(x787)*(x788)))+(((r21)*(sj4)*(sj6)))+(((IkReal(-1.00000000000000))*(cj5)*(x787)*(x789)))+(((IkReal(-1.00000000000000))*(r22)*(sj5)*(x787)))+(((IkReal(-1.00000000000000))*(cj6)*(r20)*(sj4))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(IKsqr(((((IkReal(-1.00000000000000))*(cj5)*(r22)))+(((sj5)*(x788)))+(((sj5)*(x789)))))+IKsqr(((((IkReal(-1.00000000000000))*(cj5)*(x787)*(x788)))+(((r21)*(sj4)*(sj6)))+(((IkReal(-1.00000000000000))*(cj5)*(x787)*(x789)))+(((IkReal(-1.00000000000000))*(r22)*(sj5)*(x787)))+(((IkReal(-1.00000000000000))*(cj6)*(r20)*(sj4)))))-1) <= IKFAST_SINCOS_THRESH )
    continue;
j3array[0]=IKatan2(((((IkReal(-1.00000000000000))*(cj5)*(r22)))+(((sj5)*(x788)))+(((sj5)*(x789)))), ((((IkReal(-1.00000000000000))*(cj5)*(x787)*(x788)))+(((r21)*(sj4)*(sj6)))+(((IkReal(-1.00000000000000))*(cj5)*(x787)*(x789)))+(((IkReal(-1.00000000000000))*(r22)*(sj5)*(x787)))+(((IkReal(-1.00000000000000))*(cj6)*(r20)*(sj4)))));
sj3array[0]=IKsin(j3array[0]);
cj3array[0]=IKcos(j3array[0]);
if( j3array[0] > IKPI )
{
    j3array[0]-=IK2PI;
}
else if( j3array[0] < -IKPI )
{    j3array[0]+=IK2PI;
}
j3valid[0] = true;
for(int ij3 = 0; ij3 < 1; ++ij3)
{
if( !j3valid[ij3] )
{
    continue;
}
_ij3[0] = ij3; _ij3[1] = -1;
for(int iij3 = ij3+1; iij3 < 1; ++iij3)
{
if( j3valid[iij3] && IKabs(cj3array[ij3]-cj3array[iij3]) < IKFAST_SOLUTION_THRESH && IKabs(sj3array[ij3]-sj3array[iij3]) < IKFAST_SOLUTION_THRESH )
{
    j3valid[iij3]=false; _ij3[1] = iij3; break; 
}
}
j3 = j3array[ij3]; cj3 = cj3array[ij3]; sj3 = sj3array[ij3];
{
IkReal evalcond[4];
IkReal x790=IKcos(j3);
IkReal x791=((IkReal(1.00000000000000))*(cj4));
IkReal x792=((sj0)*(sj5));
IkReal x793=((cj0)*(cj5));
IkReal x794=((cj6)*(r01));
IkReal x795=((r00)*(sj6));
IkReal x796=((cj6)*(r11));
IkReal x797=((cj5)*(sj0));
IkReal x798=((cj6)*(sj4));
IkReal x799=((sj4)*(sj6));
IkReal x800=((cj4)*(cj5));
IkReal x801=((cj6)*(r21));
IkReal x802=((r20)*(sj6));
IkReal x803=((r10)*(sj6));
IkReal x804=((IkReal(1.00000000000000))*(IKsin(j3)));
IkReal x805=((IkReal(1.00000000000000))*(cj0)*(sj5));
evalcond[0]=((((IkReal(-1.00000000000000))*(x804)))+(((IkReal(-1.00000000000000))*(cj5)*(r22)))+(((sj5)*(x801)))+(((sj5)*(x802))));
evalcond[1]=((((x800)*(x801)))+(((r20)*(x798)))+(((x800)*(x802)))+(((cj4)*(r22)*(sj5)))+(x790)+(((IkReal(-1.00000000000000))*(r21)*(x799))));
evalcond[2]=((((IkReal(-1.00000000000000))*(x792)*(x803)))+(((r12)*(x797)))+(((r02)*(x793)))+(((IkReal(-1.00000000000000))*(x794)*(x805)))+(((IkReal(-1.00000000000000))*(x792)*(x796)))+(((IkReal(-1.00000000000000))*(x790)))+(((IkReal(-1.00000000000000))*(x795)*(x805))));
evalcond[3]=((((r11)*(sj0)*(x799)))+(((IkReal(-1.00000000000000))*(x791)*(x797)*(x803)))+(((IkReal(-1.00000000000000))*(x791)*(x793)*(x794)))+(((IkReal(-1.00000000000000))*(x804)))+(((IkReal(-1.00000000000000))*(cj0)*(r02)*(sj5)*(x791)))+(((IkReal(-1.00000000000000))*(r12)*(x791)*(x792)))+(((IkReal(-1.00000000000000))*(cj0)*(r00)*(x798)))+(((cj0)*(r01)*(x799)))+(((IkReal(-1.00000000000000))*(x791)*(x796)*(x797)))+(((IkReal(-1.00000000000000))*(r10)*(sj0)*(x798)))+(((IkReal(-1.00000000000000))*(x791)*(x793)*(x795))));
if( IKabs(evalcond[0]) > 0.000001  || IKabs(evalcond[1]) > 0.000001  || IKabs(evalcond[2]) > 0.000001  || IKabs(evalcond[3]) > 0.000001  )
{
continue;
}
}

{
std::vector<IkSingleDOFSolutionBase<IkReal> > vinfos(7);
vinfos[0].jointtype = 1;
vinfos[0].foffset = j0;
vinfos[0].indices[0] = _ij0[0];
vinfos[0].indices[1] = _ij0[1];
vinfos[0].maxsolutions = _nj0;
vinfos[1].jointtype = 1;
vinfos[1].foffset = j1;
vinfos[1].indices[0] = _ij1[0];
vinfos[1].indices[1] = _ij1[1];
vinfos[1].maxsolutions = _nj1;
vinfos[2].jointtype = 1;
vinfos[2].foffset = j2;
vinfos[2].indices[0] = _ij2[0];
vinfos[2].indices[1] = _ij2[1];
vinfos[2].maxsolutions = _nj2;
vinfos[3].jointtype = 1;
vinfos[3].foffset = j3;
vinfos[3].indices[0] = _ij3[0];
vinfos[3].indices[1] = _ij3[1];
vinfos[3].maxsolutions = _nj3;
vinfos[4].jointtype = 1;
vinfos[4].foffset = j4;
vinfos[4].indices[0] = _ij4[0];
vinfos[4].indices[1] = _ij4[1];
vinfos[4].maxsolutions = _nj4;
vinfos[5].jointtype = 1;
vinfos[5].foffset = j5;
vinfos[5].indices[0] = _ij5[0];
vinfos[5].indices[1] = _ij5[1];
vinfos[5].maxsolutions = _nj5;
vinfos[6].jointtype = 1;
vinfos[6].foffset = j6;
vinfos[6].indices[0] = _ij6[0];
vinfos[6].indices[1] = _ij6[1];
vinfos[6].maxsolutions = _nj6;
std::vector<int> vfree(0);
solutions.AddSolution(vinfos,vfree);
}
}
}

} else
{
IkReal x806=((cj5)*(sj4));
IkReal x807=((IkReal(1.00000000000000))*(sj6));
IkReal x808=((r10)*(sj0));
IkReal x809=((sj4)*(sj5));
IkReal x810=((cj5)*(cj6));
IkReal x811=((r01)*(sj0));
IkReal x812=((IkReal(1.00000000000000))*(r02));
IkReal x813=((IkReal(0.374290000000000))*(cj0));
IkReal x814=((cj5)*(r12));
IkReal x815=((cj6)*(sj5));
IkReal x816=((cj0)*(r11));
IkReal x817=((cj5)*(sj0));
IkReal x818=((r20)*(sj6));
IkReal x819=((IkReal(1.00000000000000))*(sj0));
IkReal x820=((cj4)*(cj5));
IkReal x821=((IkReal(1.00000000000000))*(cj6));
IkReal x822=((IkReal(0.0100000000000000))*(sj5));
IkReal x823=((sj5)*(sj6));
IkReal x824=((cj0)*(r10));
IkReal x825=((cj4)*(cj6));
IkReal x826=((cj0)*(r01));
IkReal x827=((IkReal(1.00000000000000))*(cj4));
IkReal x828=((cj0)*(r00));
IkReal x829=((IkReal(0.374290000000000))*(sj0));
IkReal x830=((cj0)*(r12));
IkReal x831=((IkReal(0.374290000000000))*(sj5));
IkReal x832=((cj4)*(sj6));
IkReal x833=((IkReal(1.00000000000000))*(cj0));
IkReal x834=((r02)*(sj0));
IkReal x835=((IkReal(0.0100000000000000))*(cj5));
IkReal x836=((r11)*(sj0));
IkReal x837=((r00)*(sj0)*(sj6));
IkReal x838=((r00)*(x825));
IkReal x839=((sj6)*(x835));
evalcond[0]=((IkReal(-3.14159265358979))+(IKfmod(j2, IkReal(6.28318530717959))));
evalcond[1]=((((cj6)*(r21)*(x806)))+(((r21)*(x832)))+(((x806)*(x818)))+(((IkReal(-1.00000000000000))*(cj4)*(r20)*(x821)))+(((r22)*(x809))));
evalcond[2]=((IkReal(-0.0690000000000000))+(((IkReal(-1.00000000000000))*(x818)*(x835)))+(((IkReal(0.374290000000000))*(r21)*(x815)))+(((IkReal(-0.0100000000000000))*(r21)*(x810)))+(((IkReal(-0.374290000000000))*(cj5)*(r22)))+(pz)+(((IkReal(-1.00000000000000))*(r22)*(x822)))+(((x818)*(x831))));
evalcond[3]=((((IkReal(-1.00000000000000))*(x815)*(x816)))+(((IkReal(-1.00000000000000))*(sj5)*(x807)*(x824)))+(((r00)*(sj0)*(x823)))+(((cj0)*(x814)))+(((IkReal(-1.00000000000000))*(x812)*(x817)))+(((x811)*(x815))));
evalcond[4]=((IkReal(-1.00000000000000))+(((cj6)*(x806)*(x811)))+(((IkReal(-1.00000000000000))*(x806)*(x807)*(x824)))+(((IkReal(-1.00000000000000))*(x806)*(x816)*(x821)))+(((x824)*(x825)))+(((x811)*(x832)))+(((IkReal(-1.00000000000000))*(cj4)*(x807)*(x816)))+(((IkReal(-1.00000000000000))*(x819)*(x838)))+(((x809)*(x834)))+(((IkReal(-1.00000000000000))*(x809)*(x830)))+(((x806)*(x837))));
evalcond[5]=((((IkReal(-1.00000000000000))*(sj4)*(x807)*(x811)))+(((IkReal(-1.00000000000000))*(sj5)*(x827)*(x830)))+(((sj4)*(sj6)*(x816)))+(((cj6)*(r00)*(sj0)*(sj4)))+(((r00)*(x817)*(x832)))+(((IkReal(-1.00000000000000))*(sj4)*(x821)*(x824)))+(((cj4)*(x810)*(x811)))+(((IkReal(-1.00000000000000))*(x810)*(x816)*(x827)))+(((IkReal(-1.00000000000000))*(x807)*(x820)*(x824)))+(((cj4)*(sj5)*(x834))));
evalcond[6]=((((IkReal(-1.00000000000000))*(cj0)*(x809)*(x812)))+(((IkReal(-1.00000000000000))*(x806)*(x821)*(x826)))+(((IkReal(-1.00000000000000))*(cj4)*(x807)*(x826)))+(((IkReal(-1.00000000000000))*(x806)*(x807)*(x828)))+(((IkReal(-1.00000000000000))*(x806)*(x807)*(x808)))+(((IkReal(-1.00000000000000))*(cj4)*(x807)*(x836)))+(((IkReal(-1.00000000000000))*(r12)*(x809)*(x819)))+(((x808)*(x825)))+(((x825)*(x828)))+(((IkReal(-1.00000000000000))*(cj6)*(r11)*(x806)*(x819))));
evalcond[7]=((((x824)*(x839)))+(((IkReal(-1.00000000000000))*(r11)*(x813)*(x815)))+(((r00)*(x823)*(x829)))+(((IkReal(-0.0100000000000000))*(x810)*(x811)))+(((IkReal(-1.00000000000000))*(py)*(x833)))+(((IkReal(-0.374290000000000))*(r02)*(x817)))+(((IkReal(0.0100000000000000))*(x810)*(x816)))+(((IkReal(-0.0100000000000000))*(r00)*(sj6)*(x817)))+(((IkReal(0.374290000000000))*(x811)*(x815)))+(((x813)*(x814)))+(((IkReal(-1.00000000000000))*(x822)*(x834)))+(((x822)*(x830)))+(((IkReal(-1.00000000000000))*(r10)*(x813)*(x823)))+(((px)*(sj0))));
evalcond[8]=((IkReal(0.433420000000000))+(((IkReal(-1.00000000000000))*(r00)*(x813)*(x823)))+(((IkReal(-0.374290000000000))*(x808)*(x823)))+(((IkReal(0.0100000000000000))*(x810)*(x826)))+(((x808)*(x839)))+(((IkReal(0.0100000000000000))*(x810)*(x836)))+(((IkReal(-1.00000000000000))*(px)*(x833)))+(((r12)*(sj0)*(x822)))+(((IkReal(-1.00000000000000))*(r11)*(x815)*(x829)))+(((IkReal(-1.00000000000000))*(r01)*(x813)*(x815)))+(((cj5)*(r02)*(x813)))+(((IkReal(-1.00000000000000))*(py)*(x819)))+(((x814)*(x829)))+(((cj0)*(r02)*(x822)))+(((x828)*(x839))));
if( IKabs(evalcond[0]) < 0.0000010000000000  && IKabs(evalcond[1]) < 0.0000010000000000  && IKabs(evalcond[2]) < 0.0000010000000000  && IKabs(evalcond[3]) < 0.0000010000000000  && IKabs(evalcond[4]) < 0.0000010000000000  && IKabs(evalcond[5]) < 0.0000010000000000  && IKabs(evalcond[6]) < 0.0000010000000000  && IKabs(evalcond[7]) < 0.0000010000000000  && IKabs(evalcond[8]) < 0.0000010000000000  )
{
{
IkReal j3array[1], cj3array[1], sj3array[1];
bool j3valid[1]={false};
_nj3 = 1;
IkReal x840=((IkReal(1.00000000000000))*(r21));
IkReal x841=((cj4)*(cj5));
IkReal x842=((r20)*(sj6));
if( IKabs(((((IkReal(-1.00000000000000))*(sj5)*(x842)))+(((cj5)*(r22)))+(((IkReal(-1.00000000000000))*(cj6)*(sj5)*(x840))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(((((IkReal(-1.00000000000000))*(sj4)*(sj6)*(x840)))+(((x841)*(x842)))+(((cj6)*(r20)*(sj4)))+(((cj4)*(r22)*(sj5)))+(((cj6)*(r21)*(x841))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(IKsqr(((((IkReal(-1.00000000000000))*(sj5)*(x842)))+(((cj5)*(r22)))+(((IkReal(-1.00000000000000))*(cj6)*(sj5)*(x840)))))+IKsqr(((((IkReal(-1.00000000000000))*(sj4)*(sj6)*(x840)))+(((x841)*(x842)))+(((cj6)*(r20)*(sj4)))+(((cj4)*(r22)*(sj5)))+(((cj6)*(r21)*(x841)))))-1) <= IKFAST_SINCOS_THRESH )
    continue;
j3array[0]=IKatan2(((((IkReal(-1.00000000000000))*(sj5)*(x842)))+(((cj5)*(r22)))+(((IkReal(-1.00000000000000))*(cj6)*(sj5)*(x840)))), ((((IkReal(-1.00000000000000))*(sj4)*(sj6)*(x840)))+(((x841)*(x842)))+(((cj6)*(r20)*(sj4)))+(((cj4)*(r22)*(sj5)))+(((cj6)*(r21)*(x841)))));
sj3array[0]=IKsin(j3array[0]);
cj3array[0]=IKcos(j3array[0]);
if( j3array[0] > IKPI )
{
    j3array[0]-=IK2PI;
}
else if( j3array[0] < -IKPI )
{    j3array[0]+=IK2PI;
}
j3valid[0] = true;
for(int ij3 = 0; ij3 < 1; ++ij3)
{
if( !j3valid[ij3] )
{
    continue;
}
_ij3[0] = ij3; _ij3[1] = -1;
for(int iij3 = ij3+1; iij3 < 1; ++iij3)
{
if( j3valid[iij3] && IKabs(cj3array[ij3]-cj3array[iij3]) < IKFAST_SOLUTION_THRESH && IKabs(sj3array[ij3]-sj3array[iij3]) < IKFAST_SOLUTION_THRESH )
{
    j3valid[iij3]=false; _ij3[1] = iij3; break; 
}
}
j3 = j3array[ij3]; cj3 = cj3array[ij3]; sj3 = sj3array[ij3];
{
IkReal evalcond[4];
IkReal x843=IKsin(j3);
IkReal x844=((IkReal(1.00000000000000))*(cj4));
IkReal x845=((sj0)*(sj5));
IkReal x846=((cj0)*(cj5));
IkReal x847=((cj6)*(r01));
IkReal x848=((r00)*(sj6));
IkReal x849=((cj6)*(r11));
IkReal x850=((cj5)*(sj0));
IkReal x851=((cj6)*(sj4));
IkReal x852=((sj4)*(sj6));
IkReal x853=((cj4)*(cj5));
IkReal x854=((cj6)*(r21));
IkReal x855=((r20)*(sj6));
IkReal x856=((r10)*(sj6));
IkReal x857=((IkReal(1.00000000000000))*(IKcos(j3)));
IkReal x858=((IkReal(1.00000000000000))*(cj0)*(sj5));
evalcond[0]=((((sj5)*(x854)))+(((sj5)*(x855)))+(((IkReal(-1.00000000000000))*(cj5)*(r22)))+(x843));
evalcond[1]=((((r20)*(x851)))+(((x853)*(x854)))+(((cj4)*(r22)*(sj5)))+(((x853)*(x855)))+(((IkReal(-1.00000000000000))*(x857)))+(((IkReal(-1.00000000000000))*(r21)*(x852))));
evalcond[2]=((((r12)*(x850)))+(((IkReal(-1.00000000000000))*(x848)*(x858)))+(((IkReal(-1.00000000000000))*(x845)*(x849)))+(((IkReal(-1.00000000000000))*(x857)))+(((IkReal(-1.00000000000000))*(x847)*(x858)))+(((IkReal(-1.00000000000000))*(x845)*(x856)))+(((r02)*(x846))));
evalcond[3]=((((r11)*(sj0)*(x852)))+(((IkReal(-1.00000000000000))*(cj0)*(r02)*(sj5)*(x844)))+(((cj0)*(r01)*(x852)))+(((IkReal(-1.00000000000000))*(x843)))+(((IkReal(-1.00000000000000))*(x844)*(x849)*(x850)))+(((IkReal(-1.00000000000000))*(r10)*(sj0)*(x851)))+(((IkReal(-1.00000000000000))*(r12)*(x844)*(x845)))+(((IkReal(-1.00000000000000))*(cj0)*(r00)*(x851)))+(((IkReal(-1.00000000000000))*(x844)*(x846)*(x848)))+(((IkReal(-1.00000000000000))*(x844)*(x846)*(x847)))+(((IkReal(-1.00000000000000))*(x844)*(x850)*(x856))));
if( IKabs(evalcond[0]) > 0.000001  || IKabs(evalcond[1]) > 0.000001  || IKabs(evalcond[2]) > 0.000001  || IKabs(evalcond[3]) > 0.000001  )
{
continue;
}
}

{
std::vector<IkSingleDOFSolutionBase<IkReal> > vinfos(7);
vinfos[0].jointtype = 1;
vinfos[0].foffset = j0;
vinfos[0].indices[0] = _ij0[0];
vinfos[0].indices[1] = _ij0[1];
vinfos[0].maxsolutions = _nj0;
vinfos[1].jointtype = 1;
vinfos[1].foffset = j1;
vinfos[1].indices[0] = _ij1[0];
vinfos[1].indices[1] = _ij1[1];
vinfos[1].maxsolutions = _nj1;
vinfos[2].jointtype = 1;
vinfos[2].foffset = j2;
vinfos[2].indices[0] = _ij2[0];
vinfos[2].indices[1] = _ij2[1];
vinfos[2].maxsolutions = _nj2;
vinfos[3].jointtype = 1;
vinfos[3].foffset = j3;
vinfos[3].indices[0] = _ij3[0];
vinfos[3].indices[1] = _ij3[1];
vinfos[3].maxsolutions = _nj3;
vinfos[4].jointtype = 1;
vinfos[4].foffset = j4;
vinfos[4].indices[0] = _ij4[0];
vinfos[4].indices[1] = _ij4[1];
vinfos[4].maxsolutions = _nj4;
vinfos[5].jointtype = 1;
vinfos[5].foffset = j5;
vinfos[5].indices[0] = _ij5[0];
vinfos[5].indices[1] = _ij5[1];
vinfos[5].maxsolutions = _nj5;
vinfos[6].jointtype = 1;
vinfos[6].foffset = j6;
vinfos[6].indices[0] = _ij6[0];
vinfos[6].indices[1] = _ij6[1];
vinfos[6].maxsolutions = _nj6;
std::vector<int> vfree(0);
solutions.AddSolution(vinfos,vfree);
}
}
}

} else
{
IkReal x859=((IkReal(1.00000000000000))*(cj0));
IkReal x860=((cj4)*(sj6));
IkReal x861=((sj0)*(sj4));
IkReal x862=((cj5)*(sj6));
IkReal x863=((sj4)*(sj5));
IkReal x864=((r12)*(sj5));
IkReal x865=((IkReal(0.374290000000000))*(cj5));
IkReal x866=((r02)*(sj0));
IkReal x867=((r20)*(sj4));
IkReal x868=((IkReal(1.00000000000000))*(sj0));
IkReal x869=((IkReal(1.00000000000000))*(cj5));
IkReal x870=((cj0)*(r10));
IkReal x871=((cj4)*(cj6));
IkReal x872=((r00)*(sj0));
IkReal x873=((cj6)*(r21));
IkReal x874=((IkReal(0.374290000000000))*(sj5));
IkReal x875=((cj0)*(r00));
IkReal x876=((IkReal(0.0100000000000000))*(sj5));
IkReal x877=((cj0)*(r02));
IkReal x878=((cj5)*(sj4));
IkReal x879=((cj6)*(r01));
IkReal x880=((cj6)*(r11));
IkReal x881=((r01)*(sj0));
IkReal x882=((r10)*(sj0));
IkReal x883=((IkReal(0.0100000000000000))*(cj5)*(cj6));
IkReal x884=((sj6)*(x874));
IkReal x885=((cj0)*(cj6)*(x874));
evalcond[0]=((IkReal(-3.14159265358979))+(IKfmod(((IkReal(1.57079632679490))+(j2)), IkReal(6.28318530717959))));
evalcond[1]=((((IkReal(-1.00000000000000))*(r22)*(x869)))+(((sj5)*(x873)))+(((r20)*(sj5)*(sj6))));
evalcond[2]=((IkReal(-1.00000000000000))+(((r22)*(x863)))+(((x873)*(x878)))+(((x862)*(x867)))+(((IkReal(-1.00000000000000))*(r20)*(x871)))+(((r21)*(x860))));
evalcond[3]=((((IkReal(-0.0100000000000000))*(r20)*(x862)))+(((IkReal(-0.0100000000000000))*(cj5)*(x873)))+(((IkReal(-1.00000000000000))*(r22)*(x876)))+(((x873)*(x874)))+(((r20)*(x884)))+(((IkReal(-1.00000000000000))*(r22)*(x865)))+(pz));
evalcond[4]=((((IkReal(-1.00000000000000))*(r21)*(sj4)*(sj6)))+(((cj4)*(r22)*(sj5)))+(((cj5)*(r20)*(x860)))+(((cj6)*(x867)))+(((cj5)*(r21)*(x871))));
evalcond[5]=((((x860)*(x881)))+(((x870)*(x871)))+(((IkReal(-1.00000000000000))*(r12)*(x859)*(x863)))+(((IkReal(-1.00000000000000))*(r00)*(x868)*(x871)))+(((IkReal(-1.00000000000000))*(x859)*(x878)*(x880)))+(((IkReal(-1.00000000000000))*(r10)*(sj4)*(x859)*(x862)))+(((r02)*(sj5)*(x861)))+(((r00)*(x861)*(x862)))+(((cj5)*(x861)*(x879)))+(((IkReal(-1.00000000000000))*(r11)*(x859)*(x860))));
evalcond[6]=((((IkReal(-1.00000000000000))*(x859)*(x878)*(x879)))+(((IkReal(-1.00000000000000))*(r10)*(x861)*(x862)))+(((IkReal(-1.00000000000000))*(x861)*(x864)))+(((IkReal(-1.00000000000000))*(x861)*(x869)*(x880)))+(((IkReal(-1.00000000000000))*(r02)*(x859)*(x863)))+(((x871)*(x882)))+(((IkReal(-1.00000000000000))*(r00)*(sj4)*(x859)*(x862)))+(((IkReal(-1.00000000000000))*(r01)*(x859)*(x860)))+(((x871)*(x875)))+(((IkReal(-1.00000000000000))*(r11)*(x860)*(x868))));
evalcond[7]=((IkReal(0.0690000000000000))+(((IkReal(-0.0100000000000000))*(cj5)*(sj0)*(x879)))+(((IkReal(0.0100000000000000))*(cj0)*(x864)))+(((IkReal(-0.0100000000000000))*(x862)*(x872)))+(((IkReal(-1.00000000000000))*(x865)*(x866)))+(((IkReal(0.0100000000000000))*(x862)*(x870)))+(((sj0)*(x874)*(x879)))+(((x872)*(x884)))+(((cj0)*(r12)*(x865)))+(((IkReal(-1.00000000000000))*(cj0)*(x874)*(x880)))+(((IkReal(-1.00000000000000))*(py)*(x859)))+(((IkReal(-1.00000000000000))*(x870)*(x884)))+(((px)*(sj0)))+(((IkReal(-1.00000000000000))*(x866)*(x876)))+(((IkReal(0.0100000000000000))*(cj0)*(cj5)*(x880))));
evalcond[8]=((IkReal(0.433420000000000))+(((IkReal(-1.00000000000000))*(py)*(x868)))+(((IkReal(0.0100000000000000))*(cj0)*(cj5)*(x879)))+(((IkReal(-1.00000000000000))*(x882)*(x884)))+(((r12)*(sj0)*(x865)))+(((IkReal(0.0100000000000000))*(sj0)*(x864)))+(((x876)*(x877)))+(((IkReal(0.0100000000000000))*(x862)*(x875)))+(((IkReal(-1.00000000000000))*(cj0)*(x874)*(x879)))+(((IkReal(-1.00000000000000))*(sj0)*(x874)*(x880)))+(((IkReal(-1.00000000000000))*(x875)*(x884)))+(((x865)*(x877)))+(((IkReal(0.0100000000000000))*(x862)*(x882)))+(((IkReal(0.0100000000000000))*(cj5)*(sj0)*(x880)))+(((IkReal(-1.00000000000000))*(px)*(x859))));
if( IKabs(evalcond[0]) < 0.0000010000000000  && IKabs(evalcond[1]) < 0.0000010000000000  && IKabs(evalcond[2]) < 0.0000010000000000  && IKabs(evalcond[3]) < 0.0000010000000000  && IKabs(evalcond[4]) < 0.0000010000000000  && IKabs(evalcond[5]) < 0.0000010000000000  && IKabs(evalcond[6]) < 0.0000010000000000  && IKabs(evalcond[7]) < 0.0000010000000000  && IKabs(evalcond[8]) < 0.0000010000000000  )
{
{
IkReal j3array[1], cj3array[1], sj3array[1];
bool j3valid[1]={false};
_nj3 = 1;
IkReal x886=((cj0)*(cj5));
IkReal x887=((IkReal(1.00000000000000))*(cj0));
IkReal x888=((cj6)*(r11));
IkReal x889=((r10)*(sj6));
IkReal x890=((cj5)*(sj0));
IkReal x891=((r00)*(sj5)*(sj6));
IkReal x892=((cj6)*(r01)*(sj5));
IkReal x893=((IkReal(1.00000000000000))*(sj0)*(sj5));
if( IKabs(((((r12)*(x886)))+(((IkReal(-1.00000000000000))*(r02)*(x890)))+(((sj0)*(x891)))+(((IkReal(-1.00000000000000))*(sj5)*(x887)*(x888)))+(((IkReal(-1.00000000000000))*(sj5)*(x887)*(x889)))+(((sj0)*(x892))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(((((IkReal(-1.00000000000000))*(x887)*(x892)))+(((IkReal(-1.00000000000000))*(x887)*(x891)))+(((IkReal(-1.00000000000000))*(x888)*(x893)))+(((IkReal(-1.00000000000000))*(x889)*(x893)))+(((r02)*(x886)))+(((r12)*(x890))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(IKsqr(((((r12)*(x886)))+(((IkReal(-1.00000000000000))*(r02)*(x890)))+(((sj0)*(x891)))+(((IkReal(-1.00000000000000))*(sj5)*(x887)*(x888)))+(((IkReal(-1.00000000000000))*(sj5)*(x887)*(x889)))+(((sj0)*(x892)))))+IKsqr(((((IkReal(-1.00000000000000))*(x887)*(x892)))+(((IkReal(-1.00000000000000))*(x887)*(x891)))+(((IkReal(-1.00000000000000))*(x888)*(x893)))+(((IkReal(-1.00000000000000))*(x889)*(x893)))+(((r02)*(x886)))+(((r12)*(x890)))))-1) <= IKFAST_SINCOS_THRESH )
    continue;
j3array[0]=IKatan2(((((r12)*(x886)))+(((IkReal(-1.00000000000000))*(r02)*(x890)))+(((sj0)*(x891)))+(((IkReal(-1.00000000000000))*(sj5)*(x887)*(x888)))+(((IkReal(-1.00000000000000))*(sj5)*(x887)*(x889)))+(((sj0)*(x892)))), ((((IkReal(-1.00000000000000))*(x887)*(x892)))+(((IkReal(-1.00000000000000))*(x887)*(x891)))+(((IkReal(-1.00000000000000))*(x888)*(x893)))+(((IkReal(-1.00000000000000))*(x889)*(x893)))+(((r02)*(x886)))+(((r12)*(x890)))));
sj3array[0]=IKsin(j3array[0]);
cj3array[0]=IKcos(j3array[0]);
if( j3array[0] > IKPI )
{
    j3array[0]-=IK2PI;
}
else if( j3array[0] < -IKPI )
{    j3array[0]+=IK2PI;
}
j3valid[0] = true;
for(int ij3 = 0; ij3 < 1; ++ij3)
{
if( !j3valid[ij3] )
{
    continue;
}
_ij3[0] = ij3; _ij3[1] = -1;
for(int iij3 = ij3+1; iij3 < 1; ++iij3)
{
if( j3valid[iij3] && IKabs(cj3array[ij3]-cj3array[iij3]) < IKFAST_SOLUTION_THRESH && IKabs(sj3array[ij3]-sj3array[iij3]) < IKFAST_SOLUTION_THRESH )
{
    j3valid[iij3]=false; _ij3[1] = iij3; break; 
}
}
j3 = j3array[ij3]; cj3 = cj3array[ij3]; sj3 = sj3array[ij3];
{
IkReal evalcond[4];
IkReal x894=IKcos(j3);
IkReal x895=((sj0)*(sj5));
IkReal x896=((r00)*(sj6));
IkReal x897=((cj6)*(sj0));
IkReal x898=((IkReal(1.00000000000000))*(cj4));
IkReal x899=((r00)*(sj4));
IkReal x900=((cj0)*(cj5));
IkReal x901=((cj5)*(sj0));
IkReal x902=((cj6)*(r11));
IkReal x903=((r10)*(sj6));
IkReal x904=((cj0)*(sj5));
IkReal x905=((r10)*(sj4));
IkReal x906=((IkReal(1.00000000000000))*(IKsin(j3)));
IkReal x907=((cj4)*(cj5)*(r01));
IkReal x908=((IkReal(1.00000000000000))*(cj0)*(cj6));
IkReal x909=((cj0)*(sj4)*(sj6));
IkReal x910=((sj0)*(sj4)*(sj6));
evalcond[0]=((((IkReal(-1.00000000000000))*(r02)*(x901)))+(((IkReal(-1.00000000000000))*(x903)*(x904)))+(((cj6)*(r01)*(x895)))+(((IkReal(-1.00000000000000))*(x902)*(x904)))+(((r12)*(x900)))+(((x895)*(x896)))+(((IkReal(-1.00000000000000))*(x906))));
evalcond[1]=((((IkReal(-1.00000000000000))*(x895)*(x903)))+(((IkReal(-1.00000000000000))*(x896)*(x904)))+(((IkReal(-1.00000000000000))*(cj6)*(r01)*(x904)))+(((r02)*(x900)))+(((IkReal(-1.00000000000000))*(x894)))+(((IkReal(-1.00000000000000))*(x895)*(x902)))+(((r12)*(x901))));
evalcond[2]=((((IkReal(-1.00000000000000))*(x905)*(x908)))+(((r11)*(x909)))+(((IkReal(-1.00000000000000))*(r12)*(x898)*(x904)))+(((IkReal(-1.00000000000000))*(r01)*(x910)))+(((x897)*(x907)))+(((IkReal(-1.00000000000000))*(x898)*(x900)*(x903)))+(((x897)*(x899)))+(((IkReal(-1.00000000000000))*(x898)*(x900)*(x902)))+(x894)+(((cj4)*(x896)*(x901)))+(((cj4)*(r02)*(x895))));
evalcond[3]=((((IkReal(-1.00000000000000))*(cj5)*(r11)*(x897)*(x898)))+(((IkReal(-1.00000000000000))*(r12)*(x895)*(x898)))+(((IkReal(-1.00000000000000))*(r02)*(x898)*(x904)))+(((IkReal(-1.00000000000000))*(cj6)*(r01)*(x898)*(x900)))+(((IkReal(-1.00000000000000))*(x899)*(x908)))+(((r11)*(x910)))+(((IkReal(-1.00000000000000))*(x897)*(x905)))+(((IkReal(-1.00000000000000))*(x896)*(x898)*(x900)))+(((r01)*(x909)))+(((IkReal(-1.00000000000000))*(x898)*(x901)*(x903)))+(((IkReal(-1.00000000000000))*(x906))));
if( IKabs(evalcond[0]) > 0.000001  || IKabs(evalcond[1]) > 0.000001  || IKabs(evalcond[2]) > 0.000001  || IKabs(evalcond[3]) > 0.000001  )
{
continue;
}
}

{
std::vector<IkSingleDOFSolutionBase<IkReal> > vinfos(7);
vinfos[0].jointtype = 1;
vinfos[0].foffset = j0;
vinfos[0].indices[0] = _ij0[0];
vinfos[0].indices[1] = _ij0[1];
vinfos[0].maxsolutions = _nj0;
vinfos[1].jointtype = 1;
vinfos[1].foffset = j1;
vinfos[1].indices[0] = _ij1[0];
vinfos[1].indices[1] = _ij1[1];
vinfos[1].maxsolutions = _nj1;
vinfos[2].jointtype = 1;
vinfos[2].foffset = j2;
vinfos[2].indices[0] = _ij2[0];
vinfos[2].indices[1] = _ij2[1];
vinfos[2].maxsolutions = _nj2;
vinfos[3].jointtype = 1;
vinfos[3].foffset = j3;
vinfos[3].indices[0] = _ij3[0];
vinfos[3].indices[1] = _ij3[1];
vinfos[3].maxsolutions = _nj3;
vinfos[4].jointtype = 1;
vinfos[4].foffset = j4;
vinfos[4].indices[0] = _ij4[0];
vinfos[4].indices[1] = _ij4[1];
vinfos[4].maxsolutions = _nj4;
vinfos[5].jointtype = 1;
vinfos[5].foffset = j5;
vinfos[5].indices[0] = _ij5[0];
vinfos[5].indices[1] = _ij5[1];
vinfos[5].maxsolutions = _nj5;
vinfos[6].jointtype = 1;
vinfos[6].foffset = j6;
vinfos[6].indices[0] = _ij6[0];
vinfos[6].indices[1] = _ij6[1];
vinfos[6].maxsolutions = _nj6;
std::vector<int> vfree(0);
solutions.AddSolution(vinfos,vfree);
}
}
}

} else
{
IkReal x911=((IkReal(1.00000000000000))*(cj0));
IkReal x912=((cj4)*(sj6));
IkReal x913=((sj0)*(sj4));
IkReal x914=((cj5)*(sj6));
IkReal x915=((sj4)*(sj5));
IkReal x916=((r12)*(sj5));
IkReal x917=((IkReal(0.374290000000000))*(cj5));
IkReal x918=((r02)*(sj0));
IkReal x919=((r20)*(sj4));
IkReal x920=((IkReal(1.00000000000000))*(sj0));
IkReal x921=((IkReal(1.00000000000000))*(cj5));
IkReal x922=((cj0)*(r10));
IkReal x923=((cj4)*(cj6));
IkReal x924=((r00)*(sj0));
IkReal x925=((cj6)*(r21));
IkReal x926=((IkReal(0.374290000000000))*(sj5));
IkReal x927=((cj0)*(r00));
IkReal x928=((IkReal(0.0100000000000000))*(sj5));
IkReal x929=((cj0)*(r02));
IkReal x930=((cj5)*(sj4));
IkReal x931=((cj6)*(r01));
IkReal x932=((cj6)*(r11));
IkReal x933=((r01)*(sj0));
IkReal x934=((r10)*(sj0));
IkReal x935=((IkReal(0.0100000000000000))*(cj5)*(cj6));
IkReal x936=((sj6)*(x926));
IkReal x937=((cj0)*(cj6)*(x926));
evalcond[0]=((IkReal(-3.14159265358979))+(IKfmod(((IkReal(4.71238898038469))+(j2)), IkReal(6.28318530717959))));
evalcond[1]=((((IkReal(-1.00000000000000))*(r22)*(x921)))+(((sj5)*(x925)))+(((r20)*(sj5)*(sj6))));
evalcond[2]=((IkReal(1.00000000000000))+(((r21)*(x912)))+(((x914)*(x919)))+(((IkReal(-1.00000000000000))*(r20)*(x923)))+(((r22)*(x915)))+(((x925)*(x930))));
evalcond[3]=((((x925)*(x926)))+(((IkReal(-1.00000000000000))*(r22)*(x917)))+(pz)+(((r20)*(x936)))+(((IkReal(-0.0100000000000000))*(r20)*(x914)))+(((IkReal(-0.0100000000000000))*(cj5)*(x925)))+(((IkReal(-1.00000000000000))*(r22)*(x928))));
evalcond[4]=((((cj5)*(r21)*(x923)))+(((IkReal(-1.00000000000000))*(r21)*(sj4)*(sj6)))+(((cj5)*(r20)*(x912)))+(((cj4)*(r22)*(sj5)))+(((cj6)*(x919))));
evalcond[5]=((((IkReal(-1.00000000000000))*(r11)*(x911)*(x912)))+(((IkReal(-1.00000000000000))*(r10)*(sj4)*(x911)*(x914)))+(((IkReal(-1.00000000000000))*(r00)*(x920)*(x923)))+(((IkReal(-1.00000000000000))*(r12)*(x911)*(x915)))+(((r02)*(sj5)*(x913)))+(((IkReal(-1.00000000000000))*(x911)*(x930)*(x932)))+(((cj5)*(x913)*(x931)))+(((x912)*(x933)))+(((r00)*(x913)*(x914)))+(((x922)*(x923))));
evalcond[6]=((((IkReal(-1.00000000000000))*(r02)*(x911)*(x915)))+(((x923)*(x934)))+(((IkReal(-1.00000000000000))*(x911)*(x930)*(x931)))+(((IkReal(-1.00000000000000))*(r10)*(x913)*(x914)))+(((IkReal(-1.00000000000000))*(x913)*(x921)*(x932)))+(((IkReal(-1.00000000000000))*(x913)*(x916)))+(((IkReal(-1.00000000000000))*(r11)*(x912)*(x920)))+(((x923)*(x927)))+(((IkReal(-1.00000000000000))*(r01)*(x911)*(x912)))+(((IkReal(-1.00000000000000))*(r00)*(sj4)*(x911)*(x914))));
evalcond[7]=((IkReal(-0.0690000000000000))+(((IkReal(-1.00000000000000))*(py)*(x911)))+(((IkReal(-0.0100000000000000))*(x914)*(x924)))+(((IkReal(-1.00000000000000))*(x918)*(x928)))+(((IkReal(0.0100000000000000))*(cj0)*(cj5)*(x932)))+(((IkReal(0.0100000000000000))*(cj0)*(x916)))+(((IkReal(-0.0100000000000000))*(cj5)*(sj0)*(x931)))+(((IkReal(-1.00000000000000))*(x917)*(x918)))+(((sj0)*(x926)*(x931)))+(((IkReal(-1.00000000000000))*(x922)*(x936)))+(((IkReal(0.0100000000000000))*(x914)*(x922)))+(((cj0)*(r12)*(x917)))+(((px)*(sj0)))+(((IkReal(-1.00000000000000))*(cj0)*(x926)*(x932)))+(((x924)*(x936))));
evalcond[8]=((IkReal(0.433420000000000))+(((IkReal(0.0100000000000000))*(cj5)*(sj0)*(x932)))+(((IkReal(0.0100000000000000))*(x914)*(x927)))+(((IkReal(0.0100000000000000))*(x914)*(x934)))+(((IkReal(0.0100000000000000))*(cj0)*(cj5)*(x931)))+(((x928)*(x929)))+(((IkReal(-1.00000000000000))*(sj0)*(x926)*(x932)))+(((IkReal(-1.00000000000000))*(py)*(x920)))+(((IkReal(-1.00000000000000))*(cj0)*(x926)*(x931)))+(((x917)*(x929)))+(((IkReal(-1.00000000000000))*(px)*(x911)))+(((IkReal(-1.00000000000000))*(x934)*(x936)))+(((IkReal(0.0100000000000000))*(sj0)*(x916)))+(((IkReal(-1.00000000000000))*(x927)*(x936)))+(((r12)*(sj0)*(x917))));
if( IKabs(evalcond[0]) < 0.0000010000000000  && IKabs(evalcond[1]) < 0.0000010000000000  && IKabs(evalcond[2]) < 0.0000010000000000  && IKabs(evalcond[3]) < 0.0000010000000000  && IKabs(evalcond[4]) < 0.0000010000000000  && IKabs(evalcond[5]) < 0.0000010000000000  && IKabs(evalcond[6]) < 0.0000010000000000  && IKabs(evalcond[7]) < 0.0000010000000000  && IKabs(evalcond[8]) < 0.0000010000000000  )
{
{
IkReal j3array[1], cj3array[1], sj3array[1];
bool j3valid[1]={false};
_nj3 = 1;
IkReal x938=((cj5)*(r02));
IkReal x939=((cj0)*(sj5));
IkReal x940=((r10)*(sj6));
IkReal x941=((IkReal(1.00000000000000))*(cj6));
IkReal x942=((sj0)*(sj5));
IkReal x943=((cj5)*(r12));
IkReal x944=((IkReal(1.00000000000000))*(r00)*(sj6));
if( IKabs(((((IkReal(-1.00000000000000))*(cj0)*(x943)))+(((IkReal(-1.00000000000000))*(r01)*(x941)*(x942)))+(((cj6)*(r11)*(x939)))+(((x939)*(x940)))+(((sj0)*(x938)))+(((IkReal(-1.00000000000000))*(x942)*(x944))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(((((IkReal(-1.00000000000000))*(x940)*(x942)))+(((IkReal(-1.00000000000000))*(r01)*(x939)*(x941)))+(((sj0)*(x943)))+(((IkReal(-1.00000000000000))*(r11)*(x941)*(x942)))+(((cj0)*(x938)))+(((IkReal(-1.00000000000000))*(x939)*(x944))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(IKsqr(((((IkReal(-1.00000000000000))*(cj0)*(x943)))+(((IkReal(-1.00000000000000))*(r01)*(x941)*(x942)))+(((cj6)*(r11)*(x939)))+(((x939)*(x940)))+(((sj0)*(x938)))+(((IkReal(-1.00000000000000))*(x942)*(x944)))))+IKsqr(((((IkReal(-1.00000000000000))*(x940)*(x942)))+(((IkReal(-1.00000000000000))*(r01)*(x939)*(x941)))+(((sj0)*(x943)))+(((IkReal(-1.00000000000000))*(r11)*(x941)*(x942)))+(((cj0)*(x938)))+(((IkReal(-1.00000000000000))*(x939)*(x944)))))-1) <= IKFAST_SINCOS_THRESH )
    continue;
j3array[0]=IKatan2(((((IkReal(-1.00000000000000))*(cj0)*(x943)))+(((IkReal(-1.00000000000000))*(r01)*(x941)*(x942)))+(((cj6)*(r11)*(x939)))+(((x939)*(x940)))+(((sj0)*(x938)))+(((IkReal(-1.00000000000000))*(x942)*(x944)))), ((((IkReal(-1.00000000000000))*(x940)*(x942)))+(((IkReal(-1.00000000000000))*(r01)*(x939)*(x941)))+(((sj0)*(x943)))+(((IkReal(-1.00000000000000))*(r11)*(x941)*(x942)))+(((cj0)*(x938)))+(((IkReal(-1.00000000000000))*(x939)*(x944)))));
sj3array[0]=IKsin(j3array[0]);
cj3array[0]=IKcos(j3array[0]);
if( j3array[0] > IKPI )
{
    j3array[0]-=IK2PI;
}
else if( j3array[0] < -IKPI )
{    j3array[0]+=IK2PI;
}
j3valid[0] = true;
for(int ij3 = 0; ij3 < 1; ++ij3)
{
if( !j3valid[ij3] )
{
    continue;
}
_ij3[0] = ij3; _ij3[1] = -1;
for(int iij3 = ij3+1; iij3 < 1; ++iij3)
{
if( j3valid[iij3] && IKabs(cj3array[ij3]-cj3array[iij3]) < IKFAST_SOLUTION_THRESH && IKabs(sj3array[ij3]-sj3array[iij3]) < IKFAST_SOLUTION_THRESH )
{
    j3valid[iij3]=false; _ij3[1] = iij3; break; 
}
}
j3 = j3array[ij3]; cj3 = cj3array[ij3]; sj3 = sj3array[ij3];
{
IkReal evalcond[4];
IkReal x945=IKsin(j3);
IkReal x946=((sj0)*(sj5));
IkReal x947=((r00)*(sj6));
IkReal x948=((IkReal(1.00000000000000))*(cj4));
IkReal x949=((cj6)*(sj0));
IkReal x950=((r00)*(sj4));
IkReal x951=((cj0)*(cj5));
IkReal x952=((cj6)*(r01));
IkReal x953=((cj5)*(sj0));
IkReal x954=((cj0)*(sj5));
IkReal x955=((cj6)*(r11));
IkReal x956=((r10)*(sj6));
IkReal x957=((r10)*(sj4));
IkReal x958=((IkReal(1.00000000000000))*(IKcos(j3)));
IkReal x959=((cj0)*(sj4)*(sj6));
IkReal x960=((sj0)*(sj4)*(sj6));
IkReal x961=((IkReal(1.00000000000000))*(cj0)*(cj6));
evalcond[0]=((((x946)*(x952)))+(((IkReal(-1.00000000000000))*(x954)*(x955)))+(((r12)*(x951)))+(((x946)*(x947)))+(x945)+(((IkReal(-1.00000000000000))*(r02)*(x953)))+(((IkReal(-1.00000000000000))*(x954)*(x956))));
evalcond[1]=((((r02)*(x951)))+(((r12)*(x953)))+(((IkReal(-1.00000000000000))*(x946)*(x955)))+(((IkReal(-1.00000000000000))*(x947)*(x954)))+(((IkReal(-1.00000000000000))*(x946)*(x956)))+(((IkReal(-1.00000000000000))*(x958)))+(((IkReal(-1.00000000000000))*(x952)*(x954))));
evalcond[2]=((((IkReal(-1.00000000000000))*(r01)*(x960)))+(((cj4)*(x947)*(x953)))+(((r11)*(x959)))+(((cj4)*(cj5)*(r01)*(x949)))+(((IkReal(-1.00000000000000))*(x957)*(x961)))+(((IkReal(-1.00000000000000))*(x948)*(x951)*(x955)))+(((x949)*(x950)))+(((IkReal(-1.00000000000000))*(r12)*(x948)*(x954)))+(((cj4)*(r02)*(x946)))+(((IkReal(-1.00000000000000))*(x948)*(x951)*(x956)))+(((IkReal(-1.00000000000000))*(x958))));
evalcond[3]=((((IkReal(-1.00000000000000))*(x950)*(x961)))+(((IkReal(-1.00000000000000))*(x945)))+(((IkReal(-1.00000000000000))*(x949)*(x957)))+(((IkReal(-1.00000000000000))*(x948)*(x953)*(x956)))+(((IkReal(-1.00000000000000))*(x948)*(x951)*(x952)))+(((r01)*(x959)))+(((IkReal(-1.00000000000000))*(r12)*(x946)*(x948)))+(((r11)*(x960)))+(((IkReal(-1.00000000000000))*(x947)*(x948)*(x951)))+(((IkReal(-1.00000000000000))*(cj5)*(r11)*(x948)*(x949)))+(((IkReal(-1.00000000000000))*(r02)*(x948)*(x954))));
if( IKabs(evalcond[0]) > 0.000001  || IKabs(evalcond[1]) > 0.000001  || IKabs(evalcond[2]) > 0.000001  || IKabs(evalcond[3]) > 0.000001  )
{
continue;
}
}

{
std::vector<IkSingleDOFSolutionBase<IkReal> > vinfos(7);
vinfos[0].jointtype = 1;
vinfos[0].foffset = j0;
vinfos[0].indices[0] = _ij0[0];
vinfos[0].indices[1] = _ij0[1];
vinfos[0].maxsolutions = _nj0;
vinfos[1].jointtype = 1;
vinfos[1].foffset = j1;
vinfos[1].indices[0] = _ij1[0];
vinfos[1].indices[1] = _ij1[1];
vinfos[1].maxsolutions = _nj1;
vinfos[2].jointtype = 1;
vinfos[2].foffset = j2;
vinfos[2].indices[0] = _ij2[0];
vinfos[2].indices[1] = _ij2[1];
vinfos[2].maxsolutions = _nj2;
vinfos[3].jointtype = 1;
vinfos[3].foffset = j3;
vinfos[3].indices[0] = _ij3[0];
vinfos[3].indices[1] = _ij3[1];
vinfos[3].maxsolutions = _nj3;
vinfos[4].jointtype = 1;
vinfos[4].foffset = j4;
vinfos[4].indices[0] = _ij4[0];
vinfos[4].indices[1] = _ij4[1];
vinfos[4].maxsolutions = _nj4;
vinfos[5].jointtype = 1;
vinfos[5].foffset = j5;
vinfos[5].indices[0] = _ij5[0];
vinfos[5].indices[1] = _ij5[1];
vinfos[5].maxsolutions = _nj5;
vinfos[6].jointtype = 1;
vinfos[6].foffset = j6;
vinfos[6].indices[0] = _ij6[0];
vinfos[6].indices[1] = _ij6[1];
vinfos[6].maxsolutions = _nj6;
std::vector<int> vfree(0);
solutions.AddSolution(vinfos,vfree);
}
}
}

} else
{
if( 1 )
{
continue;

} else
{
}
}
}
}
}
}

} else
{
{
IkReal j3array[1], cj3array[1], sj3array[1];
bool j3valid[1]={false};
_nj3 = 1;
IkReal x962=((cj0)*(cj5));
IkReal x963=((IkReal(1.00000000000000))*(cj0));
IkReal x964=((cj6)*(r11));
IkReal x965=((r10)*(sj6));
IkReal x966=((cj5)*(sj0));
IkReal x967=((r00)*(sj5)*(sj6));
IkReal x968=((cj6)*(r01)*(sj5));
IkReal x969=((IkReal(1.00000000000000))*(sj0)*(sj5));
if( IKabs(((((IKabs(sj2) != 0)?((IkReal)1/(sj2)):(IkReal)1.0e30))*(((((r12)*(x962)))+(((IkReal(-1.00000000000000))*(r02)*(x966)))+(((IkReal(-1.00000000000000))*(sj5)*(x963)*(x965)))+(((sj0)*(x967)))+(((sj0)*(x968)))+(((IkReal(-1.00000000000000))*(sj5)*(x963)*(x964))))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(((((IkReal(-1.00000000000000))*(x964)*(x969)))+(((IkReal(-1.00000000000000))*(x963)*(x968)))+(((IkReal(-1.00000000000000))*(x965)*(x969)))+(((r02)*(x962)))+(((r12)*(x966)))+(((IkReal(-1.00000000000000))*(x963)*(x967))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(IKsqr(((((IKabs(sj2) != 0)?((IkReal)1/(sj2)):(IkReal)1.0e30))*(((((r12)*(x962)))+(((IkReal(-1.00000000000000))*(r02)*(x966)))+(((IkReal(-1.00000000000000))*(sj5)*(x963)*(x965)))+(((sj0)*(x967)))+(((sj0)*(x968)))+(((IkReal(-1.00000000000000))*(sj5)*(x963)*(x964)))))))+IKsqr(((((IkReal(-1.00000000000000))*(x964)*(x969)))+(((IkReal(-1.00000000000000))*(x963)*(x968)))+(((IkReal(-1.00000000000000))*(x965)*(x969)))+(((r02)*(x962)))+(((r12)*(x966)))+(((IkReal(-1.00000000000000))*(x963)*(x967)))))-1) <= IKFAST_SINCOS_THRESH )
    continue;
j3array[0]=IKatan2(((((IKabs(sj2) != 0)?((IkReal)1/(sj2)):(IkReal)1.0e30))*(((((r12)*(x962)))+(((IkReal(-1.00000000000000))*(r02)*(x966)))+(((IkReal(-1.00000000000000))*(sj5)*(x963)*(x965)))+(((sj0)*(x967)))+(((sj0)*(x968)))+(((IkReal(-1.00000000000000))*(sj5)*(x963)*(x964)))))), ((((IkReal(-1.00000000000000))*(x964)*(x969)))+(((IkReal(-1.00000000000000))*(x963)*(x968)))+(((IkReal(-1.00000000000000))*(x965)*(x969)))+(((r02)*(x962)))+(((r12)*(x966)))+(((IkReal(-1.00000000000000))*(x963)*(x967)))));
sj3array[0]=IKsin(j3array[0]);
cj3array[0]=IKcos(j3array[0]);
if( j3array[0] > IKPI )
{
    j3array[0]-=IK2PI;
}
else if( j3array[0] < -IKPI )
{    j3array[0]+=IK2PI;
}
j3valid[0] = true;
for(int ij3 = 0; ij3 < 1; ++ij3)
{
if( !j3valid[ij3] )
{
    continue;
}
_ij3[0] = ij3; _ij3[1] = -1;
for(int iij3 = ij3+1; iij3 < 1; ++iij3)
{
if( j3valid[iij3] && IKabs(cj3array[ij3]-cj3array[iij3]) < IKFAST_SOLUTION_THRESH && IKabs(sj3array[ij3]-sj3array[iij3]) < IKFAST_SOLUTION_THRESH )
{
    j3valid[iij3]=false; _ij3[1] = iij3; break; 
}
}
j3 = j3array[ij3]; cj3 = cj3array[ij3]; sj3 = sj3array[ij3];
{
IkReal evalcond[6];
IkReal x970=IKsin(j3);
IkReal x971=IKcos(j3);
IkReal x972=((sj0)*(sj5));
IkReal x973=((r00)*(sj6));
IkReal x974=((IkReal(1.00000000000000))*(cj4));
IkReal x975=((cj6)*(r01));
IkReal x976=((cj0)*(cj5));
IkReal x977=((cj5)*(sj0));
IkReal x978=((cj6)*(r11));
IkReal x979=((cj0)*(sj5));
IkReal x980=((cj6)*(sj4));
IkReal x981=((cj4)*(cj5));
IkReal x982=((cj6)*(r21));
IkReal x983=((r20)*(sj6));
IkReal x984=((r10)*(sj6));
IkReal x985=((IkReal(1.00000000000000))*(cj0));
IkReal x986=((IkReal(1.00000000000000))*(x970));
IkReal x987=((cj0)*(sj4)*(sj6));
IkReal x988=((sj0)*(sj4)*(sj6));
evalcond[0]=((((IkReal(-1.00000000000000))*(cj2)*(x986)))+(((sj5)*(x982)))+(((IkReal(-1.00000000000000))*(cj5)*(r22)))+(((sj5)*(x983))));
evalcond[1]=((((x981)*(x983)))+(((IkReal(-1.00000000000000))*(r21)*(sj4)*(sj6)))+(((cj2)*(x971)))+(((x981)*(x982)))+(((cj4)*(r22)*(sj5)))+(((r20)*(x980))));
evalcond[2]=((((IkReal(-1.00000000000000))*(x978)*(x979)))+(((x972)*(x975)))+(((IkReal(-1.00000000000000))*(sj2)*(x986)))+(((IkReal(-1.00000000000000))*(x979)*(x984)))+(((IkReal(-1.00000000000000))*(r02)*(x977)))+(((r12)*(x976)))+(((x972)*(x973))));
evalcond[3]=((((IkReal(-1.00000000000000))*(x972)*(x978)))+(((IkReal(-1.00000000000000))*(x973)*(x979)))+(((r02)*(x976)))+(((IkReal(-1.00000000000000))*(x971)))+(((IkReal(-1.00000000000000))*(x972)*(x984)))+(((IkReal(-1.00000000000000))*(x975)*(x979)))+(((r12)*(x977))));
evalcond[4]=((((r11)*(x987)))+(((IkReal(-1.00000000000000))*(r10)*(x980)*(x985)))+(((r00)*(sj0)*(x980)))+(((IkReal(-1.00000000000000))*(x974)*(x976)*(x978)))+(((cj4)*(r02)*(x972)))+(((cj4)*(x973)*(x977)))+(((IkReal(-1.00000000000000))*(r12)*(x974)*(x979)))+(((cj4)*(x975)*(x977)))+(((IkReal(-1.00000000000000))*(r01)*(x988)))+(((IkReal(-1.00000000000000))*(x974)*(x976)*(x984)))+(((sj2)*(x971))));
evalcond[5]=((((IkReal(-1.00000000000000))*(x973)*(x974)*(x976)))+(((IkReal(-1.00000000000000))*(x974)*(x977)*(x978)))+(((IkReal(-1.00000000000000))*(x974)*(x977)*(x984)))+(((r01)*(x987)))+(((IkReal(-1.00000000000000))*(r00)*(x980)*(x985)))+(((IkReal(-1.00000000000000))*(r02)*(x974)*(x979)))+(((r11)*(x988)))+(((IkReal(-1.00000000000000))*(x986)))+(((IkReal(-1.00000000000000))*(r10)*(sj0)*(x980)))+(((IkReal(-1.00000000000000))*(x974)*(x975)*(x976)))+(((IkReal(-1.00000000000000))*(r12)*(x972)*(x974))));
if( IKabs(evalcond[0]) > 0.000001  || IKabs(evalcond[1]) > 0.000001  || IKabs(evalcond[2]) > 0.000001  || IKabs(evalcond[3]) > 0.000001  || IKabs(evalcond[4]) > 0.000001  || IKabs(evalcond[5]) > 0.000001  )
{
continue;
}
}

{
std::vector<IkSingleDOFSolutionBase<IkReal> > vinfos(7);
vinfos[0].jointtype = 1;
vinfos[0].foffset = j0;
vinfos[0].indices[0] = _ij0[0];
vinfos[0].indices[1] = _ij0[1];
vinfos[0].maxsolutions = _nj0;
vinfos[1].jointtype = 1;
vinfos[1].foffset = j1;
vinfos[1].indices[0] = _ij1[0];
vinfos[1].indices[1] = _ij1[1];
vinfos[1].maxsolutions = _nj1;
vinfos[2].jointtype = 1;
vinfos[2].foffset = j2;
vinfos[2].indices[0] = _ij2[0];
vinfos[2].indices[1] = _ij2[1];
vinfos[2].maxsolutions = _nj2;
vinfos[3].jointtype = 1;
vinfos[3].foffset = j3;
vinfos[3].indices[0] = _ij3[0];
vinfos[3].indices[1] = _ij3[1];
vinfos[3].maxsolutions = _nj3;
vinfos[4].jointtype = 1;
vinfos[4].foffset = j4;
vinfos[4].indices[0] = _ij4[0];
vinfos[4].indices[1] = _ij4[1];
vinfos[4].maxsolutions = _nj4;
vinfos[5].jointtype = 1;
vinfos[5].foffset = j5;
vinfos[5].indices[0] = _ij5[0];
vinfos[5].indices[1] = _ij5[1];
vinfos[5].maxsolutions = _nj5;
vinfos[6].jointtype = 1;
vinfos[6].foffset = j6;
vinfos[6].indices[0] = _ij6[0];
vinfos[6].indices[1] = _ij6[1];
vinfos[6].maxsolutions = _nj6;
std::vector<int> vfree(0);
solutions.AddSolution(vinfos,vfree);
}
}
}

}

}

} else
{
{
IkReal j3array[1], cj3array[1], sj3array[1];
bool j3valid[1]={false};
_nj3 = 1;
IkReal x989=((sj5)*(sj6));
IkReal x990=((IkReal(1.00000000000000))*(cj6)*(sj5));
if( IKabs(((((IKabs(cj2) != 0)?((IkReal)1/(cj2)):(IkReal)1.0e30))*(((((cj6)*(r21)*(sj5)))+(((r20)*(x989)))+(((IkReal(-1.00000000000000))*(cj5)*(r22))))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(((((cj0)*(cj5)*(r02)))+(((IkReal(-1.00000000000000))*(cj0)*(r00)*(x989)))+(((IkReal(-1.00000000000000))*(r10)*(sj0)*(x989)))+(((cj5)*(r12)*(sj0)))+(((IkReal(-1.00000000000000))*(cj0)*(r01)*(x990)))+(((IkReal(-1.00000000000000))*(r11)*(sj0)*(x990))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(IKsqr(((((IKabs(cj2) != 0)?((IkReal)1/(cj2)):(IkReal)1.0e30))*(((((cj6)*(r21)*(sj5)))+(((r20)*(x989)))+(((IkReal(-1.00000000000000))*(cj5)*(r22)))))))+IKsqr(((((cj0)*(cj5)*(r02)))+(((IkReal(-1.00000000000000))*(cj0)*(r00)*(x989)))+(((IkReal(-1.00000000000000))*(r10)*(sj0)*(x989)))+(((cj5)*(r12)*(sj0)))+(((IkReal(-1.00000000000000))*(cj0)*(r01)*(x990)))+(((IkReal(-1.00000000000000))*(r11)*(sj0)*(x990)))))-1) <= IKFAST_SINCOS_THRESH )
    continue;
j3array[0]=IKatan2(((((IKabs(cj2) != 0)?((IkReal)1/(cj2)):(IkReal)1.0e30))*(((((cj6)*(r21)*(sj5)))+(((r20)*(x989)))+(((IkReal(-1.00000000000000))*(cj5)*(r22)))))), ((((cj0)*(cj5)*(r02)))+(((IkReal(-1.00000000000000))*(cj0)*(r00)*(x989)))+(((IkReal(-1.00000000000000))*(r10)*(sj0)*(x989)))+(((cj5)*(r12)*(sj0)))+(((IkReal(-1.00000000000000))*(cj0)*(r01)*(x990)))+(((IkReal(-1.00000000000000))*(r11)*(sj0)*(x990)))));
sj3array[0]=IKsin(j3array[0]);
cj3array[0]=IKcos(j3array[0]);
if( j3array[0] > IKPI )
{
    j3array[0]-=IK2PI;
}
else if( j3array[0] < -IKPI )
{    j3array[0]+=IK2PI;
}
j3valid[0] = true;
for(int ij3 = 0; ij3 < 1; ++ij3)
{
if( !j3valid[ij3] )
{
    continue;
}
_ij3[0] = ij3; _ij3[1] = -1;
for(int iij3 = ij3+1; iij3 < 1; ++iij3)
{
if( j3valid[iij3] && IKabs(cj3array[ij3]-cj3array[iij3]) < IKFAST_SOLUTION_THRESH && IKabs(sj3array[ij3]-sj3array[iij3]) < IKFAST_SOLUTION_THRESH )
{
    j3valid[iij3]=false; _ij3[1] = iij3; break; 
}
}
j3 = j3array[ij3]; cj3 = cj3array[ij3]; sj3 = sj3array[ij3];
{
IkReal evalcond[6];
IkReal x991=IKsin(j3);
IkReal x992=IKcos(j3);
IkReal x993=((sj0)*(sj5));
IkReal x994=((r00)*(sj6));
IkReal x995=((IkReal(1.00000000000000))*(cj4));
IkReal x996=((cj6)*(r01));
IkReal x997=((cj0)*(cj5));
IkReal x998=((cj5)*(sj0));
IkReal x999=((cj6)*(r11));
IkReal x1000=((cj0)*(sj5));
IkReal x1001=((cj6)*(sj4));
IkReal x1002=((cj4)*(cj5));
IkReal x1003=((cj6)*(r21));
IkReal x1004=((r20)*(sj6));
IkReal x1005=((r10)*(sj6));
IkReal x1006=((IkReal(1.00000000000000))*(cj0));
IkReal x1007=((IkReal(1.00000000000000))*(x991));
IkReal x1008=((cj0)*(sj4)*(sj6));
IkReal x1009=((sj0)*(sj4)*(sj6));
evalcond[0]=((((sj5)*(x1003)))+(((IkReal(-1.00000000000000))*(cj2)*(x1007)))+(((IkReal(-1.00000000000000))*(cj5)*(r22)))+(((sj5)*(x1004))));
evalcond[1]=((((IkReal(-1.00000000000000))*(r21)*(sj4)*(sj6)))+(((x1002)*(x1003)))+(((r20)*(x1001)))+(((cj4)*(r22)*(sj5)))+(((cj2)*(x992)))+(((x1002)*(x1004))));
evalcond[2]=((((IkReal(-1.00000000000000))*(r02)*(x998)))+(((IkReal(-1.00000000000000))*(sj2)*(x1007)))+(((x993)*(x994)))+(((IkReal(-1.00000000000000))*(x1000)*(x999)))+(((r12)*(x997)))+(((IkReal(-1.00000000000000))*(x1000)*(x1005)))+(((x993)*(x996))));
evalcond[3]=((((r02)*(x997)))+(((IkReal(-1.00000000000000))*(x992)))+(((IkReal(-1.00000000000000))*(x993)*(x999)))+(((IkReal(-1.00000000000000))*(x1005)*(x993)))+(((IkReal(-1.00000000000000))*(x1000)*(x994)))+(((r12)*(x998)))+(((IkReal(-1.00000000000000))*(x1000)*(x996))));
evalcond[4]=((((cj4)*(r02)*(x993)))+(((sj2)*(x992)))+(((r00)*(sj0)*(x1001)))+(((IkReal(-1.00000000000000))*(r12)*(x1000)*(x995)))+(((IkReal(-1.00000000000000))*(x1005)*(x995)*(x997)))+(((IkReal(-1.00000000000000))*(x995)*(x997)*(x999)))+(((IkReal(-1.00000000000000))*(r10)*(x1001)*(x1006)))+(((r11)*(x1008)))+(((cj4)*(x994)*(x998)))+(((cj4)*(x996)*(x998)))+(((IkReal(-1.00000000000000))*(r01)*(x1009))));
evalcond[5]=((((IkReal(-1.00000000000000))*(r12)*(x993)*(x995)))+(((IkReal(-1.00000000000000))*(x995)*(x998)*(x999)))+(((r01)*(x1008)))+(((IkReal(-1.00000000000000))*(r10)*(sj0)*(x1001)))+(((IkReal(-1.00000000000000))*(x1007)))+(((IkReal(-1.00000000000000))*(r02)*(x1000)*(x995)))+(((IkReal(-1.00000000000000))*(r00)*(x1001)*(x1006)))+(((IkReal(-1.00000000000000))*(x995)*(x996)*(x997)))+(((IkReal(-1.00000000000000))*(x994)*(x995)*(x997)))+(((r11)*(x1009)))+(((IkReal(-1.00000000000000))*(x1005)*(x995)*(x998))));
if( IKabs(evalcond[0]) > 0.000001  || IKabs(evalcond[1]) > 0.000001  || IKabs(evalcond[2]) > 0.000001  || IKabs(evalcond[3]) > 0.000001  || IKabs(evalcond[4]) > 0.000001  || IKabs(evalcond[5]) > 0.000001  )
{
continue;
}
}

{
std::vector<IkSingleDOFSolutionBase<IkReal> > vinfos(7);
vinfos[0].jointtype = 1;
vinfos[0].foffset = j0;
vinfos[0].indices[0] = _ij0[0];
vinfos[0].indices[1] = _ij0[1];
vinfos[0].maxsolutions = _nj0;
vinfos[1].jointtype = 1;
vinfos[1].foffset = j1;
vinfos[1].indices[0] = _ij1[0];
vinfos[1].indices[1] = _ij1[1];
vinfos[1].maxsolutions = _nj1;
vinfos[2].jointtype = 1;
vinfos[2].foffset = j2;
vinfos[2].indices[0] = _ij2[0];
vinfos[2].indices[1] = _ij2[1];
vinfos[2].maxsolutions = _nj2;
vinfos[3].jointtype = 1;
vinfos[3].foffset = j3;
vinfos[3].indices[0] = _ij3[0];
vinfos[3].indices[1] = _ij3[1];
vinfos[3].maxsolutions = _nj3;
vinfos[4].jointtype = 1;
vinfos[4].foffset = j4;
vinfos[4].indices[0] = _ij4[0];
vinfos[4].indices[1] = _ij4[1];
vinfos[4].maxsolutions = _nj4;
vinfos[5].jointtype = 1;
vinfos[5].foffset = j5;
vinfos[5].indices[0] = _ij5[0];
vinfos[5].indices[1] = _ij5[1];
vinfos[5].maxsolutions = _nj5;
vinfos[6].jointtype = 1;
vinfos[6].foffset = j6;
vinfos[6].indices[0] = _ij6[0];
vinfos[6].indices[1] = _ij6[1];
vinfos[6].maxsolutions = _nj6;
std::vector<int> vfree(0);
solutions.AddSolution(vinfos,vfree);
}
}
}

}

}

} else
{
{
IkReal j3array[1], cj3array[1], sj3array[1];
bool j3valid[1]={false};
_nj3 = 1;
IkReal x1010=((IkReal(1.00000000000000))*(cj4));
IkReal x1011=((cj6)*(r21));
IkReal x1012=((r20)*(sj6));
if( IKabs(((gconst43)*(((((sj5)*(x1012)))+(((sj5)*(x1011)))+(((IkReal(-1.00000000000000))*(cj5)*(r22))))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(((gconst43)*(((((r21)*(sj4)*(sj6)))+(((IkReal(-1.00000000000000))*(cj5)*(x1010)*(x1012)))+(((IkReal(-1.00000000000000))*(r22)*(sj5)*(x1010)))+(((IkReal(-1.00000000000000))*(cj5)*(x1010)*(x1011)))+(((IkReal(-1.00000000000000))*(cj6)*(r20)*(sj4))))))) < IKFAST_ATAN2_MAGTHRESH )
    continue;
j3array[0]=IKatan2(((gconst43)*(((((sj5)*(x1012)))+(((sj5)*(x1011)))+(((IkReal(-1.00000000000000))*(cj5)*(r22)))))), ((gconst43)*(((((r21)*(sj4)*(sj6)))+(((IkReal(-1.00000000000000))*(cj5)*(x1010)*(x1012)))+(((IkReal(-1.00000000000000))*(r22)*(sj5)*(x1010)))+(((IkReal(-1.00000000000000))*(cj5)*(x1010)*(x1011)))+(((IkReal(-1.00000000000000))*(cj6)*(r20)*(sj4)))))));
sj3array[0]=IKsin(j3array[0]);
cj3array[0]=IKcos(j3array[0]);
if( j3array[0] > IKPI )
{
    j3array[0]-=IK2PI;
}
else if( j3array[0] < -IKPI )
{    j3array[0]+=IK2PI;
}
j3valid[0] = true;
for(int ij3 = 0; ij3 < 1; ++ij3)
{
if( !j3valid[ij3] )
{
    continue;
}
_ij3[0] = ij3; _ij3[1] = -1;
for(int iij3 = ij3+1; iij3 < 1; ++iij3)
{
if( j3valid[iij3] && IKabs(cj3array[ij3]-cj3array[iij3]) < IKFAST_SOLUTION_THRESH && IKabs(sj3array[ij3]-sj3array[iij3]) < IKFAST_SOLUTION_THRESH )
{
    j3valid[iij3]=false; _ij3[1] = iij3; break; 
}
}
j3 = j3array[ij3]; cj3 = cj3array[ij3]; sj3 = sj3array[ij3];
{
IkReal evalcond[6];
IkReal x1013=IKsin(j3);
IkReal x1014=IKcos(j3);
IkReal x1015=((sj0)*(sj5));
IkReal x1016=((r00)*(sj6));
IkReal x1017=((IkReal(1.00000000000000))*(cj4));
IkReal x1018=((cj6)*(r01));
IkReal x1019=((cj0)*(cj5));
IkReal x1020=((cj5)*(sj0));
IkReal x1021=((cj6)*(r11));
IkReal x1022=((cj0)*(sj5));
IkReal x1023=((cj6)*(sj4));
IkReal x1024=((cj4)*(cj5));
IkReal x1025=((cj6)*(r21));
IkReal x1026=((r20)*(sj6));
IkReal x1027=((r10)*(sj6));
IkReal x1028=((IkReal(1.00000000000000))*(cj0));
IkReal x1029=((IkReal(1.00000000000000))*(x1013));
IkReal x1030=((cj0)*(sj4)*(sj6));
IkReal x1031=((sj0)*(sj4)*(sj6));
evalcond[0]=((((sj5)*(x1025)))+(((IkReal(-1.00000000000000))*(cj2)*(x1029)))+(((sj5)*(x1026)))+(((IkReal(-1.00000000000000))*(cj5)*(r22))));
evalcond[1]=((((IkReal(-1.00000000000000))*(r21)*(sj4)*(sj6)))+(((r20)*(x1023)))+(((x1024)*(x1025)))+(((x1024)*(x1026)))+(((cj4)*(r22)*(sj5)))+(((cj2)*(x1014))));
evalcond[2]=((((IkReal(-1.00000000000000))*(x1021)*(x1022)))+(((r12)*(x1019)))+(((IkReal(-1.00000000000000))*(r02)*(x1020)))+(((x1015)*(x1016)))+(((IkReal(-1.00000000000000))*(sj2)*(x1029)))+(((x1015)*(x1018)))+(((IkReal(-1.00000000000000))*(x1022)*(x1027))));
evalcond[3]=((((IkReal(-1.00000000000000))*(x1015)*(x1027)))+(((IkReal(-1.00000000000000))*(x1015)*(x1021)))+(((IkReal(-1.00000000000000))*(x1014)))+(((IkReal(-1.00000000000000))*(x1018)*(x1022)))+(((r12)*(x1020)))+(((r02)*(x1019)))+(((IkReal(-1.00000000000000))*(x1016)*(x1022))));
evalcond[4]=((((r11)*(x1030)))+(((IkReal(-1.00000000000000))*(r01)*(x1031)))+(((IkReal(-1.00000000000000))*(r12)*(x1017)*(x1022)))+(((r00)*(sj0)*(x1023)))+(((IkReal(-1.00000000000000))*(r10)*(x1023)*(x1028)))+(((IkReal(-1.00000000000000))*(x1017)*(x1019)*(x1021)))+(((cj4)*(x1018)*(x1020)))+(((IkReal(-1.00000000000000))*(x1017)*(x1019)*(x1027)))+(((cj4)*(x1016)*(x1020)))+(((cj4)*(r02)*(x1015)))+(((sj2)*(x1014))));
evalcond[5]=((((IkReal(-1.00000000000000))*(r02)*(x1017)*(x1022)))+(((IkReal(-1.00000000000000))*(r10)*(sj0)*(x1023)))+(((IkReal(-1.00000000000000))*(x1017)*(x1018)*(x1019)))+(((IkReal(-1.00000000000000))*(x1017)*(x1020)*(x1027)))+(((r01)*(x1030)))+(((IkReal(-1.00000000000000))*(r12)*(x1015)*(x1017)))+(((IkReal(-1.00000000000000))*(r00)*(x1023)*(x1028)))+(((IkReal(-1.00000000000000))*(x1017)*(x1020)*(x1021)))+(((IkReal(-1.00000000000000))*(x1029)))+(((IkReal(-1.00000000000000))*(x1016)*(x1017)*(x1019)))+(((r11)*(x1031))));
if( IKabs(evalcond[0]) > 0.000001  || IKabs(evalcond[1]) > 0.000001  || IKabs(evalcond[2]) > 0.000001  || IKabs(evalcond[3]) > 0.000001  || IKabs(evalcond[4]) > 0.000001  || IKabs(evalcond[5]) > 0.000001  )
{
continue;
}
}

{
std::vector<IkSingleDOFSolutionBase<IkReal> > vinfos(7);
vinfos[0].jointtype = 1;
vinfos[0].foffset = j0;
vinfos[0].indices[0] = _ij0[0];
vinfos[0].indices[1] = _ij0[1];
vinfos[0].maxsolutions = _nj0;
vinfos[1].jointtype = 1;
vinfos[1].foffset = j1;
vinfos[1].indices[0] = _ij1[0];
vinfos[1].indices[1] = _ij1[1];
vinfos[1].maxsolutions = _nj1;
vinfos[2].jointtype = 1;
vinfos[2].foffset = j2;
vinfos[2].indices[0] = _ij2[0];
vinfos[2].indices[1] = _ij2[1];
vinfos[2].maxsolutions = _nj2;
vinfos[3].jointtype = 1;
vinfos[3].foffset = j3;
vinfos[3].indices[0] = _ij3[0];
vinfos[3].indices[1] = _ij3[1];
vinfos[3].maxsolutions = _nj3;
vinfos[4].jointtype = 1;
vinfos[4].foffset = j4;
vinfos[4].indices[0] = _ij4[0];
vinfos[4].indices[1] = _ij4[1];
vinfos[4].maxsolutions = _nj4;
vinfos[5].jointtype = 1;
vinfos[5].foffset = j5;
vinfos[5].indices[0] = _ij5[0];
vinfos[5].indices[1] = _ij5[1];
vinfos[5].maxsolutions = _nj5;
vinfos[6].jointtype = 1;
vinfos[6].foffset = j6;
vinfos[6].indices[0] = _ij6[0];
vinfos[6].indices[1] = _ij6[1];
vinfos[6].maxsolutions = _nj6;
std::vector<int> vfree(0);
solutions.AddSolution(vinfos,vfree);
}
}
}

}

}
}
}

}

}

} else
{
{
IkReal j4array[1], cj4array[1], sj4array[1];
bool j4valid[1]={false};
_nj4 = 1;
IkReal x1032=((r11)*(sj0));
IkReal x1033=((cj0)*(r01));
IkReal x1034=((cj0)*(sj2));
IkReal x1035=((sj0)*(sj2));
IkReal x1036=((cj5)*(sj6));
IkReal x1037=((IkReal(1.00000000000000))*(sj2)*(sj6));
IkReal x1038=((cj5)*(cj6)*(sj2));
if( IKabs(((gconst40)*(((((IkReal(-1.00000000000000))*(x1032)*(x1037)))+(((cj6)*(r10)*(x1035)))+(((IkReal(-1.00000000000000))*(x1033)*(x1037)))+(((cj6)*(r00)*(x1034))))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(((gconst40)*(((((r00)*(x1034)*(x1036)))+(((x1033)*(x1038)))+(((r02)*(sj5)*(x1034)))+(((r10)*(x1035)*(x1036)))+(((x1032)*(x1038)))+(((r12)*(sj5)*(x1035))))))) < IKFAST_ATAN2_MAGTHRESH )
    continue;
j4array[0]=IKatan2(((gconst40)*(((((IkReal(-1.00000000000000))*(x1032)*(x1037)))+(((cj6)*(r10)*(x1035)))+(((IkReal(-1.00000000000000))*(x1033)*(x1037)))+(((cj6)*(r00)*(x1034)))))), ((gconst40)*(((((r00)*(x1034)*(x1036)))+(((x1033)*(x1038)))+(((r02)*(sj5)*(x1034)))+(((r10)*(x1035)*(x1036)))+(((x1032)*(x1038)))+(((r12)*(sj5)*(x1035)))))));
sj4array[0]=IKsin(j4array[0]);
cj4array[0]=IKcos(j4array[0]);
if( j4array[0] > IKPI )
{
    j4array[0]-=IK2PI;
}
else if( j4array[0] < -IKPI )
{    j4array[0]+=IK2PI;
}
j4valid[0] = true;
for(int ij4 = 0; ij4 < 1; ++ij4)
{
if( !j4valid[ij4] )
{
    continue;
}
_ij4[0] = ij4; _ij4[1] = -1;
for(int iij4 = ij4+1; iij4 < 1; ++iij4)
{
if( j4valid[iij4] && IKabs(cj4array[ij4]-cj4array[iij4]) < IKFAST_SOLUTION_THRESH && IKabs(sj4array[ij4]-sj4array[iij4]) < IKFAST_SOLUTION_THRESH )
{
    j4valid[iij4]=false; _ij4[1] = iij4; break; 
}
}
j4 = j4array[ij4]; cj4 = cj4array[ij4]; sj4 = sj4array[ij4];
{
IkReal evalcond[3];
IkReal x1039=IKsin(j4);
IkReal x1040=IKcos(j4);
IkReal x1041=((r00)*(sj6));
IkReal x1042=((cj6)*(r01));
IkReal x1043=((IkReal(1.00000000000000))*(cj0));
IkReal x1044=((IkReal(1.00000000000000))*(sj0));
IkReal x1045=((r10)*(sj6));
IkReal x1046=((sj5)*(x1039));
IkReal x1047=((IkReal(1.00000000000000))*(cj6)*(r11));
IkReal x1048=((cj5)*(x1039));
IkReal x1049=((cj6)*(x1040));
IkReal x1050=((sj0)*(x1048));
IkReal x1051=((r01)*(sj6)*(x1040));
IkReal x1052=((r11)*(sj6)*(x1040));
evalcond[0]=((((r22)*(x1046)))+(((IkReal(-1.00000000000000))*(sj2)))+(((IkReal(-1.00000000000000))*(r20)*(x1049)))+(((r20)*(sj6)*(x1048)))+(((r21)*(sj6)*(x1040)))+(((cj6)*(r21)*(x1048))));
evalcond[1]=((((IkReal(-1.00000000000000))*(x1043)*(x1045)*(x1048)))+(((sj0)*(x1051)))+(((IkReal(-1.00000000000000))*(x1043)*(x1052)))+(((IkReal(-1.00000000000000))*(r12)*(x1043)*(x1046)))+(((cj0)*(r10)*(x1049)))+(((IkReal(-1.00000000000000))*(r00)*(x1044)*(x1049)))+(((IkReal(-1.00000000000000))*(cj6)*(r11)*(x1043)*(x1048)))+(cj2)+(((x1042)*(x1050)))+(((x1041)*(x1050)))+(((r02)*(sj0)*(x1046))));
evalcond[2]=((((IkReal(-1.00000000000000))*(x1044)*(x1052)))+(((IkReal(-1.00000000000000))*(x1041)*(x1043)*(x1048)))+(((IkReal(-1.00000000000000))*(x1044)*(x1045)*(x1048)))+(((IkReal(-1.00000000000000))*(r02)*(x1043)*(x1046)))+(((IkReal(-1.00000000000000))*(r12)*(x1044)*(x1046)))+(((IkReal(-1.00000000000000))*(x1042)*(x1043)*(x1048)))+(((r10)*(sj0)*(x1049)))+(((IkReal(-1.00000000000000))*(cj6)*(r11)*(x1044)*(x1048)))+(((cj0)*(r00)*(x1049)))+(((IkReal(-1.00000000000000))*(x1043)*(x1051))));
if( IKabs(evalcond[0]) > 0.000001  || IKabs(evalcond[1]) > 0.000001  || IKabs(evalcond[2]) > 0.000001  )
{
continue;
}
}

{
IkReal dummyeval[1];
IkReal gconst43;
gconst43=IKsign(cj2);
dummyeval[0]=cj2;
if( IKabs(dummyeval[0]) < 0.0000010000000000  )
{
{
IkReal dummyeval[1];
dummyeval[0]=cj2;
if( IKabs(dummyeval[0]) < 0.0000010000000000  )
{
{
IkReal dummyeval[1];
dummyeval[0]=sj2;
if( IKabs(dummyeval[0]) < 0.0000010000000000  )
{
{
IkReal evalcond[9];
IkReal x1053=((cj5)*(sj4));
IkReal x1054=((IkReal(1.00000000000000))*(sj6));
IkReal x1055=((r10)*(sj0));
IkReal x1056=((sj4)*(sj5));
IkReal x1057=((cj5)*(cj6));
IkReal x1058=((r01)*(sj0));
IkReal x1059=((IkReal(1.00000000000000))*(r02));
IkReal x1060=((IkReal(0.374290000000000))*(cj0));
IkReal x1061=((cj5)*(r12));
IkReal x1062=((cj6)*(sj5));
IkReal x1063=((cj0)*(r11));
IkReal x1064=((cj5)*(sj0));
IkReal x1065=((r20)*(sj6));
IkReal x1066=((IkReal(1.00000000000000))*(sj0));
IkReal x1067=((cj4)*(cj5));
IkReal x1068=((IkReal(1.00000000000000))*(cj6));
IkReal x1069=((IkReal(0.0100000000000000))*(sj5));
IkReal x1070=((sj5)*(sj6));
IkReal x1071=((cj0)*(r10));
IkReal x1072=((cj4)*(cj6));
IkReal x1073=((cj0)*(r01));
IkReal x1074=((IkReal(1.00000000000000))*(cj4));
IkReal x1075=((cj0)*(r00));
IkReal x1076=((IkReal(0.374290000000000))*(sj0));
IkReal x1077=((cj0)*(r12));
IkReal x1078=((IkReal(0.374290000000000))*(sj5));
IkReal x1079=((cj4)*(sj6));
IkReal x1080=((IkReal(1.00000000000000))*(cj0));
IkReal x1081=((r02)*(sj0));
IkReal x1082=((IkReal(0.0100000000000000))*(cj5));
IkReal x1083=((r11)*(sj0));
IkReal x1084=((r00)*(sj0)*(sj6));
IkReal x1085=((r00)*(x1072));
IkReal x1086=((sj6)*(x1082));
evalcond[0]=((IkReal(-3.14159265358979))+(IKfmod(((IkReal(3.14159265358979))+(j2)), IkReal(6.28318530717959))));
evalcond[1]=((((x1053)*(x1065)))+(((r21)*(x1079)))+(((cj6)*(r21)*(x1053)))+(((r22)*(x1056)))+(((IkReal(-1.00000000000000))*(cj4)*(r20)*(x1068))));
evalcond[2]=((IkReal(0.0690000000000000))+(((IkReal(-1.00000000000000))*(r22)*(x1069)))+(((x1065)*(x1078)))+(((IkReal(-0.0100000000000000))*(r21)*(x1057)))+(((IkReal(-1.00000000000000))*(x1065)*(x1082)))+(((IkReal(-0.374290000000000))*(cj5)*(r22)))+(pz)+(((IkReal(0.374290000000000))*(r21)*(x1062))));
evalcond[3]=((((IkReal(-1.00000000000000))*(x1062)*(x1063)))+(((IkReal(-1.00000000000000))*(sj5)*(x1054)*(x1071)))+(((IkReal(-1.00000000000000))*(x1059)*(x1064)))+(((x1058)*(x1062)))+(((r00)*(sj0)*(x1070)))+(((cj0)*(x1061))));
evalcond[4]=((IkReal(1.00000000000000))+(((IkReal(-1.00000000000000))*(cj4)*(x1054)*(x1063)))+(((cj6)*(x1053)*(x1058)))+(((IkReal(-1.00000000000000))*(x1056)*(x1077)))+(((IkReal(-1.00000000000000))*(x1066)*(x1085)))+(((x1071)*(x1072)))+(((x1053)*(x1084)))+(((IkReal(-1.00000000000000))*(x1053)*(x1063)*(x1068)))+(((x1058)*(x1079)))+(((IkReal(-1.00000000000000))*(x1053)*(x1054)*(x1071)))+(((x1056)*(x1081))));
evalcond[5]=((((sj4)*(sj6)*(x1063)))+(((IkReal(-1.00000000000000))*(sj4)*(x1054)*(x1058)))+(((cj6)*(r00)*(sj0)*(sj4)))+(((IkReal(-1.00000000000000))*(sj4)*(x1068)*(x1071)))+(((IkReal(-1.00000000000000))*(sj5)*(x1074)*(x1077)))+(((cj4)*(x1057)*(x1058)))+(((IkReal(-1.00000000000000))*(x1057)*(x1063)*(x1074)))+(((IkReal(-1.00000000000000))*(x1054)*(x1067)*(x1071)))+(((cj4)*(sj5)*(x1081)))+(((r00)*(x1064)*(x1079))));
evalcond[6]=((((x1072)*(x1075)))+(((IkReal(-1.00000000000000))*(cj4)*(x1054)*(x1073)))+(((x1055)*(x1072)))+(((IkReal(-1.00000000000000))*(x1053)*(x1068)*(x1073)))+(((IkReal(-1.00000000000000))*(cj0)*(x1056)*(x1059)))+(((IkReal(-1.00000000000000))*(cj6)*(r11)*(x1053)*(x1066)))+(((IkReal(-1.00000000000000))*(cj4)*(x1054)*(x1083)))+(((IkReal(-1.00000000000000))*(x1053)*(x1054)*(x1075)))+(((IkReal(-1.00000000000000))*(x1053)*(x1054)*(x1055)))+(((IkReal(-1.00000000000000))*(r12)*(x1056)*(x1066))));
evalcond[7]=((((IkReal(-1.00000000000000))*(py)*(x1080)))+(((IkReal(-0.0100000000000000))*(x1057)*(x1058)))+(((x1060)*(x1061)))+(((IkReal(-0.0100000000000000))*(r00)*(sj6)*(x1064)))+(((IkReal(-1.00000000000000))*(r11)*(x1060)*(x1062)))+(((IkReal(-1.00000000000000))*(r10)*(x1060)*(x1070)))+(((x1071)*(x1086)))+(((IkReal(0.0100000000000000))*(x1057)*(x1063)))+(((x1069)*(x1077)))+(((IkReal(-0.374290000000000))*(r02)*(x1064)))+(((IkReal(0.374290000000000))*(x1058)*(x1062)))+(((r00)*(x1070)*(x1076)))+(((px)*(sj0)))+(((IkReal(-1.00000000000000))*(x1069)*(x1081))));
evalcond[8]=((IkReal(0.433420000000000))+(((x1061)*(x1076)))+(((IkReal(-0.374290000000000))*(x1055)*(x1070)))+(((IkReal(0.0100000000000000))*(x1057)*(x1073)))+(((IkReal(-1.00000000000000))*(r01)*(x1060)*(x1062)))+(((IkReal(-1.00000000000000))*(r00)*(x1060)*(x1070)))+(((IkReal(-1.00000000000000))*(px)*(x1080)))+(((r12)*(sj0)*(x1069)))+(((IkReal(-1.00000000000000))*(r11)*(x1062)*(x1076)))+(((cj0)*(r02)*(x1069)))+(((IkReal(-1.00000000000000))*(py)*(x1066)))+(((IkReal(0.0100000000000000))*(x1057)*(x1083)))+(((cj5)*(r02)*(x1060)))+(((x1055)*(x1086)))+(((x1075)*(x1086))));
if( IKabs(evalcond[0]) < 0.0000010000000000  && IKabs(evalcond[1]) < 0.0000010000000000  && IKabs(evalcond[2]) < 0.0000010000000000  && IKabs(evalcond[3]) < 0.0000010000000000  && IKabs(evalcond[4]) < 0.0000010000000000  && IKabs(evalcond[5]) < 0.0000010000000000  && IKabs(evalcond[6]) < 0.0000010000000000  && IKabs(evalcond[7]) < 0.0000010000000000  && IKabs(evalcond[8]) < 0.0000010000000000  )
{
{
IkReal j3array[1], cj3array[1], sj3array[1];
bool j3valid[1]={false};
_nj3 = 1;
IkReal x1087=((IkReal(1.00000000000000))*(cj4));
IkReal x1088=((cj6)*(r21));
IkReal x1089=((r20)*(sj6));
if( IKabs(((((sj5)*(x1089)))+(((IkReal(-1.00000000000000))*(cj5)*(r22)))+(((sj5)*(x1088))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(((((IkReal(-1.00000000000000))*(r22)*(sj5)*(x1087)))+(((IkReal(-1.00000000000000))*(cj5)*(x1087)*(x1089)))+(((r21)*(sj4)*(sj6)))+(((IkReal(-1.00000000000000))*(cj5)*(x1087)*(x1088)))+(((IkReal(-1.00000000000000))*(cj6)*(r20)*(sj4))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(IKsqr(((((sj5)*(x1089)))+(((IkReal(-1.00000000000000))*(cj5)*(r22)))+(((sj5)*(x1088)))))+IKsqr(((((IkReal(-1.00000000000000))*(r22)*(sj5)*(x1087)))+(((IkReal(-1.00000000000000))*(cj5)*(x1087)*(x1089)))+(((r21)*(sj4)*(sj6)))+(((IkReal(-1.00000000000000))*(cj5)*(x1087)*(x1088)))+(((IkReal(-1.00000000000000))*(cj6)*(r20)*(sj4)))))-1) <= IKFAST_SINCOS_THRESH )
    continue;
j3array[0]=IKatan2(((((sj5)*(x1089)))+(((IkReal(-1.00000000000000))*(cj5)*(r22)))+(((sj5)*(x1088)))), ((((IkReal(-1.00000000000000))*(r22)*(sj5)*(x1087)))+(((IkReal(-1.00000000000000))*(cj5)*(x1087)*(x1089)))+(((r21)*(sj4)*(sj6)))+(((IkReal(-1.00000000000000))*(cj5)*(x1087)*(x1088)))+(((IkReal(-1.00000000000000))*(cj6)*(r20)*(sj4)))));
sj3array[0]=IKsin(j3array[0]);
cj3array[0]=IKcos(j3array[0]);
if( j3array[0] > IKPI )
{
    j3array[0]-=IK2PI;
}
else if( j3array[0] < -IKPI )
{    j3array[0]+=IK2PI;
}
j3valid[0] = true;
for(int ij3 = 0; ij3 < 1; ++ij3)
{
if( !j3valid[ij3] )
{
    continue;
}
_ij3[0] = ij3; _ij3[1] = -1;
for(int iij3 = ij3+1; iij3 < 1; ++iij3)
{
if( j3valid[iij3] && IKabs(cj3array[ij3]-cj3array[iij3]) < IKFAST_SOLUTION_THRESH && IKabs(sj3array[ij3]-sj3array[iij3]) < IKFAST_SOLUTION_THRESH )
{
    j3valid[iij3]=false; _ij3[1] = iij3; break; 
}
}
j3 = j3array[ij3]; cj3 = cj3array[ij3]; sj3 = sj3array[ij3];
{
IkReal evalcond[4];
IkReal x1090=IKcos(j3);
IkReal x1091=((IkReal(1.00000000000000))*(cj4));
IkReal x1092=((sj0)*(sj5));
IkReal x1093=((cj0)*(cj5));
IkReal x1094=((cj6)*(r01));
IkReal x1095=((r00)*(sj6));
IkReal x1096=((cj6)*(r11));
IkReal x1097=((cj5)*(sj0));
IkReal x1098=((cj6)*(sj4));
IkReal x1099=((sj4)*(sj6));
IkReal x1100=((cj4)*(cj5));
IkReal x1101=((cj6)*(r21));
IkReal x1102=((r20)*(sj6));
IkReal x1103=((r10)*(sj6));
IkReal x1104=((IkReal(1.00000000000000))*(IKsin(j3)));
IkReal x1105=((IkReal(1.00000000000000))*(cj0)*(sj5));
evalcond[0]=((((IkReal(-1.00000000000000))*(x1104)))+(((IkReal(-1.00000000000000))*(cj5)*(r22)))+(((sj5)*(x1102)))+(((sj5)*(x1101))));
evalcond[1]=((((r20)*(x1098)))+(((cj4)*(r22)*(sj5)))+(((IkReal(-1.00000000000000))*(r21)*(x1099)))+(x1090)+(((x1100)*(x1101)))+(((x1100)*(x1102))));
evalcond[2]=((((IkReal(-1.00000000000000))*(x1095)*(x1105)))+(((IkReal(-1.00000000000000))*(x1094)*(x1105)))+(((r02)*(x1093)))+(((IkReal(-1.00000000000000))*(x1092)*(x1103)))+(((IkReal(-1.00000000000000))*(x1092)*(x1096)))+(((r12)*(x1097)))+(((IkReal(-1.00000000000000))*(x1090))));
evalcond[3]=((((IkReal(-1.00000000000000))*(x1091)*(x1093)*(x1095)))+(((IkReal(-1.00000000000000))*(x1104)))+(((IkReal(-1.00000000000000))*(r12)*(x1091)*(x1092)))+(((IkReal(-1.00000000000000))*(x1091)*(x1093)*(x1094)))+(((cj0)*(r01)*(x1099)))+(((IkReal(-1.00000000000000))*(cj0)*(r02)*(sj5)*(x1091)))+(((IkReal(-1.00000000000000))*(r10)*(sj0)*(x1098)))+(((IkReal(-1.00000000000000))*(x1091)*(x1097)*(x1103)))+(((r11)*(sj0)*(x1099)))+(((IkReal(-1.00000000000000))*(x1091)*(x1096)*(x1097)))+(((IkReal(-1.00000000000000))*(cj0)*(r00)*(x1098))));
if( IKabs(evalcond[0]) > 0.000001  || IKabs(evalcond[1]) > 0.000001  || IKabs(evalcond[2]) > 0.000001  || IKabs(evalcond[3]) > 0.000001  )
{
continue;
}
}

{
std::vector<IkSingleDOFSolutionBase<IkReal> > vinfos(7);
vinfos[0].jointtype = 1;
vinfos[0].foffset = j0;
vinfos[0].indices[0] = _ij0[0];
vinfos[0].indices[1] = _ij0[1];
vinfos[0].maxsolutions = _nj0;
vinfos[1].jointtype = 1;
vinfos[1].foffset = j1;
vinfos[1].indices[0] = _ij1[0];
vinfos[1].indices[1] = _ij1[1];
vinfos[1].maxsolutions = _nj1;
vinfos[2].jointtype = 1;
vinfos[2].foffset = j2;
vinfos[2].indices[0] = _ij2[0];
vinfos[2].indices[1] = _ij2[1];
vinfos[2].maxsolutions = _nj2;
vinfos[3].jointtype = 1;
vinfos[3].foffset = j3;
vinfos[3].indices[0] = _ij3[0];
vinfos[3].indices[1] = _ij3[1];
vinfos[3].maxsolutions = _nj3;
vinfos[4].jointtype = 1;
vinfos[4].foffset = j4;
vinfos[4].indices[0] = _ij4[0];
vinfos[4].indices[1] = _ij4[1];
vinfos[4].maxsolutions = _nj4;
vinfos[5].jointtype = 1;
vinfos[5].foffset = j5;
vinfos[5].indices[0] = _ij5[0];
vinfos[5].indices[1] = _ij5[1];
vinfos[5].maxsolutions = _nj5;
vinfos[6].jointtype = 1;
vinfos[6].foffset = j6;
vinfos[6].indices[0] = _ij6[0];
vinfos[6].indices[1] = _ij6[1];
vinfos[6].maxsolutions = _nj6;
std::vector<int> vfree(0);
solutions.AddSolution(vinfos,vfree);
}
}
}

} else
{
IkReal x1106=((cj5)*(sj4));
IkReal x1107=((IkReal(1.00000000000000))*(sj6));
IkReal x1108=((r10)*(sj0));
IkReal x1109=((sj4)*(sj5));
IkReal x1110=((cj5)*(cj6));
IkReal x1111=((r01)*(sj0));
IkReal x1112=((IkReal(1.00000000000000))*(r02));
IkReal x1113=((IkReal(0.374290000000000))*(cj0));
IkReal x1114=((cj5)*(r12));
IkReal x1115=((cj6)*(sj5));
IkReal x1116=((cj0)*(r11));
IkReal x1117=((cj5)*(sj0));
IkReal x1118=((r20)*(sj6));
IkReal x1119=((IkReal(1.00000000000000))*(sj0));
IkReal x1120=((cj4)*(cj5));
IkReal x1121=((IkReal(1.00000000000000))*(cj6));
IkReal x1122=((IkReal(0.0100000000000000))*(sj5));
IkReal x1123=((sj5)*(sj6));
IkReal x1124=((cj0)*(r10));
IkReal x1125=((cj4)*(cj6));
IkReal x1126=((cj0)*(r01));
IkReal x1127=((IkReal(1.00000000000000))*(cj4));
IkReal x1128=((cj0)*(r00));
IkReal x1129=((IkReal(0.374290000000000))*(sj0));
IkReal x1130=((cj0)*(r12));
IkReal x1131=((IkReal(0.374290000000000))*(sj5));
IkReal x1132=((cj4)*(sj6));
IkReal x1133=((IkReal(1.00000000000000))*(cj0));
IkReal x1134=((r02)*(sj0));
IkReal x1135=((IkReal(0.0100000000000000))*(cj5));
IkReal x1136=((r11)*(sj0));
IkReal x1137=((r00)*(sj0)*(sj6));
IkReal x1138=((r00)*(x1125));
IkReal x1139=((sj6)*(x1135));
evalcond[0]=((IkReal(-3.14159265358979))+(IKfmod(j2, IkReal(6.28318530717959))));
evalcond[1]=((((r21)*(x1132)))+(((cj6)*(r21)*(x1106)))+(((x1106)*(x1118)))+(((r22)*(x1109)))+(((IkReal(-1.00000000000000))*(cj4)*(r20)*(x1121))));
evalcond[2]=((IkReal(-0.0690000000000000))+(((IkReal(0.374290000000000))*(r21)*(x1115)))+(((IkReal(-0.0100000000000000))*(r21)*(x1110)))+(((IkReal(-0.374290000000000))*(cj5)*(r22)))+(pz)+(((IkReal(-1.00000000000000))*(r22)*(x1122)))+(((IkReal(-1.00000000000000))*(x1118)*(x1135)))+(((x1118)*(x1131))));
evalcond[3]=((((IkReal(-1.00000000000000))*(sj5)*(x1107)*(x1124)))+(((x1111)*(x1115)))+(((IkReal(-1.00000000000000))*(x1115)*(x1116)))+(((r00)*(sj0)*(x1123)))+(((cj0)*(x1114)))+(((IkReal(-1.00000000000000))*(x1112)*(x1117))));
evalcond[4]=((IkReal(-1.00000000000000))+(((IkReal(-1.00000000000000))*(x1106)*(x1107)*(x1124)))+(((x1106)*(x1137)))+(((IkReal(-1.00000000000000))*(x1119)*(x1138)))+(((IkReal(-1.00000000000000))*(cj4)*(x1107)*(x1116)))+(((IkReal(-1.00000000000000))*(x1109)*(x1130)))+(((x1124)*(x1125)))+(((x1111)*(x1132)))+(((IkReal(-1.00000000000000))*(x1106)*(x1116)*(x1121)))+(((x1109)*(x1134)))+(((cj6)*(x1106)*(x1111))));
evalcond[5]=((((IkReal(-1.00000000000000))*(sj5)*(x1127)*(x1130)))+(((cj4)*(sj5)*(x1134)))+(((IkReal(-1.00000000000000))*(x1107)*(x1120)*(x1124)))+(((cj4)*(x1110)*(x1111)))+(((cj6)*(r00)*(sj0)*(sj4)))+(((r00)*(x1117)*(x1132)))+(((sj4)*(sj6)*(x1116)))+(((IkReal(-1.00000000000000))*(sj4)*(x1107)*(x1111)))+(((IkReal(-1.00000000000000))*(sj4)*(x1121)*(x1124)))+(((IkReal(-1.00000000000000))*(x1110)*(x1116)*(x1127))));
evalcond[6]=((((x1108)*(x1125)))+(((IkReal(-1.00000000000000))*(cj4)*(x1107)*(x1136)))+(((x1125)*(x1128)))+(((IkReal(-1.00000000000000))*(x1106)*(x1107)*(x1108)))+(((IkReal(-1.00000000000000))*(cj4)*(x1107)*(x1126)))+(((IkReal(-1.00000000000000))*(x1106)*(x1121)*(x1126)))+(((IkReal(-1.00000000000000))*(x1106)*(x1107)*(x1128)))+(((IkReal(-1.00000000000000))*(cj6)*(r11)*(x1106)*(x1119)))+(((IkReal(-1.00000000000000))*(r12)*(x1109)*(x1119)))+(((IkReal(-1.00000000000000))*(cj0)*(x1109)*(x1112))));
evalcond[7]=((((IkReal(-1.00000000000000))*(py)*(x1133)))+(((x1122)*(x1130)))+(((IkReal(-1.00000000000000))*(r11)*(x1113)*(x1115)))+(((IkReal(-0.0100000000000000))*(r00)*(sj6)*(x1117)))+(((r00)*(x1123)*(x1129)))+(((IkReal(0.0100000000000000))*(x1110)*(x1116)))+(((IkReal(-1.00000000000000))*(r10)*(x1113)*(x1123)))+(((IkReal(-1.00000000000000))*(x1122)*(x1134)))+(((x1124)*(x1139)))+(((IkReal(0.374290000000000))*(x1111)*(x1115)))+(((px)*(sj0)))+(((x1113)*(x1114)))+(((IkReal(-0.0100000000000000))*(x1110)*(x1111)))+(((IkReal(-0.374290000000000))*(r02)*(x1117))));
evalcond[8]=((IkReal(0.433420000000000))+(((r12)*(sj0)*(x1122)))+(((x1114)*(x1129)))+(((IkReal(0.0100000000000000))*(x1110)*(x1136)))+(((x1128)*(x1139)))+(((IkReal(-0.374290000000000))*(x1108)*(x1123)))+(((IkReal(-1.00000000000000))*(r00)*(x1113)*(x1123)))+(((IkReal(-1.00000000000000))*(px)*(x1133)))+(((IkReal(-1.00000000000000))*(r11)*(x1115)*(x1129)))+(((IkReal(-1.00000000000000))*(py)*(x1119)))+(((cj0)*(r02)*(x1122)))+(((IkReal(-1.00000000000000))*(r01)*(x1113)*(x1115)))+(((x1108)*(x1139)))+(((cj5)*(r02)*(x1113)))+(((IkReal(0.0100000000000000))*(x1110)*(x1126))));
if( IKabs(evalcond[0]) < 0.0000010000000000  && IKabs(evalcond[1]) < 0.0000010000000000  && IKabs(evalcond[2]) < 0.0000010000000000  && IKabs(evalcond[3]) < 0.0000010000000000  && IKabs(evalcond[4]) < 0.0000010000000000  && IKabs(evalcond[5]) < 0.0000010000000000  && IKabs(evalcond[6]) < 0.0000010000000000  && IKabs(evalcond[7]) < 0.0000010000000000  && IKabs(evalcond[8]) < 0.0000010000000000  )
{
{
IkReal j3array[1], cj3array[1], sj3array[1];
bool j3valid[1]={false};
_nj3 = 1;
IkReal x1140=((IkReal(1.00000000000000))*(r21));
IkReal x1141=((cj4)*(cj5));
IkReal x1142=((r20)*(sj6));
if( IKabs(((((IkReal(-1.00000000000000))*(sj5)*(x1142)))+(((IkReal(-1.00000000000000))*(cj6)*(sj5)*(x1140)))+(((cj5)*(r22))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(((((cj6)*(r20)*(sj4)))+(((x1141)*(x1142)))+(((cj4)*(r22)*(sj5)))+(((cj6)*(r21)*(x1141)))+(((IkReal(-1.00000000000000))*(sj4)*(sj6)*(x1140))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(IKsqr(((((IkReal(-1.00000000000000))*(sj5)*(x1142)))+(((IkReal(-1.00000000000000))*(cj6)*(sj5)*(x1140)))+(((cj5)*(r22)))))+IKsqr(((((cj6)*(r20)*(sj4)))+(((x1141)*(x1142)))+(((cj4)*(r22)*(sj5)))+(((cj6)*(r21)*(x1141)))+(((IkReal(-1.00000000000000))*(sj4)*(sj6)*(x1140)))))-1) <= IKFAST_SINCOS_THRESH )
    continue;
j3array[0]=IKatan2(((((IkReal(-1.00000000000000))*(sj5)*(x1142)))+(((IkReal(-1.00000000000000))*(cj6)*(sj5)*(x1140)))+(((cj5)*(r22)))), ((((cj6)*(r20)*(sj4)))+(((x1141)*(x1142)))+(((cj4)*(r22)*(sj5)))+(((cj6)*(r21)*(x1141)))+(((IkReal(-1.00000000000000))*(sj4)*(sj6)*(x1140)))));
sj3array[0]=IKsin(j3array[0]);
cj3array[0]=IKcos(j3array[0]);
if( j3array[0] > IKPI )
{
    j3array[0]-=IK2PI;
}
else if( j3array[0] < -IKPI )
{    j3array[0]+=IK2PI;
}
j3valid[0] = true;
for(int ij3 = 0; ij3 < 1; ++ij3)
{
if( !j3valid[ij3] )
{
    continue;
}
_ij3[0] = ij3; _ij3[1] = -1;
for(int iij3 = ij3+1; iij3 < 1; ++iij3)
{
if( j3valid[iij3] && IKabs(cj3array[ij3]-cj3array[iij3]) < IKFAST_SOLUTION_THRESH && IKabs(sj3array[ij3]-sj3array[iij3]) < IKFAST_SOLUTION_THRESH )
{
    j3valid[iij3]=false; _ij3[1] = iij3; break; 
}
}
j3 = j3array[ij3]; cj3 = cj3array[ij3]; sj3 = sj3array[ij3];
{
IkReal evalcond[4];
IkReal x1143=IKsin(j3);
IkReal x1144=((IkReal(1.00000000000000))*(cj4));
IkReal x1145=((sj0)*(sj5));
IkReal x1146=((cj0)*(cj5));
IkReal x1147=((cj6)*(r01));
IkReal x1148=((r00)*(sj6));
IkReal x1149=((cj6)*(r11));
IkReal x1150=((cj5)*(sj0));
IkReal x1151=((cj6)*(sj4));
IkReal x1152=((sj4)*(sj6));
IkReal x1153=((cj4)*(cj5));
IkReal x1154=((cj6)*(r21));
IkReal x1155=((r20)*(sj6));
IkReal x1156=((r10)*(sj6));
IkReal x1157=((IkReal(1.00000000000000))*(IKcos(j3)));
IkReal x1158=((IkReal(1.00000000000000))*(cj0)*(sj5));
evalcond[0]=((x1143)+(((sj5)*(x1154)))+(((IkReal(-1.00000000000000))*(cj5)*(r22)))+(((sj5)*(x1155))));
evalcond[1]=((((IkReal(-1.00000000000000))*(r21)*(x1152)))+(((cj4)*(r22)*(sj5)))+(((x1153)*(x1154)))+(((x1153)*(x1155)))+(((r20)*(x1151)))+(((IkReal(-1.00000000000000))*(x1157))));
evalcond[2]=((((r02)*(x1146)))+(((IkReal(-1.00000000000000))*(x1145)*(x1149)))+(((IkReal(-1.00000000000000))*(x1148)*(x1158)))+(((IkReal(-1.00000000000000))*(x1145)*(x1156)))+(((r12)*(x1150)))+(((IkReal(-1.00000000000000))*(x1147)*(x1158)))+(((IkReal(-1.00000000000000))*(x1157))));
evalcond[3]=((((IkReal(-1.00000000000000))*(r12)*(x1144)*(x1145)))+(((IkReal(-1.00000000000000))*(x1144)*(x1146)*(x1148)))+(((IkReal(-1.00000000000000))*(x1144)*(x1150)*(x1156)))+(((IkReal(-1.00000000000000))*(r10)*(sj0)*(x1151)))+(((IkReal(-1.00000000000000))*(x1144)*(x1149)*(x1150)))+(((r11)*(sj0)*(x1152)))+(((IkReal(-1.00000000000000))*(cj0)*(r02)*(sj5)*(x1144)))+(((IkReal(-1.00000000000000))*(x1143)))+(((IkReal(-1.00000000000000))*(cj0)*(r00)*(x1151)))+(((cj0)*(r01)*(x1152)))+(((IkReal(-1.00000000000000))*(x1144)*(x1146)*(x1147))));
if( IKabs(evalcond[0]) > 0.000001  || IKabs(evalcond[1]) > 0.000001  || IKabs(evalcond[2]) > 0.000001  || IKabs(evalcond[3]) > 0.000001  )
{
continue;
}
}

{
std::vector<IkSingleDOFSolutionBase<IkReal> > vinfos(7);
vinfos[0].jointtype = 1;
vinfos[0].foffset = j0;
vinfos[0].indices[0] = _ij0[0];
vinfos[0].indices[1] = _ij0[1];
vinfos[0].maxsolutions = _nj0;
vinfos[1].jointtype = 1;
vinfos[1].foffset = j1;
vinfos[1].indices[0] = _ij1[0];
vinfos[1].indices[1] = _ij1[1];
vinfos[1].maxsolutions = _nj1;
vinfos[2].jointtype = 1;
vinfos[2].foffset = j2;
vinfos[2].indices[0] = _ij2[0];
vinfos[2].indices[1] = _ij2[1];
vinfos[2].maxsolutions = _nj2;
vinfos[3].jointtype = 1;
vinfos[3].foffset = j3;
vinfos[3].indices[0] = _ij3[0];
vinfos[3].indices[1] = _ij3[1];
vinfos[3].maxsolutions = _nj3;
vinfos[4].jointtype = 1;
vinfos[4].foffset = j4;
vinfos[4].indices[0] = _ij4[0];
vinfos[4].indices[1] = _ij4[1];
vinfos[4].maxsolutions = _nj4;
vinfos[5].jointtype = 1;
vinfos[5].foffset = j5;
vinfos[5].indices[0] = _ij5[0];
vinfos[5].indices[1] = _ij5[1];
vinfos[5].maxsolutions = _nj5;
vinfos[6].jointtype = 1;
vinfos[6].foffset = j6;
vinfos[6].indices[0] = _ij6[0];
vinfos[6].indices[1] = _ij6[1];
vinfos[6].maxsolutions = _nj6;
std::vector<int> vfree(0);
solutions.AddSolution(vinfos,vfree);
}
}
}

} else
{
IkReal x1159=((IkReal(1.00000000000000))*(cj0));
IkReal x1160=((cj4)*(sj6));
IkReal x1161=((sj0)*(sj4));
IkReal x1162=((cj5)*(sj6));
IkReal x1163=((sj4)*(sj5));
IkReal x1164=((r12)*(sj5));
IkReal x1165=((IkReal(0.374290000000000))*(cj5));
IkReal x1166=((r02)*(sj0));
IkReal x1167=((r20)*(sj4));
IkReal x1168=((IkReal(1.00000000000000))*(sj0));
IkReal x1169=((IkReal(1.00000000000000))*(cj5));
IkReal x1170=((cj0)*(r10));
IkReal x1171=((cj4)*(cj6));
IkReal x1172=((r00)*(sj0));
IkReal x1173=((cj6)*(r21));
IkReal x1174=((IkReal(0.374290000000000))*(sj5));
IkReal x1175=((cj0)*(r00));
IkReal x1176=((IkReal(0.0100000000000000))*(sj5));
IkReal x1177=((cj0)*(r02));
IkReal x1178=((cj5)*(sj4));
IkReal x1179=((cj6)*(r01));
IkReal x1180=((cj6)*(r11));
IkReal x1181=((r01)*(sj0));
IkReal x1182=((r10)*(sj0));
IkReal x1183=((IkReal(0.0100000000000000))*(cj5)*(cj6));
IkReal x1184=((sj6)*(x1174));
IkReal x1185=((cj0)*(cj6)*(x1174));
evalcond[0]=((IkReal(-3.14159265358979))+(IKfmod(((IkReal(1.57079632679490))+(j2)), IkReal(6.28318530717959))));
evalcond[1]=((((IkReal(-1.00000000000000))*(r22)*(x1169)))+(((sj5)*(x1173)))+(((r20)*(sj5)*(sj6))));
evalcond[2]=((IkReal(-1.00000000000000))+(((x1173)*(x1178)))+(((x1162)*(x1167)))+(((IkReal(-1.00000000000000))*(r20)*(x1171)))+(((r22)*(x1163)))+(((r21)*(x1160))));
evalcond[3]=((((IkReal(-1.00000000000000))*(r22)*(x1176)))+(((IkReal(-0.0100000000000000))*(r20)*(x1162)))+(((r20)*(x1184)))+(pz)+(((IkReal(-0.0100000000000000))*(cj5)*(x1173)))+(((x1173)*(x1174)))+(((IkReal(-1.00000000000000))*(r22)*(x1165))));
evalcond[4]=((((IkReal(-1.00000000000000))*(r21)*(sj4)*(sj6)))+(((cj5)*(r20)*(x1160)))+(((cj4)*(r22)*(sj5)))+(((cj6)*(x1167)))+(((cj5)*(r21)*(x1171))));
evalcond[5]=((((IkReal(-1.00000000000000))*(r11)*(x1159)*(x1160)))+(((x1160)*(x1181)))+(((cj5)*(x1161)*(x1179)))+(((IkReal(-1.00000000000000))*(r00)*(x1168)*(x1171)))+(((r00)*(x1161)*(x1162)))+(((IkReal(-1.00000000000000))*(x1159)*(x1178)*(x1180)))+(((IkReal(-1.00000000000000))*(r12)*(x1159)*(x1163)))+(((r02)*(sj5)*(x1161)))+(((x1170)*(x1171)))+(((IkReal(-1.00000000000000))*(r10)*(sj4)*(x1159)*(x1162))));
evalcond[6]=((((IkReal(-1.00000000000000))*(r10)*(x1161)*(x1162)))+(((IkReal(-1.00000000000000))*(r00)*(sj4)*(x1159)*(x1162)))+(((IkReal(-1.00000000000000))*(r01)*(x1159)*(x1160)))+(((IkReal(-1.00000000000000))*(x1161)*(x1169)*(x1180)))+(((x1171)*(x1175)))+(((IkReal(-1.00000000000000))*(x1161)*(x1164)))+(((x1171)*(x1182)))+(((IkReal(-1.00000000000000))*(x1159)*(x1178)*(x1179)))+(((IkReal(-1.00000000000000))*(r11)*(x1160)*(x1168)))+(((IkReal(-1.00000000000000))*(r02)*(x1159)*(x1163))));
evalcond[7]=((IkReal(0.0690000000000000))+(((IkReal(-1.00000000000000))*(py)*(x1159)))+(((IkReal(-1.00000000000000))*(x1166)*(x1176)))+(((IkReal(0.0100000000000000))*(cj0)*(cj5)*(x1180)))+(((IkReal(0.0100000000000000))*(cj0)*(x1164)))+(((sj0)*(x1174)*(x1179)))+(((IkReal(0.0100000000000000))*(x1162)*(x1170)))+(((IkReal(-0.0100000000000000))*(cj5)*(sj0)*(x1179)))+(((IkReal(-1.00000000000000))*(x1165)*(x1166)))+(((x1172)*(x1184)))+(((px)*(sj0)))+(((IkReal(-1.00000000000000))*(cj0)*(x1174)*(x1180)))+(((cj0)*(r12)*(x1165)))+(((IkReal(-1.00000000000000))*(x1170)*(x1184)))+(((IkReal(-0.0100000000000000))*(x1162)*(x1172))));
evalcond[8]=((IkReal(0.433420000000000))+(((IkReal(0.0100000000000000))*(cj5)*(sj0)*(x1180)))+(((IkReal(-1.00000000000000))*(x1175)*(x1184)))+(((IkReal(-1.00000000000000))*(cj0)*(x1174)*(x1179)))+(((IkReal(0.0100000000000000))*(x1162)*(x1175)))+(((IkReal(-1.00000000000000))*(x1182)*(x1184)))+(((IkReal(0.0100000000000000))*(x1162)*(x1182)))+(((x1176)*(x1177)))+(((r12)*(sj0)*(x1165)))+(((IkReal(-1.00000000000000))*(px)*(x1159)))+(((IkReal(0.0100000000000000))*(cj0)*(cj5)*(x1179)))+(((x1165)*(x1177)))+(((IkReal(-1.00000000000000))*(py)*(x1168)))+(((IkReal(0.0100000000000000))*(sj0)*(x1164)))+(((IkReal(-1.00000000000000))*(sj0)*(x1174)*(x1180))));
if( IKabs(evalcond[0]) < 0.0000010000000000  && IKabs(evalcond[1]) < 0.0000010000000000  && IKabs(evalcond[2]) < 0.0000010000000000  && IKabs(evalcond[3]) < 0.0000010000000000  && IKabs(evalcond[4]) < 0.0000010000000000  && IKabs(evalcond[5]) < 0.0000010000000000  && IKabs(evalcond[6]) < 0.0000010000000000  && IKabs(evalcond[7]) < 0.0000010000000000  && IKabs(evalcond[8]) < 0.0000010000000000  )
{
{
IkReal j3array[1], cj3array[1], sj3array[1];
bool j3valid[1]={false};
_nj3 = 1;
IkReal x1186=((cj0)*(cj5));
IkReal x1187=((IkReal(1.00000000000000))*(cj0));
IkReal x1188=((cj6)*(r11));
IkReal x1189=((r10)*(sj6));
IkReal x1190=((cj5)*(sj0));
IkReal x1191=((r00)*(sj5)*(sj6));
IkReal x1192=((cj6)*(r01)*(sj5));
IkReal x1193=((IkReal(1.00000000000000))*(sj0)*(sj5));
if( IKabs(((((sj0)*(x1192)))+(((IkReal(-1.00000000000000))*(sj5)*(x1187)*(x1188)))+(((IkReal(-1.00000000000000))*(sj5)*(x1187)*(x1189)))+(((IkReal(-1.00000000000000))*(r02)*(x1190)))+(((sj0)*(x1191)))+(((r12)*(x1186))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(((((IkReal(-1.00000000000000))*(x1189)*(x1193)))+(((r02)*(x1186)))+(((IkReal(-1.00000000000000))*(x1188)*(x1193)))+(((IkReal(-1.00000000000000))*(x1187)*(x1191)))+(((r12)*(x1190)))+(((IkReal(-1.00000000000000))*(x1187)*(x1192))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(IKsqr(((((sj0)*(x1192)))+(((IkReal(-1.00000000000000))*(sj5)*(x1187)*(x1188)))+(((IkReal(-1.00000000000000))*(sj5)*(x1187)*(x1189)))+(((IkReal(-1.00000000000000))*(r02)*(x1190)))+(((sj0)*(x1191)))+(((r12)*(x1186)))))+IKsqr(((((IkReal(-1.00000000000000))*(x1189)*(x1193)))+(((r02)*(x1186)))+(((IkReal(-1.00000000000000))*(x1188)*(x1193)))+(((IkReal(-1.00000000000000))*(x1187)*(x1191)))+(((r12)*(x1190)))+(((IkReal(-1.00000000000000))*(x1187)*(x1192)))))-1) <= IKFAST_SINCOS_THRESH )
    continue;
j3array[0]=IKatan2(((((sj0)*(x1192)))+(((IkReal(-1.00000000000000))*(sj5)*(x1187)*(x1188)))+(((IkReal(-1.00000000000000))*(sj5)*(x1187)*(x1189)))+(((IkReal(-1.00000000000000))*(r02)*(x1190)))+(((sj0)*(x1191)))+(((r12)*(x1186)))), ((((IkReal(-1.00000000000000))*(x1189)*(x1193)))+(((r02)*(x1186)))+(((IkReal(-1.00000000000000))*(x1188)*(x1193)))+(((IkReal(-1.00000000000000))*(x1187)*(x1191)))+(((r12)*(x1190)))+(((IkReal(-1.00000000000000))*(x1187)*(x1192)))));
sj3array[0]=IKsin(j3array[0]);
cj3array[0]=IKcos(j3array[0]);
if( j3array[0] > IKPI )
{
    j3array[0]-=IK2PI;
}
else if( j3array[0] < -IKPI )
{    j3array[0]+=IK2PI;
}
j3valid[0] = true;
for(int ij3 = 0; ij3 < 1; ++ij3)
{
if( !j3valid[ij3] )
{
    continue;
}
_ij3[0] = ij3; _ij3[1] = -1;
for(int iij3 = ij3+1; iij3 < 1; ++iij3)
{
if( j3valid[iij3] && IKabs(cj3array[ij3]-cj3array[iij3]) < IKFAST_SOLUTION_THRESH && IKabs(sj3array[ij3]-sj3array[iij3]) < IKFAST_SOLUTION_THRESH )
{
    j3valid[iij3]=false; _ij3[1] = iij3; break; 
}
}
j3 = j3array[ij3]; cj3 = cj3array[ij3]; sj3 = sj3array[ij3];
{
IkReal evalcond[4];
IkReal x1194=IKcos(j3);
IkReal x1195=((sj0)*(sj5));
IkReal x1196=((r00)*(sj6));
IkReal x1197=((cj6)*(sj0));
IkReal x1198=((IkReal(1.00000000000000))*(cj4));
IkReal x1199=((r00)*(sj4));
IkReal x1200=((cj0)*(cj5));
IkReal x1201=((cj5)*(sj0));
IkReal x1202=((cj6)*(r11));
IkReal x1203=((r10)*(sj6));
IkReal x1204=((cj0)*(sj5));
IkReal x1205=((r10)*(sj4));
IkReal x1206=((IkReal(1.00000000000000))*(IKsin(j3)));
IkReal x1207=((cj4)*(cj5)*(r01));
IkReal x1208=((IkReal(1.00000000000000))*(cj0)*(cj6));
IkReal x1209=((cj0)*(sj4)*(sj6));
IkReal x1210=((sj0)*(sj4)*(sj6));
evalcond[0]=((((IkReal(-1.00000000000000))*(x1203)*(x1204)))+(((x1195)*(x1196)))+(((r12)*(x1200)))+(((cj6)*(r01)*(x1195)))+(((IkReal(-1.00000000000000))*(x1206)))+(((IkReal(-1.00000000000000))*(x1202)*(x1204)))+(((IkReal(-1.00000000000000))*(r02)*(x1201))));
evalcond[1]=((((IkReal(-1.00000000000000))*(x1195)*(x1202)))+(((IkReal(-1.00000000000000))*(x1194)))+(((r02)*(x1200)))+(((IkReal(-1.00000000000000))*(x1195)*(x1203)))+(((IkReal(-1.00000000000000))*(x1196)*(x1204)))+(((r12)*(x1201)))+(((IkReal(-1.00000000000000))*(cj6)*(r01)*(x1204))));
evalcond[2]=((((IkReal(-1.00000000000000))*(x1198)*(x1200)*(x1203)))+(((IkReal(-1.00000000000000))*(x1205)*(x1208)))+(((IkReal(-1.00000000000000))*(r12)*(x1198)*(x1204)))+(((r11)*(x1209)))+(((IkReal(-1.00000000000000))*(x1198)*(x1200)*(x1202)))+(((cj4)*(r02)*(x1195)))+(x1194)+(((x1197)*(x1207)))+(((IkReal(-1.00000000000000))*(r01)*(x1210)))+(((cj4)*(x1196)*(x1201)))+(((x1197)*(x1199))));
evalcond[3]=((((IkReal(-1.00000000000000))*(r02)*(x1198)*(x1204)))+(((IkReal(-1.00000000000000))*(cj5)*(r11)*(x1197)*(x1198)))+(((IkReal(-1.00000000000000))*(cj6)*(r01)*(x1198)*(x1200)))+(((IkReal(-1.00000000000000))*(x1196)*(x1198)*(x1200)))+(((IkReal(-1.00000000000000))*(x1197)*(x1205)))+(((IkReal(-1.00000000000000))*(x1199)*(x1208)))+(((r01)*(x1209)))+(((IkReal(-1.00000000000000))*(x1198)*(x1201)*(x1203)))+(((IkReal(-1.00000000000000))*(x1206)))+(((IkReal(-1.00000000000000))*(r12)*(x1195)*(x1198)))+(((r11)*(x1210))));
if( IKabs(evalcond[0]) > 0.000001  || IKabs(evalcond[1]) > 0.000001  || IKabs(evalcond[2]) > 0.000001  || IKabs(evalcond[3]) > 0.000001  )
{
continue;
}
}

{
std::vector<IkSingleDOFSolutionBase<IkReal> > vinfos(7);
vinfos[0].jointtype = 1;
vinfos[0].foffset = j0;
vinfos[0].indices[0] = _ij0[0];
vinfos[0].indices[1] = _ij0[1];
vinfos[0].maxsolutions = _nj0;
vinfos[1].jointtype = 1;
vinfos[1].foffset = j1;
vinfos[1].indices[0] = _ij1[0];
vinfos[1].indices[1] = _ij1[1];
vinfos[1].maxsolutions = _nj1;
vinfos[2].jointtype = 1;
vinfos[2].foffset = j2;
vinfos[2].indices[0] = _ij2[0];
vinfos[2].indices[1] = _ij2[1];
vinfos[2].maxsolutions = _nj2;
vinfos[3].jointtype = 1;
vinfos[3].foffset = j3;
vinfos[3].indices[0] = _ij3[0];
vinfos[3].indices[1] = _ij3[1];
vinfos[3].maxsolutions = _nj3;
vinfos[4].jointtype = 1;
vinfos[4].foffset = j4;
vinfos[4].indices[0] = _ij4[0];
vinfos[4].indices[1] = _ij4[1];
vinfos[4].maxsolutions = _nj4;
vinfos[5].jointtype = 1;
vinfos[5].foffset = j5;
vinfos[5].indices[0] = _ij5[0];
vinfos[5].indices[1] = _ij5[1];
vinfos[5].maxsolutions = _nj5;
vinfos[6].jointtype = 1;
vinfos[6].foffset = j6;
vinfos[6].indices[0] = _ij6[0];
vinfos[6].indices[1] = _ij6[1];
vinfos[6].maxsolutions = _nj6;
std::vector<int> vfree(0);
solutions.AddSolution(vinfos,vfree);
}
}
}

} else
{
IkReal x1211=((IkReal(1.00000000000000))*(cj0));
IkReal x1212=((cj4)*(sj6));
IkReal x1213=((sj0)*(sj4));
IkReal x1214=((cj5)*(sj6));
IkReal x1215=((sj4)*(sj5));
IkReal x1216=((r12)*(sj5));
IkReal x1217=((IkReal(0.374290000000000))*(cj5));
IkReal x1218=((r02)*(sj0));
IkReal x1219=((r20)*(sj4));
IkReal x1220=((IkReal(1.00000000000000))*(sj0));
IkReal x1221=((IkReal(1.00000000000000))*(cj5));
IkReal x1222=((cj0)*(r10));
IkReal x1223=((cj4)*(cj6));
IkReal x1224=((r00)*(sj0));
IkReal x1225=((cj6)*(r21));
IkReal x1226=((IkReal(0.374290000000000))*(sj5));
IkReal x1227=((cj0)*(r00));
IkReal x1228=((IkReal(0.0100000000000000))*(sj5));
IkReal x1229=((cj0)*(r02));
IkReal x1230=((cj5)*(sj4));
IkReal x1231=((cj6)*(r01));
IkReal x1232=((cj6)*(r11));
IkReal x1233=((r01)*(sj0));
IkReal x1234=((r10)*(sj0));
IkReal x1235=((IkReal(0.0100000000000000))*(cj5)*(cj6));
IkReal x1236=((sj6)*(x1226));
IkReal x1237=((cj0)*(cj6)*(x1226));
evalcond[0]=((IkReal(-3.14159265358979))+(IKfmod(((IkReal(4.71238898038469))+(j2)), IkReal(6.28318530717959))));
evalcond[1]=((((sj5)*(x1225)))+(((IkReal(-1.00000000000000))*(r22)*(x1221)))+(((r20)*(sj5)*(sj6))));
evalcond[2]=((IkReal(1.00000000000000))+(((IkReal(-1.00000000000000))*(r20)*(x1223)))+(((x1225)*(x1230)))+(((r21)*(x1212)))+(((r22)*(x1215)))+(((x1214)*(x1219))));
evalcond[3]=((((IkReal(-1.00000000000000))*(r22)*(x1217)))+(((IkReal(-0.0100000000000000))*(r20)*(x1214)))+(((r20)*(x1236)))+(((IkReal(-1.00000000000000))*(r22)*(x1228)))+(((x1225)*(x1226)))+(pz)+(((IkReal(-0.0100000000000000))*(cj5)*(x1225))));
evalcond[4]=((((IkReal(-1.00000000000000))*(r21)*(sj4)*(sj6)))+(((cj6)*(x1219)))+(((cj5)*(r20)*(x1212)))+(((cj4)*(r22)*(sj5)))+(((cj5)*(r21)*(x1223))));
evalcond[5]=((((r00)*(x1213)*(x1214)))+(((IkReal(-1.00000000000000))*(r12)*(x1211)*(x1215)))+(((IkReal(-1.00000000000000))*(x1211)*(x1230)*(x1232)))+(((IkReal(-1.00000000000000))*(r00)*(x1220)*(x1223)))+(((r02)*(sj5)*(x1213)))+(((x1212)*(x1233)))+(((IkReal(-1.00000000000000))*(r10)*(sj4)*(x1211)*(x1214)))+(((cj5)*(x1213)*(x1231)))+(((IkReal(-1.00000000000000))*(r11)*(x1211)*(x1212)))+(((x1222)*(x1223))));
evalcond[6]=((((IkReal(-1.00000000000000))*(x1211)*(x1230)*(x1231)))+(((IkReal(-1.00000000000000))*(r11)*(x1212)*(x1220)))+(((x1223)*(x1227)))+(((x1223)*(x1234)))+(((IkReal(-1.00000000000000))*(x1213)*(x1216)))+(((IkReal(-1.00000000000000))*(r02)*(x1211)*(x1215)))+(((IkReal(-1.00000000000000))*(r10)*(x1213)*(x1214)))+(((IkReal(-1.00000000000000))*(x1213)*(x1221)*(x1232)))+(((IkReal(-1.00000000000000))*(r01)*(x1211)*(x1212)))+(((IkReal(-1.00000000000000))*(r00)*(sj4)*(x1211)*(x1214))));
evalcond[7]=((IkReal(-0.0690000000000000))+(((cj0)*(r12)*(x1217)))+(((IkReal(-1.00000000000000))*(cj0)*(x1226)*(x1232)))+(((x1224)*(x1236)))+(((IkReal(0.0100000000000000))*(cj0)*(cj5)*(x1232)))+(((IkReal(0.0100000000000000))*(cj0)*(x1216)))+(((IkReal(-1.00000000000000))*(py)*(x1211)))+(((IkReal(-1.00000000000000))*(x1217)*(x1218)))+(((IkReal(-0.0100000000000000))*(x1214)*(x1224)))+(((IkReal(-0.0100000000000000))*(cj5)*(sj0)*(x1231)))+(((IkReal(-1.00000000000000))*(x1218)*(x1228)))+(((px)*(sj0)))+(((IkReal(0.0100000000000000))*(x1214)*(x1222)))+(((IkReal(-1.00000000000000))*(x1222)*(x1236)))+(((sj0)*(x1226)*(x1231))));
evalcond[8]=((IkReal(0.433420000000000))+(((IkReal(-1.00000000000000))*(cj0)*(x1226)*(x1231)))+(((IkReal(-1.00000000000000))*(sj0)*(x1226)*(x1232)))+(((IkReal(-1.00000000000000))*(x1227)*(x1236)))+(((IkReal(0.0100000000000000))*(sj0)*(x1216)))+(((IkReal(0.0100000000000000))*(x1214)*(x1234)))+(((IkReal(-1.00000000000000))*(py)*(x1220)))+(((x1217)*(x1229)))+(((IkReal(-1.00000000000000))*(px)*(x1211)))+(((IkReal(0.0100000000000000))*(cj0)*(cj5)*(x1231)))+(((IkReal(0.0100000000000000))*(x1214)*(x1227)))+(((IkReal(-1.00000000000000))*(x1234)*(x1236)))+(((x1228)*(x1229)))+(((r12)*(sj0)*(x1217)))+(((IkReal(0.0100000000000000))*(cj5)*(sj0)*(x1232))));
if( IKabs(evalcond[0]) < 0.0000010000000000  && IKabs(evalcond[1]) < 0.0000010000000000  && IKabs(evalcond[2]) < 0.0000010000000000  && IKabs(evalcond[3]) < 0.0000010000000000  && IKabs(evalcond[4]) < 0.0000010000000000  && IKabs(evalcond[5]) < 0.0000010000000000  && IKabs(evalcond[6]) < 0.0000010000000000  && IKabs(evalcond[7]) < 0.0000010000000000  && IKabs(evalcond[8]) < 0.0000010000000000  )
{
{
IkReal j3array[1], cj3array[1], sj3array[1];
bool j3valid[1]={false};
_nj3 = 1;
IkReal x1238=((cj5)*(r02));
IkReal x1239=((cj0)*(sj5));
IkReal x1240=((r10)*(sj6));
IkReal x1241=((IkReal(1.00000000000000))*(cj6));
IkReal x1242=((sj0)*(sj5));
IkReal x1243=((cj5)*(r12));
IkReal x1244=((IkReal(1.00000000000000))*(r00)*(sj6));
if( IKabs(((((IkReal(-1.00000000000000))*(cj0)*(x1243)))+(((IkReal(-1.00000000000000))*(r01)*(x1241)*(x1242)))+(((IkReal(-1.00000000000000))*(x1242)*(x1244)))+(((x1239)*(x1240)))+(((cj6)*(r11)*(x1239)))+(((sj0)*(x1238))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(((((IkReal(-1.00000000000000))*(x1240)*(x1242)))+(((IkReal(-1.00000000000000))*(r01)*(x1239)*(x1241)))+(((IkReal(-1.00000000000000))*(r11)*(x1241)*(x1242)))+(((IkReal(-1.00000000000000))*(x1239)*(x1244)))+(((sj0)*(x1243)))+(((cj0)*(x1238))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(IKsqr(((((IkReal(-1.00000000000000))*(cj0)*(x1243)))+(((IkReal(-1.00000000000000))*(r01)*(x1241)*(x1242)))+(((IkReal(-1.00000000000000))*(x1242)*(x1244)))+(((x1239)*(x1240)))+(((cj6)*(r11)*(x1239)))+(((sj0)*(x1238)))))+IKsqr(((((IkReal(-1.00000000000000))*(x1240)*(x1242)))+(((IkReal(-1.00000000000000))*(r01)*(x1239)*(x1241)))+(((IkReal(-1.00000000000000))*(r11)*(x1241)*(x1242)))+(((IkReal(-1.00000000000000))*(x1239)*(x1244)))+(((sj0)*(x1243)))+(((cj0)*(x1238)))))-1) <= IKFAST_SINCOS_THRESH )
    continue;
j3array[0]=IKatan2(((((IkReal(-1.00000000000000))*(cj0)*(x1243)))+(((IkReal(-1.00000000000000))*(r01)*(x1241)*(x1242)))+(((IkReal(-1.00000000000000))*(x1242)*(x1244)))+(((x1239)*(x1240)))+(((cj6)*(r11)*(x1239)))+(((sj0)*(x1238)))), ((((IkReal(-1.00000000000000))*(x1240)*(x1242)))+(((IkReal(-1.00000000000000))*(r01)*(x1239)*(x1241)))+(((IkReal(-1.00000000000000))*(r11)*(x1241)*(x1242)))+(((IkReal(-1.00000000000000))*(x1239)*(x1244)))+(((sj0)*(x1243)))+(((cj0)*(x1238)))));
sj3array[0]=IKsin(j3array[0]);
cj3array[0]=IKcos(j3array[0]);
if( j3array[0] > IKPI )
{
    j3array[0]-=IK2PI;
}
else if( j3array[0] < -IKPI )
{    j3array[0]+=IK2PI;
}
j3valid[0] = true;
for(int ij3 = 0; ij3 < 1; ++ij3)
{
if( !j3valid[ij3] )
{
    continue;
}
_ij3[0] = ij3; _ij3[1] = -1;
for(int iij3 = ij3+1; iij3 < 1; ++iij3)
{
if( j3valid[iij3] && IKabs(cj3array[ij3]-cj3array[iij3]) < IKFAST_SOLUTION_THRESH && IKabs(sj3array[ij3]-sj3array[iij3]) < IKFAST_SOLUTION_THRESH )
{
    j3valid[iij3]=false; _ij3[1] = iij3; break; 
}
}
j3 = j3array[ij3]; cj3 = cj3array[ij3]; sj3 = sj3array[ij3];
{
IkReal evalcond[4];
IkReal x1245=IKsin(j3);
IkReal x1246=((sj0)*(sj5));
IkReal x1247=((r00)*(sj6));
IkReal x1248=((IkReal(1.00000000000000))*(cj4));
IkReal x1249=((cj6)*(sj0));
IkReal x1250=((r00)*(sj4));
IkReal x1251=((cj0)*(cj5));
IkReal x1252=((cj6)*(r01));
IkReal x1253=((cj5)*(sj0));
IkReal x1254=((cj0)*(sj5));
IkReal x1255=((cj6)*(r11));
IkReal x1256=((r10)*(sj6));
IkReal x1257=((r10)*(sj4));
IkReal x1258=((IkReal(1.00000000000000))*(IKcos(j3)));
IkReal x1259=((cj0)*(sj4)*(sj6));
IkReal x1260=((sj0)*(sj4)*(sj6));
IkReal x1261=((IkReal(1.00000000000000))*(cj0)*(cj6));
evalcond[0]=((((x1246)*(x1252)))+(((r12)*(x1251)))+(((IkReal(-1.00000000000000))*(x1254)*(x1255)))+(((IkReal(-1.00000000000000))*(r02)*(x1253)))+(x1245)+(((IkReal(-1.00000000000000))*(x1254)*(x1256)))+(((x1246)*(x1247))));
evalcond[1]=((((IkReal(-1.00000000000000))*(x1252)*(x1254)))+(((IkReal(-1.00000000000000))*(x1246)*(x1256)))+(((r12)*(x1253)))+(((IkReal(-1.00000000000000))*(x1247)*(x1254)))+(((IkReal(-1.00000000000000))*(x1246)*(x1255)))+(((r02)*(x1251)))+(((IkReal(-1.00000000000000))*(x1258))));
evalcond[2]=((((IkReal(-1.00000000000000))*(x1257)*(x1261)))+(((IkReal(-1.00000000000000))*(r01)*(x1260)))+(((x1249)*(x1250)))+(((IkReal(-1.00000000000000))*(r12)*(x1248)*(x1254)))+(((IkReal(-1.00000000000000))*(x1248)*(x1251)*(x1255)))+(((cj4)*(x1247)*(x1253)))+(((cj4)*(r02)*(x1246)))+(((cj4)*(cj5)*(r01)*(x1249)))+(((IkReal(-1.00000000000000))*(x1248)*(x1251)*(x1256)))+(((r11)*(x1259)))+(((IkReal(-1.00000000000000))*(x1258))));
evalcond[3]=((((r01)*(x1259)))+(((r11)*(x1260)))+(((IkReal(-1.00000000000000))*(x1250)*(x1261)))+(((IkReal(-1.00000000000000))*(x1245)))+(((IkReal(-1.00000000000000))*(x1247)*(x1248)*(x1251)))+(((IkReal(-1.00000000000000))*(r12)*(x1246)*(x1248)))+(((IkReal(-1.00000000000000))*(x1248)*(x1251)*(x1252)))+(((IkReal(-1.00000000000000))*(x1249)*(x1257)))+(((IkReal(-1.00000000000000))*(x1248)*(x1253)*(x1256)))+(((IkReal(-1.00000000000000))*(cj5)*(r11)*(x1248)*(x1249)))+(((IkReal(-1.00000000000000))*(r02)*(x1248)*(x1254))));
if( IKabs(evalcond[0]) > 0.000001  || IKabs(evalcond[1]) > 0.000001  || IKabs(evalcond[2]) > 0.000001  || IKabs(evalcond[3]) > 0.000001  )
{
continue;
}
}

{
std::vector<IkSingleDOFSolutionBase<IkReal> > vinfos(7);
vinfos[0].jointtype = 1;
vinfos[0].foffset = j0;
vinfos[0].indices[0] = _ij0[0];
vinfos[0].indices[1] = _ij0[1];
vinfos[0].maxsolutions = _nj0;
vinfos[1].jointtype = 1;
vinfos[1].foffset = j1;
vinfos[1].indices[0] = _ij1[0];
vinfos[1].indices[1] = _ij1[1];
vinfos[1].maxsolutions = _nj1;
vinfos[2].jointtype = 1;
vinfos[2].foffset = j2;
vinfos[2].indices[0] = _ij2[0];
vinfos[2].indices[1] = _ij2[1];
vinfos[2].maxsolutions = _nj2;
vinfos[3].jointtype = 1;
vinfos[3].foffset = j3;
vinfos[3].indices[0] = _ij3[0];
vinfos[3].indices[1] = _ij3[1];
vinfos[3].maxsolutions = _nj3;
vinfos[4].jointtype = 1;
vinfos[4].foffset = j4;
vinfos[4].indices[0] = _ij4[0];
vinfos[4].indices[1] = _ij4[1];
vinfos[4].maxsolutions = _nj4;
vinfos[5].jointtype = 1;
vinfos[5].foffset = j5;
vinfos[5].indices[0] = _ij5[0];
vinfos[5].indices[1] = _ij5[1];
vinfos[5].maxsolutions = _nj5;
vinfos[6].jointtype = 1;
vinfos[6].foffset = j6;
vinfos[6].indices[0] = _ij6[0];
vinfos[6].indices[1] = _ij6[1];
vinfos[6].maxsolutions = _nj6;
std::vector<int> vfree(0);
solutions.AddSolution(vinfos,vfree);
}
}
}

} else
{
if( 1 )
{
continue;

} else
{
}
}
}
}
}
}

} else
{
{
IkReal j3array[1], cj3array[1], sj3array[1];
bool j3valid[1]={false};
_nj3 = 1;
IkReal x1262=((cj0)*(cj5));
IkReal x1263=((IkReal(1.00000000000000))*(cj0));
IkReal x1264=((cj6)*(r11));
IkReal x1265=((r10)*(sj6));
IkReal x1266=((cj5)*(sj0));
IkReal x1267=((r00)*(sj5)*(sj6));
IkReal x1268=((cj6)*(r01)*(sj5));
IkReal x1269=((IkReal(1.00000000000000))*(sj0)*(sj5));
if( IKabs(((((IKabs(sj2) != 0)?((IkReal)1/(sj2)):(IkReal)1.0e30))*(((((r12)*(x1262)))+(((IkReal(-1.00000000000000))*(r02)*(x1266)))+(((IkReal(-1.00000000000000))*(sj5)*(x1263)*(x1265)))+(((IkReal(-1.00000000000000))*(sj5)*(x1263)*(x1264)))+(((sj0)*(x1268)))+(((sj0)*(x1267))))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(((((IkReal(-1.00000000000000))*(x1264)*(x1269)))+(((IkReal(-1.00000000000000))*(x1265)*(x1269)))+(((IkReal(-1.00000000000000))*(x1263)*(x1267)))+(((r12)*(x1266)))+(((IkReal(-1.00000000000000))*(x1263)*(x1268)))+(((r02)*(x1262))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(IKsqr(((((IKabs(sj2) != 0)?((IkReal)1/(sj2)):(IkReal)1.0e30))*(((((r12)*(x1262)))+(((IkReal(-1.00000000000000))*(r02)*(x1266)))+(((IkReal(-1.00000000000000))*(sj5)*(x1263)*(x1265)))+(((IkReal(-1.00000000000000))*(sj5)*(x1263)*(x1264)))+(((sj0)*(x1268)))+(((sj0)*(x1267)))))))+IKsqr(((((IkReal(-1.00000000000000))*(x1264)*(x1269)))+(((IkReal(-1.00000000000000))*(x1265)*(x1269)))+(((IkReal(-1.00000000000000))*(x1263)*(x1267)))+(((r12)*(x1266)))+(((IkReal(-1.00000000000000))*(x1263)*(x1268)))+(((r02)*(x1262)))))-1) <= IKFAST_SINCOS_THRESH )
    continue;
j3array[0]=IKatan2(((((IKabs(sj2) != 0)?((IkReal)1/(sj2)):(IkReal)1.0e30))*(((((r12)*(x1262)))+(((IkReal(-1.00000000000000))*(r02)*(x1266)))+(((IkReal(-1.00000000000000))*(sj5)*(x1263)*(x1265)))+(((IkReal(-1.00000000000000))*(sj5)*(x1263)*(x1264)))+(((sj0)*(x1268)))+(((sj0)*(x1267)))))), ((((IkReal(-1.00000000000000))*(x1264)*(x1269)))+(((IkReal(-1.00000000000000))*(x1265)*(x1269)))+(((IkReal(-1.00000000000000))*(x1263)*(x1267)))+(((r12)*(x1266)))+(((IkReal(-1.00000000000000))*(x1263)*(x1268)))+(((r02)*(x1262)))));
sj3array[0]=IKsin(j3array[0]);
cj3array[0]=IKcos(j3array[0]);
if( j3array[0] > IKPI )
{
    j3array[0]-=IK2PI;
}
else if( j3array[0] < -IKPI )
{    j3array[0]+=IK2PI;
}
j3valid[0] = true;
for(int ij3 = 0; ij3 < 1; ++ij3)
{
if( !j3valid[ij3] )
{
    continue;
}
_ij3[0] = ij3; _ij3[1] = -1;
for(int iij3 = ij3+1; iij3 < 1; ++iij3)
{
if( j3valid[iij3] && IKabs(cj3array[ij3]-cj3array[iij3]) < IKFAST_SOLUTION_THRESH && IKabs(sj3array[ij3]-sj3array[iij3]) < IKFAST_SOLUTION_THRESH )
{
    j3valid[iij3]=false; _ij3[1] = iij3; break; 
}
}
j3 = j3array[ij3]; cj3 = cj3array[ij3]; sj3 = sj3array[ij3];
{
IkReal evalcond[6];
IkReal x1270=IKsin(j3);
IkReal x1271=IKcos(j3);
IkReal x1272=((sj0)*(sj5));
IkReal x1273=((r00)*(sj6));
IkReal x1274=((IkReal(1.00000000000000))*(cj4));
IkReal x1275=((cj6)*(r01));
IkReal x1276=((cj0)*(cj5));
IkReal x1277=((cj5)*(sj0));
IkReal x1278=((cj6)*(r11));
IkReal x1279=((cj0)*(sj5));
IkReal x1280=((cj6)*(sj4));
IkReal x1281=((cj4)*(cj5));
IkReal x1282=((cj6)*(r21));
IkReal x1283=((r20)*(sj6));
IkReal x1284=((r10)*(sj6));
IkReal x1285=((IkReal(1.00000000000000))*(cj0));
IkReal x1286=((IkReal(1.00000000000000))*(x1270));
IkReal x1287=((cj0)*(sj4)*(sj6));
IkReal x1288=((sj0)*(sj4)*(sj6));
evalcond[0]=((((sj5)*(x1282)))+(((sj5)*(x1283)))+(((IkReal(-1.00000000000000))*(cj5)*(r22)))+(((IkReal(-1.00000000000000))*(cj2)*(x1286))));
evalcond[1]=((((cj2)*(x1271)))+(((IkReal(-1.00000000000000))*(r21)*(sj4)*(sj6)))+(((x1281)*(x1283)))+(((x1281)*(x1282)))+(((cj4)*(r22)*(sj5)))+(((r20)*(x1280))));
evalcond[2]=((((r12)*(x1276)))+(((x1272)*(x1275)))+(((IkReal(-1.00000000000000))*(x1279)*(x1284)))+(((IkReal(-1.00000000000000))*(sj2)*(x1286)))+(((x1272)*(x1273)))+(((IkReal(-1.00000000000000))*(x1278)*(x1279)))+(((IkReal(-1.00000000000000))*(r02)*(x1277))));
evalcond[3]=((((r12)*(x1277)))+(((IkReal(-1.00000000000000))*(x1272)*(x1284)))+(((IkReal(-1.00000000000000))*(x1275)*(x1279)))+(((IkReal(-1.00000000000000))*(x1271)))+(((r02)*(x1276)))+(((IkReal(-1.00000000000000))*(x1272)*(x1278)))+(((IkReal(-1.00000000000000))*(x1273)*(x1279))));
evalcond[4]=((((IkReal(-1.00000000000000))*(x1274)*(x1276)*(x1278)))+(((IkReal(-1.00000000000000))*(r01)*(x1288)))+(((cj4)*(x1275)*(x1277)))+(((cj4)*(x1273)*(x1277)))+(((r00)*(sj0)*(x1280)))+(((IkReal(-1.00000000000000))*(r10)*(x1280)*(x1285)))+(((r11)*(x1287)))+(((IkReal(-1.00000000000000))*(r12)*(x1274)*(x1279)))+(((cj4)*(r02)*(x1272)))+(((sj2)*(x1271)))+(((IkReal(-1.00000000000000))*(x1274)*(x1276)*(x1284))));
evalcond[5]=((((IkReal(-1.00000000000000))*(x1286)))+(((IkReal(-1.00000000000000))*(x1274)*(x1277)*(x1278)))+(((IkReal(-1.00000000000000))*(x1273)*(x1274)*(x1276)))+(((r11)*(x1288)))+(((IkReal(-1.00000000000000))*(r10)*(sj0)*(x1280)))+(((r01)*(x1287)))+(((IkReal(-1.00000000000000))*(x1274)*(x1277)*(x1284)))+(((IkReal(-1.00000000000000))*(r02)*(x1274)*(x1279)))+(((IkReal(-1.00000000000000))*(x1274)*(x1275)*(x1276)))+(((IkReal(-1.00000000000000))*(r00)*(x1280)*(x1285)))+(((IkReal(-1.00000000000000))*(r12)*(x1272)*(x1274))));
if( IKabs(evalcond[0]) > 0.000001  || IKabs(evalcond[1]) > 0.000001  || IKabs(evalcond[2]) > 0.000001  || IKabs(evalcond[3]) > 0.000001  || IKabs(evalcond[4]) > 0.000001  || IKabs(evalcond[5]) > 0.000001  )
{
continue;
}
}

{
std::vector<IkSingleDOFSolutionBase<IkReal> > vinfos(7);
vinfos[0].jointtype = 1;
vinfos[0].foffset = j0;
vinfos[0].indices[0] = _ij0[0];
vinfos[0].indices[1] = _ij0[1];
vinfos[0].maxsolutions = _nj0;
vinfos[1].jointtype = 1;
vinfos[1].foffset = j1;
vinfos[1].indices[0] = _ij1[0];
vinfos[1].indices[1] = _ij1[1];
vinfos[1].maxsolutions = _nj1;
vinfos[2].jointtype = 1;
vinfos[2].foffset = j2;
vinfos[2].indices[0] = _ij2[0];
vinfos[2].indices[1] = _ij2[1];
vinfos[2].maxsolutions = _nj2;
vinfos[3].jointtype = 1;
vinfos[3].foffset = j3;
vinfos[3].indices[0] = _ij3[0];
vinfos[3].indices[1] = _ij3[1];
vinfos[3].maxsolutions = _nj3;
vinfos[4].jointtype = 1;
vinfos[4].foffset = j4;
vinfos[4].indices[0] = _ij4[0];
vinfos[4].indices[1] = _ij4[1];
vinfos[4].maxsolutions = _nj4;
vinfos[5].jointtype = 1;
vinfos[5].foffset = j5;
vinfos[5].indices[0] = _ij5[0];
vinfos[5].indices[1] = _ij5[1];
vinfos[5].maxsolutions = _nj5;
vinfos[6].jointtype = 1;
vinfos[6].foffset = j6;
vinfos[6].indices[0] = _ij6[0];
vinfos[6].indices[1] = _ij6[1];
vinfos[6].maxsolutions = _nj6;
std::vector<int> vfree(0);
solutions.AddSolution(vinfos,vfree);
}
}
}

}

}

} else
{
{
IkReal j3array[1], cj3array[1], sj3array[1];
bool j3valid[1]={false};
_nj3 = 1;
IkReal x1289=((sj5)*(sj6));
IkReal x1290=((IkReal(1.00000000000000))*(cj6)*(sj5));
if( IKabs(((((IKabs(cj2) != 0)?((IkReal)1/(cj2)):(IkReal)1.0e30))*(((((r20)*(x1289)))+(((cj6)*(r21)*(sj5)))+(((IkReal(-1.00000000000000))*(cj5)*(r22))))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(((((cj0)*(cj5)*(r02)))+(((IkReal(-1.00000000000000))*(r10)*(sj0)*(x1289)))+(((cj5)*(r12)*(sj0)))+(((IkReal(-1.00000000000000))*(r11)*(sj0)*(x1290)))+(((IkReal(-1.00000000000000))*(cj0)*(r00)*(x1289)))+(((IkReal(-1.00000000000000))*(cj0)*(r01)*(x1290))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(IKsqr(((((IKabs(cj2) != 0)?((IkReal)1/(cj2)):(IkReal)1.0e30))*(((((r20)*(x1289)))+(((cj6)*(r21)*(sj5)))+(((IkReal(-1.00000000000000))*(cj5)*(r22)))))))+IKsqr(((((cj0)*(cj5)*(r02)))+(((IkReal(-1.00000000000000))*(r10)*(sj0)*(x1289)))+(((cj5)*(r12)*(sj0)))+(((IkReal(-1.00000000000000))*(r11)*(sj0)*(x1290)))+(((IkReal(-1.00000000000000))*(cj0)*(r00)*(x1289)))+(((IkReal(-1.00000000000000))*(cj0)*(r01)*(x1290)))))-1) <= IKFAST_SINCOS_THRESH )
    continue;
j3array[0]=IKatan2(((((IKabs(cj2) != 0)?((IkReal)1/(cj2)):(IkReal)1.0e30))*(((((r20)*(x1289)))+(((cj6)*(r21)*(sj5)))+(((IkReal(-1.00000000000000))*(cj5)*(r22)))))), ((((cj0)*(cj5)*(r02)))+(((IkReal(-1.00000000000000))*(r10)*(sj0)*(x1289)))+(((cj5)*(r12)*(sj0)))+(((IkReal(-1.00000000000000))*(r11)*(sj0)*(x1290)))+(((IkReal(-1.00000000000000))*(cj0)*(r00)*(x1289)))+(((IkReal(-1.00000000000000))*(cj0)*(r01)*(x1290)))));
sj3array[0]=IKsin(j3array[0]);
cj3array[0]=IKcos(j3array[0]);
if( j3array[0] > IKPI )
{
    j3array[0]-=IK2PI;
}
else if( j3array[0] < -IKPI )
{    j3array[0]+=IK2PI;
}
j3valid[0] = true;
for(int ij3 = 0; ij3 < 1; ++ij3)
{
if( !j3valid[ij3] )
{
    continue;
}
_ij3[0] = ij3; _ij3[1] = -1;
for(int iij3 = ij3+1; iij3 < 1; ++iij3)
{
if( j3valid[iij3] && IKabs(cj3array[ij3]-cj3array[iij3]) < IKFAST_SOLUTION_THRESH && IKabs(sj3array[ij3]-sj3array[iij3]) < IKFAST_SOLUTION_THRESH )
{
    j3valid[iij3]=false; _ij3[1] = iij3; break; 
}
}
j3 = j3array[ij3]; cj3 = cj3array[ij3]; sj3 = sj3array[ij3];
{
IkReal evalcond[6];
IkReal x1291=IKsin(j3);
IkReal x1292=IKcos(j3);
IkReal x1293=((sj0)*(sj5));
IkReal x1294=((r00)*(sj6));
IkReal x1295=((IkReal(1.00000000000000))*(cj4));
IkReal x1296=((cj6)*(r01));
IkReal x1297=((cj0)*(cj5));
IkReal x1298=((cj5)*(sj0));
IkReal x1299=((cj6)*(r11));
IkReal x1300=((cj0)*(sj5));
IkReal x1301=((cj6)*(sj4));
IkReal x1302=((cj4)*(cj5));
IkReal x1303=((cj6)*(r21));
IkReal x1304=((r20)*(sj6));
IkReal x1305=((r10)*(sj6));
IkReal x1306=((IkReal(1.00000000000000))*(cj0));
IkReal x1307=((IkReal(1.00000000000000))*(x1291));
IkReal x1308=((cj0)*(sj4)*(sj6));
IkReal x1309=((sj0)*(sj4)*(sj6));
evalcond[0]=((((IkReal(-1.00000000000000))*(cj2)*(x1307)))+(((sj5)*(x1304)))+(((IkReal(-1.00000000000000))*(cj5)*(r22)))+(((sj5)*(x1303))));
evalcond[1]=((((IkReal(-1.00000000000000))*(r21)*(sj4)*(sj6)))+(((cj4)*(r22)*(sj5)))+(((x1302)*(x1303)))+(((r20)*(x1301)))+(((cj2)*(x1292)))+(((x1302)*(x1304))));
evalcond[2]=((((IkReal(-1.00000000000000))*(x1300)*(x1305)))+(((r12)*(x1297)))+(((IkReal(-1.00000000000000))*(sj2)*(x1307)))+(((IkReal(-1.00000000000000))*(r02)*(x1298)))+(((x1293)*(x1294)))+(((IkReal(-1.00000000000000))*(x1299)*(x1300)))+(((x1293)*(x1296))));
evalcond[3]=((((IkReal(-1.00000000000000))*(x1292)))+(((IkReal(-1.00000000000000))*(x1293)*(x1305)))+(((IkReal(-1.00000000000000))*(x1293)*(x1299)))+(((IkReal(-1.00000000000000))*(x1296)*(x1300)))+(((r12)*(x1298)))+(((IkReal(-1.00000000000000))*(x1294)*(x1300)))+(((r02)*(x1297))));
evalcond[4]=((((IkReal(-1.00000000000000))*(r10)*(x1301)*(x1306)))+(((cj4)*(r02)*(x1293)))+(((IkReal(-1.00000000000000))*(x1295)*(x1297)*(x1305)))+(((r00)*(sj0)*(x1301)))+(((IkReal(-1.00000000000000))*(x1295)*(x1297)*(x1299)))+(((cj4)*(x1296)*(x1298)))+(((IkReal(-1.00000000000000))*(r12)*(x1295)*(x1300)))+(((r11)*(x1308)))+(((cj4)*(x1294)*(x1298)))+(((sj2)*(x1292)))+(((IkReal(-1.00000000000000))*(r01)*(x1309))));
evalcond[5]=((((IkReal(-1.00000000000000))*(r02)*(x1295)*(x1300)))+(((IkReal(-1.00000000000000))*(x1295)*(x1298)*(x1299)))+(((IkReal(-1.00000000000000))*(x1295)*(x1298)*(x1305)))+(((IkReal(-1.00000000000000))*(r00)*(x1301)*(x1306)))+(((IkReal(-1.00000000000000))*(r12)*(x1293)*(x1295)))+(((IkReal(-1.00000000000000))*(x1294)*(x1295)*(x1297)))+(((IkReal(-1.00000000000000))*(x1295)*(x1296)*(x1297)))+(((IkReal(-1.00000000000000))*(x1307)))+(((IkReal(-1.00000000000000))*(r10)*(sj0)*(x1301)))+(((r11)*(x1309)))+(((r01)*(x1308))));
if( IKabs(evalcond[0]) > 0.000001  || IKabs(evalcond[1]) > 0.000001  || IKabs(evalcond[2]) > 0.000001  || IKabs(evalcond[3]) > 0.000001  || IKabs(evalcond[4]) > 0.000001  || IKabs(evalcond[5]) > 0.000001  )
{
continue;
}
}

{
std::vector<IkSingleDOFSolutionBase<IkReal> > vinfos(7);
vinfos[0].jointtype = 1;
vinfos[0].foffset = j0;
vinfos[0].indices[0] = _ij0[0];
vinfos[0].indices[1] = _ij0[1];
vinfos[0].maxsolutions = _nj0;
vinfos[1].jointtype = 1;
vinfos[1].foffset = j1;
vinfos[1].indices[0] = _ij1[0];
vinfos[1].indices[1] = _ij1[1];
vinfos[1].maxsolutions = _nj1;
vinfos[2].jointtype = 1;
vinfos[2].foffset = j2;
vinfos[2].indices[0] = _ij2[0];
vinfos[2].indices[1] = _ij2[1];
vinfos[2].maxsolutions = _nj2;
vinfos[3].jointtype = 1;
vinfos[3].foffset = j3;
vinfos[3].indices[0] = _ij3[0];
vinfos[3].indices[1] = _ij3[1];
vinfos[3].maxsolutions = _nj3;
vinfos[4].jointtype = 1;
vinfos[4].foffset = j4;
vinfos[4].indices[0] = _ij4[0];
vinfos[4].indices[1] = _ij4[1];
vinfos[4].maxsolutions = _nj4;
vinfos[5].jointtype = 1;
vinfos[5].foffset = j5;
vinfos[5].indices[0] = _ij5[0];
vinfos[5].indices[1] = _ij5[1];
vinfos[5].maxsolutions = _nj5;
vinfos[6].jointtype = 1;
vinfos[6].foffset = j6;
vinfos[6].indices[0] = _ij6[0];
vinfos[6].indices[1] = _ij6[1];
vinfos[6].maxsolutions = _nj6;
std::vector<int> vfree(0);
solutions.AddSolution(vinfos,vfree);
}
}
}

}

}

} else
{
{
IkReal j3array[1], cj3array[1], sj3array[1];
bool j3valid[1]={false};
_nj3 = 1;
IkReal x1310=((IkReal(1.00000000000000))*(cj4));
IkReal x1311=((cj6)*(r21));
IkReal x1312=((r20)*(sj6));
if( IKabs(((gconst43)*(((((sj5)*(x1311)))+(((IkReal(-1.00000000000000))*(cj5)*(r22)))+(((sj5)*(x1312))))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(((gconst43)*(((((IkReal(-1.00000000000000))*(cj5)*(x1310)*(x1312)))+(((r21)*(sj4)*(sj6)))+(((IkReal(-1.00000000000000))*(cj5)*(x1310)*(x1311)))+(((IkReal(-1.00000000000000))*(r22)*(sj5)*(x1310)))+(((IkReal(-1.00000000000000))*(cj6)*(r20)*(sj4))))))) < IKFAST_ATAN2_MAGTHRESH )
    continue;
j3array[0]=IKatan2(((gconst43)*(((((sj5)*(x1311)))+(((IkReal(-1.00000000000000))*(cj5)*(r22)))+(((sj5)*(x1312)))))), ((gconst43)*(((((IkReal(-1.00000000000000))*(cj5)*(x1310)*(x1312)))+(((r21)*(sj4)*(sj6)))+(((IkReal(-1.00000000000000))*(cj5)*(x1310)*(x1311)))+(((IkReal(-1.00000000000000))*(r22)*(sj5)*(x1310)))+(((IkReal(-1.00000000000000))*(cj6)*(r20)*(sj4)))))));
sj3array[0]=IKsin(j3array[0]);
cj3array[0]=IKcos(j3array[0]);
if( j3array[0] > IKPI )
{
    j3array[0]-=IK2PI;
}
else if( j3array[0] < -IKPI )
{    j3array[0]+=IK2PI;
}
j3valid[0] = true;
for(int ij3 = 0; ij3 < 1; ++ij3)
{
if( !j3valid[ij3] )
{
    continue;
}
_ij3[0] = ij3; _ij3[1] = -1;
for(int iij3 = ij3+1; iij3 < 1; ++iij3)
{
if( j3valid[iij3] && IKabs(cj3array[ij3]-cj3array[iij3]) < IKFAST_SOLUTION_THRESH && IKabs(sj3array[ij3]-sj3array[iij3]) < IKFAST_SOLUTION_THRESH )
{
    j3valid[iij3]=false; _ij3[1] = iij3; break; 
}
}
j3 = j3array[ij3]; cj3 = cj3array[ij3]; sj3 = sj3array[ij3];
{
IkReal evalcond[6];
IkReal x1313=IKsin(j3);
IkReal x1314=IKcos(j3);
IkReal x1315=((sj0)*(sj5));
IkReal x1316=((r00)*(sj6));
IkReal x1317=((IkReal(1.00000000000000))*(cj4));
IkReal x1318=((cj6)*(r01));
IkReal x1319=((cj0)*(cj5));
IkReal x1320=((cj5)*(sj0));
IkReal x1321=((cj6)*(r11));
IkReal x1322=((cj0)*(sj5));
IkReal x1323=((cj6)*(sj4));
IkReal x1324=((cj4)*(cj5));
IkReal x1325=((cj6)*(r21));
IkReal x1326=((r20)*(sj6));
IkReal x1327=((r10)*(sj6));
IkReal x1328=((IkReal(1.00000000000000))*(cj0));
IkReal x1329=((IkReal(1.00000000000000))*(x1313));
IkReal x1330=((cj0)*(sj4)*(sj6));
IkReal x1331=((sj0)*(sj4)*(sj6));
evalcond[0]=((((IkReal(-1.00000000000000))*(cj5)*(r22)))+(((sj5)*(x1325)))+(((sj5)*(x1326)))+(((IkReal(-1.00000000000000))*(cj2)*(x1329))));
evalcond[1]=((((IkReal(-1.00000000000000))*(r21)*(sj4)*(sj6)))+(((x1324)*(x1325)))+(((r20)*(x1323)))+(((cj2)*(x1314)))+(((cj4)*(r22)*(sj5)))+(((x1324)*(x1326))));
evalcond[2]=((((x1315)*(x1318)))+(((r12)*(x1319)))+(((IkReal(-1.00000000000000))*(x1321)*(x1322)))+(((IkReal(-1.00000000000000))*(sj2)*(x1329)))+(((IkReal(-1.00000000000000))*(x1322)*(x1327)))+(((x1315)*(x1316)))+(((IkReal(-1.00000000000000))*(r02)*(x1320))));
evalcond[3]=((((IkReal(-1.00000000000000))*(x1316)*(x1322)))+(((IkReal(-1.00000000000000))*(x1315)*(x1321)))+(((r12)*(x1320)))+(((IkReal(-1.00000000000000))*(x1314)))+(((IkReal(-1.00000000000000))*(x1318)*(x1322)))+(((IkReal(-1.00000000000000))*(x1315)*(x1327)))+(((r02)*(x1319))));
evalcond[4]=((((cj4)*(r02)*(x1315)))+(((IkReal(-1.00000000000000))*(x1317)*(x1319)*(x1321)))+(((cj4)*(x1316)*(x1320)))+(((r11)*(x1330)))+(((IkReal(-1.00000000000000))*(r12)*(x1317)*(x1322)))+(((IkReal(-1.00000000000000))*(x1317)*(x1319)*(x1327)))+(((cj4)*(x1318)*(x1320)))+(((sj2)*(x1314)))+(((IkReal(-1.00000000000000))*(r01)*(x1331)))+(((IkReal(-1.00000000000000))*(r10)*(x1323)*(x1328)))+(((r00)*(sj0)*(x1323))));
evalcond[5]=((((IkReal(-1.00000000000000))*(r10)*(sj0)*(x1323)))+(((IkReal(-1.00000000000000))*(x1317)*(x1320)*(x1327)))+(((IkReal(-1.00000000000000))*(r12)*(x1315)*(x1317)))+(((r11)*(x1331)))+(((IkReal(-1.00000000000000))*(x1317)*(x1320)*(x1321)))+(((r01)*(x1330)))+(((IkReal(-1.00000000000000))*(r02)*(x1317)*(x1322)))+(((IkReal(-1.00000000000000))*(r00)*(x1323)*(x1328)))+(((IkReal(-1.00000000000000))*(x1316)*(x1317)*(x1319)))+(((IkReal(-1.00000000000000))*(x1329)))+(((IkReal(-1.00000000000000))*(x1317)*(x1318)*(x1319))));
if( IKabs(evalcond[0]) > 0.000001  || IKabs(evalcond[1]) > 0.000001  || IKabs(evalcond[2]) > 0.000001  || IKabs(evalcond[3]) > 0.000001  || IKabs(evalcond[4]) > 0.000001  || IKabs(evalcond[5]) > 0.000001  )
{
continue;
}
}

{
std::vector<IkSingleDOFSolutionBase<IkReal> > vinfos(7);
vinfos[0].jointtype = 1;
vinfos[0].foffset = j0;
vinfos[0].indices[0] = _ij0[0];
vinfos[0].indices[1] = _ij0[1];
vinfos[0].maxsolutions = _nj0;
vinfos[1].jointtype = 1;
vinfos[1].foffset = j1;
vinfos[1].indices[0] = _ij1[0];
vinfos[1].indices[1] = _ij1[1];
vinfos[1].maxsolutions = _nj1;
vinfos[2].jointtype = 1;
vinfos[2].foffset = j2;
vinfos[2].indices[0] = _ij2[0];
vinfos[2].indices[1] = _ij2[1];
vinfos[2].maxsolutions = _nj2;
vinfos[3].jointtype = 1;
vinfos[3].foffset = j3;
vinfos[3].indices[0] = _ij3[0];
vinfos[3].indices[1] = _ij3[1];
vinfos[3].maxsolutions = _nj3;
vinfos[4].jointtype = 1;
vinfos[4].foffset = j4;
vinfos[4].indices[0] = _ij4[0];
vinfos[4].indices[1] = _ij4[1];
vinfos[4].maxsolutions = _nj4;
vinfos[5].jointtype = 1;
vinfos[5].foffset = j5;
vinfos[5].indices[0] = _ij5[0];
vinfos[5].indices[1] = _ij5[1];
vinfos[5].maxsolutions = _nj5;
vinfos[6].jointtype = 1;
vinfos[6].foffset = j6;
vinfos[6].indices[0] = _ij6[0];
vinfos[6].indices[1] = _ij6[1];
vinfos[6].maxsolutions = _nj6;
std::vector<int> vfree(0);
solutions.AddSolution(vinfos,vfree);
}
}
}

}

}
}
}

}

}
}
}

} else
{
IkReal x1332=((cj0)*(cj5));
IkReal x1333=((IkReal(0.374290000000000))*(sj0));
IkReal x1334=((cj6)*(r11));
IkReal x1335=((IkReal(0.0100000000000000))*(sj6));
IkReal x1336=((cj6)*(r01));
IkReal x1337=((IkReal(0.0100000000000000))*(sj0));
IkReal x1338=((cj0)*(sj5));
evalcond[0]=((IkReal(-3.14159265358979))+(IKfmod(j1, IkReal(6.28318530717959))));
evalcond[1]=((IkReal(-0.295420000000000))+(((IkReal(-1.00000000000000))*(sj5)*(x1333)*(x1334)))+(((IkReal(-1.00000000000000))*(cj0)*(px)))+(((cj5)*(x1334)*(x1337)))+(((r00)*(x1332)*(x1335)))+(((IkReal(-1.00000000000000))*(r10)*(sj5)*(sj6)*(x1333)))+(((IkReal(-0.374290000000000))*(x1336)*(x1338)))+(((IkReal(0.0100000000000000))*(x1332)*(x1336)))+(((cj5)*(r12)*(x1333)))+(((r12)*(sj5)*(x1337)))+(((IkReal(-0.374290000000000))*(r00)*(sj6)*(x1338)))+(((IkReal(0.0100000000000000))*(r02)*(x1338)))+(((IkReal(-1.00000000000000))*(py)*(sj0)))+(((IkReal(0.374290000000000))*(r02)*(x1332)))+(((cj5)*(r10)*(sj0)*(x1335))));
if( IKabs(evalcond[0]) < 0.0000010000000000  && IKabs(evalcond[1]) < 0.0000010000000000  )
{
{
IkReal j2array[1], cj2array[1], sj2array[1];
bool j2valid[1]={false};
_nj2 = 1;
IkReal x1339=((cj0)*(r11));
IkReal x1340=((r01)*(sj0));
IkReal x1341=((r20)*(sj6));
IkReal x1342=((IkReal(0.144927536231884))*(cj5));
IkReal x1343=((IkReal(5.42449275362319))*(cj5));
IkReal x1344=((IkReal(5.42449275362319))*(sj5));
IkReal x1345=((IkReal(0.144927536231884))*(sj5));
IkReal x1346=((cj0)*(r12));
IkReal x1347=((r02)*(sj0));
IkReal x1348=((cj6)*(x1344));
IkReal x1349=((cj0)*(r10)*(sj6));
IkReal x1350=((r00)*(sj0)*(sj6));
if( IKabs(((((x1344)*(x1349)))+(((x1342)*(x1350)))+(((x1345)*(x1347)))+(((IkReal(14.4927536231884))*(cj0)*(py)))+(((IkReal(-1.00000000000000))*(x1344)*(x1350)))+(((IkReal(-14.4927536231884))*(px)*(sj0)))+(((cj6)*(x1340)*(x1342)))+(((IkReal(-1.00000000000000))*(x1342)*(x1349)))+(((IkReal(-1.00000000000000))*(cj6)*(x1339)*(x1342)))+(((IkReal(-1.00000000000000))*(x1345)*(x1346)))+(((x1339)*(x1348)))+(((x1343)*(x1347)))+(((IkReal(-1.00000000000000))*(x1343)*(x1346)))+(((IkReal(-1.00000000000000))*(x1340)*(x1348))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(((((x1341)*(x1344)))+(((IkReal(-1.00000000000000))*(r22)*(x1343)))+(((IkReal(14.4927536231884))*(pz)))+(((IkReal(-1.00000000000000))*(cj6)*(r21)*(x1342)))+(((r21)*(x1348)))+(((IkReal(-1.00000000000000))*(x1341)*(x1342)))+(((IkReal(-1.00000000000000))*(r22)*(x1345))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(IKsqr(((((x1344)*(x1349)))+(((x1342)*(x1350)))+(((x1345)*(x1347)))+(((IkReal(14.4927536231884))*(cj0)*(py)))+(((IkReal(-1.00000000000000))*(x1344)*(x1350)))+(((IkReal(-14.4927536231884))*(px)*(sj0)))+(((cj6)*(x1340)*(x1342)))+(((IkReal(-1.00000000000000))*(x1342)*(x1349)))+(((IkReal(-1.00000000000000))*(cj6)*(x1339)*(x1342)))+(((IkReal(-1.00000000000000))*(x1345)*(x1346)))+(((x1339)*(x1348)))+(((x1343)*(x1347)))+(((IkReal(-1.00000000000000))*(x1343)*(x1346)))+(((IkReal(-1.00000000000000))*(x1340)*(x1348)))))+IKsqr(((((x1341)*(x1344)))+(((IkReal(-1.00000000000000))*(r22)*(x1343)))+(((IkReal(14.4927536231884))*(pz)))+(((IkReal(-1.00000000000000))*(cj6)*(r21)*(x1342)))+(((r21)*(x1348)))+(((IkReal(-1.00000000000000))*(x1341)*(x1342)))+(((IkReal(-1.00000000000000))*(r22)*(x1345)))))-1) <= IKFAST_SINCOS_THRESH )
    continue;
j2array[0]=IKatan2(((((x1344)*(x1349)))+(((x1342)*(x1350)))+(((x1345)*(x1347)))+(((IkReal(14.4927536231884))*(cj0)*(py)))+(((IkReal(-1.00000000000000))*(x1344)*(x1350)))+(((IkReal(-14.4927536231884))*(px)*(sj0)))+(((cj6)*(x1340)*(x1342)))+(((IkReal(-1.00000000000000))*(x1342)*(x1349)))+(((IkReal(-1.00000000000000))*(cj6)*(x1339)*(x1342)))+(((IkReal(-1.00000000000000))*(x1345)*(x1346)))+(((x1339)*(x1348)))+(((x1343)*(x1347)))+(((IkReal(-1.00000000000000))*(x1343)*(x1346)))+(((IkReal(-1.00000000000000))*(x1340)*(x1348)))), ((((x1341)*(x1344)))+(((IkReal(-1.00000000000000))*(r22)*(x1343)))+(((IkReal(14.4927536231884))*(pz)))+(((IkReal(-1.00000000000000))*(cj6)*(r21)*(x1342)))+(((r21)*(x1348)))+(((IkReal(-1.00000000000000))*(x1341)*(x1342)))+(((IkReal(-1.00000000000000))*(r22)*(x1345)))));
sj2array[0]=IKsin(j2array[0]);
cj2array[0]=IKcos(j2array[0]);
if( j2array[0] > IKPI )
{
    j2array[0]-=IK2PI;
}
else if( j2array[0] < -IKPI )
{    j2array[0]+=IK2PI;
}
j2valid[0] = true;
for(int ij2 = 0; ij2 < 1; ++ij2)
{
if( !j2valid[ij2] )
{
    continue;
}
_ij2[0] = ij2; _ij2[1] = -1;
for(int iij2 = ij2+1; iij2 < 1; ++iij2)
{
if( j2valid[iij2] && IKabs(cj2array[ij2]-cj2array[iij2]) < IKFAST_SOLUTION_THRESH && IKabs(sj2array[ij2]-sj2array[iij2]) < IKFAST_SOLUTION_THRESH )
{
    j2valid[iij2]=false; _ij2[1] = iij2; break; 
}
}
j2 = j2array[ij2]; cj2 = cj2array[ij2]; sj2 = sj2array[ij2];
{
IkReal evalcond[2];
IkReal x1351=((cj6)*(r11));
IkReal x1352=((IkReal(0.374290000000000))*(sj0));
IkReal x1353=((IkReal(0.0100000000000000))*(cj5));
IkReal x1354=((cj6)*(r21));
IkReal x1355=((r10)*(sj6));
IkReal x1356=((IkReal(0.374290000000000))*(sj5));
IkReal x1357=((IkReal(0.0100000000000000))*(sj5));
IkReal x1358=((cj6)*(r01));
IkReal x1359=((r20)*(sj6));
IkReal x1360=((IkReal(0.374290000000000))*(cj5));
IkReal x1361=((cj0)*(r12));
IkReal x1362=((r00)*(sj6));
IkReal x1363=((cj0)*(x1356));
evalcond[0]=((((IkReal(-1.00000000000000))*(r22)*(x1360)))+(((IkReal(-0.0690000000000000))*(IKcos(j2))))+(((IkReal(-1.00000000000000))*(x1353)*(x1359)))+(((x1356)*(x1359)))+(((IkReal(-1.00000000000000))*(r22)*(x1357)))+(((IkReal(-1.00000000000000))*(x1353)*(x1354)))+(pz)+(((x1354)*(x1356))));
evalcond[1]=((((cj0)*(x1351)*(x1353)))+(((IkReal(-1.00000000000000))*(x1355)*(x1363)))+(((IkReal(-1.00000000000000))*(cj5)*(r02)*(x1352)))+(((IkReal(-1.00000000000000))*(cj0)*(py)))+(((cj0)*(x1353)*(x1355)))+(((IkReal(-1.00000000000000))*(sj0)*(x1353)*(x1358)))+(((IkReal(-1.00000000000000))*(sj0)*(x1353)*(x1362)))+(((IkReal(-1.00000000000000))*(r02)*(sj0)*(x1357)))+(((IkReal(0.0690000000000000))*(IKsin(j2))))+(((sj5)*(x1352)*(x1358)))+(((x1357)*(x1361)))+(((x1360)*(x1361)))+(((sj5)*(x1352)*(x1362)))+(((IkReal(-1.00000000000000))*(x1351)*(x1363)))+(((px)*(sj0))));
if( IKabs(evalcond[0]) > 0.000001  || IKabs(evalcond[1]) > 0.000001  )
{
continue;
}
}

{
IkReal dummyeval[1];
IkReal gconst53;
IkReal x1364=(cj6)*(cj6);
IkReal x1365=(sj6)*(sj6);
IkReal x1366=((sj5)*(sj6));
IkReal x1367=((IkReal(1.00000000000000))*(cj0));
IkReal x1368=((cj6)*(sj5));
IkReal x1369=((r20)*(sj0));
IkReal x1370=((cj0)*(r20));
IkReal x1371=((r00)*(r21));
IkReal x1372=((r22)*(sj0));
IkReal x1373=((IkReal(1.00000000000000))*(r21)*(sj0));
IkReal x1374=((cj5)*(x1365));
IkReal x1375=((cj5)*(x1364));
gconst53=IKsign(((((r11)*(x1369)*(x1375)))+(((IkReal(-1.00000000000000))*(x1367)*(x1371)*(x1375)))+(((cj0)*(r01)*(r22)*(x1366)))+(((IkReal(-1.00000000000000))*(r10)*(x1373)*(x1374)))+(((r01)*(x1370)*(x1374)))+(((r01)*(x1370)*(x1375)))+(((r11)*(x1366)*(x1372)))+(((r11)*(x1369)*(x1374)))+(((IkReal(-1.00000000000000))*(r00)*(r22)*(x1367)*(x1368)))+(((IkReal(-1.00000000000000))*(r10)*(x1373)*(x1375)))+(((r12)*(x1368)*(x1369)))+(((r02)*(x1368)*(x1370)))+(((IkReal(-1.00000000000000))*(r02)*(r21)*(x1366)*(x1367)))+(((IkReal(-1.00000000000000))*(r12)*(x1366)*(x1373)))+(((IkReal(-1.00000000000000))*(r10)*(x1368)*(x1372)))+(((IkReal(-1.00000000000000))*(x1367)*(x1371)*(x1374)))));
IkReal x1376=(cj6)*(cj6);
IkReal x1377=(sj6)*(sj6);
IkReal x1378=((sj5)*(sj6));
IkReal x1379=((IkReal(1.00000000000000))*(cj0));
IkReal x1380=((cj6)*(sj5));
IkReal x1381=((r20)*(sj0));
IkReal x1382=((cj0)*(r20));
IkReal x1383=((r00)*(r21));
IkReal x1384=((r22)*(sj0));
IkReal x1385=((IkReal(1.00000000000000))*(r21)*(sj0));
IkReal x1386=((cj5)*(x1377));
IkReal x1387=((cj5)*(x1376));
dummyeval[0]=((((r01)*(x1382)*(x1386)))+(((IkReal(-1.00000000000000))*(r10)*(x1385)*(x1387)))+(((r02)*(x1380)*(x1382)))+(((IkReal(-1.00000000000000))*(x1379)*(x1383)*(x1387)))+(((cj0)*(r01)*(r22)*(x1378)))+(((r11)*(x1381)*(x1386)))+(((r11)*(x1381)*(x1387)))+(((IkReal(-1.00000000000000))*(r10)*(x1385)*(x1386)))+(((r11)*(x1378)*(x1384)))+(((IkReal(-1.00000000000000))*(r12)*(x1378)*(x1385)))+(((IkReal(-1.00000000000000))*(r10)*(x1380)*(x1384)))+(((r12)*(x1380)*(x1381)))+(((IkReal(-1.00000000000000))*(x1379)*(x1383)*(x1386)))+(((r01)*(x1382)*(x1387)))+(((IkReal(-1.00000000000000))*(r00)*(r22)*(x1379)*(x1380)))+(((IkReal(-1.00000000000000))*(r02)*(r21)*(x1378)*(x1379))));
if( IKabs(dummyeval[0]) < 0.0000010000000000  )
{
{
IkReal dummyeval[1];
IkReal gconst52;
IkReal x1388=(cj6)*(cj6);
IkReal x1389=(sj6)*(sj6);
IkReal x1390=((IkReal(1.00000000000000))*(r01));
IkReal x1391=((sj0)*(sj5));
IkReal x1392=((cj6)*(r22));
IkReal x1393=((r21)*(sj6));
IkReal x1394=((r00)*(r21));
IkReal x1395=((cj0)*(sj5));
IkReal x1396=((cj6)*(r20));
IkReal x1397=((r22)*(sj6));
IkReal x1398=((cj0)*(cj5));
IkReal x1399=((IkReal(1.00000000000000))*(r10));
IkReal x1400=((cj5)*(sj0));
IkReal x1401=((r20)*(x1389));
IkReal x1402=((x1388)*(x1400));
gconst52=IKsign(((((r11)*(x1395)*(x1397)))+(((r11)*(x1398)*(x1401)))+(((IkReal(-1.00000000000000))*(r12)*(x1393)*(x1395)))+(((IkReal(-1.00000000000000))*(x1390)*(x1391)*(x1397)))+(((r00)*(x1391)*(x1392)))+(((r12)*(x1395)*(x1396)))+(((r02)*(x1391)*(x1393)))+(((x1394)*(x1402)))+(((IkReal(-1.00000000000000))*(x1390)*(x1400)*(x1401)))+(((IkReal(-1.00000000000000))*(r02)*(x1391)*(x1396)))+(((IkReal(-1.00000000000000))*(r21)*(x1388)*(x1398)*(x1399)))+(((IkReal(-1.00000000000000))*(x1392)*(x1395)*(x1399)))+(((IkReal(-1.00000000000000))*(r20)*(x1390)*(x1402)))+(((x1389)*(x1394)*(x1400)))+(((r11)*(r20)*(x1388)*(x1398)))+(((IkReal(-1.00000000000000))*(r21)*(x1389)*(x1398)*(x1399)))));
IkReal x1403=(cj6)*(cj6);
IkReal x1404=(sj6)*(sj6);
IkReal x1405=((IkReal(1.00000000000000))*(r01));
IkReal x1406=((sj0)*(sj5));
IkReal x1407=((cj6)*(r22));
IkReal x1408=((r21)*(sj6));
IkReal x1409=((r00)*(r21));
IkReal x1410=((cj0)*(sj5));
IkReal x1411=((cj6)*(r20));
IkReal x1412=((r22)*(sj6));
IkReal x1413=((cj0)*(cj5));
IkReal x1414=((IkReal(1.00000000000000))*(r10));
IkReal x1415=((cj5)*(sj0));
IkReal x1416=((r20)*(x1404));
IkReal x1417=((x1403)*(x1415));
dummyeval[0]=((((r11)*(r20)*(x1403)*(x1413)))+(((IkReal(-1.00000000000000))*(r12)*(x1408)*(x1410)))+(((IkReal(-1.00000000000000))*(x1407)*(x1410)*(x1414)))+(((r12)*(x1410)*(x1411)))+(((IkReal(-1.00000000000000))*(r21)*(x1403)*(x1413)*(x1414)))+(((x1404)*(x1409)*(x1415)))+(((r11)*(x1413)*(x1416)))+(((r02)*(x1406)*(x1408)))+(((IkReal(-1.00000000000000))*(r20)*(x1405)*(x1417)))+(((r00)*(x1406)*(x1407)))+(((IkReal(-1.00000000000000))*(r21)*(x1404)*(x1413)*(x1414)))+(((IkReal(-1.00000000000000))*(x1405)*(x1406)*(x1412)))+(((IkReal(-1.00000000000000))*(x1405)*(x1415)*(x1416)))+(((x1409)*(x1417)))+(((r11)*(x1410)*(x1412)))+(((IkReal(-1.00000000000000))*(r02)*(x1406)*(x1411))));
if( IKabs(dummyeval[0]) < 0.0000010000000000  )
{
{
IkReal dummyeval[1];
dummyeval[0]=cj2;
if( IKabs(dummyeval[0]) < 0.0000010000000000  )
{
{
IkReal evalcond[5];
IkReal x1418=((cj5)*(r22));
IkReal x1419=((IkReal(0.374290000000000))*(sj5));
IkReal x1420=((cj0)*(sj6));
IkReal x1421=((cj6)*(r21));
IkReal x1422=((IkReal(0.0100000000000000))*(sj5));
IkReal x1423=((cj0)*(r02));
IkReal x1424=((IkReal(0.0100000000000000))*(cj5));
IkReal x1425=((IkReal(1.00000000000000))*(py));
IkReal x1426=((r01)*(sj0));
IkReal x1427=((r20)*(sj6));
IkReal x1428=((r11)*(sj0));
IkReal x1429=((IkReal(0.374290000000000))*(cj5));
IkReal x1430=((cj0)*(r12));
IkReal x1431=((sj0)*(x1429));
IkReal x1432=((cj6)*(x1424));
IkReal x1433=((r10)*(sj0)*(sj6));
IkReal x1434=((r00)*(sj0)*(sj6));
IkReal x1435=((cj0)*(cj6)*(x1419));
evalcond[0]=((IkReal(-3.14159265358979))+(IKfmod(((IkReal(1.57079632679490))+(j2)), IkReal(6.28318530717959))));
evalcond[1]=((((sj5)*(x1421)))+(((sj5)*(x1427)))+(((IkReal(-1.00000000000000))*(x1418))));
evalcond[2]=((((IkReal(-1.00000000000000))*(x1424)*(x1427)))+(((IkReal(-1.00000000000000))*(r22)*(x1422)))+(((IkReal(-1.00000000000000))*(x1421)*(x1424)))+(((x1419)*(x1421)))+(pz)+(((IkReal(-0.374290000000000))*(x1418)))+(((x1419)*(x1427))));
evalcond[3]=((IkReal(0.0690000000000000))+(((cj0)*(r11)*(x1432)))+(((IkReal(-1.00000000000000))*(r11)*(x1435)))+(((IkReal(-1.00000000000000))*(cj0)*(x1425)))+(((r10)*(x1420)*(x1424)))+(((cj6)*(x1419)*(x1426)))+(((IkReal(-1.00000000000000))*(x1426)*(x1432)))+(((IkReal(-1.00000000000000))*(r02)*(sj0)*(x1422)))+(((x1422)*(x1430)))+(((IkReal(-1.00000000000000))*(x1424)*(x1434)))+(((x1429)*(x1430)))+(((IkReal(-1.00000000000000))*(r02)*(x1431)))+(((px)*(sj0)))+(((x1419)*(x1434)))+(((IkReal(-1.00000000000000))*(r10)*(x1419)*(x1420))));
evalcond[4]=((IkReal(-0.295420000000000))+(((IkReal(-1.00000000000000))*(cj0)*(px)))+(((x1424)*(x1433)))+(((x1422)*(x1423)))+(((x1428)*(x1432)))+(((r12)*(sj0)*(x1422)))+(((x1423)*(x1429)))+(((IkReal(-1.00000000000000))*(r00)*(x1419)*(x1420)))+(((IkReal(-1.00000000000000))*(sj0)*(x1425)))+(((r00)*(x1420)*(x1424)))+(((cj0)*(r01)*(x1432)))+(((r12)*(x1431)))+(((IkReal(-1.00000000000000))*(cj6)*(x1419)*(x1428)))+(((IkReal(-1.00000000000000))*(r01)*(x1435)))+(((IkReal(-1.00000000000000))*(x1419)*(x1433))));
if( IKabs(evalcond[0]) < 0.0000010000000000  && IKabs(evalcond[1]) < 0.0000010000000000  && IKabs(evalcond[2]) < 0.0000010000000000  && IKabs(evalcond[3]) < 0.0000010000000000  && IKabs(evalcond[4]) < 0.0000010000000000  )
{
{
IkReal j3array[1], cj3array[1], sj3array[1];
bool j3valid[1]={false};
_nj3 = 1;
IkReal x1436=((sj0)*(sj5));
IkReal x1437=((r00)*(sj6));
IkReal x1438=((IkReal(1.00000000000000))*(cj5));
IkReal x1439=((cj6)*(r11));
IkReal x1440=((cj6)*(r01));
IkReal x1441=((r10)*(sj6));
IkReal x1442=((cj0)*(sj5));
if( IKabs(((((x1436)*(x1440)))+(((x1436)*(x1437)))+(((IkReal(-1.00000000000000))*(x1441)*(x1442)))+(((IkReal(-1.00000000000000))*(x1439)*(x1442)))+(((cj0)*(cj5)*(r12)))+(((IkReal(-1.00000000000000))*(r02)*(sj0)*(x1438))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(((((x1440)*(x1442)))+(((x1436)*(x1439)))+(((x1437)*(x1442)))+(((IkReal(-1.00000000000000))*(r12)*(sj0)*(x1438)))+(((x1436)*(x1441)))+(((IkReal(-1.00000000000000))*(cj0)*(r02)*(x1438))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(IKsqr(((((x1436)*(x1440)))+(((x1436)*(x1437)))+(((IkReal(-1.00000000000000))*(x1441)*(x1442)))+(((IkReal(-1.00000000000000))*(x1439)*(x1442)))+(((cj0)*(cj5)*(r12)))+(((IkReal(-1.00000000000000))*(r02)*(sj0)*(x1438)))))+IKsqr(((((x1440)*(x1442)))+(((x1436)*(x1439)))+(((x1437)*(x1442)))+(((IkReal(-1.00000000000000))*(r12)*(sj0)*(x1438)))+(((x1436)*(x1441)))+(((IkReal(-1.00000000000000))*(cj0)*(r02)*(x1438)))))-1) <= IKFAST_SINCOS_THRESH )
    continue;
j3array[0]=IKatan2(((((x1436)*(x1440)))+(((x1436)*(x1437)))+(((IkReal(-1.00000000000000))*(x1441)*(x1442)))+(((IkReal(-1.00000000000000))*(x1439)*(x1442)))+(((cj0)*(cj5)*(r12)))+(((IkReal(-1.00000000000000))*(r02)*(sj0)*(x1438)))), ((((x1440)*(x1442)))+(((x1436)*(x1439)))+(((x1437)*(x1442)))+(((IkReal(-1.00000000000000))*(r12)*(sj0)*(x1438)))+(((x1436)*(x1441)))+(((IkReal(-1.00000000000000))*(cj0)*(r02)*(x1438)))));
sj3array[0]=IKsin(j3array[0]);
cj3array[0]=IKcos(j3array[0]);
if( j3array[0] > IKPI )
{
    j3array[0]-=IK2PI;
}
else if( j3array[0] < -IKPI )
{    j3array[0]+=IK2PI;
}
j3valid[0] = true;
for(int ij3 = 0; ij3 < 1; ++ij3)
{
if( !j3valid[ij3] )
{
    continue;
}
_ij3[0] = ij3; _ij3[1] = -1;
for(int iij3 = ij3+1; iij3 < 1; ++iij3)
{
if( j3valid[iij3] && IKabs(cj3array[ij3]-cj3array[iij3]) < IKFAST_SOLUTION_THRESH && IKabs(sj3array[ij3]-sj3array[iij3]) < IKFAST_SOLUTION_THRESH )
{
    j3valid[iij3]=false; _ij3[1] = iij3; break; 
}
}
j3 = j3array[ij3]; cj3 = cj3array[ij3]; sj3 = sj3array[ij3];
{
IkReal evalcond[2];
IkReal x1443=((cj0)*(cj5));
IkReal x1444=((IkReal(1.00000000000000))*(cj0));
IkReal x1445=((cj6)*(r11));
IkReal x1446=((r10)*(sj6));
IkReal x1447=((cj5)*(sj0));
IkReal x1448=((r00)*(sj5)*(sj6));
IkReal x1449=((cj6)*(r01)*(sj5));
IkReal x1450=((IkReal(1.00000000000000))*(sj0)*(sj5));
evalcond[0]=((((IkReal(-1.00000000000000))*(sj5)*(x1444)*(x1445)))+(((IkReal(-1.00000000000000))*(r02)*(x1447)))+(((r12)*(x1443)))+(((sj0)*(x1448)))+(((IkReal(-1.00000000000000))*(IKsin(j3))))+(((sj0)*(x1449)))+(((IkReal(-1.00000000000000))*(sj5)*(x1444)*(x1446))));
evalcond[1]=((((IkReal(-1.00000000000000))*(x1446)*(x1450)))+(((r12)*(x1447)))+(((IkReal(-1.00000000000000))*(x1445)*(x1450)))+(((IkReal(-1.00000000000000))*(x1444)*(x1448)))+(IKcos(j3))+(((r02)*(x1443)))+(((IkReal(-1.00000000000000))*(x1444)*(x1449))));
if( IKabs(evalcond[0]) > 0.000001  || IKabs(evalcond[1]) > 0.000001  )
{
continue;
}
}

{
IkReal dummyeval[1];
IkReal gconst59;
IkReal x1451=(r21)*(r21);
IkReal x1452=(cj5)*(cj5);
IkReal x1453=(sj6)*(sj6);
IkReal x1454=(cj6)*(cj6);
IkReal x1455=(r20)*(r20);
IkReal x1456=((cj6)*(r21));
IkReal x1457=((IkReal(2.00000000000000))*(r20)*(sj6));
IkReal x1458=((cj5)*(r22)*(sj5));
IkReal x1459=((IkReal(1.00000000000000))*(x1453));
IkReal x1460=((IkReal(1.00000000000000))*(x1454));
gconst59=IKsign(((((x1456)*(x1457)))+(((IkReal(-1.00000000000000))*(x1455)*(x1460)))+(((IkReal(-1.00000000000000))*(x1457)*(x1458)))+(((IkReal(-1.00000000000000))*(x1451)*(x1452)*(x1460)))+(((IkReal(-1.00000000000000))*((r22)*(r22))*((sj5)*(sj5))))+(((IkReal(-1.00000000000000))*(x1452)*(x1456)*(x1457)))+(((IkReal(-2.00000000000000))*(x1456)*(x1458)))+(((IkReal(-1.00000000000000))*(x1451)*(x1459)))+(((IkReal(-1.00000000000000))*(x1452)*(x1455)*(x1459)))));
IkReal x1461=(r21)*(r21);
IkReal x1462=(cj5)*(cj5);
IkReal x1463=(sj6)*(sj6);
IkReal x1464=(cj6)*(cj6);
IkReal x1465=(r20)*(r20);
IkReal x1466=((cj6)*(r21));
IkReal x1467=((IkReal(2.00000000000000))*(r20)*(sj6));
IkReal x1468=((cj5)*(r22)*(sj5));
IkReal x1469=((IkReal(1.00000000000000))*(x1463));
IkReal x1470=((IkReal(1.00000000000000))*(x1464));
dummyeval[0]=((((IkReal(-1.00000000000000))*(x1462)*(x1466)*(x1467)))+(((IkReal(-1.00000000000000))*((r22)*(r22))*((sj5)*(sj5))))+(((IkReal(-1.00000000000000))*(x1461)*(x1462)*(x1470)))+(((IkReal(-2.00000000000000))*(x1466)*(x1468)))+(((IkReal(-1.00000000000000))*(x1462)*(x1465)*(x1469)))+(((IkReal(-1.00000000000000))*(x1467)*(x1468)))+(((IkReal(-1.00000000000000))*(x1465)*(x1470)))+(((IkReal(-1.00000000000000))*(x1461)*(x1469)))+(((x1466)*(x1467))));
if( IKabs(dummyeval[0]) < 0.0000010000000000  )
{
{
IkReal dummyeval[1];
IkReal gconst60;
IkReal x1471=(cj6)*(cj6);
IkReal x1472=(sj6)*(sj6);
IkReal x1473=((IkReal(1.00000000000000))*(r01));
IkReal x1474=((sj0)*(sj5));
IkReal x1475=((cj6)*(r22));
IkReal x1476=((r21)*(sj6));
IkReal x1477=((r00)*(r21));
IkReal x1478=((cj0)*(sj5));
IkReal x1479=((cj6)*(r20));
IkReal x1480=((r22)*(sj6));
IkReal x1481=((cj0)*(cj5));
IkReal x1482=((IkReal(1.00000000000000))*(r10));
IkReal x1483=((cj5)*(sj0));
IkReal x1484=((r20)*(x1472));
IkReal x1485=((x1471)*(x1483));
gconst60=IKsign(((((IkReal(-1.00000000000000))*(r12)*(x1476)*(x1478)))+(((IkReal(-1.00000000000000))*(r02)*(x1474)*(x1479)))+(((IkReal(-1.00000000000000))*(x1473)*(x1483)*(x1484)))+(((r02)*(x1474)*(x1476)))+(((IkReal(-1.00000000000000))*(r20)*(x1473)*(x1485)))+(((r11)*(x1478)*(x1480)))+(((r11)*(x1481)*(x1484)))+(((IkReal(-1.00000000000000))*(r21)*(x1472)*(x1481)*(x1482)))+(((r00)*(x1474)*(x1475)))+(((IkReal(-1.00000000000000))*(r21)*(x1471)*(x1481)*(x1482)))+(((x1472)*(x1477)*(x1483)))+(((r12)*(x1478)*(x1479)))+(((r11)*(r20)*(x1471)*(x1481)))+(((IkReal(-1.00000000000000))*(x1475)*(x1478)*(x1482)))+(((IkReal(-1.00000000000000))*(x1473)*(x1474)*(x1480)))+(((x1477)*(x1485)))));
IkReal x1486=(cj6)*(cj6);
IkReal x1487=(sj6)*(sj6);
IkReal x1488=((IkReal(1.00000000000000))*(r01));
IkReal x1489=((sj0)*(sj5));
IkReal x1490=((cj6)*(r22));
IkReal x1491=((r21)*(sj6));
IkReal x1492=((r00)*(r21));
IkReal x1493=((cj0)*(sj5));
IkReal x1494=((cj6)*(r20));
IkReal x1495=((r22)*(sj6));
IkReal x1496=((cj0)*(cj5));
IkReal x1497=((IkReal(1.00000000000000))*(r10));
IkReal x1498=((cj5)*(sj0));
IkReal x1499=((r20)*(x1487));
IkReal x1500=((x1486)*(x1498));
dummyeval[0]=((((IkReal(-1.00000000000000))*(x1488)*(x1489)*(x1495)))+(((IkReal(-1.00000000000000))*(r12)*(x1491)*(x1493)))+(((IkReal(-1.00000000000000))*(x1490)*(x1493)*(x1497)))+(((r12)*(x1493)*(x1494)))+(((r11)*(x1493)*(x1495)))+(((r11)*(r20)*(x1486)*(x1496)))+(((IkReal(-1.00000000000000))*(r20)*(x1488)*(x1500)))+(((IkReal(-1.00000000000000))*(x1488)*(x1498)*(x1499)))+(((x1492)*(x1500)))+(((x1487)*(x1492)*(x1498)))+(((IkReal(-1.00000000000000))*(r21)*(x1486)*(x1496)*(x1497)))+(((r11)*(x1496)*(x1499)))+(((IkReal(-1.00000000000000))*(r02)*(x1489)*(x1494)))+(((r02)*(x1489)*(x1491)))+(((IkReal(-1.00000000000000))*(r21)*(x1487)*(x1496)*(x1497)))+(((r00)*(x1489)*(x1490))));
if( IKabs(dummyeval[0]) < 0.0000010000000000  )
{
continue;

} else
{
{
IkReal j4array[1], cj4array[1], sj4array[1];
bool j4valid[1]={false};
_nj4 = 1;
IkReal x1501=((sj0)*(sj6));
IkReal x1502=((cj0)*(r10));
IkReal x1503=((IkReal(1.00000000000000))*(cj5));
IkReal x1504=((cj6)*(sj0));
IkReal x1505=((cj0)*(r11));
if( IKabs(((gconst60)*(((((IkReal(-1.00000000000000))*(sj6)*(x1505)))+(((r01)*(x1501)))+(((cj6)*(x1502)))+(((IkReal(-1.00000000000000))*(r00)*(x1504))))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(((gconst60)*(((((cj5)*(sj6)*(x1502)))+(((cj0)*(r12)*(sj5)))+(((IkReal(-1.00000000000000))*(r02)*(sj0)*(sj5)))+(((cj5)*(cj6)*(x1505)))+(((IkReal(-1.00000000000000))*(r00)*(x1501)*(x1503)))+(((IkReal(-1.00000000000000))*(r01)*(x1503)*(x1504))))))) < IKFAST_ATAN2_MAGTHRESH )
    continue;
j4array[0]=IKatan2(((gconst60)*(((((IkReal(-1.00000000000000))*(sj6)*(x1505)))+(((r01)*(x1501)))+(((cj6)*(x1502)))+(((IkReal(-1.00000000000000))*(r00)*(x1504)))))), ((gconst60)*(((((cj5)*(sj6)*(x1502)))+(((cj0)*(r12)*(sj5)))+(((IkReal(-1.00000000000000))*(r02)*(sj0)*(sj5)))+(((cj5)*(cj6)*(x1505)))+(((IkReal(-1.00000000000000))*(r00)*(x1501)*(x1503)))+(((IkReal(-1.00000000000000))*(r01)*(x1503)*(x1504)))))));
sj4array[0]=IKsin(j4array[0]);
cj4array[0]=IKcos(j4array[0]);
if( j4array[0] > IKPI )
{
    j4array[0]-=IK2PI;
}
else if( j4array[0] < -IKPI )
{    j4array[0]+=IK2PI;
}
j4valid[0] = true;
for(int ij4 = 0; ij4 < 1; ++ij4)
{
if( !j4valid[ij4] )
{
    continue;
}
_ij4[0] = ij4; _ij4[1] = -1;
for(int iij4 = ij4+1; iij4 < 1; ++iij4)
{
if( j4valid[iij4] && IKabs(cj4array[ij4]-cj4array[iij4]) < IKFAST_SOLUTION_THRESH && IKabs(sj4array[ij4]-sj4array[iij4]) < IKFAST_SOLUTION_THRESH )
{
    j4valid[iij4]=false; _ij4[1] = iij4; break; 
}
}
j4 = j4array[ij4]; cj4 = cj4array[ij4]; sj4 = sj4array[ij4];
{
IkReal evalcond[6];
IkReal x1506=IKsin(j4);
IkReal x1507=IKcos(j4);
IkReal x1508=((r22)*(sj5));
IkReal x1509=((IkReal(1.00000000000000))*(cj6));
IkReal x1510=((IkReal(1.00000000000000))*(cj0));
IkReal x1511=((cj5)*(r11));
IkReal x1512=((cj5)*(cj6));
IkReal x1513=((r11)*(sj6));
IkReal x1514=((IkReal(1.00000000000000))*(sj6));
IkReal x1515=((cj6)*(r00));
IkReal x1516=((r12)*(sj5));
IkReal x1517=((r02)*(sj5));
IkReal x1518=((cj6)*(r10));
IkReal x1519=((cj5)*(sj6));
IkReal x1520=((cj5)*(r01));
IkReal x1521=((sj0)*(x1506));
IkReal x1522=((r00)*(x1519));
IkReal x1523=((cj0)*(x1506));
IkReal x1524=((sj0)*(x1507));
IkReal x1525=((r20)*(x1507));
IkReal x1526=((cj0)*(x1507));
IkReal x1527=((r21)*(x1506));
IkReal x1528=((r21)*(x1507));
IkReal x1529=((r20)*(x1506));
IkReal x1530=((x1507)*(x1516));
IkReal x1531=((r01)*(sj6)*(x1507));
IkReal x1532=((cj5)*(r10)*(x1514));
evalcond[0]=((IkReal(1.00000000000000))+(((x1506)*(x1508)))+(((IkReal(-1.00000000000000))*(x1509)*(x1525)))+(((sj6)*(x1528)))+(((x1519)*(x1529)))+(((x1512)*(x1527))));
evalcond[1]=((((IkReal(-1.00000000000000))*(x1514)*(x1527)))+(((x1507)*(x1508)))+(((x1512)*(x1528)))+(((cj6)*(x1529)))+(((x1519)*(x1525))));
evalcond[2]=((((IkReal(-1.00000000000000))*(x1506)*(x1510)*(x1516)))+(((IkReal(-1.00000000000000))*(r00)*(x1509)*(x1524)))+(((IkReal(-1.00000000000000))*(x1507)*(x1510)*(x1513)))+(((x1518)*(x1526)))+(((x1517)*(x1521)))+(((r01)*(x1512)*(x1521)))+(((r01)*(sj6)*(x1524)))+(((x1521)*(x1522)))+(((IkReal(-1.00000000000000))*(x1509)*(x1511)*(x1523)))+(((IkReal(-1.00000000000000))*(r10)*(x1506)*(x1510)*(x1519))));
evalcond[3]=((((x1517)*(x1524)))+(((IkReal(-1.00000000000000))*(x1510)*(x1530)))+(((IkReal(-1.00000000000000))*(r10)*(x1507)*(x1510)*(x1519)))+(cj3)+(((r01)*(x1512)*(x1524)))+(((x1515)*(x1521)))+(((x1513)*(x1523)))+(((IkReal(-1.00000000000000))*(x1509)*(x1511)*(x1526)))+(((x1522)*(x1524)))+(((IkReal(-1.00000000000000))*(r10)*(x1509)*(x1523)))+(((IkReal(-1.00000000000000))*(r01)*(x1514)*(x1521))));
evalcond[4]=((((IkReal(-1.00000000000000))*(x1506)*(x1510)*(x1517)))+(((IkReal(-1.00000000000000))*(x1509)*(x1511)*(x1521)))+(((IkReal(-1.00000000000000))*(x1506)*(x1510)*(x1522)))+(((x1518)*(x1524)))+(((IkReal(-1.00000000000000))*(x1510)*(x1531)))+(((IkReal(-1.00000000000000))*(x1521)*(x1532)))+(((IkReal(-1.00000000000000))*(x1516)*(x1521)))+(((IkReal(-1.00000000000000))*(x1509)*(x1520)*(x1523)))+(((IkReal(-1.00000000000000))*(x1513)*(x1524)))+(((x1515)*(x1526))));
evalcond[5]=((((IkReal(-1.00000000000000))*(x1509)*(x1511)*(x1524)))+(((r01)*(sj6)*(x1523)))+(((IkReal(-1.00000000000000))*(x1516)*(x1524)))+(sj3)+(((IkReal(-1.00000000000000))*(x1507)*(x1510)*(x1522)))+(((IkReal(-1.00000000000000))*(x1509)*(x1520)*(x1526)))+(((IkReal(-1.00000000000000))*(x1507)*(x1510)*(x1517)))+(((IkReal(-1.00000000000000))*(r00)*(x1509)*(x1523)))+(((IkReal(-1.00000000000000))*(x1524)*(x1532)))+(((x1513)*(x1521)))+(((IkReal(-1.00000000000000))*(r10)*(x1509)*(x1521))));
if( IKabs(evalcond[0]) > 0.000001  || IKabs(evalcond[1]) > 0.000001  || IKabs(evalcond[2]) > 0.000001  || IKabs(evalcond[3]) > 0.000001  || IKabs(evalcond[4]) > 0.000001  || IKabs(evalcond[5]) > 0.000001  )
{
continue;
}
}

{
std::vector<IkSingleDOFSolutionBase<IkReal> > vinfos(7);
vinfos[0].jointtype = 1;
vinfos[0].foffset = j0;
vinfos[0].indices[0] = _ij0[0];
vinfos[0].indices[1] = _ij0[1];
vinfos[0].maxsolutions = _nj0;
vinfos[1].jointtype = 1;
vinfos[1].foffset = j1;
vinfos[1].indices[0] = _ij1[0];
vinfos[1].indices[1] = _ij1[1];
vinfos[1].maxsolutions = _nj1;
vinfos[2].jointtype = 1;
vinfos[2].foffset = j2;
vinfos[2].indices[0] = _ij2[0];
vinfos[2].indices[1] = _ij2[1];
vinfos[2].maxsolutions = _nj2;
vinfos[3].jointtype = 1;
vinfos[3].foffset = j3;
vinfos[3].indices[0] = _ij3[0];
vinfos[3].indices[1] = _ij3[1];
vinfos[3].maxsolutions = _nj3;
vinfos[4].jointtype = 1;
vinfos[4].foffset = j4;
vinfos[4].indices[0] = _ij4[0];
vinfos[4].indices[1] = _ij4[1];
vinfos[4].maxsolutions = _nj4;
vinfos[5].jointtype = 1;
vinfos[5].foffset = j5;
vinfos[5].indices[0] = _ij5[0];
vinfos[5].indices[1] = _ij5[1];
vinfos[5].maxsolutions = _nj5;
vinfos[6].jointtype = 1;
vinfos[6].foffset = j6;
vinfos[6].indices[0] = _ij6[0];
vinfos[6].indices[1] = _ij6[1];
vinfos[6].maxsolutions = _nj6;
std::vector<int> vfree(0);
solutions.AddSolution(vinfos,vfree);
}
}
}

}

}

} else
{
{
IkReal j4array[1], cj4array[1], sj4array[1];
bool j4valid[1]={false};
_nj4 = 1;
if( IKabs(((gconst59)*(((((cj5)*(r20)*(sj6)))+(((r22)*(sj5)))+(((cj5)*(cj6)*(r21))))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(((gconst59)*(((((r21)*(sj6)))+(((IkReal(-1.00000000000000))*(cj6)*(r20))))))) < IKFAST_ATAN2_MAGTHRESH )
    continue;
j4array[0]=IKatan2(((gconst59)*(((((cj5)*(r20)*(sj6)))+(((r22)*(sj5)))+(((cj5)*(cj6)*(r21)))))), ((gconst59)*(((((r21)*(sj6)))+(((IkReal(-1.00000000000000))*(cj6)*(r20)))))));
sj4array[0]=IKsin(j4array[0]);
cj4array[0]=IKcos(j4array[0]);
if( j4array[0] > IKPI )
{
    j4array[0]-=IK2PI;
}
else if( j4array[0] < -IKPI )
{    j4array[0]+=IK2PI;
}
j4valid[0] = true;
for(int ij4 = 0; ij4 < 1; ++ij4)
{
if( !j4valid[ij4] )
{
    continue;
}
_ij4[0] = ij4; _ij4[1] = -1;
for(int iij4 = ij4+1; iij4 < 1; ++iij4)
{
if( j4valid[iij4] && IKabs(cj4array[ij4]-cj4array[iij4]) < IKFAST_SOLUTION_THRESH && IKabs(sj4array[ij4]-sj4array[iij4]) < IKFAST_SOLUTION_THRESH )
{
    j4valid[iij4]=false; _ij4[1] = iij4; break; 
}
}
j4 = j4array[ij4]; cj4 = cj4array[ij4]; sj4 = sj4array[ij4];
{
IkReal evalcond[6];
IkReal x1533=IKsin(j4);
IkReal x1534=IKcos(j4);
IkReal x1535=((r22)*(sj5));
IkReal x1536=((IkReal(1.00000000000000))*(cj6));
IkReal x1537=((IkReal(1.00000000000000))*(cj0));
IkReal x1538=((cj5)*(r11));
IkReal x1539=((cj5)*(cj6));
IkReal x1540=((r11)*(sj6));
IkReal x1541=((IkReal(1.00000000000000))*(sj6));
IkReal x1542=((cj6)*(r00));
IkReal x1543=((r12)*(sj5));
IkReal x1544=((r02)*(sj5));
IkReal x1545=((cj6)*(r10));
IkReal x1546=((cj5)*(sj6));
IkReal x1547=((cj5)*(r01));
IkReal x1548=((sj0)*(x1533));
IkReal x1549=((r00)*(x1546));
IkReal x1550=((cj0)*(x1533));
IkReal x1551=((sj0)*(x1534));
IkReal x1552=((r20)*(x1534));
IkReal x1553=((cj0)*(x1534));
IkReal x1554=((r21)*(x1533));
IkReal x1555=((r21)*(x1534));
IkReal x1556=((r20)*(x1533));
IkReal x1557=((x1534)*(x1543));
IkReal x1558=((r01)*(sj6)*(x1534));
IkReal x1559=((cj5)*(r10)*(x1541));
evalcond[0]=((IkReal(1.00000000000000))+(((IkReal(-1.00000000000000))*(x1536)*(x1552)))+(((x1546)*(x1556)))+(((x1533)*(x1535)))+(((x1539)*(x1554)))+(((sj6)*(x1555))));
evalcond[1]=((((cj6)*(x1556)))+(((x1534)*(x1535)))+(((x1546)*(x1552)))+(((x1539)*(x1555)))+(((IkReal(-1.00000000000000))*(x1541)*(x1554))));
evalcond[2]=((((IkReal(-1.00000000000000))*(x1536)*(x1538)*(x1550)))+(((IkReal(-1.00000000000000))*(x1533)*(x1537)*(x1543)))+(((x1544)*(x1548)))+(((IkReal(-1.00000000000000))*(r10)*(x1533)*(x1537)*(x1546)))+(((IkReal(-1.00000000000000))*(x1534)*(x1537)*(x1540)))+(((r01)*(sj6)*(x1551)))+(((x1548)*(x1549)))+(((r01)*(x1539)*(x1548)))+(((x1545)*(x1553)))+(((IkReal(-1.00000000000000))*(r00)*(x1536)*(x1551))));
evalcond[3]=((((x1540)*(x1550)))+(((x1542)*(x1548)))+(((IkReal(-1.00000000000000))*(r10)*(x1536)*(x1550)))+(((r01)*(x1539)*(x1551)))+(((x1544)*(x1551)))+(((IkReal(-1.00000000000000))*(x1537)*(x1557)))+(((IkReal(-1.00000000000000))*(r01)*(x1541)*(x1548)))+(((IkReal(-1.00000000000000))*(r10)*(x1534)*(x1537)*(x1546)))+(cj3)+(((x1549)*(x1551)))+(((IkReal(-1.00000000000000))*(x1536)*(x1538)*(x1553))));
evalcond[4]=((((IkReal(-1.00000000000000))*(x1540)*(x1551)))+(((x1542)*(x1553)))+(((IkReal(-1.00000000000000))*(x1536)*(x1538)*(x1548)))+(((IkReal(-1.00000000000000))*(x1533)*(x1537)*(x1544)))+(((IkReal(-1.00000000000000))*(x1533)*(x1537)*(x1549)))+(((IkReal(-1.00000000000000))*(x1536)*(x1547)*(x1550)))+(((IkReal(-1.00000000000000))*(x1543)*(x1548)))+(((IkReal(-1.00000000000000))*(x1548)*(x1559)))+(((x1545)*(x1551)))+(((IkReal(-1.00000000000000))*(x1537)*(x1558))));
evalcond[5]=((((IkReal(-1.00000000000000))*(x1536)*(x1547)*(x1553)))+(((x1540)*(x1548)))+(((r01)*(sj6)*(x1550)))+(((IkReal(-1.00000000000000))*(r00)*(x1536)*(x1550)))+(sj3)+(((IkReal(-1.00000000000000))*(x1536)*(x1538)*(x1551)))+(((IkReal(-1.00000000000000))*(r10)*(x1536)*(x1548)))+(((IkReal(-1.00000000000000))*(x1551)*(x1559)))+(((IkReal(-1.00000000000000))*(x1534)*(x1537)*(x1544)))+(((IkReal(-1.00000000000000))*(x1534)*(x1537)*(x1549)))+(((IkReal(-1.00000000000000))*(x1543)*(x1551))));
if( IKabs(evalcond[0]) > 0.000001  || IKabs(evalcond[1]) > 0.000001  || IKabs(evalcond[2]) > 0.000001  || IKabs(evalcond[3]) > 0.000001  || IKabs(evalcond[4]) > 0.000001  || IKabs(evalcond[5]) > 0.000001  )
{
continue;
}
}

{
std::vector<IkSingleDOFSolutionBase<IkReal> > vinfos(7);
vinfos[0].jointtype = 1;
vinfos[0].foffset = j0;
vinfos[0].indices[0] = _ij0[0];
vinfos[0].indices[1] = _ij0[1];
vinfos[0].maxsolutions = _nj0;
vinfos[1].jointtype = 1;
vinfos[1].foffset = j1;
vinfos[1].indices[0] = _ij1[0];
vinfos[1].indices[1] = _ij1[1];
vinfos[1].maxsolutions = _nj1;
vinfos[2].jointtype = 1;
vinfos[2].foffset = j2;
vinfos[2].indices[0] = _ij2[0];
vinfos[2].indices[1] = _ij2[1];
vinfos[2].maxsolutions = _nj2;
vinfos[3].jointtype = 1;
vinfos[3].foffset = j3;
vinfos[3].indices[0] = _ij3[0];
vinfos[3].indices[1] = _ij3[1];
vinfos[3].maxsolutions = _nj3;
vinfos[4].jointtype = 1;
vinfos[4].foffset = j4;
vinfos[4].indices[0] = _ij4[0];
vinfos[4].indices[1] = _ij4[1];
vinfos[4].maxsolutions = _nj4;
vinfos[5].jointtype = 1;
vinfos[5].foffset = j5;
vinfos[5].indices[0] = _ij5[0];
vinfos[5].indices[1] = _ij5[1];
vinfos[5].maxsolutions = _nj5;
vinfos[6].jointtype = 1;
vinfos[6].foffset = j6;
vinfos[6].indices[0] = _ij6[0];
vinfos[6].indices[1] = _ij6[1];
vinfos[6].maxsolutions = _nj6;
std::vector<int> vfree(0);
solutions.AddSolution(vinfos,vfree);
}
}
}

}

}
}
}

} else
{
IkReal x1560=((cj5)*(r22));
IkReal x1561=((IkReal(0.374290000000000))*(sj5));
IkReal x1562=((cj0)*(sj6));
IkReal x1563=((cj6)*(r21));
IkReal x1564=((IkReal(0.0100000000000000))*(sj5));
IkReal x1565=((cj0)*(r02));
IkReal x1566=((IkReal(0.0100000000000000))*(cj5));
IkReal x1567=((IkReal(1.00000000000000))*(py));
IkReal x1568=((r01)*(sj0));
IkReal x1569=((r20)*(sj6));
IkReal x1570=((r11)*(sj0));
IkReal x1571=((IkReal(0.374290000000000))*(cj5));
IkReal x1572=((cj0)*(r12));
IkReal x1573=((sj0)*(x1571));
IkReal x1574=((cj6)*(x1566));
IkReal x1575=((r10)*(sj0)*(sj6));
IkReal x1576=((r00)*(sj0)*(sj6));
IkReal x1577=((cj0)*(cj6)*(x1561));
evalcond[0]=((IkReal(-3.14159265358979))+(IKfmod(((IkReal(4.71238898038469))+(j2)), IkReal(6.28318530717959))));
evalcond[1]=((((IkReal(-1.00000000000000))*(x1560)))+(((sj5)*(x1569)))+(((sj5)*(x1563))));
evalcond[2]=((((IkReal(-1.00000000000000))*(x1566)*(x1569)))+(((x1561)*(x1563)))+(((IkReal(-1.00000000000000))*(r22)*(x1564)))+(pz)+(((x1561)*(x1569)))+(((IkReal(-1.00000000000000))*(x1563)*(x1566)))+(((IkReal(-0.374290000000000))*(x1560))));
evalcond[3]=((IkReal(-0.0690000000000000))+(((IkReal(-1.00000000000000))*(x1566)*(x1576)))+(((IkReal(-1.00000000000000))*(r11)*(x1577)))+(((x1571)*(x1572)))+(((r10)*(x1562)*(x1566)))+(((x1561)*(x1576)))+(((IkReal(-1.00000000000000))*(cj0)*(x1567)))+(((IkReal(-1.00000000000000))*(r02)*(sj0)*(x1564)))+(((cj6)*(x1561)*(x1568)))+(((IkReal(-1.00000000000000))*(x1568)*(x1574)))+(((px)*(sj0)))+(((cj0)*(r11)*(x1574)))+(((x1564)*(x1572)))+(((IkReal(-1.00000000000000))*(r02)*(x1573)))+(((IkReal(-1.00000000000000))*(r10)*(x1561)*(x1562))));
evalcond[4]=((IkReal(-0.295420000000000))+(((IkReal(-1.00000000000000))*(cj0)*(px)))+(((IkReal(-1.00000000000000))*(r00)*(x1561)*(x1562)))+(((cj0)*(r01)*(x1574)))+(((x1565)*(x1571)))+(((IkReal(-1.00000000000000))*(sj0)*(x1567)))+(((x1570)*(x1574)))+(((r12)*(sj0)*(x1564)))+(((x1564)*(x1565)))+(((r12)*(x1573)))+(((IkReal(-1.00000000000000))*(x1561)*(x1575)))+(((IkReal(-1.00000000000000))*(cj6)*(x1561)*(x1570)))+(((r00)*(x1562)*(x1566)))+(((x1566)*(x1575)))+(((IkReal(-1.00000000000000))*(r01)*(x1577))));
if( IKabs(evalcond[0]) < 0.0000010000000000  && IKabs(evalcond[1]) < 0.0000010000000000  && IKabs(evalcond[2]) < 0.0000010000000000  && IKabs(evalcond[3]) < 0.0000010000000000  && IKabs(evalcond[4]) < 0.0000010000000000  )
{
{
IkReal j3array[1], cj3array[1], sj3array[1];
bool j3valid[1]={false};
_nj3 = 1;
IkReal x1578=((IkReal(1.00000000000000))*(cj5));
IkReal x1579=((r10)*(sj5)*(sj6));
IkReal x1580=((cj6)*(sj0)*(sj5));
IkReal x1581=((r00)*(sj5)*(sj6));
IkReal x1582=((cj0)*(cj6)*(sj5));
if( IKabs(((((cj0)*(x1579)))+(((IkReal(-1.00000000000000))*(sj0)*(x1581)))+(((IkReal(-1.00000000000000))*(r01)*(x1580)))+(((cj5)*(r02)*(sj0)))+(((r11)*(x1582)))+(((IkReal(-1.00000000000000))*(cj0)*(r12)*(x1578))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(((((IkReal(-1.00000000000000))*(r12)*(sj0)*(x1578)))+(((sj0)*(x1579)))+(((IkReal(-1.00000000000000))*(cj0)*(r02)*(x1578)))+(((r11)*(x1580)))+(((r01)*(x1582)))+(((cj0)*(x1581))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(IKsqr(((((cj0)*(x1579)))+(((IkReal(-1.00000000000000))*(sj0)*(x1581)))+(((IkReal(-1.00000000000000))*(r01)*(x1580)))+(((cj5)*(r02)*(sj0)))+(((r11)*(x1582)))+(((IkReal(-1.00000000000000))*(cj0)*(r12)*(x1578)))))+IKsqr(((((IkReal(-1.00000000000000))*(r12)*(sj0)*(x1578)))+(((sj0)*(x1579)))+(((IkReal(-1.00000000000000))*(cj0)*(r02)*(x1578)))+(((r11)*(x1580)))+(((r01)*(x1582)))+(((cj0)*(x1581)))))-1) <= IKFAST_SINCOS_THRESH )
    continue;
j3array[0]=IKatan2(((((cj0)*(x1579)))+(((IkReal(-1.00000000000000))*(sj0)*(x1581)))+(((IkReal(-1.00000000000000))*(r01)*(x1580)))+(((cj5)*(r02)*(sj0)))+(((r11)*(x1582)))+(((IkReal(-1.00000000000000))*(cj0)*(r12)*(x1578)))), ((((IkReal(-1.00000000000000))*(r12)*(sj0)*(x1578)))+(((sj0)*(x1579)))+(((IkReal(-1.00000000000000))*(cj0)*(r02)*(x1578)))+(((r11)*(x1580)))+(((r01)*(x1582)))+(((cj0)*(x1581)))));
sj3array[0]=IKsin(j3array[0]);
cj3array[0]=IKcos(j3array[0]);
if( j3array[0] > IKPI )
{
    j3array[0]-=IK2PI;
}
else if( j3array[0] < -IKPI )
{    j3array[0]+=IK2PI;
}
j3valid[0] = true;
for(int ij3 = 0; ij3 < 1; ++ij3)
{
if( !j3valid[ij3] )
{
    continue;
}
_ij3[0] = ij3; _ij3[1] = -1;
for(int iij3 = ij3+1; iij3 < 1; ++iij3)
{
if( j3valid[iij3] && IKabs(cj3array[ij3]-cj3array[iij3]) < IKFAST_SOLUTION_THRESH && IKabs(sj3array[ij3]-sj3array[iij3]) < IKFAST_SOLUTION_THRESH )
{
    j3valid[iij3]=false; _ij3[1] = iij3; break; 
}
}
j3 = j3array[ij3]; cj3 = cj3array[ij3]; sj3 = sj3array[ij3];
{
IkReal evalcond[2];
IkReal x1583=((cj0)*(cj5));
IkReal x1584=((IkReal(1.00000000000000))*(cj0));
IkReal x1585=((cj6)*(r11));
IkReal x1586=((r10)*(sj6));
IkReal x1587=((cj5)*(sj0));
IkReal x1588=((r00)*(sj5)*(sj6));
IkReal x1589=((cj6)*(r01)*(sj5));
IkReal x1590=((IkReal(1.00000000000000))*(sj0)*(sj5));
evalcond[0]=((((IkReal(-1.00000000000000))*(sj5)*(x1584)*(x1585)))+(((IkReal(-1.00000000000000))*(r02)*(x1587)))+(((r12)*(x1583)))+(((sj0)*(x1588)))+(IKsin(j3))+(((sj0)*(x1589)))+(((IkReal(-1.00000000000000))*(sj5)*(x1584)*(x1586))));
evalcond[1]=((((IkReal(-1.00000000000000))*(x1584)*(x1589)))+(((r02)*(x1583)))+(((IkReal(-1.00000000000000))*(x1585)*(x1590)))+(IKcos(j3))+(((IkReal(-1.00000000000000))*(x1586)*(x1590)))+(((IkReal(-1.00000000000000))*(x1584)*(x1588)))+(((r12)*(x1587))));
if( IKabs(evalcond[0]) > 0.000001  || IKabs(evalcond[1]) > 0.000001  )
{
continue;
}
}

{
IkReal dummyeval[1];
IkReal gconst63;
IkReal x1591=(cj5)*(cj5);
IkReal x1592=(r20)*(r20);
IkReal x1593=(sj6)*(sj6);
IkReal x1594=(cj6)*(cj6);
IkReal x1595=(r21)*(r21);
IkReal x1596=((cj6)*(r21));
IkReal x1597=((IkReal(2.00000000000000))*(r20)*(sj6));
IkReal x1598=((cj5)*(r22)*(sj5));
gconst63=IKsign(((((x1592)*(x1594)))+(((x1593)*(x1595)))+(((IkReal(-1.00000000000000))*(x1596)*(x1597)))+((((r22)*(r22))*((sj5)*(sj5))))+(((x1591)*(x1594)*(x1595)))+(((x1591)*(x1592)*(x1593)))+(((IkReal(2.00000000000000))*(x1596)*(x1598)))+(((x1597)*(x1598)))+(((x1591)*(x1596)*(x1597)))));
IkReal x1599=(cj5)*(cj5);
IkReal x1600=(r20)*(r20);
IkReal x1601=(sj6)*(sj6);
IkReal x1602=(cj6)*(cj6);
IkReal x1603=(r21)*(r21);
IkReal x1604=((cj6)*(r21));
IkReal x1605=((IkReal(2.00000000000000))*(r20)*(sj6));
IkReal x1606=((cj5)*(r22)*(sj5));
dummyeval[0]=((((x1601)*(x1603)))+((((r22)*(r22))*((sj5)*(sj5))))+(((x1600)*(x1602)))+(((IkReal(2.00000000000000))*(x1604)*(x1606)))+(((x1605)*(x1606)))+(((x1599)*(x1604)*(x1605)))+(((x1599)*(x1600)*(x1601)))+(((x1599)*(x1602)*(x1603)))+(((IkReal(-1.00000000000000))*(x1604)*(x1605))));
if( IKabs(dummyeval[0]) < 0.0000010000000000  )
{
{
IkReal dummyeval[1];
IkReal gconst64;
IkReal x1607=(cj6)*(cj6);
IkReal x1608=(sj6)*(sj6);
IkReal x1609=((IkReal(1.00000000000000))*(r21));
IkReal x1610=((cj6)*(r20));
IkReal x1611=((r22)*(sj5));
IkReal x1612=((r01)*(sj0));
IkReal x1613=((r00)*(sj0));
IkReal x1614=((cj0)*(r10));
IkReal x1615=((r02)*(sj0)*(sj5));
IkReal x1616=((cj5)*(x1607));
IkReal x1617=((cj0)*(r12)*(sj5));
IkReal x1618=((IkReal(1.00000000000000))*(cj0)*(r11));
IkReal x1619=((cj5)*(x1608));
IkReal x1620=((r20)*(x1619));
gconst64=IKsign(((((IkReal(-1.00000000000000))*(x1609)*(x1613)*(x1619)))+(((cj6)*(x1611)*(x1614)))+(((r21)*(x1614)*(x1619)))+(((IkReal(-1.00000000000000))*(x1609)*(x1613)*(x1616)))+(((IkReal(-1.00000000000000))*(x1610)*(x1617)))+(((IkReal(-1.00000000000000))*(r20)*(x1616)*(x1618)))+(((IkReal(-1.00000000000000))*(x1618)*(x1620)))+(((IkReal(-1.00000000000000))*(cj6)*(x1611)*(x1613)))+(((sj6)*(x1611)*(x1612)))+(((r21)*(x1614)*(x1616)))+(((r21)*(sj6)*(x1617)))+(((IkReal(-1.00000000000000))*(sj6)*(x1611)*(x1618)))+(((IkReal(-1.00000000000000))*(sj6)*(x1609)*(x1615)))+(((r20)*(x1612)*(x1616)))+(((x1610)*(x1615)))+(((x1612)*(x1620)))));
IkReal x1621=(cj6)*(cj6);
IkReal x1622=(sj6)*(sj6);
IkReal x1623=((IkReal(1.00000000000000))*(r21));
IkReal x1624=((cj6)*(r20));
IkReal x1625=((r22)*(sj5));
IkReal x1626=((r01)*(sj0));
IkReal x1627=((r00)*(sj0));
IkReal x1628=((cj0)*(r10));
IkReal x1629=((r02)*(sj0)*(sj5));
IkReal x1630=((cj5)*(x1621));
IkReal x1631=((cj0)*(r12)*(sj5));
IkReal x1632=((IkReal(1.00000000000000))*(cj0)*(r11));
IkReal x1633=((cj5)*(x1622));
IkReal x1634=((r20)*(x1633));
dummyeval[0]=((((IkReal(-1.00000000000000))*(x1623)*(x1627)*(x1630)))+(((IkReal(-1.00000000000000))*(r20)*(x1630)*(x1632)))+(((sj6)*(x1625)*(x1626)))+(((IkReal(-1.00000000000000))*(x1624)*(x1631)))+(((IkReal(-1.00000000000000))*(sj6)*(x1625)*(x1632)))+(((r21)*(x1628)*(x1633)))+(((x1626)*(x1634)))+(((IkReal(-1.00000000000000))*(x1632)*(x1634)))+(((cj6)*(x1625)*(x1628)))+(((x1624)*(x1629)))+(((r21)*(sj6)*(x1631)))+(((r20)*(x1626)*(x1630)))+(((r21)*(x1628)*(x1630)))+(((IkReal(-1.00000000000000))*(cj6)*(x1625)*(x1627)))+(((IkReal(-1.00000000000000))*(x1623)*(x1627)*(x1633)))+(((IkReal(-1.00000000000000))*(sj6)*(x1623)*(x1629))));
if( IKabs(dummyeval[0]) < 0.0000010000000000  )
{
continue;

} else
{
{
IkReal j4array[1], cj4array[1], sj4array[1];
bool j4valid[1]={false};
_nj4 = 1;
IkReal x1635=((sj0)*(sj6));
IkReal x1636=((cj0)*(r10));
IkReal x1637=((IkReal(1.00000000000000))*(cj5));
IkReal x1638=((cj6)*(sj0));
IkReal x1639=((cj0)*(r11));
if( IKabs(((gconst64)*(((((IkReal(-1.00000000000000))*(sj6)*(x1639)))+(((cj6)*(x1636)))+(((IkReal(-1.00000000000000))*(r00)*(x1638)))+(((r01)*(x1635))))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(((gconst64)*(((((cj5)*(cj6)*(x1639)))+(((cj5)*(sj6)*(x1636)))+(((IkReal(-1.00000000000000))*(r01)*(x1637)*(x1638)))+(((cj0)*(r12)*(sj5)))+(((IkReal(-1.00000000000000))*(r00)*(x1635)*(x1637)))+(((IkReal(-1.00000000000000))*(r02)*(sj0)*(sj5))))))) < IKFAST_ATAN2_MAGTHRESH )
    continue;
j4array[0]=IKatan2(((gconst64)*(((((IkReal(-1.00000000000000))*(sj6)*(x1639)))+(((cj6)*(x1636)))+(((IkReal(-1.00000000000000))*(r00)*(x1638)))+(((r01)*(x1635)))))), ((gconst64)*(((((cj5)*(cj6)*(x1639)))+(((cj5)*(sj6)*(x1636)))+(((IkReal(-1.00000000000000))*(r01)*(x1637)*(x1638)))+(((cj0)*(r12)*(sj5)))+(((IkReal(-1.00000000000000))*(r00)*(x1635)*(x1637)))+(((IkReal(-1.00000000000000))*(r02)*(sj0)*(sj5)))))));
sj4array[0]=IKsin(j4array[0]);
cj4array[0]=IKcos(j4array[0]);
if( j4array[0] > IKPI )
{
    j4array[0]-=IK2PI;
}
else if( j4array[0] < -IKPI )
{    j4array[0]+=IK2PI;
}
j4valid[0] = true;
for(int ij4 = 0; ij4 < 1; ++ij4)
{
if( !j4valid[ij4] )
{
    continue;
}
_ij4[0] = ij4; _ij4[1] = -1;
for(int iij4 = ij4+1; iij4 < 1; ++iij4)
{
if( j4valid[iij4] && IKabs(cj4array[ij4]-cj4array[iij4]) < IKFAST_SOLUTION_THRESH && IKabs(sj4array[ij4]-sj4array[iij4]) < IKFAST_SOLUTION_THRESH )
{
    j4valid[iij4]=false; _ij4[1] = iij4; break; 
}
}
j4 = j4array[ij4]; cj4 = cj4array[ij4]; sj4 = sj4array[ij4];
{
IkReal evalcond[6];
IkReal x1640=IKsin(j4);
IkReal x1641=IKcos(j4);
IkReal x1642=((r22)*(sj5));
IkReal x1643=((IkReal(1.00000000000000))*(cj6));
IkReal x1644=((IkReal(1.00000000000000))*(cj0));
IkReal x1645=((cj5)*(r11));
IkReal x1646=((cj5)*(cj6));
IkReal x1647=((r11)*(sj6));
IkReal x1648=((IkReal(1.00000000000000))*(sj6));
IkReal x1649=((cj6)*(r00));
IkReal x1650=((r12)*(sj5));
IkReal x1651=((r02)*(sj5));
IkReal x1652=((cj6)*(r10));
IkReal x1653=((cj5)*(sj6));
IkReal x1654=((cj5)*(r01));
IkReal x1655=((sj0)*(x1640));
IkReal x1656=((r00)*(x1653));
IkReal x1657=((cj0)*(x1640));
IkReal x1658=((sj0)*(x1641));
IkReal x1659=((r20)*(x1641));
IkReal x1660=((cj0)*(x1641));
IkReal x1661=((r21)*(x1640));
IkReal x1662=((r21)*(x1641));
IkReal x1663=((r20)*(x1640));
IkReal x1664=((x1641)*(x1650));
IkReal x1665=((r01)*(sj6)*(x1641));
IkReal x1666=((cj5)*(r10)*(x1648));
evalcond[0]=((IkReal(-1.00000000000000))+(((IkReal(-1.00000000000000))*(x1643)*(x1659)))+(((x1646)*(x1661)))+(((x1640)*(x1642)))+(((sj6)*(x1662)))+(((x1653)*(x1663))));
evalcond[1]=((((IkReal(-1.00000000000000))*(x1648)*(x1661)))+(((x1641)*(x1642)))+(((x1653)*(x1659)))+(((x1646)*(x1662)))+(((cj6)*(x1663))));
evalcond[2]=((((IkReal(-1.00000000000000))*(r10)*(x1640)*(x1644)*(x1653)))+(((r01)*(sj6)*(x1658)))+(((x1651)*(x1655)))+(((r01)*(x1646)*(x1655)))+(((x1652)*(x1660)))+(((IkReal(-1.00000000000000))*(x1640)*(x1644)*(x1650)))+(((IkReal(-1.00000000000000))*(x1643)*(x1645)*(x1657)))+(((IkReal(-1.00000000000000))*(x1641)*(x1644)*(x1647)))+(((x1655)*(x1656)))+(((IkReal(-1.00000000000000))*(r00)*(x1643)*(x1658))));
evalcond[3]=((((x1649)*(x1655)))+(((x1656)*(x1658)))+(((IkReal(-1.00000000000000))*(r01)*(x1648)*(x1655)))+(((IkReal(-1.00000000000000))*(r10)*(x1641)*(x1644)*(x1653)))+(((IkReal(-1.00000000000000))*(cj3)))+(((IkReal(-1.00000000000000))*(x1644)*(x1664)))+(((x1651)*(x1658)))+(((x1647)*(x1657)))+(((r01)*(x1646)*(x1658)))+(((IkReal(-1.00000000000000))*(r10)*(x1643)*(x1657)))+(((IkReal(-1.00000000000000))*(x1643)*(x1645)*(x1660))));
evalcond[4]=((((IkReal(-1.00000000000000))*(x1644)*(x1665)))+(((IkReal(-1.00000000000000))*(x1640)*(x1644)*(x1656)))+(((IkReal(-1.00000000000000))*(x1643)*(x1654)*(x1657)))+(((IkReal(-1.00000000000000))*(x1643)*(x1645)*(x1655)))+(((IkReal(-1.00000000000000))*(x1655)*(x1666)))+(((x1649)*(x1660)))+(((x1652)*(x1658)))+(((IkReal(-1.00000000000000))*(x1640)*(x1644)*(x1651)))+(((IkReal(-1.00000000000000))*(x1650)*(x1655)))+(((IkReal(-1.00000000000000))*(x1647)*(x1658))));
evalcond[5]=((((IkReal(-1.00000000000000))*(x1643)*(x1645)*(x1658)))+(sj3)+(((x1647)*(x1655)))+(((IkReal(-1.00000000000000))*(x1658)*(x1666)))+(((IkReal(-1.00000000000000))*(x1641)*(x1644)*(x1651)))+(((IkReal(-1.00000000000000))*(r00)*(x1643)*(x1657)))+(((IkReal(-1.00000000000000))*(r10)*(x1643)*(x1655)))+(((IkReal(-1.00000000000000))*(x1641)*(x1644)*(x1656)))+(((IkReal(-1.00000000000000))*(x1650)*(x1658)))+(((IkReal(-1.00000000000000))*(x1643)*(x1654)*(x1660)))+(((r01)*(sj6)*(x1657))));
if( IKabs(evalcond[0]) > 0.000001  || IKabs(evalcond[1]) > 0.000001  || IKabs(evalcond[2]) > 0.000001  || IKabs(evalcond[3]) > 0.000001  || IKabs(evalcond[4]) > 0.000001  || IKabs(evalcond[5]) > 0.000001  )
{
continue;
}
}

{
std::vector<IkSingleDOFSolutionBase<IkReal> > vinfos(7);
vinfos[0].jointtype = 1;
vinfos[0].foffset = j0;
vinfos[0].indices[0] = _ij0[0];
vinfos[0].indices[1] = _ij0[1];
vinfos[0].maxsolutions = _nj0;
vinfos[1].jointtype = 1;
vinfos[1].foffset = j1;
vinfos[1].indices[0] = _ij1[0];
vinfos[1].indices[1] = _ij1[1];
vinfos[1].maxsolutions = _nj1;
vinfos[2].jointtype = 1;
vinfos[2].foffset = j2;
vinfos[2].indices[0] = _ij2[0];
vinfos[2].indices[1] = _ij2[1];
vinfos[2].maxsolutions = _nj2;
vinfos[3].jointtype = 1;
vinfos[3].foffset = j3;
vinfos[3].indices[0] = _ij3[0];
vinfos[3].indices[1] = _ij3[1];
vinfos[3].maxsolutions = _nj3;
vinfos[4].jointtype = 1;
vinfos[4].foffset = j4;
vinfos[4].indices[0] = _ij4[0];
vinfos[4].indices[1] = _ij4[1];
vinfos[4].maxsolutions = _nj4;
vinfos[5].jointtype = 1;
vinfos[5].foffset = j5;
vinfos[5].indices[0] = _ij5[0];
vinfos[5].indices[1] = _ij5[1];
vinfos[5].maxsolutions = _nj5;
vinfos[6].jointtype = 1;
vinfos[6].foffset = j6;
vinfos[6].indices[0] = _ij6[0];
vinfos[6].indices[1] = _ij6[1];
vinfos[6].maxsolutions = _nj6;
std::vector<int> vfree(0);
solutions.AddSolution(vinfos,vfree);
}
}
}

}

}

} else
{
{
IkReal j4array[1], cj4array[1], sj4array[1];
bool j4valid[1]={false};
_nj4 = 1;
if( IKabs(((gconst63)*(((((cj5)*(r20)*(sj6)))+(((r22)*(sj5)))+(((cj5)*(cj6)*(r21))))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(((gconst63)*(((((r21)*(sj6)))+(((IkReal(-1.00000000000000))*(cj6)*(r20))))))) < IKFAST_ATAN2_MAGTHRESH )
    continue;
j4array[0]=IKatan2(((gconst63)*(((((cj5)*(r20)*(sj6)))+(((r22)*(sj5)))+(((cj5)*(cj6)*(r21)))))), ((gconst63)*(((((r21)*(sj6)))+(((IkReal(-1.00000000000000))*(cj6)*(r20)))))));
sj4array[0]=IKsin(j4array[0]);
cj4array[0]=IKcos(j4array[0]);
if( j4array[0] > IKPI )
{
    j4array[0]-=IK2PI;
}
else if( j4array[0] < -IKPI )
{    j4array[0]+=IK2PI;
}
j4valid[0] = true;
for(int ij4 = 0; ij4 < 1; ++ij4)
{
if( !j4valid[ij4] )
{
    continue;
}
_ij4[0] = ij4; _ij4[1] = -1;
for(int iij4 = ij4+1; iij4 < 1; ++iij4)
{
if( j4valid[iij4] && IKabs(cj4array[ij4]-cj4array[iij4]) < IKFAST_SOLUTION_THRESH && IKabs(sj4array[ij4]-sj4array[iij4]) < IKFAST_SOLUTION_THRESH )
{
    j4valid[iij4]=false; _ij4[1] = iij4; break; 
}
}
j4 = j4array[ij4]; cj4 = cj4array[ij4]; sj4 = sj4array[ij4];
{
IkReal evalcond[6];
IkReal x1667=IKsin(j4);
IkReal x1668=IKcos(j4);
IkReal x1669=((r22)*(sj5));
IkReal x1670=((IkReal(1.00000000000000))*(cj6));
IkReal x1671=((IkReal(1.00000000000000))*(cj0));
IkReal x1672=((cj5)*(r11));
IkReal x1673=((cj5)*(cj6));
IkReal x1674=((r11)*(sj6));
IkReal x1675=((IkReal(1.00000000000000))*(sj6));
IkReal x1676=((cj6)*(r00));
IkReal x1677=((r12)*(sj5));
IkReal x1678=((r02)*(sj5));
IkReal x1679=((cj6)*(r10));
IkReal x1680=((cj5)*(sj6));
IkReal x1681=((cj5)*(r01));
IkReal x1682=((sj0)*(x1667));
IkReal x1683=((r00)*(x1680));
IkReal x1684=((cj0)*(x1667));
IkReal x1685=((sj0)*(x1668));
IkReal x1686=((r20)*(x1668));
IkReal x1687=((cj0)*(x1668));
IkReal x1688=((r21)*(x1667));
IkReal x1689=((r21)*(x1668));
IkReal x1690=((r20)*(x1667));
IkReal x1691=((x1668)*(x1677));
IkReal x1692=((r01)*(sj6)*(x1668));
IkReal x1693=((cj5)*(r10)*(x1675));
evalcond[0]=((IkReal(-1.00000000000000))+(((x1680)*(x1690)))+(((x1667)*(x1669)))+(((sj6)*(x1689)))+(((IkReal(-1.00000000000000))*(x1670)*(x1686)))+(((x1673)*(x1688))));
evalcond[1]=((((cj6)*(x1690)))+(((x1668)*(x1669)))+(((x1673)*(x1689)))+(((IkReal(-1.00000000000000))*(x1675)*(x1688)))+(((x1680)*(x1686))));
evalcond[2]=((((r01)*(sj6)*(x1685)))+(((x1682)*(x1683)))+(((x1679)*(x1687)))+(((x1678)*(x1682)))+(((IkReal(-1.00000000000000))*(x1668)*(x1671)*(x1674)))+(((IkReal(-1.00000000000000))*(r10)*(x1667)*(x1671)*(x1680)))+(((IkReal(-1.00000000000000))*(x1667)*(x1671)*(x1677)))+(((IkReal(-1.00000000000000))*(x1670)*(x1672)*(x1684)))+(((r01)*(x1673)*(x1682)))+(((IkReal(-1.00000000000000))*(r00)*(x1670)*(x1685))));
evalcond[3]=((((IkReal(-1.00000000000000))*(r01)*(x1675)*(x1682)))+(((IkReal(-1.00000000000000))*(x1671)*(x1691)))+(((IkReal(-1.00000000000000))*(r10)*(x1670)*(x1684)))+(((IkReal(-1.00000000000000))*(r10)*(x1668)*(x1671)*(x1680)))+(((r01)*(x1673)*(x1685)))+(((IkReal(-1.00000000000000))*(cj3)))+(((IkReal(-1.00000000000000))*(x1670)*(x1672)*(x1687)))+(((x1676)*(x1682)))+(((x1683)*(x1685)))+(((x1674)*(x1684)))+(((x1678)*(x1685))));
evalcond[4]=((((x1676)*(x1687)))+(((IkReal(-1.00000000000000))*(x1667)*(x1671)*(x1683)))+(((IkReal(-1.00000000000000))*(x1670)*(x1681)*(x1684)))+(((IkReal(-1.00000000000000))*(x1670)*(x1672)*(x1682)))+(((IkReal(-1.00000000000000))*(x1667)*(x1671)*(x1678)))+(((IkReal(-1.00000000000000))*(x1677)*(x1682)))+(((IkReal(-1.00000000000000))*(x1682)*(x1693)))+(((IkReal(-1.00000000000000))*(x1671)*(x1692)))+(((IkReal(-1.00000000000000))*(x1674)*(x1685)))+(((x1679)*(x1685))));
evalcond[5]=((((IkReal(-1.00000000000000))*(x1685)*(x1693)))+(((IkReal(-1.00000000000000))*(x1677)*(x1685)))+(((IkReal(-1.00000000000000))*(r10)*(x1670)*(x1682)))+(((IkReal(-1.00000000000000))*(x1670)*(x1672)*(x1685)))+(sj3)+(((x1674)*(x1682)))+(((IkReal(-1.00000000000000))*(x1670)*(x1681)*(x1687)))+(((IkReal(-1.00000000000000))*(x1668)*(x1671)*(x1678)))+(((r01)*(sj6)*(x1684)))+(((IkReal(-1.00000000000000))*(r00)*(x1670)*(x1684)))+(((IkReal(-1.00000000000000))*(x1668)*(x1671)*(x1683))));
if( IKabs(evalcond[0]) > 0.000001  || IKabs(evalcond[1]) > 0.000001  || IKabs(evalcond[2]) > 0.000001  || IKabs(evalcond[3]) > 0.000001  || IKabs(evalcond[4]) > 0.000001  || IKabs(evalcond[5]) > 0.000001  )
{
continue;
}
}

{
std::vector<IkSingleDOFSolutionBase<IkReal> > vinfos(7);
vinfos[0].jointtype = 1;
vinfos[0].foffset = j0;
vinfos[0].indices[0] = _ij0[0];
vinfos[0].indices[1] = _ij0[1];
vinfos[0].maxsolutions = _nj0;
vinfos[1].jointtype = 1;
vinfos[1].foffset = j1;
vinfos[1].indices[0] = _ij1[0];
vinfos[1].indices[1] = _ij1[1];
vinfos[1].maxsolutions = _nj1;
vinfos[2].jointtype = 1;
vinfos[2].foffset = j2;
vinfos[2].indices[0] = _ij2[0];
vinfos[2].indices[1] = _ij2[1];
vinfos[2].maxsolutions = _nj2;
vinfos[3].jointtype = 1;
vinfos[3].foffset = j3;
vinfos[3].indices[0] = _ij3[0];
vinfos[3].indices[1] = _ij3[1];
vinfos[3].maxsolutions = _nj3;
vinfos[4].jointtype = 1;
vinfos[4].foffset = j4;
vinfos[4].indices[0] = _ij4[0];
vinfos[4].indices[1] = _ij4[1];
vinfos[4].maxsolutions = _nj4;
vinfos[5].jointtype = 1;
vinfos[5].foffset = j5;
vinfos[5].indices[0] = _ij5[0];
vinfos[5].indices[1] = _ij5[1];
vinfos[5].maxsolutions = _nj5;
vinfos[6].jointtype = 1;
vinfos[6].foffset = j6;
vinfos[6].indices[0] = _ij6[0];
vinfos[6].indices[1] = _ij6[1];
vinfos[6].maxsolutions = _nj6;
std::vector<int> vfree(0);
solutions.AddSolution(vinfos,vfree);
}
}
}

}

}
}
}

} else
{
if( 1 )
{
continue;

} else
{
}
}
}
}

} else
{
{
IkReal j3array[1], cj3array[1], sj3array[1];
bool j3valid[1]={false};
_nj3 = 1;
IkReal x1694=((cj6)*(sj5));
IkReal x1695=((IkReal(1.00000000000000))*(cj5));
IkReal x1696=((sj5)*(sj6));
if( IKabs(((((IKabs(cj2) != 0)?((IkReal)1/(cj2)):(IkReal)1.0e30))*(((((IkReal(-1.00000000000000))*(r20)*(x1696)))+(((IkReal(-1.00000000000000))*(r21)*(x1694)))+(((cj5)*(r22))))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(((((cj0)*(r00)*(x1696)))+(((r10)*(sj0)*(x1696)))+(((cj0)*(r01)*(x1694)))+(((r11)*(sj0)*(x1694)))+(((IkReal(-1.00000000000000))*(r12)*(sj0)*(x1695)))+(((IkReal(-1.00000000000000))*(cj0)*(r02)*(x1695))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(IKsqr(((((IKabs(cj2) != 0)?((IkReal)1/(cj2)):(IkReal)1.0e30))*(((((IkReal(-1.00000000000000))*(r20)*(x1696)))+(((IkReal(-1.00000000000000))*(r21)*(x1694)))+(((cj5)*(r22)))))))+IKsqr(((((cj0)*(r00)*(x1696)))+(((r10)*(sj0)*(x1696)))+(((cj0)*(r01)*(x1694)))+(((r11)*(sj0)*(x1694)))+(((IkReal(-1.00000000000000))*(r12)*(sj0)*(x1695)))+(((IkReal(-1.00000000000000))*(cj0)*(r02)*(x1695)))))-1) <= IKFAST_SINCOS_THRESH )
    continue;
j3array[0]=IKatan2(((((IKabs(cj2) != 0)?((IkReal)1/(cj2)):(IkReal)1.0e30))*(((((IkReal(-1.00000000000000))*(r20)*(x1696)))+(((IkReal(-1.00000000000000))*(r21)*(x1694)))+(((cj5)*(r22)))))), ((((cj0)*(r00)*(x1696)))+(((r10)*(sj0)*(x1696)))+(((cj0)*(r01)*(x1694)))+(((r11)*(sj0)*(x1694)))+(((IkReal(-1.00000000000000))*(r12)*(sj0)*(x1695)))+(((IkReal(-1.00000000000000))*(cj0)*(r02)*(x1695)))));
sj3array[0]=IKsin(j3array[0]);
cj3array[0]=IKcos(j3array[0]);
if( j3array[0] > IKPI )
{
    j3array[0]-=IK2PI;
}
else if( j3array[0] < -IKPI )
{    j3array[0]+=IK2PI;
}
j3valid[0] = true;
for(int ij3 = 0; ij3 < 1; ++ij3)
{
if( !j3valid[ij3] )
{
    continue;
}
_ij3[0] = ij3; _ij3[1] = -1;
for(int iij3 = ij3+1; iij3 < 1; ++iij3)
{
if( j3valid[iij3] && IKabs(cj3array[ij3]-cj3array[iij3]) < IKFAST_SOLUTION_THRESH && IKabs(sj3array[ij3]-sj3array[iij3]) < IKFAST_SOLUTION_THRESH )
{
    j3valid[iij3]=false; _ij3[1] = iij3; break; 
}
}
j3 = j3array[ij3]; cj3 = cj3array[ij3]; sj3 = sj3array[ij3];
{
IkReal evalcond[3];
IkReal x1697=IKsin(j3);
IkReal x1698=((sj5)*(sj6));
IkReal x1699=((cj0)*(cj5));
IkReal x1700=((IkReal(1.00000000000000))*(cj0));
IkReal x1701=((IkReal(1.00000000000000))*(sj0));
IkReal x1702=((cj6)*(r01)*(sj5));
IkReal x1703=((cj6)*(r11)*(sj5));
evalcond[0]=((((cj2)*(x1697)))+(((cj6)*(r21)*(sj5)))+(((IkReal(-1.00000000000000))*(cj5)*(r22)))+(((r20)*(x1698))));
evalcond[1]=((((r12)*(x1699)))+(((IkReal(-1.00000000000000))*(x1700)*(x1703)))+(((IkReal(-1.00000000000000))*(cj5)*(r02)*(x1701)))+(((sj0)*(x1702)))+(((r00)*(sj0)*(x1698)))+(((IkReal(-1.00000000000000))*(sj2)*(x1697)))+(((IkReal(-1.00000000000000))*(r10)*(x1698)*(x1700))));
evalcond[2]=((((IkReal(-1.00000000000000))*(r00)*(x1698)*(x1700)))+(((r02)*(x1699)))+(((IkReal(-1.00000000000000))*(x1700)*(x1702)))+(((cj5)*(r12)*(sj0)))+(((IkReal(-1.00000000000000))*(r10)*(x1698)*(x1701)))+(IKcos(j3))+(((IkReal(-1.00000000000000))*(x1701)*(x1703))));
if( IKabs(evalcond[0]) > 0.000001  || IKabs(evalcond[1]) > 0.000001  || IKabs(evalcond[2]) > 0.000001  )
{
continue;
}
}

{
IkReal dummyeval[1];
IkReal gconst54;
IkReal x1704=(r21)*(r21);
IkReal x1705=(cj5)*(cj5);
IkReal x1706=(sj6)*(sj6);
IkReal x1707=(cj6)*(cj6);
IkReal x1708=(r20)*(r20);
IkReal x1709=((cj6)*(r21));
IkReal x1710=((IkReal(2.00000000000000))*(r20)*(sj6));
IkReal x1711=((cj5)*(r22)*(sj5));
IkReal x1712=((IkReal(1.00000000000000))*(x1706));
IkReal x1713=((IkReal(1.00000000000000))*(x1707));
gconst54=IKsign(((((IkReal(-1.00000000000000))*(x1708)*(x1713)))+(((IkReal(-2.00000000000000))*(x1709)*(x1711)))+(((x1709)*(x1710)))+(((IkReal(-1.00000000000000))*(x1704)*(x1712)))+(((IkReal(-1.00000000000000))*(x1704)*(x1705)*(x1713)))+(((IkReal(-1.00000000000000))*((r22)*(r22))*((sj5)*(sj5))))+(((IkReal(-1.00000000000000))*(x1705)*(x1709)*(x1710)))+(((IkReal(-1.00000000000000))*(x1710)*(x1711)))+(((IkReal(-1.00000000000000))*(x1705)*(x1708)*(x1712)))));
IkReal x1714=(r21)*(r21);
IkReal x1715=(cj5)*(cj5);
IkReal x1716=(sj6)*(sj6);
IkReal x1717=(cj6)*(cj6);
IkReal x1718=(r20)*(r20);
IkReal x1719=((cj6)*(r21));
IkReal x1720=((IkReal(2.00000000000000))*(r20)*(sj6));
IkReal x1721=((cj5)*(r22)*(sj5));
IkReal x1722=((IkReal(1.00000000000000))*(x1716));
IkReal x1723=((IkReal(1.00000000000000))*(x1717));
dummyeval[0]=((((IkReal(-1.00000000000000))*((r22)*(r22))*((sj5)*(sj5))))+(((IkReal(-1.00000000000000))*(x1714)*(x1722)))+(((IkReal(-1.00000000000000))*(x1715)*(x1719)*(x1720)))+(((x1719)*(x1720)))+(((IkReal(-1.00000000000000))*(x1720)*(x1721)))+(((IkReal(-2.00000000000000))*(x1719)*(x1721)))+(((IkReal(-1.00000000000000))*(x1718)*(x1723)))+(((IkReal(-1.00000000000000))*(x1715)*(x1718)*(x1722)))+(((IkReal(-1.00000000000000))*(x1714)*(x1715)*(x1723))));
if( IKabs(dummyeval[0]) < 0.0000010000000000  )
{
{
IkReal dummyeval[1];
IkReal gconst55;
IkReal x1724=(cj6)*(cj6);
IkReal x1725=(sj6)*(sj6);
IkReal x1726=((IkReal(1.00000000000000))*(r01));
IkReal x1727=((sj0)*(sj5));
IkReal x1728=((cj6)*(r22));
IkReal x1729=((r21)*(sj6));
IkReal x1730=((r00)*(r21));
IkReal x1731=((cj0)*(sj5));
IkReal x1732=((cj6)*(r20));
IkReal x1733=((r22)*(sj6));
IkReal x1734=((cj0)*(cj5));
IkReal x1735=((IkReal(1.00000000000000))*(r10));
IkReal x1736=((cj5)*(sj0));
IkReal x1737=((r20)*(x1725));
IkReal x1738=((x1724)*(x1736));
gconst55=IKsign(((((x1725)*(x1730)*(x1736)))+(((r11)*(r20)*(x1724)*(x1734)))+(((IkReal(-1.00000000000000))*(r02)*(x1727)*(x1732)))+(((IkReal(-1.00000000000000))*(r20)*(x1726)*(x1738)))+(((r02)*(x1727)*(x1729)))+(((IkReal(-1.00000000000000))*(x1728)*(x1731)*(x1735)))+(((IkReal(-1.00000000000000))*(r12)*(x1729)*(x1731)))+(((IkReal(-1.00000000000000))*(x1726)*(x1736)*(x1737)))+(((x1730)*(x1738)))+(((r11)*(x1734)*(x1737)))+(((IkReal(-1.00000000000000))*(r21)*(x1725)*(x1734)*(x1735)))+(((IkReal(-1.00000000000000))*(r21)*(x1724)*(x1734)*(x1735)))+(((r00)*(x1727)*(x1728)))+(((r11)*(x1731)*(x1733)))+(((IkReal(-1.00000000000000))*(x1726)*(x1727)*(x1733)))+(((r12)*(x1731)*(x1732)))));
IkReal x1739=(cj6)*(cj6);
IkReal x1740=(sj6)*(sj6);
IkReal x1741=((IkReal(1.00000000000000))*(r01));
IkReal x1742=((sj0)*(sj5));
IkReal x1743=((cj6)*(r22));
IkReal x1744=((r21)*(sj6));
IkReal x1745=((r00)*(r21));
IkReal x1746=((cj0)*(sj5));
IkReal x1747=((cj6)*(r20));
IkReal x1748=((r22)*(sj6));
IkReal x1749=((cj0)*(cj5));
IkReal x1750=((IkReal(1.00000000000000))*(r10));
IkReal x1751=((cj5)*(sj0));
IkReal x1752=((r20)*(x1740));
IkReal x1753=((x1739)*(x1751));
dummyeval[0]=((((IkReal(-1.00000000000000))*(r20)*(x1741)*(x1753)))+(((IkReal(-1.00000000000000))*(r21)*(x1740)*(x1749)*(x1750)))+(((IkReal(-1.00000000000000))*(r21)*(x1739)*(x1749)*(x1750)))+(((r00)*(x1742)*(x1743)))+(((x1740)*(x1745)*(x1751)))+(((r11)*(x1749)*(x1752)))+(((r12)*(x1746)*(x1747)))+(((x1745)*(x1753)))+(((r02)*(x1742)*(x1744)))+(((IkReal(-1.00000000000000))*(r12)*(x1744)*(x1746)))+(((IkReal(-1.00000000000000))*(r02)*(x1742)*(x1747)))+(((IkReal(-1.00000000000000))*(x1741)*(x1751)*(x1752)))+(((IkReal(-1.00000000000000))*(x1741)*(x1742)*(x1748)))+(((IkReal(-1.00000000000000))*(x1743)*(x1746)*(x1750)))+(((r11)*(r20)*(x1739)*(x1749)))+(((r11)*(x1746)*(x1748))));
if( IKabs(dummyeval[0]) < 0.0000010000000000  )
{
continue;

} else
{
{
IkReal j4array[1], cj4array[1], sj4array[1];
bool j4valid[1]={false};
_nj4 = 1;
IkReal x1754=((cj5)*(sj6));
IkReal x1755=((cj2)*(r20));
IkReal x1756=((IkReal(1.00000000000000))*(sj6));
IkReal x1757=((cj2)*(r21));
IkReal x1758=((cj0)*(sj2));
IkReal x1759=((cj5)*(cj6));
IkReal x1760=((IkReal(1.00000000000000))*(sj0)*(sj2));
IkReal x1761=((r10)*(x1758));
if( IKabs(((gconst55)*(((((IkReal(-1.00000000000000))*(r11)*(x1756)*(x1758)))+(((r01)*(sj0)*(sj2)*(sj6)))+(((cj6)*(x1761)))+(((IkReal(-1.00000000000000))*(cj6)*(r00)*(x1760)))+(((IkReal(-1.00000000000000))*(x1756)*(x1757)))+(((cj6)*(x1755))))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(((gconst55)*(((((cj2)*(r22)*(sj5)))+(((IkReal(-1.00000000000000))*(r00)*(x1754)*(x1760)))+(((IkReal(-1.00000000000000))*(r01)*(x1759)*(x1760)))+(((IkReal(-1.00000000000000))*(r02)*(sj5)*(x1760)))+(((x1754)*(x1755)))+(((x1754)*(x1761)))+(((r12)*(sj5)*(x1758)))+(((x1757)*(x1759)))+(((r11)*(x1758)*(x1759))))))) < IKFAST_ATAN2_MAGTHRESH )
    continue;
j4array[0]=IKatan2(((gconst55)*(((((IkReal(-1.00000000000000))*(r11)*(x1756)*(x1758)))+(((r01)*(sj0)*(sj2)*(sj6)))+(((cj6)*(x1761)))+(((IkReal(-1.00000000000000))*(cj6)*(r00)*(x1760)))+(((IkReal(-1.00000000000000))*(x1756)*(x1757)))+(((cj6)*(x1755)))))), ((gconst55)*(((((cj2)*(r22)*(sj5)))+(((IkReal(-1.00000000000000))*(r00)*(x1754)*(x1760)))+(((IkReal(-1.00000000000000))*(r01)*(x1759)*(x1760)))+(((IkReal(-1.00000000000000))*(r02)*(sj5)*(x1760)))+(((x1754)*(x1755)))+(((x1754)*(x1761)))+(((r12)*(sj5)*(x1758)))+(((x1757)*(x1759)))+(((r11)*(x1758)*(x1759)))))));
sj4array[0]=IKsin(j4array[0]);
cj4array[0]=IKcos(j4array[0]);
if( j4array[0] > IKPI )
{
    j4array[0]-=IK2PI;
}
else if( j4array[0] < -IKPI )
{    j4array[0]+=IK2PI;
}
j4valid[0] = true;
for(int ij4 = 0; ij4 < 1; ++ij4)
{
if( !j4valid[ij4] )
{
    continue;
}
_ij4[0] = ij4; _ij4[1] = -1;
for(int iij4 = ij4+1; iij4 < 1; ++iij4)
{
if( j4valid[iij4] && IKabs(cj4array[ij4]-cj4array[iij4]) < IKFAST_SOLUTION_THRESH && IKabs(sj4array[ij4]-sj4array[iij4]) < IKFAST_SOLUTION_THRESH )
{
    j4valid[iij4]=false; _ij4[1] = iij4; break; 
}
}
j4 = j4array[ij4]; cj4 = cj4array[ij4]; sj4 = sj4array[ij4];
{
IkReal evalcond[6];
IkReal x1762=IKsin(j4);
IkReal x1763=IKcos(j4);
IkReal x1764=((r00)*(sj6));
IkReal x1765=((IkReal(1.00000000000000))*(r12));
IkReal x1766=((IkReal(1.00000000000000))*(cj6));
IkReal x1767=((cj6)*(r01));
IkReal x1768=((cj0)*(r11));
IkReal x1769=((r01)*(sj6));
IkReal x1770=((IkReal(1.00000000000000))*(cj5));
IkReal x1771=((cj5)*(r11));
IkReal x1772=((cj0)*(r01));
IkReal x1773=((r02)*(sj5));
IkReal x1774=((cj6)*(r10));
IkReal x1775=((sj5)*(x1762));
IkReal x1776=((cj0)*(x1763));
IkReal x1777=((sj6)*(x1762));
IkReal x1778=((sj0)*(x1763));
IkReal x1779=((r10)*(x1762));
IkReal x1780=((IkReal(1.00000000000000))*(r10)*(sj6));
IkReal x1781=((cj5)*(x1762));
IkReal x1782=((IkReal(1.00000000000000))*(r11)*(sj6));
IkReal x1783=((r00)*(x1762));
IkReal x1784=((r20)*(x1763));
IkReal x1785=((r21)*(x1763));
IkReal x1786=((sj0)*(x1781));
evalcond[0]=((((sj6)*(x1785)))+(sj2)+(((cj5)*(r20)*(x1777)))+(((r22)*(x1775)))+(((IkReal(-1.00000000000000))*(x1766)*(x1784)))+(((cj6)*(r21)*(x1781))));
evalcond[1]=((((cj5)*(cj6)*(x1785)))+(((cj6)*(r20)*(x1762)))+(((r22)*(sj5)*(x1763)))+(((cj5)*(sj6)*(x1784)))+(((IkReal(-1.00000000000000))*(r21)*(x1777)))+(((IkReal(-1.00000000000000))*(cj2)*(cj3))));
evalcond[2]=((((x1769)*(x1778)))+(((IkReal(-1.00000000000000))*(x1766)*(x1768)*(x1781)))+(((IkReal(-1.00000000000000))*(sj6)*(x1763)*(x1768)))+(((x1767)*(x1786)))+(cj2)+(((x1774)*(x1776)))+(((x1764)*(x1786)))+(((sj0)*(x1762)*(x1773)))+(((IkReal(-1.00000000000000))*(r00)*(x1766)*(x1778)))+(((IkReal(-1.00000000000000))*(cj0)*(x1765)*(x1775)))+(((IkReal(-1.00000000000000))*(cj0)*(r10)*(x1770)*(x1777))));
evalcond[3]=((((IkReal(-1.00000000000000))*(r10)*(sj6)*(x1770)*(x1776)))+(((x1768)*(x1777)))+(((IkReal(-1.00000000000000))*(cj5)*(x1763)*(x1766)*(x1768)))+(((cj5)*(x1764)*(x1778)))+(((cj6)*(sj0)*(x1783)))+(((cj5)*(x1767)*(x1778)))+(((IkReal(-1.00000000000000))*(sj0)*(x1762)*(x1769)))+(((x1773)*(x1778)))+(((IkReal(-1.00000000000000))*(cj0)*(x1766)*(x1779)))+(((IkReal(-1.00000000000000))*(sj5)*(x1765)*(x1776)))+(((cj3)*(sj2))));
evalcond[4]=((((IkReal(-1.00000000000000))*(x1778)*(x1782)))+(((cj6)*(r00)*(x1776)))+(((IkReal(-1.00000000000000))*(cj0)*(x1762)*(x1764)*(x1770)))+(((IkReal(-1.00000000000000))*(x1769)*(x1776)))+(((IkReal(-1.00000000000000))*(r10)*(sj0)*(x1770)*(x1777)))+(((IkReal(-1.00000000000000))*(sj0)*(x1765)*(x1775)))+(((IkReal(-1.00000000000000))*(cj0)*(x1762)*(x1773)))+(((x1774)*(x1778)))+(((IkReal(-1.00000000000000))*(x1766)*(x1772)*(x1781)))+(((IkReal(-1.00000000000000))*(sj0)*(x1762)*(x1766)*(x1771))));
evalcond[5]=((((IkReal(-1.00000000000000))*(x1773)*(x1776)))+(((IkReal(-1.00000000000000))*(sj5)*(x1765)*(x1778)))+(sj3)+(((IkReal(-1.00000000000000))*(cj0)*(x1766)*(x1783)))+(((r11)*(sj0)*(x1777)))+(((IkReal(-1.00000000000000))*(x1766)*(x1771)*(x1778)))+(((IkReal(-1.00000000000000))*(cj5)*(x1763)*(x1766)*(x1772)))+(((cj0)*(x1762)*(x1769)))+(((IkReal(-1.00000000000000))*(r10)*(sj6)*(x1770)*(x1778)))+(((IkReal(-1.00000000000000))*(x1764)*(x1770)*(x1776)))+(((IkReal(-1.00000000000000))*(sj0)*(x1766)*(x1779))));
if( IKabs(evalcond[0]) > 0.000001  || IKabs(evalcond[1]) > 0.000001  || IKabs(evalcond[2]) > 0.000001  || IKabs(evalcond[3]) > 0.000001  || IKabs(evalcond[4]) > 0.000001  || IKabs(evalcond[5]) > 0.000001  )
{
continue;
}
}

{
std::vector<IkSingleDOFSolutionBase<IkReal> > vinfos(7);
vinfos[0].jointtype = 1;
vinfos[0].foffset = j0;
vinfos[0].indices[0] = _ij0[0];
vinfos[0].indices[1] = _ij0[1];
vinfos[0].maxsolutions = _nj0;
vinfos[1].jointtype = 1;
vinfos[1].foffset = j1;
vinfos[1].indices[0] = _ij1[0];
vinfos[1].indices[1] = _ij1[1];
vinfos[1].maxsolutions = _nj1;
vinfos[2].jointtype = 1;
vinfos[2].foffset = j2;
vinfos[2].indices[0] = _ij2[0];
vinfos[2].indices[1] = _ij2[1];
vinfos[2].maxsolutions = _nj2;
vinfos[3].jointtype = 1;
vinfos[3].foffset = j3;
vinfos[3].indices[0] = _ij3[0];
vinfos[3].indices[1] = _ij3[1];
vinfos[3].maxsolutions = _nj3;
vinfos[4].jointtype = 1;
vinfos[4].foffset = j4;
vinfos[4].indices[0] = _ij4[0];
vinfos[4].indices[1] = _ij4[1];
vinfos[4].maxsolutions = _nj4;
vinfos[5].jointtype = 1;
vinfos[5].foffset = j5;
vinfos[5].indices[0] = _ij5[0];
vinfos[5].indices[1] = _ij5[1];
vinfos[5].maxsolutions = _nj5;
vinfos[6].jointtype = 1;
vinfos[6].foffset = j6;
vinfos[6].indices[0] = _ij6[0];
vinfos[6].indices[1] = _ij6[1];
vinfos[6].maxsolutions = _nj6;
std::vector<int> vfree(0);
solutions.AddSolution(vinfos,vfree);
}
}
}

}

}

} else
{
{
IkReal j4array[1], cj4array[1], sj4array[1];
bool j4valid[1]={false};
_nj4 = 1;
IkReal x1787=((cj6)*(r20));
IkReal x1788=((r22)*(sj5));
IkReal x1789=((r21)*(sj2));
IkReal x1790=((cj5)*(cj6));
IkReal x1791=((cj5)*(r20)*(sj6));
IkReal x1792=((IkReal(1.00000000000000))*(cj2)*(cj3));
if( IKabs(((gconst54)*(((((IkReal(-1.00000000000000))*(x1787)*(x1792)))+(((cj2)*(cj3)*(r21)*(sj6)))+(((sj2)*(x1788)))+(((sj2)*(x1791)))+(((x1789)*(x1790))))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(((gconst54)*(((((IkReal(-1.00000000000000))*(r21)*(x1790)*(x1792)))+(((IkReal(-1.00000000000000))*(sj2)*(x1787)))+(((IkReal(-1.00000000000000))*(x1788)*(x1792)))+(((sj6)*(x1789)))+(((IkReal(-1.00000000000000))*(x1791)*(x1792))))))) < IKFAST_ATAN2_MAGTHRESH )
    continue;
j4array[0]=IKatan2(((gconst54)*(((((IkReal(-1.00000000000000))*(x1787)*(x1792)))+(((cj2)*(cj3)*(r21)*(sj6)))+(((sj2)*(x1788)))+(((sj2)*(x1791)))+(((x1789)*(x1790)))))), ((gconst54)*(((((IkReal(-1.00000000000000))*(r21)*(x1790)*(x1792)))+(((IkReal(-1.00000000000000))*(sj2)*(x1787)))+(((IkReal(-1.00000000000000))*(x1788)*(x1792)))+(((sj6)*(x1789)))+(((IkReal(-1.00000000000000))*(x1791)*(x1792)))))));
sj4array[0]=IKsin(j4array[0]);
cj4array[0]=IKcos(j4array[0]);
if( j4array[0] > IKPI )
{
    j4array[0]-=IK2PI;
}
else if( j4array[0] < -IKPI )
{    j4array[0]+=IK2PI;
}
j4valid[0] = true;
for(int ij4 = 0; ij4 < 1; ++ij4)
{
if( !j4valid[ij4] )
{
    continue;
}
_ij4[0] = ij4; _ij4[1] = -1;
for(int iij4 = ij4+1; iij4 < 1; ++iij4)
{
if( j4valid[iij4] && IKabs(cj4array[ij4]-cj4array[iij4]) < IKFAST_SOLUTION_THRESH && IKabs(sj4array[ij4]-sj4array[iij4]) < IKFAST_SOLUTION_THRESH )
{
    j4valid[iij4]=false; _ij4[1] = iij4; break; 
}
}
j4 = j4array[ij4]; cj4 = cj4array[ij4]; sj4 = sj4array[ij4];
{
IkReal evalcond[6];
IkReal x1793=IKsin(j4);
IkReal x1794=IKcos(j4);
IkReal x1795=((r00)*(sj6));
IkReal x1796=((IkReal(1.00000000000000))*(r12));
IkReal x1797=((IkReal(1.00000000000000))*(cj6));
IkReal x1798=((cj6)*(r01));
IkReal x1799=((cj0)*(r11));
IkReal x1800=((r01)*(sj6));
IkReal x1801=((IkReal(1.00000000000000))*(cj5));
IkReal x1802=((cj5)*(r11));
IkReal x1803=((cj0)*(r01));
IkReal x1804=((r02)*(sj5));
IkReal x1805=((cj6)*(r10));
IkReal x1806=((sj5)*(x1793));
IkReal x1807=((cj0)*(x1794));
IkReal x1808=((sj6)*(x1793));
IkReal x1809=((sj0)*(x1794));
IkReal x1810=((r10)*(x1793));
IkReal x1811=((IkReal(1.00000000000000))*(r10)*(sj6));
IkReal x1812=((cj5)*(x1793));
IkReal x1813=((IkReal(1.00000000000000))*(r11)*(sj6));
IkReal x1814=((r00)*(x1793));
IkReal x1815=((r20)*(x1794));
IkReal x1816=((r21)*(x1794));
IkReal x1817=((sj0)*(x1812));
evalcond[0]=((((r22)*(x1806)))+(((sj6)*(x1816)))+(sj2)+(((cj6)*(r21)*(x1812)))+(((cj5)*(r20)*(x1808)))+(((IkReal(-1.00000000000000))*(x1797)*(x1815))));
evalcond[1]=((((r22)*(sj5)*(x1794)))+(((cj6)*(r20)*(x1793)))+(((cj5)*(cj6)*(x1816)))+(((cj5)*(sj6)*(x1815)))+(((IkReal(-1.00000000000000))*(r21)*(x1808)))+(((IkReal(-1.00000000000000))*(cj2)*(cj3))));
evalcond[2]=((((IkReal(-1.00000000000000))*(x1797)*(x1799)*(x1812)))+(((sj0)*(x1793)*(x1804)))+(((x1800)*(x1809)))+(((IkReal(-1.00000000000000))*(cj0)*(x1796)*(x1806)))+(((x1795)*(x1817)))+(cj2)+(((x1805)*(x1807)))+(((x1798)*(x1817)))+(((IkReal(-1.00000000000000))*(sj6)*(x1794)*(x1799)))+(((IkReal(-1.00000000000000))*(r00)*(x1797)*(x1809)))+(((IkReal(-1.00000000000000))*(cj0)*(r10)*(x1801)*(x1808))));
evalcond[3]=((((cj6)*(sj0)*(x1814)))+(((x1799)*(x1808)))+(((IkReal(-1.00000000000000))*(r10)*(sj6)*(x1801)*(x1807)))+(((IkReal(-1.00000000000000))*(sj0)*(x1793)*(x1800)))+(((x1804)*(x1809)))+(((cj3)*(sj2)))+(((cj5)*(x1798)*(x1809)))+(((cj5)*(x1795)*(x1809)))+(((IkReal(-1.00000000000000))*(cj0)*(x1797)*(x1810)))+(((IkReal(-1.00000000000000))*(sj5)*(x1796)*(x1807)))+(((IkReal(-1.00000000000000))*(cj5)*(x1794)*(x1797)*(x1799))));
evalcond[4]=((((x1805)*(x1809)))+(((IkReal(-1.00000000000000))*(x1809)*(x1813)))+(((IkReal(-1.00000000000000))*(x1797)*(x1803)*(x1812)))+(((IkReal(-1.00000000000000))*(cj0)*(x1793)*(x1804)))+(((IkReal(-1.00000000000000))*(sj0)*(x1796)*(x1806)))+(((IkReal(-1.00000000000000))*(cj0)*(x1793)*(x1795)*(x1801)))+(((IkReal(-1.00000000000000))*(r10)*(sj0)*(x1801)*(x1808)))+(((IkReal(-1.00000000000000))*(sj0)*(x1793)*(x1797)*(x1802)))+(((IkReal(-1.00000000000000))*(x1800)*(x1807)))+(((cj6)*(r00)*(x1807))));
evalcond[5]=((((IkReal(-1.00000000000000))*(x1804)*(x1807)))+(((IkReal(-1.00000000000000))*(x1797)*(x1802)*(x1809)))+(((cj0)*(x1793)*(x1800)))+(sj3)+(((IkReal(-1.00000000000000))*(cj5)*(x1794)*(x1797)*(x1803)))+(((IkReal(-1.00000000000000))*(sj0)*(x1797)*(x1810)))+(((IkReal(-1.00000000000000))*(cj0)*(x1797)*(x1814)))+(((IkReal(-1.00000000000000))*(r10)*(sj6)*(x1801)*(x1809)))+(((IkReal(-1.00000000000000))*(sj5)*(x1796)*(x1809)))+(((r11)*(sj0)*(x1808)))+(((IkReal(-1.00000000000000))*(x1795)*(x1801)*(x1807))));
if( IKabs(evalcond[0]) > 0.000001  || IKabs(evalcond[1]) > 0.000001  || IKabs(evalcond[2]) > 0.000001  || IKabs(evalcond[3]) > 0.000001  || IKabs(evalcond[4]) > 0.000001  || IKabs(evalcond[5]) > 0.000001  )
{
continue;
}
}

{
std::vector<IkSingleDOFSolutionBase<IkReal> > vinfos(7);
vinfos[0].jointtype = 1;
vinfos[0].foffset = j0;
vinfos[0].indices[0] = _ij0[0];
vinfos[0].indices[1] = _ij0[1];
vinfos[0].maxsolutions = _nj0;
vinfos[1].jointtype = 1;
vinfos[1].foffset = j1;
vinfos[1].indices[0] = _ij1[0];
vinfos[1].indices[1] = _ij1[1];
vinfos[1].maxsolutions = _nj1;
vinfos[2].jointtype = 1;
vinfos[2].foffset = j2;
vinfos[2].indices[0] = _ij2[0];
vinfos[2].indices[1] = _ij2[1];
vinfos[2].maxsolutions = _nj2;
vinfos[3].jointtype = 1;
vinfos[3].foffset = j3;
vinfos[3].indices[0] = _ij3[0];
vinfos[3].indices[1] = _ij3[1];
vinfos[3].maxsolutions = _nj3;
vinfos[4].jointtype = 1;
vinfos[4].foffset = j4;
vinfos[4].indices[0] = _ij4[0];
vinfos[4].indices[1] = _ij4[1];
vinfos[4].maxsolutions = _nj4;
vinfos[5].jointtype = 1;
vinfos[5].foffset = j5;
vinfos[5].indices[0] = _ij5[0];
vinfos[5].indices[1] = _ij5[1];
vinfos[5].maxsolutions = _nj5;
vinfos[6].jointtype = 1;
vinfos[6].foffset = j6;
vinfos[6].indices[0] = _ij6[0];
vinfos[6].indices[1] = _ij6[1];
vinfos[6].maxsolutions = _nj6;
std::vector<int> vfree(0);
solutions.AddSolution(vinfos,vfree);
}
}
}

}

}
}
}

}

}

} else
{
{
IkReal j4array[1], cj4array[1], sj4array[1];
bool j4valid[1]={false};
_nj4 = 1;
IkReal x1818=((cj5)*(sj6));
IkReal x1819=((cj2)*(r20));
IkReal x1820=((IkReal(1.00000000000000))*(sj6));
IkReal x1821=((cj2)*(r21));
IkReal x1822=((cj5)*(cj6));
IkReal x1823=((IkReal(1.00000000000000))*(sj0)*(sj2));
IkReal x1824=((cj0)*(r10)*(sj2));
IkReal x1825=((cj0)*(r11)*(sj2));
if( IKabs(((gconst52)*(((((IkReal(-1.00000000000000))*(x1820)*(x1821)))+(((r01)*(sj0)*(sj2)*(sj6)))+(((IkReal(-1.00000000000000))*(x1820)*(x1825)))+(((IkReal(-1.00000000000000))*(cj6)*(r00)*(x1823)))+(((cj6)*(x1824)))+(((cj6)*(x1819))))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(((gconst52)*(((((x1818)*(x1824)))+(((cj2)*(r22)*(sj5)))+(((cj0)*(r12)*(sj2)*(sj5)))+(((x1821)*(x1822)))+(((IkReal(-1.00000000000000))*(r01)*(x1822)*(x1823)))+(((x1818)*(x1819)))+(((IkReal(-1.00000000000000))*(r02)*(sj5)*(x1823)))+(((x1822)*(x1825)))+(((IkReal(-1.00000000000000))*(r00)*(x1818)*(x1823))))))) < IKFAST_ATAN2_MAGTHRESH )
    continue;
j4array[0]=IKatan2(((gconst52)*(((((IkReal(-1.00000000000000))*(x1820)*(x1821)))+(((r01)*(sj0)*(sj2)*(sj6)))+(((IkReal(-1.00000000000000))*(x1820)*(x1825)))+(((IkReal(-1.00000000000000))*(cj6)*(r00)*(x1823)))+(((cj6)*(x1824)))+(((cj6)*(x1819)))))), ((gconst52)*(((((x1818)*(x1824)))+(((cj2)*(r22)*(sj5)))+(((cj0)*(r12)*(sj2)*(sj5)))+(((x1821)*(x1822)))+(((IkReal(-1.00000000000000))*(r01)*(x1822)*(x1823)))+(((x1818)*(x1819)))+(((IkReal(-1.00000000000000))*(r02)*(sj5)*(x1823)))+(((x1822)*(x1825)))+(((IkReal(-1.00000000000000))*(r00)*(x1818)*(x1823)))))));
sj4array[0]=IKsin(j4array[0]);
cj4array[0]=IKcos(j4array[0]);
if( j4array[0] > IKPI )
{
    j4array[0]-=IK2PI;
}
else if( j4array[0] < -IKPI )
{    j4array[0]+=IK2PI;
}
j4valid[0] = true;
for(int ij4 = 0; ij4 < 1; ++ij4)
{
if( !j4valid[ij4] )
{
    continue;
}
_ij4[0] = ij4; _ij4[1] = -1;
for(int iij4 = ij4+1; iij4 < 1; ++iij4)
{
if( j4valid[iij4] && IKabs(cj4array[ij4]-cj4array[iij4]) < IKFAST_SOLUTION_THRESH && IKabs(sj4array[ij4]-sj4array[iij4]) < IKFAST_SOLUTION_THRESH )
{
    j4valid[iij4]=false; _ij4[1] = iij4; break; 
}
}
j4 = j4array[ij4]; cj4 = cj4array[ij4]; sj4 = sj4array[ij4];
{
IkReal evalcond[3];
IkReal x1826=IKsin(j4);
IkReal x1827=IKcos(j4);
IkReal x1828=((r00)*(sj6));
IkReal x1829=((cj6)*(r01));
IkReal x1830=((IkReal(1.00000000000000))*(cj0));
IkReal x1831=((IkReal(1.00000000000000))*(sj0));
IkReal x1832=((r10)*(sj6));
IkReal x1833=((sj5)*(x1826));
IkReal x1834=((IkReal(1.00000000000000))*(cj6)*(r11));
IkReal x1835=((cj5)*(x1826));
IkReal x1836=((cj6)*(x1827));
IkReal x1837=((sj0)*(x1835));
IkReal x1838=((r01)*(sj6)*(x1827));
IkReal x1839=((r11)*(sj6)*(x1827));
evalcond[0]=((sj2)+(((r22)*(x1833)))+(((r20)*(sj6)*(x1835)))+(((r21)*(sj6)*(x1827)))+(((IkReal(-1.00000000000000))*(r20)*(x1836)))+(((cj6)*(r21)*(x1835))));
evalcond[1]=((((IkReal(-1.00000000000000))*(x1830)*(x1839)))+(((cj0)*(r10)*(x1836)))+(((r02)*(sj0)*(x1833)))+(((IkReal(-1.00000000000000))*(r12)*(x1830)*(x1833)))+(cj2)+(((IkReal(-1.00000000000000))*(x1830)*(x1832)*(x1835)))+(((sj0)*(x1838)))+(((x1828)*(x1837)))+(((IkReal(-1.00000000000000))*(cj6)*(r11)*(x1830)*(x1835)))+(((IkReal(-1.00000000000000))*(r00)*(x1831)*(x1836)))+(((x1829)*(x1837))));
evalcond[2]=((((IkReal(-1.00000000000000))*(x1831)*(x1839)))+(((IkReal(-1.00000000000000))*(r02)*(x1830)*(x1833)))+(((IkReal(-1.00000000000000))*(x1829)*(x1830)*(x1835)))+(((r10)*(sj0)*(x1836)))+(((IkReal(-1.00000000000000))*(r12)*(x1831)*(x1833)))+(((IkReal(-1.00000000000000))*(cj6)*(r11)*(x1831)*(x1835)))+(((IkReal(-1.00000000000000))*(x1830)*(x1838)))+(((IkReal(-1.00000000000000))*(x1831)*(x1832)*(x1835)))+(((IkReal(-1.00000000000000))*(x1828)*(x1830)*(x1835)))+(((cj0)*(r00)*(x1836))));
if( IKabs(evalcond[0]) > 0.000001  || IKabs(evalcond[1]) > 0.000001  || IKabs(evalcond[2]) > 0.000001  )
{
continue;
}
}

{
IkReal dummyeval[1];
IkReal gconst56;
gconst56=IKsign(cj2);
dummyeval[0]=cj2;
if( IKabs(dummyeval[0]) < 0.0000010000000000  )
{
{
IkReal dummyeval[1];
dummyeval[0]=cj2;
if( IKabs(dummyeval[0]) < 0.0000010000000000  )
{
{
IkReal dummyeval[1];
dummyeval[0]=sj2;
if( IKabs(dummyeval[0]) < 0.0000010000000000  )
{
{
IkReal evalcond[9];
IkReal x1840=((cj5)*(sj4));
IkReal x1841=((IkReal(1.00000000000000))*(sj6));
IkReal x1842=((r10)*(sj0));
IkReal x1843=((sj4)*(sj5));
IkReal x1844=((cj5)*(cj6));
IkReal x1845=((r01)*(sj0));
IkReal x1846=((IkReal(1.00000000000000))*(r02));
IkReal x1847=((IkReal(0.374290000000000))*(cj0));
IkReal x1848=((cj5)*(r12));
IkReal x1849=((cj6)*(sj5));
IkReal x1850=((cj0)*(r11));
IkReal x1851=((cj5)*(sj0));
IkReal x1852=((r20)*(sj6));
IkReal x1853=((IkReal(1.00000000000000))*(sj0));
IkReal x1854=((cj4)*(cj5));
IkReal x1855=((IkReal(1.00000000000000))*(cj6));
IkReal x1856=((IkReal(0.0100000000000000))*(sj5));
IkReal x1857=((sj5)*(sj6));
IkReal x1858=((cj0)*(r10));
IkReal x1859=((cj4)*(cj6));
IkReal x1860=((cj0)*(r01));
IkReal x1861=((IkReal(1.00000000000000))*(cj4));
IkReal x1862=((cj0)*(r00));
IkReal x1863=((IkReal(0.374290000000000))*(sj0));
IkReal x1864=((cj0)*(r12));
IkReal x1865=((IkReal(0.374290000000000))*(sj5));
IkReal x1866=((cj4)*(sj6));
IkReal x1867=((IkReal(1.00000000000000))*(cj0));
IkReal x1868=((r02)*(sj0));
IkReal x1869=((IkReal(0.0100000000000000))*(cj5));
IkReal x1870=((r11)*(sj0));
IkReal x1871=((r00)*(sj0)*(sj6));
IkReal x1872=((r00)*(x1859));
IkReal x1873=((sj6)*(x1869));
evalcond[0]=((IkReal(-3.14159265358979))+(IKfmod(((IkReal(3.14159265358979))+(j2)), IkReal(6.28318530717959))));
evalcond[1]=((((r21)*(x1866)))+(((cj6)*(r21)*(x1840)))+(((x1840)*(x1852)))+(((r22)*(x1843)))+(((IkReal(-1.00000000000000))*(cj4)*(r20)*(x1855))));
evalcond[2]=((IkReal(-0.0690000000000000))+(((IkReal(-1.00000000000000))*(x1852)*(x1869)))+(((IkReal(-0.374290000000000))*(cj5)*(r22)))+(((IkReal(-0.0100000000000000))*(r21)*(x1844)))+(((x1852)*(x1865)))+(pz)+(((IkReal(0.374290000000000))*(r21)*(x1849)))+(((IkReal(-1.00000000000000))*(r22)*(x1856))));
evalcond[3]=((((IkReal(-1.00000000000000))*(x1846)*(x1851)))+(((x1845)*(x1849)))+(((cj0)*(x1848)))+(((IkReal(-1.00000000000000))*(x1849)*(x1850)))+(((r00)*(sj0)*(x1857)))+(((IkReal(-1.00000000000000))*(sj5)*(x1841)*(x1858))));
evalcond[4]=((IkReal(1.00000000000000))+(((x1845)*(x1866)))+(((IkReal(-1.00000000000000))*(x1853)*(x1872)))+(((IkReal(-1.00000000000000))*(x1840)*(x1850)*(x1855)))+(((x1840)*(x1871)))+(((x1858)*(x1859)))+(((IkReal(-1.00000000000000))*(x1840)*(x1841)*(x1858)))+(((IkReal(-1.00000000000000))*(cj4)*(x1841)*(x1850)))+(((x1843)*(x1868)))+(((cj6)*(x1840)*(x1845)))+(((IkReal(-1.00000000000000))*(x1843)*(x1864))));
evalcond[5]=((((IkReal(-1.00000000000000))*(sj4)*(x1841)*(x1845)))+(((r00)*(x1851)*(x1866)))+(((IkReal(-1.00000000000000))*(sj4)*(x1855)*(x1858)))+(((cj6)*(r00)*(sj0)*(sj4)))+(((cj4)*(sj5)*(x1868)))+(((IkReal(-1.00000000000000))*(x1841)*(x1854)*(x1858)))+(((IkReal(-1.00000000000000))*(sj5)*(x1861)*(x1864)))+(((cj4)*(x1844)*(x1845)))+(((sj4)*(sj6)*(x1850)))+(((IkReal(-1.00000000000000))*(x1844)*(x1850)*(x1861))));
evalcond[6]=((((IkReal(-1.00000000000000))*(x1840)*(x1841)*(x1862)))+(((IkReal(-1.00000000000000))*(cj0)*(x1843)*(x1846)))+(((IkReal(-1.00000000000000))*(x1840)*(x1855)*(x1860)))+(((x1859)*(x1862)))+(((IkReal(-1.00000000000000))*(x1840)*(x1841)*(x1842)))+(((IkReal(-1.00000000000000))*(cj4)*(x1841)*(x1870)))+(((x1842)*(x1859)))+(((IkReal(-1.00000000000000))*(cj4)*(x1841)*(x1860)))+(((IkReal(-1.00000000000000))*(cj6)*(r11)*(x1840)*(x1853)))+(((IkReal(-1.00000000000000))*(r12)*(x1843)*(x1853))));
evalcond[7]=((((IkReal(0.0100000000000000))*(x1844)*(x1850)))+(((IkReal(-0.0100000000000000))*(x1844)*(x1845)))+(((IkReal(-0.374290000000000))*(r02)*(x1851)))+(((x1847)*(x1848)))+(((r00)*(x1857)*(x1863)))+(((IkReal(-1.00000000000000))*(r11)*(x1847)*(x1849)))+(((x1856)*(x1864)))+(((IkReal(0.374290000000000))*(x1845)*(x1849)))+(((IkReal(-1.00000000000000))*(py)*(x1867)))+(((IkReal(-1.00000000000000))*(r10)*(x1847)*(x1857)))+(((IkReal(-0.0100000000000000))*(r00)*(sj6)*(x1851)))+(((IkReal(-1.00000000000000))*(x1856)*(x1868)))+(((px)*(sj0)))+(((x1858)*(x1873))));
evalcond[8]=((IkReal(-0.295420000000000))+(((IkReal(-1.00000000000000))*(py)*(x1853)))+(((r12)*(sj0)*(x1856)))+(((cj0)*(r02)*(x1856)))+(((IkReal(0.0100000000000000))*(x1844)*(x1870)))+(((IkReal(-1.00000000000000))*(px)*(x1867)))+(((IkReal(0.0100000000000000))*(x1844)*(x1860)))+(((x1862)*(x1873)))+(((IkReal(-1.00000000000000))*(r01)*(x1847)*(x1849)))+(((cj5)*(r02)*(x1847)))+(((IkReal(-0.374290000000000))*(x1842)*(x1857)))+(((IkReal(-1.00000000000000))*(r00)*(x1847)*(x1857)))+(((x1842)*(x1873)))+(((x1848)*(x1863)))+(((IkReal(-1.00000000000000))*(r11)*(x1849)*(x1863))));
if( IKabs(evalcond[0]) < 0.0000010000000000  && IKabs(evalcond[1]) < 0.0000010000000000  && IKabs(evalcond[2]) < 0.0000010000000000  && IKabs(evalcond[3]) < 0.0000010000000000  && IKabs(evalcond[4]) < 0.0000010000000000  && IKabs(evalcond[5]) < 0.0000010000000000  && IKabs(evalcond[6]) < 0.0000010000000000  && IKabs(evalcond[7]) < 0.0000010000000000  && IKabs(evalcond[8]) < 0.0000010000000000  )
{
{
IkReal j3array[1], cj3array[1], sj3array[1];
bool j3valid[1]={false};
_nj3 = 1;
IkReal x1874=((IkReal(1.00000000000000))*(r21));
IkReal x1875=((cj4)*(cj5));
IkReal x1876=((r20)*(sj6));
if( IKabs(((((IkReal(-1.00000000000000))*(cj6)*(sj5)*(x1874)))+(((IkReal(-1.00000000000000))*(sj5)*(x1876)))+(((cj5)*(r22))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(((((cj6)*(r20)*(sj4)))+(((cj6)*(r21)*(x1875)))+(((cj4)*(r22)*(sj5)))+(((x1875)*(x1876)))+(((IkReal(-1.00000000000000))*(sj4)*(sj6)*(x1874))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(IKsqr(((((IkReal(-1.00000000000000))*(cj6)*(sj5)*(x1874)))+(((IkReal(-1.00000000000000))*(sj5)*(x1876)))+(((cj5)*(r22)))))+IKsqr(((((cj6)*(r20)*(sj4)))+(((cj6)*(r21)*(x1875)))+(((cj4)*(r22)*(sj5)))+(((x1875)*(x1876)))+(((IkReal(-1.00000000000000))*(sj4)*(sj6)*(x1874)))))-1) <= IKFAST_SINCOS_THRESH )
    continue;
j3array[0]=IKatan2(((((IkReal(-1.00000000000000))*(cj6)*(sj5)*(x1874)))+(((IkReal(-1.00000000000000))*(sj5)*(x1876)))+(((cj5)*(r22)))), ((((cj6)*(r20)*(sj4)))+(((cj6)*(r21)*(x1875)))+(((cj4)*(r22)*(sj5)))+(((x1875)*(x1876)))+(((IkReal(-1.00000000000000))*(sj4)*(sj6)*(x1874)))));
sj3array[0]=IKsin(j3array[0]);
cj3array[0]=IKcos(j3array[0]);
if( j3array[0] > IKPI )
{
    j3array[0]-=IK2PI;
}
else if( j3array[0] < -IKPI )
{    j3array[0]+=IK2PI;
}
j3valid[0] = true;
for(int ij3 = 0; ij3 < 1; ++ij3)
{
if( !j3valid[ij3] )
{
    continue;
}
_ij3[0] = ij3; _ij3[1] = -1;
for(int iij3 = ij3+1; iij3 < 1; ++iij3)
{
if( j3valid[iij3] && IKabs(cj3array[ij3]-cj3array[iij3]) < IKFAST_SOLUTION_THRESH && IKabs(sj3array[ij3]-sj3array[iij3]) < IKFAST_SOLUTION_THRESH )
{
    j3valid[iij3]=false; _ij3[1] = iij3; break; 
}
}
j3 = j3array[ij3]; cj3 = cj3array[ij3]; sj3 = sj3array[ij3];
{
IkReal evalcond[4];
IkReal x1877=IKcos(j3);
IkReal x1878=IKsin(j3);
IkReal x1879=((IkReal(1.00000000000000))*(cj4));
IkReal x1880=((sj0)*(sj5));
IkReal x1881=((cj0)*(cj5));
IkReal x1882=((cj6)*(r01));
IkReal x1883=((r00)*(sj6));
IkReal x1884=((cj6)*(r11));
IkReal x1885=((cj5)*(sj0));
IkReal x1886=((cj6)*(sj4));
IkReal x1887=((sj4)*(sj6));
IkReal x1888=((cj4)*(cj5));
IkReal x1889=((cj6)*(r21));
IkReal x1890=((r20)*(sj6));
IkReal x1891=((r10)*(sj6));
IkReal x1892=((IkReal(1.00000000000000))*(cj0)*(sj5));
evalcond[0]=((((IkReal(-1.00000000000000))*(cj5)*(r22)))+(x1878)+(((sj5)*(x1889)))+(((sj5)*(x1890))));
evalcond[1]=((((x1888)*(x1889)))+(((x1888)*(x1890)))+(((IkReal(-1.00000000000000))*(r21)*(x1887)))+(((cj4)*(r22)*(sj5)))+(((r20)*(x1886)))+(((IkReal(-1.00000000000000))*(x1877))));
evalcond[2]=((((IkReal(-1.00000000000000))*(x1880)*(x1891)))+(((r12)*(x1885)))+(((r02)*(x1881)))+(((IkReal(-1.00000000000000))*(x1883)*(x1892)))+(x1877)+(((IkReal(-1.00000000000000))*(x1880)*(x1884)))+(((IkReal(-1.00000000000000))*(x1882)*(x1892))));
evalcond[3]=((((IkReal(-1.00000000000000))*(cj0)*(r00)*(x1886)))+(((r11)*(sj0)*(x1887)))+(((IkReal(-1.00000000000000))*(r10)*(sj0)*(x1886)))+(((IkReal(-1.00000000000000))*(x1879)*(x1881)*(x1882)))+(((IkReal(-1.00000000000000))*(x1879)*(x1881)*(x1883)))+(((IkReal(-1.00000000000000))*(r12)*(x1879)*(x1880)))+(((IkReal(-1.00000000000000))*(x1879)*(x1885)*(x1891)))+(x1878)+(((cj0)*(r01)*(x1887)))+(((IkReal(-1.00000000000000))*(cj0)*(r02)*(sj5)*(x1879)))+(((IkReal(-1.00000000000000))*(x1879)*(x1884)*(x1885))));
if( IKabs(evalcond[0]) > 0.000001  || IKabs(evalcond[1]) > 0.000001  || IKabs(evalcond[2]) > 0.000001  || IKabs(evalcond[3]) > 0.000001  )
{
continue;
}
}

{
std::vector<IkSingleDOFSolutionBase<IkReal> > vinfos(7);
vinfos[0].jointtype = 1;
vinfos[0].foffset = j0;
vinfos[0].indices[0] = _ij0[0];
vinfos[0].indices[1] = _ij0[1];
vinfos[0].maxsolutions = _nj0;
vinfos[1].jointtype = 1;
vinfos[1].foffset = j1;
vinfos[1].indices[0] = _ij1[0];
vinfos[1].indices[1] = _ij1[1];
vinfos[1].maxsolutions = _nj1;
vinfos[2].jointtype = 1;
vinfos[2].foffset = j2;
vinfos[2].indices[0] = _ij2[0];
vinfos[2].indices[1] = _ij2[1];
vinfos[2].maxsolutions = _nj2;
vinfos[3].jointtype = 1;
vinfos[3].foffset = j3;
vinfos[3].indices[0] = _ij3[0];
vinfos[3].indices[1] = _ij3[1];
vinfos[3].maxsolutions = _nj3;
vinfos[4].jointtype = 1;
vinfos[4].foffset = j4;
vinfos[4].indices[0] = _ij4[0];
vinfos[4].indices[1] = _ij4[1];
vinfos[4].maxsolutions = _nj4;
vinfos[5].jointtype = 1;
vinfos[5].foffset = j5;
vinfos[5].indices[0] = _ij5[0];
vinfos[5].indices[1] = _ij5[1];
vinfos[5].maxsolutions = _nj5;
vinfos[6].jointtype = 1;
vinfos[6].foffset = j6;
vinfos[6].indices[0] = _ij6[0];
vinfos[6].indices[1] = _ij6[1];
vinfos[6].maxsolutions = _nj6;
std::vector<int> vfree(0);
solutions.AddSolution(vinfos,vfree);
}
}
}

} else
{
IkReal x1893=((cj5)*(sj4));
IkReal x1894=((IkReal(1.00000000000000))*(sj6));
IkReal x1895=((r10)*(sj0));
IkReal x1896=((sj4)*(sj5));
IkReal x1897=((cj5)*(cj6));
IkReal x1898=((r01)*(sj0));
IkReal x1899=((IkReal(1.00000000000000))*(r02));
IkReal x1900=((IkReal(0.374290000000000))*(cj0));
IkReal x1901=((cj5)*(r12));
IkReal x1902=((cj6)*(sj5));
IkReal x1903=((cj0)*(r11));
IkReal x1904=((cj5)*(sj0));
IkReal x1905=((r20)*(sj6));
IkReal x1906=((IkReal(1.00000000000000))*(sj0));
IkReal x1907=((cj4)*(cj5));
IkReal x1908=((IkReal(1.00000000000000))*(cj6));
IkReal x1909=((IkReal(0.0100000000000000))*(sj5));
IkReal x1910=((sj5)*(sj6));
IkReal x1911=((cj0)*(r10));
IkReal x1912=((cj4)*(cj6));
IkReal x1913=((cj0)*(r01));
IkReal x1914=((IkReal(1.00000000000000))*(cj4));
IkReal x1915=((cj0)*(r00));
IkReal x1916=((IkReal(0.374290000000000))*(sj0));
IkReal x1917=((cj0)*(r12));
IkReal x1918=((IkReal(0.374290000000000))*(sj5));
IkReal x1919=((cj4)*(sj6));
IkReal x1920=((IkReal(1.00000000000000))*(cj0));
IkReal x1921=((r02)*(sj0));
IkReal x1922=((IkReal(0.0100000000000000))*(cj5));
IkReal x1923=((r11)*(sj0));
IkReal x1924=((r00)*(sj0)*(sj6));
IkReal x1925=((r00)*(x1912));
IkReal x1926=((sj6)*(x1922));
evalcond[0]=((IkReal(-3.14159265358979))+(IKfmod(j2, IkReal(6.28318530717959))));
evalcond[1]=((((IkReal(-1.00000000000000))*(cj4)*(r20)*(x1908)))+(((r21)*(x1919)))+(((r22)*(x1896)))+(((x1893)*(x1905)))+(((cj6)*(r21)*(x1893))));
evalcond[2]=((IkReal(0.0690000000000000))+(((IkReal(0.374290000000000))*(r21)*(x1902)))+(((IkReal(-1.00000000000000))*(r22)*(x1909)))+(((IkReal(-0.0100000000000000))*(r21)*(x1897)))+(((IkReal(-0.374290000000000))*(cj5)*(r22)))+(((x1905)*(x1918)))+(((IkReal(-1.00000000000000))*(x1905)*(x1922)))+(pz));
evalcond[3]=((((IkReal(-1.00000000000000))*(sj5)*(x1894)*(x1911)))+(((r00)*(sj0)*(x1910)))+(((cj0)*(x1901)))+(((x1898)*(x1902)))+(((IkReal(-1.00000000000000))*(x1899)*(x1904)))+(((IkReal(-1.00000000000000))*(x1902)*(x1903))));
evalcond[4]=((IkReal(-1.00000000000000))+(((cj6)*(x1893)*(x1898)))+(((IkReal(-1.00000000000000))*(x1893)*(x1894)*(x1911)))+(((IkReal(-1.00000000000000))*(x1896)*(x1917)))+(((x1893)*(x1924)))+(((IkReal(-1.00000000000000))*(cj4)*(x1894)*(x1903)))+(((x1911)*(x1912)))+(((IkReal(-1.00000000000000))*(x1906)*(x1925)))+(((x1898)*(x1919)))+(((IkReal(-1.00000000000000))*(x1893)*(x1903)*(x1908)))+(((x1896)*(x1921))));
evalcond[5]=((((IkReal(-1.00000000000000))*(sj4)*(x1894)*(x1898)))+(((cj4)*(sj5)*(x1921)))+(((cj4)*(x1897)*(x1898)))+(((r00)*(x1904)*(x1919)))+(((cj6)*(r00)*(sj0)*(sj4)))+(((sj4)*(sj6)*(x1903)))+(((IkReal(-1.00000000000000))*(sj5)*(x1914)*(x1917)))+(((IkReal(-1.00000000000000))*(x1897)*(x1903)*(x1914)))+(((IkReal(-1.00000000000000))*(x1894)*(x1907)*(x1911)))+(((IkReal(-1.00000000000000))*(sj4)*(x1908)*(x1911))));
evalcond[6]=((((x1912)*(x1915)))+(((IkReal(-1.00000000000000))*(x1893)*(x1894)*(x1915)))+(((IkReal(-1.00000000000000))*(cj6)*(r11)*(x1893)*(x1906)))+(((IkReal(-1.00000000000000))*(cj0)*(x1896)*(x1899)))+(((IkReal(-1.00000000000000))*(cj4)*(x1894)*(x1923)))+(((IkReal(-1.00000000000000))*(x1893)*(x1894)*(x1895)))+(((IkReal(-1.00000000000000))*(cj4)*(x1894)*(x1913)))+(((IkReal(-1.00000000000000))*(r12)*(x1896)*(x1906)))+(((IkReal(-1.00000000000000))*(x1893)*(x1908)*(x1913)))+(((x1895)*(x1912))));
evalcond[7]=((((IkReal(0.0100000000000000))*(x1897)*(x1903)))+(((x1900)*(x1901)))+(((IkReal(-0.374290000000000))*(r02)*(x1904)))+(((IkReal(-0.0100000000000000))*(x1897)*(x1898)))+(((IkReal(-1.00000000000000))*(x1909)*(x1921)))+(((IkReal(-1.00000000000000))*(py)*(x1920)))+(((x1911)*(x1926)))+(((r00)*(x1910)*(x1916)))+(((IkReal(-1.00000000000000))*(r11)*(x1900)*(x1902)))+(((x1909)*(x1917)))+(((IkReal(-1.00000000000000))*(r10)*(x1900)*(x1910)))+(((IkReal(0.374290000000000))*(x1898)*(x1902)))+(((px)*(sj0)))+(((IkReal(-0.0100000000000000))*(r00)*(sj6)*(x1904))));
evalcond[8]=((IkReal(-0.295420000000000))+(((cj0)*(r02)*(x1909)))+(((IkReal(-1.00000000000000))*(py)*(x1906)))+(((IkReal(-1.00000000000000))*(r00)*(x1900)*(x1910)))+(((x1901)*(x1916)))+(((x1895)*(x1926)))+(((IkReal(-1.00000000000000))*(px)*(x1920)))+(((IkReal(-1.00000000000000))*(r11)*(x1902)*(x1916)))+(((r12)*(sj0)*(x1909)))+(((x1915)*(x1926)))+(((cj5)*(r02)*(x1900)))+(((IkReal(-1.00000000000000))*(r01)*(x1900)*(x1902)))+(((IkReal(-0.374290000000000))*(x1895)*(x1910)))+(((IkReal(0.0100000000000000))*(x1897)*(x1913)))+(((IkReal(0.0100000000000000))*(x1897)*(x1923))));
if( IKabs(evalcond[0]) < 0.0000010000000000  && IKabs(evalcond[1]) < 0.0000010000000000  && IKabs(evalcond[2]) < 0.0000010000000000  && IKabs(evalcond[3]) < 0.0000010000000000  && IKabs(evalcond[4]) < 0.0000010000000000  && IKabs(evalcond[5]) < 0.0000010000000000  && IKabs(evalcond[6]) < 0.0000010000000000  && IKabs(evalcond[7]) < 0.0000010000000000  && IKabs(evalcond[8]) < 0.0000010000000000  )
{
{
IkReal j3array[1], cj3array[1], sj3array[1];
bool j3valid[1]={false};
_nj3 = 1;
IkReal x1927=((IkReal(1.00000000000000))*(cj4));
IkReal x1928=((cj6)*(r21));
IkReal x1929=((r20)*(sj6));
if( IKabs(((((sj5)*(x1929)))+(((sj5)*(x1928)))+(((IkReal(-1.00000000000000))*(cj5)*(r22))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(((((IkReal(-1.00000000000000))*(cj5)*(x1927)*(x1928)))+(((r21)*(sj4)*(sj6)))+(((IkReal(-1.00000000000000))*(r22)*(sj5)*(x1927)))+(((IkReal(-1.00000000000000))*(cj5)*(x1927)*(x1929)))+(((IkReal(-1.00000000000000))*(cj6)*(r20)*(sj4))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(IKsqr(((((sj5)*(x1929)))+(((sj5)*(x1928)))+(((IkReal(-1.00000000000000))*(cj5)*(r22)))))+IKsqr(((((IkReal(-1.00000000000000))*(cj5)*(x1927)*(x1928)))+(((r21)*(sj4)*(sj6)))+(((IkReal(-1.00000000000000))*(r22)*(sj5)*(x1927)))+(((IkReal(-1.00000000000000))*(cj5)*(x1927)*(x1929)))+(((IkReal(-1.00000000000000))*(cj6)*(r20)*(sj4)))))-1) <= IKFAST_SINCOS_THRESH )
    continue;
j3array[0]=IKatan2(((((sj5)*(x1929)))+(((sj5)*(x1928)))+(((IkReal(-1.00000000000000))*(cj5)*(r22)))), ((((IkReal(-1.00000000000000))*(cj5)*(x1927)*(x1928)))+(((r21)*(sj4)*(sj6)))+(((IkReal(-1.00000000000000))*(r22)*(sj5)*(x1927)))+(((IkReal(-1.00000000000000))*(cj5)*(x1927)*(x1929)))+(((IkReal(-1.00000000000000))*(cj6)*(r20)*(sj4)))));
sj3array[0]=IKsin(j3array[0]);
cj3array[0]=IKcos(j3array[0]);
if( j3array[0] > IKPI )
{
    j3array[0]-=IK2PI;
}
else if( j3array[0] < -IKPI )
{    j3array[0]+=IK2PI;
}
j3valid[0] = true;
for(int ij3 = 0; ij3 < 1; ++ij3)
{
if( !j3valid[ij3] )
{
    continue;
}
_ij3[0] = ij3; _ij3[1] = -1;
for(int iij3 = ij3+1; iij3 < 1; ++iij3)
{
if( j3valid[iij3] && IKabs(cj3array[ij3]-cj3array[iij3]) < IKFAST_SOLUTION_THRESH && IKabs(sj3array[ij3]-sj3array[iij3]) < IKFAST_SOLUTION_THRESH )
{
    j3valid[iij3]=false; _ij3[1] = iij3; break; 
}
}
j3 = j3array[ij3]; cj3 = cj3array[ij3]; sj3 = sj3array[ij3];
{
IkReal evalcond[4];
IkReal x1930=IKcos(j3);
IkReal x1931=IKsin(j3);
IkReal x1932=((IkReal(1.00000000000000))*(cj4));
IkReal x1933=((sj0)*(sj5));
IkReal x1934=((cj0)*(cj5));
IkReal x1935=((cj6)*(r01));
IkReal x1936=((r00)*(sj6));
IkReal x1937=((cj6)*(r11));
IkReal x1938=((cj5)*(sj0));
IkReal x1939=((cj6)*(sj4));
IkReal x1940=((sj4)*(sj6));
IkReal x1941=((cj4)*(cj5));
IkReal x1942=((cj6)*(r21));
IkReal x1943=((r20)*(sj6));
IkReal x1944=((r10)*(sj6));
IkReal x1945=((IkReal(1.00000000000000))*(cj0)*(sj5));
evalcond[0]=((((sj5)*(x1943)))+(((IkReal(-1.00000000000000))*(x1931)))+(((sj5)*(x1942)))+(((IkReal(-1.00000000000000))*(cj5)*(r22))));
evalcond[1]=((x1930)+(((IkReal(-1.00000000000000))*(r21)*(x1940)))+(((x1941)*(x1943)))+(((r20)*(x1939)))+(((cj4)*(r22)*(sj5)))+(((x1941)*(x1942))));
evalcond[2]=((x1930)+(((r02)*(x1934)))+(((IkReal(-1.00000000000000))*(x1936)*(x1945)))+(((r12)*(x1938)))+(((IkReal(-1.00000000000000))*(x1935)*(x1945)))+(((IkReal(-1.00000000000000))*(x1933)*(x1937)))+(((IkReal(-1.00000000000000))*(x1933)*(x1944))));
evalcond[3]=((x1931)+(((IkReal(-1.00000000000000))*(r12)*(x1932)*(x1933)))+(((IkReal(-1.00000000000000))*(x1932)*(x1934)*(x1936)))+(((IkReal(-1.00000000000000))*(x1932)*(x1938)*(x1944)))+(((cj0)*(r01)*(x1940)))+(((IkReal(-1.00000000000000))*(cj0)*(r02)*(sj5)*(x1932)))+(((IkReal(-1.00000000000000))*(cj0)*(r00)*(x1939)))+(((r11)*(sj0)*(x1940)))+(((IkReal(-1.00000000000000))*(x1932)*(x1934)*(x1935)))+(((IkReal(-1.00000000000000))*(r10)*(sj0)*(x1939)))+(((IkReal(-1.00000000000000))*(x1932)*(x1937)*(x1938))));
if( IKabs(evalcond[0]) > 0.000001  || IKabs(evalcond[1]) > 0.000001  || IKabs(evalcond[2]) > 0.000001  || IKabs(evalcond[3]) > 0.000001  )
{
continue;
}
}

{
std::vector<IkSingleDOFSolutionBase<IkReal> > vinfos(7);
vinfos[0].jointtype = 1;
vinfos[0].foffset = j0;
vinfos[0].indices[0] = _ij0[0];
vinfos[0].indices[1] = _ij0[1];
vinfos[0].maxsolutions = _nj0;
vinfos[1].jointtype = 1;
vinfos[1].foffset = j1;
vinfos[1].indices[0] = _ij1[0];
vinfos[1].indices[1] = _ij1[1];
vinfos[1].maxsolutions = _nj1;
vinfos[2].jointtype = 1;
vinfos[2].foffset = j2;
vinfos[2].indices[0] = _ij2[0];
vinfos[2].indices[1] = _ij2[1];
vinfos[2].maxsolutions = _nj2;
vinfos[3].jointtype = 1;
vinfos[3].foffset = j3;
vinfos[3].indices[0] = _ij3[0];
vinfos[3].indices[1] = _ij3[1];
vinfos[3].maxsolutions = _nj3;
vinfos[4].jointtype = 1;
vinfos[4].foffset = j4;
vinfos[4].indices[0] = _ij4[0];
vinfos[4].indices[1] = _ij4[1];
vinfos[4].maxsolutions = _nj4;
vinfos[5].jointtype = 1;
vinfos[5].foffset = j5;
vinfos[5].indices[0] = _ij5[0];
vinfos[5].indices[1] = _ij5[1];
vinfos[5].maxsolutions = _nj5;
vinfos[6].jointtype = 1;
vinfos[6].foffset = j6;
vinfos[6].indices[0] = _ij6[0];
vinfos[6].indices[1] = _ij6[1];
vinfos[6].maxsolutions = _nj6;
std::vector<int> vfree(0);
solutions.AddSolution(vinfos,vfree);
}
}
}

} else
{
IkReal x1946=((IkReal(1.00000000000000))*(cj0));
IkReal x1947=((cj4)*(sj6));
IkReal x1948=((sj0)*(sj4));
IkReal x1949=((cj5)*(sj6));
IkReal x1950=((sj4)*(sj5));
IkReal x1951=((r12)*(sj5));
IkReal x1952=((IkReal(0.374290000000000))*(cj5));
IkReal x1953=((r02)*(sj0));
IkReal x1954=((r20)*(sj4));
IkReal x1955=((IkReal(1.00000000000000))*(sj0));
IkReal x1956=((IkReal(1.00000000000000))*(cj5));
IkReal x1957=((cj0)*(r10));
IkReal x1958=((cj4)*(cj6));
IkReal x1959=((r00)*(sj0));
IkReal x1960=((cj6)*(r21));
IkReal x1961=((IkReal(0.374290000000000))*(sj5));
IkReal x1962=((cj0)*(r00));
IkReal x1963=((IkReal(0.0100000000000000))*(sj5));
IkReal x1964=((cj0)*(r02));
IkReal x1965=((cj5)*(sj4));
IkReal x1966=((cj6)*(r01));
IkReal x1967=((cj6)*(r11));
IkReal x1968=((r01)*(sj0));
IkReal x1969=((r10)*(sj0));
IkReal x1970=((IkReal(0.0100000000000000))*(cj5)*(cj6));
IkReal x1971=((sj6)*(x1961));
IkReal x1972=((cj0)*(cj6)*(x1961));
evalcond[0]=((IkReal(-3.14159265358979))+(IKfmod(((IkReal(1.57079632679490))+(j2)), IkReal(6.28318530717959))));
evalcond[1]=((((IkReal(-1.00000000000000))*(r22)*(x1956)))+(((sj5)*(x1960)))+(((r20)*(sj5)*(sj6))));
evalcond[2]=((IkReal(1.00000000000000))+(((r21)*(x1947)))+(((x1949)*(x1954)))+(((x1960)*(x1965)))+(((IkReal(-1.00000000000000))*(r20)*(x1958)))+(((r22)*(x1950))));
evalcond[3]=((((r20)*(x1971)))+(((IkReal(-0.0100000000000000))*(r20)*(x1949)))+(((IkReal(-1.00000000000000))*(r22)*(x1963)))+(pz)+(((IkReal(-1.00000000000000))*(r22)*(x1952)))+(((x1960)*(x1961)))+(((IkReal(-0.0100000000000000))*(cj5)*(x1960))));
evalcond[4]=((((IkReal(-1.00000000000000))*(r21)*(sj4)*(sj6)))+(((cj5)*(r20)*(x1947)))+(((cj4)*(r22)*(sj5)))+(((cj5)*(r21)*(x1958)))+(((cj6)*(x1954))));
evalcond[5]=((((cj5)*(x1948)*(x1966)))+(((x1957)*(x1958)))+(((x1947)*(x1968)))+(((r00)*(x1948)*(x1949)))+(((IkReal(-1.00000000000000))*(r11)*(x1946)*(x1947)))+(((IkReal(-1.00000000000000))*(x1946)*(x1965)*(x1967)))+(((r02)*(sj5)*(x1948)))+(((IkReal(-1.00000000000000))*(r12)*(x1946)*(x1950)))+(((IkReal(-1.00000000000000))*(r10)*(sj4)*(x1946)*(x1949)))+(((IkReal(-1.00000000000000))*(r00)*(x1955)*(x1958))));
evalcond[6]=((((x1958)*(x1969)))+(((IkReal(-1.00000000000000))*(x1946)*(x1965)*(x1966)))+(((IkReal(-1.00000000000000))*(r00)*(sj4)*(x1946)*(x1949)))+(((IkReal(-1.00000000000000))*(r11)*(x1947)*(x1955)))+(((IkReal(-1.00000000000000))*(r02)*(x1946)*(x1950)))+(((IkReal(-1.00000000000000))*(r10)*(x1948)*(x1949)))+(((IkReal(-1.00000000000000))*(r01)*(x1946)*(x1947)))+(((IkReal(-1.00000000000000))*(x1948)*(x1951)))+(((IkReal(-1.00000000000000))*(x1948)*(x1956)*(x1967)))+(((x1958)*(x1962))));
evalcond[7]=((IkReal(0.0690000000000000))+(((IkReal(-1.00000000000000))*(cj0)*(x1961)*(x1967)))+(((IkReal(-0.0100000000000000))*(cj5)*(sj0)*(x1966)))+(((IkReal(-0.0100000000000000))*(x1949)*(x1959)))+(((cj0)*(r12)*(x1952)))+(((IkReal(0.0100000000000000))*(cj0)*(cj5)*(x1967)))+(((IkReal(-1.00000000000000))*(x1953)*(x1963)))+(((IkReal(-1.00000000000000))*(x1957)*(x1971)))+(((IkReal(-1.00000000000000))*(x1952)*(x1953)))+(((IkReal(0.0100000000000000))*(x1949)*(x1957)))+(((IkReal(0.0100000000000000))*(cj0)*(x1951)))+(((px)*(sj0)))+(((x1959)*(x1971)))+(((IkReal(-1.00000000000000))*(py)*(x1946)))+(((sj0)*(x1961)*(x1966))));
evalcond[8]=((IkReal(-0.295420000000000))+(((r12)*(sj0)*(x1952)))+(((x1963)*(x1964)))+(((IkReal(0.0100000000000000))*(sj0)*(x1951)))+(((IkReal(-1.00000000000000))*(px)*(x1946)))+(((IkReal(-1.00000000000000))*(sj0)*(x1961)*(x1967)))+(((IkReal(0.0100000000000000))*(x1949)*(x1969)))+(((IkReal(-1.00000000000000))*(cj0)*(x1961)*(x1966)))+(((IkReal(-1.00000000000000))*(x1969)*(x1971)))+(((IkReal(-1.00000000000000))*(py)*(x1955)))+(((IkReal(0.0100000000000000))*(cj0)*(cj5)*(x1966)))+(((IkReal(-1.00000000000000))*(x1962)*(x1971)))+(((IkReal(0.0100000000000000))*(cj5)*(sj0)*(x1967)))+(((IkReal(0.0100000000000000))*(x1949)*(x1962)))+(((x1952)*(x1964))));
if( IKabs(evalcond[0]) < 0.0000010000000000  && IKabs(evalcond[1]) < 0.0000010000000000  && IKabs(evalcond[2]) < 0.0000010000000000  && IKabs(evalcond[3]) < 0.0000010000000000  && IKabs(evalcond[4]) < 0.0000010000000000  && IKabs(evalcond[5]) < 0.0000010000000000  && IKabs(evalcond[6]) < 0.0000010000000000  && IKabs(evalcond[7]) < 0.0000010000000000  && IKabs(evalcond[8]) < 0.0000010000000000  )
{
{
IkReal j3array[1], cj3array[1], sj3array[1];
bool j3valid[1]={false};
_nj3 = 1;
IkReal x1973=((sj0)*(sj5));
IkReal x1974=((r00)*(sj6));
IkReal x1975=((IkReal(1.00000000000000))*(cj5));
IkReal x1976=((cj6)*(r11));
IkReal x1977=((cj6)*(r01));
IkReal x1978=((r10)*(sj6));
IkReal x1979=((cj0)*(sj5));
if( IKabs(((((IkReal(-1.00000000000000))*(x1978)*(x1979)))+(((IkReal(-1.00000000000000))*(x1976)*(x1979)))+(((x1973)*(x1974)))+(((IkReal(-1.00000000000000))*(r02)*(sj0)*(x1975)))+(((cj0)*(cj5)*(r12)))+(((x1973)*(x1977))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(((((IkReal(-1.00000000000000))*(cj0)*(r02)*(x1975)))+(((x1974)*(x1979)))+(((IkReal(-1.00000000000000))*(r12)*(sj0)*(x1975)))+(((x1973)*(x1976)))+(((x1973)*(x1978)))+(((x1977)*(x1979))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(IKsqr(((((IkReal(-1.00000000000000))*(x1978)*(x1979)))+(((IkReal(-1.00000000000000))*(x1976)*(x1979)))+(((x1973)*(x1974)))+(((IkReal(-1.00000000000000))*(r02)*(sj0)*(x1975)))+(((cj0)*(cj5)*(r12)))+(((x1973)*(x1977)))))+IKsqr(((((IkReal(-1.00000000000000))*(cj0)*(r02)*(x1975)))+(((x1974)*(x1979)))+(((IkReal(-1.00000000000000))*(r12)*(sj0)*(x1975)))+(((x1973)*(x1976)))+(((x1973)*(x1978)))+(((x1977)*(x1979)))))-1) <= IKFAST_SINCOS_THRESH )
    continue;
j3array[0]=IKatan2(((((IkReal(-1.00000000000000))*(x1978)*(x1979)))+(((IkReal(-1.00000000000000))*(x1976)*(x1979)))+(((x1973)*(x1974)))+(((IkReal(-1.00000000000000))*(r02)*(sj0)*(x1975)))+(((cj0)*(cj5)*(r12)))+(((x1973)*(x1977)))), ((((IkReal(-1.00000000000000))*(cj0)*(r02)*(x1975)))+(((x1974)*(x1979)))+(((IkReal(-1.00000000000000))*(r12)*(sj0)*(x1975)))+(((x1973)*(x1976)))+(((x1973)*(x1978)))+(((x1977)*(x1979)))));
sj3array[0]=IKsin(j3array[0]);
cj3array[0]=IKcos(j3array[0]);
if( j3array[0] > IKPI )
{
    j3array[0]-=IK2PI;
}
else if( j3array[0] < -IKPI )
{    j3array[0]+=IK2PI;
}
j3valid[0] = true;
for(int ij3 = 0; ij3 < 1; ++ij3)
{
if( !j3valid[ij3] )
{
    continue;
}
_ij3[0] = ij3; _ij3[1] = -1;
for(int iij3 = ij3+1; iij3 < 1; ++iij3)
{
if( j3valid[iij3] && IKabs(cj3array[ij3]-cj3array[iij3]) < IKFAST_SOLUTION_THRESH && IKabs(sj3array[ij3]-sj3array[iij3]) < IKFAST_SOLUTION_THRESH )
{
    j3valid[iij3]=false; _ij3[1] = iij3; break; 
}
}
j3 = j3array[ij3]; cj3 = cj3array[ij3]; sj3 = sj3array[ij3];
{
IkReal evalcond[4];
IkReal x1980=IKcos(j3);
IkReal x1981=IKsin(j3);
IkReal x1982=((sj0)*(sj5));
IkReal x1983=((r00)*(sj6));
IkReal x1984=((cj6)*(sj0));
IkReal x1985=((IkReal(1.00000000000000))*(cj4));
IkReal x1986=((r00)*(sj4));
IkReal x1987=((cj0)*(cj5));
IkReal x1988=((cj5)*(sj0));
IkReal x1989=((cj6)*(r11));
IkReal x1990=((r10)*(sj6));
IkReal x1991=((cj0)*(sj5));
IkReal x1992=((r10)*(sj4));
IkReal x1993=((cj4)*(cj5)*(r01));
IkReal x1994=((IkReal(1.00000000000000))*(cj0)*(cj6));
IkReal x1995=((cj0)*(sj4)*(sj6));
IkReal x1996=((sj0)*(sj4)*(sj6));
evalcond[0]=((((IkReal(-1.00000000000000))*(r02)*(x1988)))+(((x1982)*(x1983)))+(((cj6)*(r01)*(x1982)))+(((IkReal(-1.00000000000000))*(x1989)*(x1991)))+(((IkReal(-1.00000000000000))*(x1981)))+(((IkReal(-1.00000000000000))*(x1990)*(x1991)))+(((r12)*(x1987))));
evalcond[1]=((((IkReal(-1.00000000000000))*(cj6)*(r01)*(x1991)))+(x1980)+(((r12)*(x1988)))+(((IkReal(-1.00000000000000))*(x1982)*(x1989)))+(((IkReal(-1.00000000000000))*(x1983)*(x1991)))+(((r02)*(x1987)))+(((IkReal(-1.00000000000000))*(x1982)*(x1990))));
evalcond[2]=((((cj4)*(x1983)*(x1988)))+(x1980)+(((r11)*(x1995)))+(((IkReal(-1.00000000000000))*(x1992)*(x1994)))+(((cj4)*(r02)*(x1982)))+(((x1984)*(x1993)))+(((IkReal(-1.00000000000000))*(r12)*(x1985)*(x1991)))+(((IkReal(-1.00000000000000))*(x1985)*(x1987)*(x1990)))+(((IkReal(-1.00000000000000))*(r01)*(x1996)))+(((IkReal(-1.00000000000000))*(x1985)*(x1987)*(x1989)))+(((x1984)*(x1986))));
evalcond[3]=((((IkReal(-1.00000000000000))*(x1984)*(x1992)))+(x1981)+(((IkReal(-1.00000000000000))*(r02)*(x1985)*(x1991)))+(((IkReal(-1.00000000000000))*(cj6)*(r01)*(x1985)*(x1987)))+(((IkReal(-1.00000000000000))*(cj5)*(r11)*(x1984)*(x1985)))+(((IkReal(-1.00000000000000))*(x1986)*(x1994)))+(((IkReal(-1.00000000000000))*(x1983)*(x1985)*(x1987)))+(((r01)*(x1995)))+(((r11)*(x1996)))+(((IkReal(-1.00000000000000))*(x1985)*(x1988)*(x1990)))+(((IkReal(-1.00000000000000))*(r12)*(x1982)*(x1985))));
if( IKabs(evalcond[0]) > 0.000001  || IKabs(evalcond[1]) > 0.000001  || IKabs(evalcond[2]) > 0.000001  || IKabs(evalcond[3]) > 0.000001  )
{
continue;
}
}

{
std::vector<IkSingleDOFSolutionBase<IkReal> > vinfos(7);
vinfos[0].jointtype = 1;
vinfos[0].foffset = j0;
vinfos[0].indices[0] = _ij0[0];
vinfos[0].indices[1] = _ij0[1];
vinfos[0].maxsolutions = _nj0;
vinfos[1].jointtype = 1;
vinfos[1].foffset = j1;
vinfos[1].indices[0] = _ij1[0];
vinfos[1].indices[1] = _ij1[1];
vinfos[1].maxsolutions = _nj1;
vinfos[2].jointtype = 1;
vinfos[2].foffset = j2;
vinfos[2].indices[0] = _ij2[0];
vinfos[2].indices[1] = _ij2[1];
vinfos[2].maxsolutions = _nj2;
vinfos[3].jointtype = 1;
vinfos[3].foffset = j3;
vinfos[3].indices[0] = _ij3[0];
vinfos[3].indices[1] = _ij3[1];
vinfos[3].maxsolutions = _nj3;
vinfos[4].jointtype = 1;
vinfos[4].foffset = j4;
vinfos[4].indices[0] = _ij4[0];
vinfos[4].indices[1] = _ij4[1];
vinfos[4].maxsolutions = _nj4;
vinfos[5].jointtype = 1;
vinfos[5].foffset = j5;
vinfos[5].indices[0] = _ij5[0];
vinfos[5].indices[1] = _ij5[1];
vinfos[5].maxsolutions = _nj5;
vinfos[6].jointtype = 1;
vinfos[6].foffset = j6;
vinfos[6].indices[0] = _ij6[0];
vinfos[6].indices[1] = _ij6[1];
vinfos[6].maxsolutions = _nj6;
std::vector<int> vfree(0);
solutions.AddSolution(vinfos,vfree);
}
}
}

} else
{
IkReal x1997=((IkReal(1.00000000000000))*(cj0));
IkReal x1998=((cj4)*(sj6));
IkReal x1999=((sj0)*(sj4));
IkReal x2000=((cj5)*(sj6));
IkReal x2001=((sj4)*(sj5));
IkReal x2002=((r12)*(sj5));
IkReal x2003=((IkReal(0.374290000000000))*(cj5));
IkReal x2004=((r02)*(sj0));
IkReal x2005=((r20)*(sj4));
IkReal x2006=((IkReal(1.00000000000000))*(sj0));
IkReal x2007=((IkReal(1.00000000000000))*(cj5));
IkReal x2008=((cj0)*(r10));
IkReal x2009=((cj4)*(cj6));
IkReal x2010=((r00)*(sj0));
IkReal x2011=((cj6)*(r21));
IkReal x2012=((IkReal(0.374290000000000))*(sj5));
IkReal x2013=((cj0)*(r00));
IkReal x2014=((IkReal(0.0100000000000000))*(sj5));
IkReal x2015=((cj0)*(r02));
IkReal x2016=((cj5)*(sj4));
IkReal x2017=((cj6)*(r01));
IkReal x2018=((cj6)*(r11));
IkReal x2019=((r01)*(sj0));
IkReal x2020=((r10)*(sj0));
IkReal x2021=((IkReal(0.0100000000000000))*(cj5)*(cj6));
IkReal x2022=((sj6)*(x2012));
IkReal x2023=((cj0)*(cj6)*(x2012));
evalcond[0]=((IkReal(-3.14159265358979))+(IKfmod(((IkReal(4.71238898038469))+(j2)), IkReal(6.28318530717959))));
evalcond[1]=((((sj5)*(x2011)))+(((IkReal(-1.00000000000000))*(r22)*(x2007)))+(((r20)*(sj5)*(sj6))));
evalcond[2]=((IkReal(-1.00000000000000))+(((r22)*(x2001)))+(((r21)*(x1998)))+(((x2000)*(x2005)))+(((IkReal(-1.00000000000000))*(r20)*(x2009)))+(((x2011)*(x2016))));
evalcond[3]=((((IkReal(-0.0100000000000000))*(cj5)*(x2011)))+(((x2011)*(x2012)))+(((IkReal(-1.00000000000000))*(r22)*(x2003)))+(((IkReal(-0.0100000000000000))*(r20)*(x2000)))+(pz)+(((IkReal(-1.00000000000000))*(r22)*(x2014)))+(((r20)*(x2022))));
evalcond[4]=((((cj5)*(r21)*(x2009)))+(((IkReal(-1.00000000000000))*(r21)*(sj4)*(sj6)))+(((cj4)*(r22)*(sj5)))+(((cj6)*(x2005)))+(((cj5)*(r20)*(x1998))));
evalcond[5]=((((r02)*(sj5)*(x1999)))+(((x1998)*(x2019)))+(((IkReal(-1.00000000000000))*(r10)*(sj4)*(x1997)*(x2000)))+(((x2008)*(x2009)))+(((r00)*(x1999)*(x2000)))+(((IkReal(-1.00000000000000))*(r00)*(x2006)*(x2009)))+(((IkReal(-1.00000000000000))*(x1997)*(x2016)*(x2018)))+(((IkReal(-1.00000000000000))*(r11)*(x1997)*(x1998)))+(((IkReal(-1.00000000000000))*(r12)*(x1997)*(x2001)))+(((cj5)*(x1999)*(x2017))));
evalcond[6]=((((IkReal(-1.00000000000000))*(r01)*(x1997)*(x1998)))+(((IkReal(-1.00000000000000))*(x1999)*(x2002)))+(((x2009)*(x2020)))+(((x2009)*(x2013)))+(((IkReal(-1.00000000000000))*(r10)*(x1999)*(x2000)))+(((IkReal(-1.00000000000000))*(r00)*(sj4)*(x1997)*(x2000)))+(((IkReal(-1.00000000000000))*(r02)*(x1997)*(x2001)))+(((IkReal(-1.00000000000000))*(x1999)*(x2007)*(x2018)))+(((IkReal(-1.00000000000000))*(x1997)*(x2016)*(x2017)))+(((IkReal(-1.00000000000000))*(r11)*(x1998)*(x2006))));
evalcond[7]=((IkReal(-0.0690000000000000))+(((IkReal(-1.00000000000000))*(x2008)*(x2022)))+(((IkReal(-1.00000000000000))*(cj0)*(x2012)*(x2018)))+(((IkReal(-1.00000000000000))*(x2004)*(x2014)))+(((x2010)*(x2022)))+(((IkReal(-1.00000000000000))*(py)*(x1997)))+(((IkReal(0.0100000000000000))*(cj0)*(x2002)))+(((IkReal(-0.0100000000000000))*(cj5)*(sj0)*(x2017)))+(((IkReal(-0.0100000000000000))*(x2000)*(x2010)))+(((IkReal(-1.00000000000000))*(x2003)*(x2004)))+(((cj0)*(r12)*(x2003)))+(((px)*(sj0)))+(((sj0)*(x2012)*(x2017)))+(((IkReal(0.0100000000000000))*(x2000)*(x2008)))+(((IkReal(0.0100000000000000))*(cj0)*(cj5)*(x2018))));
evalcond[8]=((IkReal(-0.295420000000000))+(((IkReal(0.0100000000000000))*(sj0)*(x2002)))+(((r12)*(sj0)*(x2003)))+(((IkReal(0.0100000000000000))*(cj5)*(sj0)*(x2018)))+(((IkReal(0.0100000000000000))*(cj0)*(cj5)*(x2017)))+(((x2014)*(x2015)))+(((IkReal(-1.00000000000000))*(sj0)*(x2012)*(x2018)))+(((IkReal(0.0100000000000000))*(x2000)*(x2013)))+(((IkReal(-1.00000000000000))*(cj0)*(x2012)*(x2017)))+(((IkReal(-1.00000000000000))*(x2020)*(x2022)))+(((IkReal(-1.00000000000000))*(py)*(x2006)))+(((IkReal(-1.00000000000000))*(x2013)*(x2022)))+(((IkReal(-1.00000000000000))*(px)*(x1997)))+(((IkReal(0.0100000000000000))*(x2000)*(x2020)))+(((x2003)*(x2015))));
if( IKabs(evalcond[0]) < 0.0000010000000000  && IKabs(evalcond[1]) < 0.0000010000000000  && IKabs(evalcond[2]) < 0.0000010000000000  && IKabs(evalcond[3]) < 0.0000010000000000  && IKabs(evalcond[4]) < 0.0000010000000000  && IKabs(evalcond[5]) < 0.0000010000000000  && IKabs(evalcond[6]) < 0.0000010000000000  && IKabs(evalcond[7]) < 0.0000010000000000  && IKabs(evalcond[8]) < 0.0000010000000000  )
{
{
IkReal j3array[1], cj3array[1], sj3array[1];
bool j3valid[1]={false};
_nj3 = 1;
IkReal x2024=((IkReal(1.00000000000000))*(cj5));
IkReal x2025=((r10)*(sj5)*(sj6));
IkReal x2026=((cj6)*(sj0)*(sj5));
IkReal x2027=((r00)*(sj5)*(sj6));
IkReal x2028=((cj0)*(cj6)*(sj5));
if( IKabs(((((IkReal(-1.00000000000000))*(r01)*(x2026)))+(((r11)*(x2028)))+(((cj0)*(x2025)))+(((IkReal(-1.00000000000000))*(cj0)*(r12)*(x2024)))+(((cj5)*(r02)*(sj0)))+(((IkReal(-1.00000000000000))*(sj0)*(x2027))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(((((cj0)*(x2027)))+(((sj0)*(x2025)))+(((r01)*(x2028)))+(((r11)*(x2026)))+(((IkReal(-1.00000000000000))*(cj0)*(r02)*(x2024)))+(((IkReal(-1.00000000000000))*(r12)*(sj0)*(x2024))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(IKsqr(((((IkReal(-1.00000000000000))*(r01)*(x2026)))+(((r11)*(x2028)))+(((cj0)*(x2025)))+(((IkReal(-1.00000000000000))*(cj0)*(r12)*(x2024)))+(((cj5)*(r02)*(sj0)))+(((IkReal(-1.00000000000000))*(sj0)*(x2027)))))+IKsqr(((((cj0)*(x2027)))+(((sj0)*(x2025)))+(((r01)*(x2028)))+(((r11)*(x2026)))+(((IkReal(-1.00000000000000))*(cj0)*(r02)*(x2024)))+(((IkReal(-1.00000000000000))*(r12)*(sj0)*(x2024)))))-1) <= IKFAST_SINCOS_THRESH )
    continue;
j3array[0]=IKatan2(((((IkReal(-1.00000000000000))*(r01)*(x2026)))+(((r11)*(x2028)))+(((cj0)*(x2025)))+(((IkReal(-1.00000000000000))*(cj0)*(r12)*(x2024)))+(((cj5)*(r02)*(sj0)))+(((IkReal(-1.00000000000000))*(sj0)*(x2027)))), ((((cj0)*(x2027)))+(((sj0)*(x2025)))+(((r01)*(x2028)))+(((r11)*(x2026)))+(((IkReal(-1.00000000000000))*(cj0)*(r02)*(x2024)))+(((IkReal(-1.00000000000000))*(r12)*(sj0)*(x2024)))));
sj3array[0]=IKsin(j3array[0]);
cj3array[0]=IKcos(j3array[0]);
if( j3array[0] > IKPI )
{
    j3array[0]-=IK2PI;
}
else if( j3array[0] < -IKPI )
{    j3array[0]+=IK2PI;
}
j3valid[0] = true;
for(int ij3 = 0; ij3 < 1; ++ij3)
{
if( !j3valid[ij3] )
{
    continue;
}
_ij3[0] = ij3; _ij3[1] = -1;
for(int iij3 = ij3+1; iij3 < 1; ++iij3)
{
if( j3valid[iij3] && IKabs(cj3array[ij3]-cj3array[iij3]) < IKFAST_SOLUTION_THRESH && IKabs(sj3array[ij3]-sj3array[iij3]) < IKFAST_SOLUTION_THRESH )
{
    j3valid[iij3]=false; _ij3[1] = iij3; break; 
}
}
j3 = j3array[ij3]; cj3 = cj3array[ij3]; sj3 = sj3array[ij3];
{
IkReal evalcond[4];
IkReal x2029=IKcos(j3);
IkReal x2030=IKsin(j3);
IkReal x2031=((sj0)*(sj5));
IkReal x2032=((r00)*(sj6));
IkReal x2033=((IkReal(1.00000000000000))*(cj4));
IkReal x2034=((cj6)*(sj0));
IkReal x2035=((r00)*(sj4));
IkReal x2036=((cj0)*(cj5));
IkReal x2037=((cj6)*(r01));
IkReal x2038=((cj5)*(sj0));
IkReal x2039=((cj0)*(sj5));
IkReal x2040=((cj6)*(r11));
IkReal x2041=((r10)*(sj6));
IkReal x2042=((r10)*(sj4));
IkReal x2043=((cj0)*(sj4)*(sj6));
IkReal x2044=((sj0)*(sj4)*(sj6));
IkReal x2045=((IkReal(1.00000000000000))*(cj0)*(cj6));
evalcond[0]=((x2030)+(((x2031)*(x2032)))+(((IkReal(-1.00000000000000))*(r02)*(x2038)))+(((IkReal(-1.00000000000000))*(x2039)*(x2040)))+(((r12)*(x2036)))+(((x2031)*(x2037)))+(((IkReal(-1.00000000000000))*(x2039)*(x2041))));
evalcond[1]=((x2029)+(((IkReal(-1.00000000000000))*(x2032)*(x2039)))+(((r02)*(x2036)))+(((IkReal(-1.00000000000000))*(x2031)*(x2041)))+(((IkReal(-1.00000000000000))*(x2037)*(x2039)))+(((r12)*(x2038)))+(((IkReal(-1.00000000000000))*(x2031)*(x2040))));
evalcond[2]=((((IkReal(-1.00000000000000))*(x2029)))+(((cj4)*(x2032)*(x2038)))+(((IkReal(-1.00000000000000))*(x2033)*(x2036)*(x2041)))+(((IkReal(-1.00000000000000))*(r12)*(x2033)*(x2039)))+(((IkReal(-1.00000000000000))*(x2042)*(x2045)))+(((IkReal(-1.00000000000000))*(x2033)*(x2036)*(x2040)))+(((IkReal(-1.00000000000000))*(r01)*(x2044)))+(((r11)*(x2043)))+(((cj4)*(cj5)*(r01)*(x2034)))+(((cj4)*(r02)*(x2031)))+(((x2034)*(x2035))));
evalcond[3]=((x2030)+(((r01)*(x2043)))+(((IkReal(-1.00000000000000))*(r02)*(x2033)*(x2039)))+(((r11)*(x2044)))+(((IkReal(-1.00000000000000))*(x2034)*(x2042)))+(((IkReal(-1.00000000000000))*(r12)*(x2031)*(x2033)))+(((IkReal(-1.00000000000000))*(x2032)*(x2033)*(x2036)))+(((IkReal(-1.00000000000000))*(cj5)*(r11)*(x2033)*(x2034)))+(((IkReal(-1.00000000000000))*(x2033)*(x2038)*(x2041)))+(((IkReal(-1.00000000000000))*(x2033)*(x2036)*(x2037)))+(((IkReal(-1.00000000000000))*(x2035)*(x2045))));
if( IKabs(evalcond[0]) > 0.000001  || IKabs(evalcond[1]) > 0.000001  || IKabs(evalcond[2]) > 0.000001  || IKabs(evalcond[3]) > 0.000001  )
{
continue;
}
}

{
std::vector<IkSingleDOFSolutionBase<IkReal> > vinfos(7);
vinfos[0].jointtype = 1;
vinfos[0].foffset = j0;
vinfos[0].indices[0] = _ij0[0];
vinfos[0].indices[1] = _ij0[1];
vinfos[0].maxsolutions = _nj0;
vinfos[1].jointtype = 1;
vinfos[1].foffset = j1;
vinfos[1].indices[0] = _ij1[0];
vinfos[1].indices[1] = _ij1[1];
vinfos[1].maxsolutions = _nj1;
vinfos[2].jointtype = 1;
vinfos[2].foffset = j2;
vinfos[2].indices[0] = _ij2[0];
vinfos[2].indices[1] = _ij2[1];
vinfos[2].maxsolutions = _nj2;
vinfos[3].jointtype = 1;
vinfos[3].foffset = j3;
vinfos[3].indices[0] = _ij3[0];
vinfos[3].indices[1] = _ij3[1];
vinfos[3].maxsolutions = _nj3;
vinfos[4].jointtype = 1;
vinfos[4].foffset = j4;
vinfos[4].indices[0] = _ij4[0];
vinfos[4].indices[1] = _ij4[1];
vinfos[4].maxsolutions = _nj4;
vinfos[5].jointtype = 1;
vinfos[5].foffset = j5;
vinfos[5].indices[0] = _ij5[0];
vinfos[5].indices[1] = _ij5[1];
vinfos[5].maxsolutions = _nj5;
vinfos[6].jointtype = 1;
vinfos[6].foffset = j6;
vinfos[6].indices[0] = _ij6[0];
vinfos[6].indices[1] = _ij6[1];
vinfos[6].maxsolutions = _nj6;
std::vector<int> vfree(0);
solutions.AddSolution(vinfos,vfree);
}
}
}

} else
{
if( 1 )
{
continue;

} else
{
}
}
}
}
}
}

} else
{
{
IkReal j3array[1], cj3array[1], sj3array[1];
bool j3valid[1]={false};
_nj3 = 1;
IkReal x2046=((sj0)*(sj5));
IkReal x2047=((r00)*(sj6));
IkReal x2048=((IkReal(1.00000000000000))*(cj5));
IkReal x2049=((cj6)*(r11));
IkReal x2050=((cj6)*(r01));
IkReal x2051=((cj0)*(sj5));
IkReal x2052=((r10)*(sj6));
if( IKabs(((((IKabs(sj2) != 0)?((IkReal)1/(sj2)):(IkReal)1.0e30))*(((((IkReal(-1.00000000000000))*(x2049)*(x2051)))+(((x2046)*(x2047)))+(((x2046)*(x2050)))+(((IkReal(-1.00000000000000))*(r02)*(sj0)*(x2048)))+(((cj0)*(cj5)*(r12)))+(((IkReal(-1.00000000000000))*(x2051)*(x2052))))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(((((IkReal(-1.00000000000000))*(r12)*(sj0)*(x2048)))+(((x2046)*(x2052)))+(((x2050)*(x2051)))+(((IkReal(-1.00000000000000))*(cj0)*(r02)*(x2048)))+(((x2046)*(x2049)))+(((x2047)*(x2051))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(IKsqr(((((IKabs(sj2) != 0)?((IkReal)1/(sj2)):(IkReal)1.0e30))*(((((IkReal(-1.00000000000000))*(x2049)*(x2051)))+(((x2046)*(x2047)))+(((x2046)*(x2050)))+(((IkReal(-1.00000000000000))*(r02)*(sj0)*(x2048)))+(((cj0)*(cj5)*(r12)))+(((IkReal(-1.00000000000000))*(x2051)*(x2052)))))))+IKsqr(((((IkReal(-1.00000000000000))*(r12)*(sj0)*(x2048)))+(((x2046)*(x2052)))+(((x2050)*(x2051)))+(((IkReal(-1.00000000000000))*(cj0)*(r02)*(x2048)))+(((x2046)*(x2049)))+(((x2047)*(x2051)))))-1) <= IKFAST_SINCOS_THRESH )
    continue;
j3array[0]=IKatan2(((((IKabs(sj2) != 0)?((IkReal)1/(sj2)):(IkReal)1.0e30))*(((((IkReal(-1.00000000000000))*(x2049)*(x2051)))+(((x2046)*(x2047)))+(((x2046)*(x2050)))+(((IkReal(-1.00000000000000))*(r02)*(sj0)*(x2048)))+(((cj0)*(cj5)*(r12)))+(((IkReal(-1.00000000000000))*(x2051)*(x2052)))))), ((((IkReal(-1.00000000000000))*(r12)*(sj0)*(x2048)))+(((x2046)*(x2052)))+(((x2050)*(x2051)))+(((IkReal(-1.00000000000000))*(cj0)*(r02)*(x2048)))+(((x2046)*(x2049)))+(((x2047)*(x2051)))));
sj3array[0]=IKsin(j3array[0]);
cj3array[0]=IKcos(j3array[0]);
if( j3array[0] > IKPI )
{
    j3array[0]-=IK2PI;
}
else if( j3array[0] < -IKPI )
{    j3array[0]+=IK2PI;
}
j3valid[0] = true;
for(int ij3 = 0; ij3 < 1; ++ij3)
{
if( !j3valid[ij3] )
{
    continue;
}
_ij3[0] = ij3; _ij3[1] = -1;
for(int iij3 = ij3+1; iij3 < 1; ++iij3)
{
if( j3valid[iij3] && IKabs(cj3array[ij3]-cj3array[iij3]) < IKFAST_SOLUTION_THRESH && IKabs(sj3array[ij3]-sj3array[iij3]) < IKFAST_SOLUTION_THRESH )
{
    j3valid[iij3]=false; _ij3[1] = iij3; break; 
}
}
j3 = j3array[ij3]; cj3 = cj3array[ij3]; sj3 = sj3array[ij3];
{
IkReal evalcond[6];
IkReal x2053=IKsin(j3);
IkReal x2054=IKcos(j3);
IkReal x2055=((sj0)*(sj5));
IkReal x2056=((r00)*(sj6));
IkReal x2057=((IkReal(1.00000000000000))*(cj4));
IkReal x2058=((cj6)*(r01));
IkReal x2059=((cj0)*(cj5));
IkReal x2060=((cj5)*(sj0));
IkReal x2061=((cj6)*(r11));
IkReal x2062=((cj6)*(sj4));
IkReal x2063=((cj0)*(sj5));
IkReal x2064=((cj4)*(cj5));
IkReal x2065=((cj6)*(r21));
IkReal x2066=((r20)*(sj6));
IkReal x2067=((r10)*(sj6));
IkReal x2068=((IkReal(1.00000000000000))*(cj0));
IkReal x2069=((cj0)*(sj4)*(sj6));
IkReal x2070=((sj0)*(sj4)*(sj6));
evalcond[0]=((((sj5)*(x2066)))+(((IkReal(-1.00000000000000))*(cj5)*(r22)))+(((cj2)*(x2053)))+(((sj5)*(x2065))));
evalcond[1]=((((r20)*(x2062)))+(((IkReal(-1.00000000000000))*(r21)*(sj4)*(sj6)))+(((x2064)*(x2066)))+(((IkReal(-1.00000000000000))*(cj2)*(x2054)))+(((cj4)*(r22)*(sj5)))+(((x2064)*(x2065))));
evalcond[2]=((((x2055)*(x2056)))+(((IkReal(-1.00000000000000))*(x2063)*(x2067)))+(((IkReal(-1.00000000000000))*(r02)*(x2060)))+(((IkReal(-1.00000000000000))*(sj2)*(x2053)))+(((x2055)*(x2058)))+(((r12)*(x2059)))+(((IkReal(-1.00000000000000))*(x2061)*(x2063))));
evalcond[3]=((((IkReal(-1.00000000000000))*(x2055)*(x2061)))+(((r02)*(x2059)))+(((IkReal(-1.00000000000000))*(x2058)*(x2063)))+(x2054)+(((IkReal(-1.00000000000000))*(x2056)*(x2063)))+(((r12)*(x2060)))+(((IkReal(-1.00000000000000))*(x2055)*(x2067))));
evalcond[4]=((((IkReal(-1.00000000000000))*(r01)*(x2070)))+(((IkReal(-1.00000000000000))*(r12)*(x2057)*(x2063)))+(((r00)*(sj0)*(x2062)))+(((cj4)*(r02)*(x2055)))+(((IkReal(-1.00000000000000))*(r10)*(x2062)*(x2068)))+(((IkReal(-1.00000000000000))*(x2057)*(x2059)*(x2061)))+(((r11)*(x2069)))+(((cj4)*(x2058)*(x2060)))+(((IkReal(-1.00000000000000))*(x2057)*(x2059)*(x2067)))+(((cj4)*(x2056)*(x2060)))+(((sj2)*(x2054))));
evalcond[5]=((((IkReal(-1.00000000000000))*(x2057)*(x2058)*(x2059)))+(((IkReal(-1.00000000000000))*(x2057)*(x2060)*(x2061)))+(x2053)+(((IkReal(-1.00000000000000))*(r12)*(x2055)*(x2057)))+(((r01)*(x2069)))+(((IkReal(-1.00000000000000))*(r00)*(x2062)*(x2068)))+(((r11)*(x2070)))+(((IkReal(-1.00000000000000))*(r10)*(sj0)*(x2062)))+(((IkReal(-1.00000000000000))*(x2057)*(x2060)*(x2067)))+(((IkReal(-1.00000000000000))*(x2056)*(x2057)*(x2059)))+(((IkReal(-1.00000000000000))*(r02)*(x2057)*(x2063))));
if( IKabs(evalcond[0]) > 0.000001  || IKabs(evalcond[1]) > 0.000001  || IKabs(evalcond[2]) > 0.000001  || IKabs(evalcond[3]) > 0.000001  || IKabs(evalcond[4]) > 0.000001  || IKabs(evalcond[5]) > 0.000001  )
{
continue;
}
}

{
std::vector<IkSingleDOFSolutionBase<IkReal> > vinfos(7);
vinfos[0].jointtype = 1;
vinfos[0].foffset = j0;
vinfos[0].indices[0] = _ij0[0];
vinfos[0].indices[1] = _ij0[1];
vinfos[0].maxsolutions = _nj0;
vinfos[1].jointtype = 1;
vinfos[1].foffset = j1;
vinfos[1].indices[0] = _ij1[0];
vinfos[1].indices[1] = _ij1[1];
vinfos[1].maxsolutions = _nj1;
vinfos[2].jointtype = 1;
vinfos[2].foffset = j2;
vinfos[2].indices[0] = _ij2[0];
vinfos[2].indices[1] = _ij2[1];
vinfos[2].maxsolutions = _nj2;
vinfos[3].jointtype = 1;
vinfos[3].foffset = j3;
vinfos[3].indices[0] = _ij3[0];
vinfos[3].indices[1] = _ij3[1];
vinfos[3].maxsolutions = _nj3;
vinfos[4].jointtype = 1;
vinfos[4].foffset = j4;
vinfos[4].indices[0] = _ij4[0];
vinfos[4].indices[1] = _ij4[1];
vinfos[4].maxsolutions = _nj4;
vinfos[5].jointtype = 1;
vinfos[5].foffset = j5;
vinfos[5].indices[0] = _ij5[0];
vinfos[5].indices[1] = _ij5[1];
vinfos[5].maxsolutions = _nj5;
vinfos[6].jointtype = 1;
vinfos[6].foffset = j6;
vinfos[6].indices[0] = _ij6[0];
vinfos[6].indices[1] = _ij6[1];
vinfos[6].maxsolutions = _nj6;
std::vector<int> vfree(0);
solutions.AddSolution(vinfos,vfree);
}
}
}

}

}

} else
{
{
IkReal j3array[1], cj3array[1], sj3array[1];
bool j3valid[1]={false};
_nj3 = 1;
IkReal x2071=((cj6)*(sj5));
IkReal x2072=((IkReal(1.00000000000000))*(cj5));
IkReal x2073=((sj5)*(sj6));
if( IKabs(((((IKabs(cj2) != 0)?((IkReal)1/(cj2)):(IkReal)1.0e30))*(((((IkReal(-1.00000000000000))*(r21)*(x2071)))+(((IkReal(-1.00000000000000))*(r20)*(x2073)))+(((cj5)*(r22))))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(((((r11)*(sj0)*(x2071)))+(((IkReal(-1.00000000000000))*(r12)*(sj0)*(x2072)))+(((IkReal(-1.00000000000000))*(cj0)*(r02)*(x2072)))+(((cj0)*(r01)*(x2071)))+(((cj0)*(r00)*(x2073)))+(((r10)*(sj0)*(x2073))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(IKsqr(((((IKabs(cj2) != 0)?((IkReal)1/(cj2)):(IkReal)1.0e30))*(((((IkReal(-1.00000000000000))*(r21)*(x2071)))+(((IkReal(-1.00000000000000))*(r20)*(x2073)))+(((cj5)*(r22)))))))+IKsqr(((((r11)*(sj0)*(x2071)))+(((IkReal(-1.00000000000000))*(r12)*(sj0)*(x2072)))+(((IkReal(-1.00000000000000))*(cj0)*(r02)*(x2072)))+(((cj0)*(r01)*(x2071)))+(((cj0)*(r00)*(x2073)))+(((r10)*(sj0)*(x2073)))))-1) <= IKFAST_SINCOS_THRESH )
    continue;
j3array[0]=IKatan2(((((IKabs(cj2) != 0)?((IkReal)1/(cj2)):(IkReal)1.0e30))*(((((IkReal(-1.00000000000000))*(r21)*(x2071)))+(((IkReal(-1.00000000000000))*(r20)*(x2073)))+(((cj5)*(r22)))))), ((((r11)*(sj0)*(x2071)))+(((IkReal(-1.00000000000000))*(r12)*(sj0)*(x2072)))+(((IkReal(-1.00000000000000))*(cj0)*(r02)*(x2072)))+(((cj0)*(r01)*(x2071)))+(((cj0)*(r00)*(x2073)))+(((r10)*(sj0)*(x2073)))));
sj3array[0]=IKsin(j3array[0]);
cj3array[0]=IKcos(j3array[0]);
if( j3array[0] > IKPI )
{
    j3array[0]-=IK2PI;
}
else if( j3array[0] < -IKPI )
{    j3array[0]+=IK2PI;
}
j3valid[0] = true;
for(int ij3 = 0; ij3 < 1; ++ij3)
{
if( !j3valid[ij3] )
{
    continue;
}
_ij3[0] = ij3; _ij3[1] = -1;
for(int iij3 = ij3+1; iij3 < 1; ++iij3)
{
if( j3valid[iij3] && IKabs(cj3array[ij3]-cj3array[iij3]) < IKFAST_SOLUTION_THRESH && IKabs(sj3array[ij3]-sj3array[iij3]) < IKFAST_SOLUTION_THRESH )
{
    j3valid[iij3]=false; _ij3[1] = iij3; break; 
}
}
j3 = j3array[ij3]; cj3 = cj3array[ij3]; sj3 = sj3array[ij3];
{
IkReal evalcond[6];
IkReal x2074=IKsin(j3);
IkReal x2075=IKcos(j3);
IkReal x2076=((sj0)*(sj5));
IkReal x2077=((r00)*(sj6));
IkReal x2078=((IkReal(1.00000000000000))*(cj4));
IkReal x2079=((cj6)*(r01));
IkReal x2080=((cj0)*(cj5));
IkReal x2081=((cj5)*(sj0));
IkReal x2082=((cj6)*(r11));
IkReal x2083=((cj6)*(sj4));
IkReal x2084=((cj0)*(sj5));
IkReal x2085=((cj4)*(cj5));
IkReal x2086=((cj6)*(r21));
IkReal x2087=((r20)*(sj6));
IkReal x2088=((r10)*(sj6));
IkReal x2089=((IkReal(1.00000000000000))*(cj0));
IkReal x2090=((cj0)*(sj4)*(sj6));
IkReal x2091=((sj0)*(sj4)*(sj6));
evalcond[0]=((((sj5)*(x2087)))+(((cj2)*(x2074)))+(((sj5)*(x2086)))+(((IkReal(-1.00000000000000))*(cj5)*(r22))));
evalcond[1]=((((IkReal(-1.00000000000000))*(cj2)*(x2075)))+(((x2085)*(x2087)))+(((IkReal(-1.00000000000000))*(r21)*(sj4)*(sj6)))+(((cj4)*(r22)*(sj5)))+(((x2085)*(x2086)))+(((r20)*(x2083))));
evalcond[2]=((((IkReal(-1.00000000000000))*(x2084)*(x2088)))+(((IkReal(-1.00000000000000))*(sj2)*(x2074)))+(((x2076)*(x2079)))+(((IkReal(-1.00000000000000))*(x2082)*(x2084)))+(((x2076)*(x2077)))+(((r12)*(x2080)))+(((IkReal(-1.00000000000000))*(r02)*(x2081))));
evalcond[3]=((x2075)+(((IkReal(-1.00000000000000))*(x2076)*(x2082)))+(((r12)*(x2081)))+(((r02)*(x2080)))+(((IkReal(-1.00000000000000))*(x2077)*(x2084)))+(((IkReal(-1.00000000000000))*(x2076)*(x2088)))+(((IkReal(-1.00000000000000))*(x2079)*(x2084))));
evalcond[4]=((((IkReal(-1.00000000000000))*(r10)*(x2083)*(x2089)))+(((IkReal(-1.00000000000000))*(x2078)*(x2080)*(x2082)))+(((r00)*(sj0)*(x2083)))+(((IkReal(-1.00000000000000))*(r12)*(x2078)*(x2084)))+(((cj4)*(r02)*(x2076)))+(((r11)*(x2090)))+(((sj2)*(x2075)))+(((IkReal(-1.00000000000000))*(x2078)*(x2080)*(x2088)))+(((cj4)*(x2077)*(x2081)))+(((cj4)*(x2079)*(x2081)))+(((IkReal(-1.00000000000000))*(r01)*(x2091))));
evalcond[5]=((x2074)+(((r01)*(x2090)))+(((IkReal(-1.00000000000000))*(x2078)*(x2079)*(x2080)))+(((IkReal(-1.00000000000000))*(x2078)*(x2081)*(x2082)))+(((IkReal(-1.00000000000000))*(x2077)*(x2078)*(x2080)))+(((IkReal(-1.00000000000000))*(r12)*(x2076)*(x2078)))+(((IkReal(-1.00000000000000))*(r10)*(sj0)*(x2083)))+(((r11)*(x2091)))+(((IkReal(-1.00000000000000))*(r00)*(x2083)*(x2089)))+(((IkReal(-1.00000000000000))*(r02)*(x2078)*(x2084)))+(((IkReal(-1.00000000000000))*(x2078)*(x2081)*(x2088))));
if( IKabs(evalcond[0]) > 0.000001  || IKabs(evalcond[1]) > 0.000001  || IKabs(evalcond[2]) > 0.000001  || IKabs(evalcond[3]) > 0.000001  || IKabs(evalcond[4]) > 0.000001  || IKabs(evalcond[5]) > 0.000001  )
{
continue;
}
}

{
std::vector<IkSingleDOFSolutionBase<IkReal> > vinfos(7);
vinfos[0].jointtype = 1;
vinfos[0].foffset = j0;
vinfos[0].indices[0] = _ij0[0];
vinfos[0].indices[1] = _ij0[1];
vinfos[0].maxsolutions = _nj0;
vinfos[1].jointtype = 1;
vinfos[1].foffset = j1;
vinfos[1].indices[0] = _ij1[0];
vinfos[1].indices[1] = _ij1[1];
vinfos[1].maxsolutions = _nj1;
vinfos[2].jointtype = 1;
vinfos[2].foffset = j2;
vinfos[2].indices[0] = _ij2[0];
vinfos[2].indices[1] = _ij2[1];
vinfos[2].maxsolutions = _nj2;
vinfos[3].jointtype = 1;
vinfos[3].foffset = j3;
vinfos[3].indices[0] = _ij3[0];
vinfos[3].indices[1] = _ij3[1];
vinfos[3].maxsolutions = _nj3;
vinfos[4].jointtype = 1;
vinfos[4].foffset = j4;
vinfos[4].indices[0] = _ij4[0];
vinfos[4].indices[1] = _ij4[1];
vinfos[4].maxsolutions = _nj4;
vinfos[5].jointtype = 1;
vinfos[5].foffset = j5;
vinfos[5].indices[0] = _ij5[0];
vinfos[5].indices[1] = _ij5[1];
vinfos[5].maxsolutions = _nj5;
vinfos[6].jointtype = 1;
vinfos[6].foffset = j6;
vinfos[6].indices[0] = _ij6[0];
vinfos[6].indices[1] = _ij6[1];
vinfos[6].maxsolutions = _nj6;
std::vector<int> vfree(0);
solutions.AddSolution(vinfos,vfree);
}
}
}

}

}

} else
{
{
IkReal j3array[1], cj3array[1], sj3array[1];
bool j3valid[1]={false};
_nj3 = 1;
IkReal x2092=((IkReal(1.00000000000000))*(r21));
IkReal x2093=((cj4)*(cj5));
IkReal x2094=((r20)*(sj6));
if( IKabs(((gconst56)*(((((IkReal(-1.00000000000000))*(cj6)*(sj5)*(x2092)))+(((IkReal(-1.00000000000000))*(sj5)*(x2094)))+(((cj5)*(r22))))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(((gconst56)*(((((x2093)*(x2094)))+(((IkReal(-1.00000000000000))*(sj4)*(sj6)*(x2092)))+(((cj6)*(r20)*(sj4)))+(((cj4)*(r22)*(sj5)))+(((cj6)*(r21)*(x2093))))))) < IKFAST_ATAN2_MAGTHRESH )
    continue;
j3array[0]=IKatan2(((gconst56)*(((((IkReal(-1.00000000000000))*(cj6)*(sj5)*(x2092)))+(((IkReal(-1.00000000000000))*(sj5)*(x2094)))+(((cj5)*(r22)))))), ((gconst56)*(((((x2093)*(x2094)))+(((IkReal(-1.00000000000000))*(sj4)*(sj6)*(x2092)))+(((cj6)*(r20)*(sj4)))+(((cj4)*(r22)*(sj5)))+(((cj6)*(r21)*(x2093)))))));
sj3array[0]=IKsin(j3array[0]);
cj3array[0]=IKcos(j3array[0]);
if( j3array[0] > IKPI )
{
    j3array[0]-=IK2PI;
}
else if( j3array[0] < -IKPI )
{    j3array[0]+=IK2PI;
}
j3valid[0] = true;
for(int ij3 = 0; ij3 < 1; ++ij3)
{
if( !j3valid[ij3] )
{
    continue;
}
_ij3[0] = ij3; _ij3[1] = -1;
for(int iij3 = ij3+1; iij3 < 1; ++iij3)
{
if( j3valid[iij3] && IKabs(cj3array[ij3]-cj3array[iij3]) < IKFAST_SOLUTION_THRESH && IKabs(sj3array[ij3]-sj3array[iij3]) < IKFAST_SOLUTION_THRESH )
{
    j3valid[iij3]=false; _ij3[1] = iij3; break; 
}
}
j3 = j3array[ij3]; cj3 = cj3array[ij3]; sj3 = sj3array[ij3];
{
IkReal evalcond[6];
IkReal x2095=IKsin(j3);
IkReal x2096=IKcos(j3);
IkReal x2097=((sj0)*(sj5));
IkReal x2098=((r00)*(sj6));
IkReal x2099=((IkReal(1.00000000000000))*(cj4));
IkReal x2100=((cj6)*(r01));
IkReal x2101=((cj0)*(cj5));
IkReal x2102=((cj5)*(sj0));
IkReal x2103=((cj6)*(r11));
IkReal x2104=((cj6)*(sj4));
IkReal x2105=((cj0)*(sj5));
IkReal x2106=((cj4)*(cj5));
IkReal x2107=((cj6)*(r21));
IkReal x2108=((r20)*(sj6));
IkReal x2109=((r10)*(sj6));
IkReal x2110=((IkReal(1.00000000000000))*(cj0));
IkReal x2111=((cj0)*(sj4)*(sj6));
IkReal x2112=((sj0)*(sj4)*(sj6));
evalcond[0]=((((sj5)*(x2108)))+(((IkReal(-1.00000000000000))*(cj5)*(r22)))+(((cj2)*(x2095)))+(((sj5)*(x2107))));
evalcond[1]=((((IkReal(-1.00000000000000))*(cj2)*(x2096)))+(((IkReal(-1.00000000000000))*(r21)*(sj4)*(sj6)))+(((x2106)*(x2108)))+(((cj4)*(r22)*(sj5)))+(((x2106)*(x2107)))+(((r20)*(x2104))));
evalcond[2]=((((IkReal(-1.00000000000000))*(sj2)*(x2095)))+(((IkReal(-1.00000000000000))*(x2103)*(x2105)))+(((IkReal(-1.00000000000000))*(x2105)*(x2109)))+(((x2097)*(x2098)))+(((r12)*(x2101)))+(((x2097)*(x2100)))+(((IkReal(-1.00000000000000))*(r02)*(x2102))));
evalcond[3]=((x2096)+(((IkReal(-1.00000000000000))*(x2098)*(x2105)))+(((IkReal(-1.00000000000000))*(x2100)*(x2105)))+(((r12)*(x2102)))+(((r02)*(x2101)))+(((IkReal(-1.00000000000000))*(x2097)*(x2103)))+(((IkReal(-1.00000000000000))*(x2097)*(x2109))));
evalcond[4]=((((IkReal(-1.00000000000000))*(x2099)*(x2101)*(x2103)))+(((IkReal(-1.00000000000000))*(r10)*(x2104)*(x2110)))+(((sj2)*(x2096)))+(((cj4)*(r02)*(x2097)))+(((cj4)*(x2100)*(x2102)))+(((cj4)*(x2098)*(x2102)))+(((IkReal(-1.00000000000000))*(r12)*(x2099)*(x2105)))+(((IkReal(-1.00000000000000))*(x2099)*(x2101)*(x2109)))+(((IkReal(-1.00000000000000))*(r01)*(x2112)))+(((r11)*(x2111)))+(((r00)*(sj0)*(x2104))));
evalcond[5]=((((IkReal(-1.00000000000000))*(x2099)*(x2100)*(x2101)))+(((IkReal(-1.00000000000000))*(r00)*(x2104)*(x2110)))+(((r01)*(x2111)))+(((IkReal(-1.00000000000000))*(x2098)*(x2099)*(x2101)))+(x2095)+(((r11)*(x2112)))+(((IkReal(-1.00000000000000))*(r12)*(x2097)*(x2099)))+(((IkReal(-1.00000000000000))*(r02)*(x2099)*(x2105)))+(((IkReal(-1.00000000000000))*(r10)*(sj0)*(x2104)))+(((IkReal(-1.00000000000000))*(x2099)*(x2102)*(x2109)))+(((IkReal(-1.00000000000000))*(x2099)*(x2102)*(x2103))));
if( IKabs(evalcond[0]) > 0.000001  || IKabs(evalcond[1]) > 0.000001  || IKabs(evalcond[2]) > 0.000001  || IKabs(evalcond[3]) > 0.000001  || IKabs(evalcond[4]) > 0.000001  || IKabs(evalcond[5]) > 0.000001  )
{
continue;
}
}

{
std::vector<IkSingleDOFSolutionBase<IkReal> > vinfos(7);
vinfos[0].jointtype = 1;
vinfos[0].foffset = j0;
vinfos[0].indices[0] = _ij0[0];
vinfos[0].indices[1] = _ij0[1];
vinfos[0].maxsolutions = _nj0;
vinfos[1].jointtype = 1;
vinfos[1].foffset = j1;
vinfos[1].indices[0] = _ij1[0];
vinfos[1].indices[1] = _ij1[1];
vinfos[1].maxsolutions = _nj1;
vinfos[2].jointtype = 1;
vinfos[2].foffset = j2;
vinfos[2].indices[0] = _ij2[0];
vinfos[2].indices[1] = _ij2[1];
vinfos[2].maxsolutions = _nj2;
vinfos[3].jointtype = 1;
vinfos[3].foffset = j3;
vinfos[3].indices[0] = _ij3[0];
vinfos[3].indices[1] = _ij3[1];
vinfos[3].maxsolutions = _nj3;
vinfos[4].jointtype = 1;
vinfos[4].foffset = j4;
vinfos[4].indices[0] = _ij4[0];
vinfos[4].indices[1] = _ij4[1];
vinfos[4].maxsolutions = _nj4;
vinfos[5].jointtype = 1;
vinfos[5].foffset = j5;
vinfos[5].indices[0] = _ij5[0];
vinfos[5].indices[1] = _ij5[1];
vinfos[5].maxsolutions = _nj5;
vinfos[6].jointtype = 1;
vinfos[6].foffset = j6;
vinfos[6].indices[0] = _ij6[0];
vinfos[6].indices[1] = _ij6[1];
vinfos[6].maxsolutions = _nj6;
std::vector<int> vfree(0);
solutions.AddSolution(vinfos,vfree);
}
}
}

}

}
}
}

}

}

} else
{
{
IkReal j4array[1], cj4array[1], sj4array[1];
bool j4valid[1]={false};
_nj4 = 1;
IkReal x2113=((r11)*(sj0));
IkReal x2114=((cj0)*(r01));
IkReal x2115=((cj0)*(sj2));
IkReal x2116=((sj0)*(sj2));
IkReal x2117=((cj5)*(sj6));
IkReal x2118=((IkReal(1.00000000000000))*(sj2)*(sj6));
IkReal x2119=((cj5)*(cj6)*(sj2));
if( IKabs(((gconst53)*(((((cj6)*(r00)*(x2115)))+(((IkReal(-1.00000000000000))*(x2114)*(x2118)))+(((cj6)*(r10)*(x2116)))+(((IkReal(-1.00000000000000))*(x2113)*(x2118))))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(((gconst53)*(((((x2114)*(x2119)))+(((r02)*(sj5)*(x2115)))+(((r00)*(x2115)*(x2117)))+(((r10)*(x2116)*(x2117)))+(((x2113)*(x2119)))+(((r12)*(sj5)*(x2116))))))) < IKFAST_ATAN2_MAGTHRESH )
    continue;
j4array[0]=IKatan2(((gconst53)*(((((cj6)*(r00)*(x2115)))+(((IkReal(-1.00000000000000))*(x2114)*(x2118)))+(((cj6)*(r10)*(x2116)))+(((IkReal(-1.00000000000000))*(x2113)*(x2118)))))), ((gconst53)*(((((x2114)*(x2119)))+(((r02)*(sj5)*(x2115)))+(((r00)*(x2115)*(x2117)))+(((r10)*(x2116)*(x2117)))+(((x2113)*(x2119)))+(((r12)*(sj5)*(x2116)))))));
sj4array[0]=IKsin(j4array[0]);
cj4array[0]=IKcos(j4array[0]);
if( j4array[0] > IKPI )
{
    j4array[0]-=IK2PI;
}
else if( j4array[0] < -IKPI )
{    j4array[0]+=IK2PI;
}
j4valid[0] = true;
for(int ij4 = 0; ij4 < 1; ++ij4)
{
if( !j4valid[ij4] )
{
    continue;
}
_ij4[0] = ij4; _ij4[1] = -1;
for(int iij4 = ij4+1; iij4 < 1; ++iij4)
{
if( j4valid[iij4] && IKabs(cj4array[ij4]-cj4array[iij4]) < IKFAST_SOLUTION_THRESH && IKabs(sj4array[ij4]-sj4array[iij4]) < IKFAST_SOLUTION_THRESH )
{
    j4valid[iij4]=false; _ij4[1] = iij4; break; 
}
}
j4 = j4array[ij4]; cj4 = cj4array[ij4]; sj4 = sj4array[ij4];
{
IkReal evalcond[3];
IkReal x2120=IKsin(j4);
IkReal x2121=IKcos(j4);
IkReal x2122=((r00)*(sj6));
IkReal x2123=((cj6)*(r01));
IkReal x2124=((IkReal(1.00000000000000))*(cj0));
IkReal x2125=((IkReal(1.00000000000000))*(sj0));
IkReal x2126=((r10)*(sj6));
IkReal x2127=((sj5)*(x2120));
IkReal x2128=((IkReal(1.00000000000000))*(cj6)*(r11));
IkReal x2129=((cj5)*(x2120));
IkReal x2130=((cj6)*(x2121));
IkReal x2131=((sj0)*(x2129));
IkReal x2132=((r01)*(sj6)*(x2121));
IkReal x2133=((r11)*(sj6)*(x2121));
evalcond[0]=((sj2)+(((cj6)*(r21)*(x2129)))+(((IkReal(-1.00000000000000))*(r20)*(x2130)))+(((r21)*(sj6)*(x2121)))+(((r20)*(sj6)*(x2129)))+(((r22)*(x2127))));
evalcond[1]=((((sj0)*(x2132)))+(((x2123)*(x2131)))+(((IkReal(-1.00000000000000))*(r12)*(x2124)*(x2127)))+(((IkReal(-1.00000000000000))*(cj6)*(r11)*(x2124)*(x2129)))+(((IkReal(-1.00000000000000))*(r00)*(x2125)*(x2130)))+(((IkReal(-1.00000000000000))*(x2124)*(x2126)*(x2129)))+(((cj0)*(r10)*(x2130)))+(cj2)+(((r02)*(sj0)*(x2127)))+(((IkReal(-1.00000000000000))*(x2124)*(x2133)))+(((x2122)*(x2131))));
evalcond[2]=((((IkReal(-1.00000000000000))*(x2125)*(x2133)))+(((IkReal(-1.00000000000000))*(x2125)*(x2126)*(x2129)))+(((IkReal(-1.00000000000000))*(cj6)*(r11)*(x2125)*(x2129)))+(((IkReal(-1.00000000000000))*(x2123)*(x2124)*(x2129)))+(((IkReal(-1.00000000000000))*(x2124)*(x2132)))+(((IkReal(-1.00000000000000))*(r12)*(x2125)*(x2127)))+(((IkReal(-1.00000000000000))*(r02)*(x2124)*(x2127)))+(((IkReal(-1.00000000000000))*(x2122)*(x2124)*(x2129)))+(((r10)*(sj0)*(x2130)))+(((cj0)*(r00)*(x2130))));
if( IKabs(evalcond[0]) > 0.000001  || IKabs(evalcond[1]) > 0.000001  || IKabs(evalcond[2]) > 0.000001  )
{
continue;
}
}

{
IkReal dummyeval[1];
IkReal gconst56;
gconst56=IKsign(cj2);
dummyeval[0]=cj2;
if( IKabs(dummyeval[0]) < 0.0000010000000000  )
{
{
IkReal dummyeval[1];
dummyeval[0]=cj2;
if( IKabs(dummyeval[0]) < 0.0000010000000000  )
{
{
IkReal dummyeval[1];
dummyeval[0]=sj2;
if( IKabs(dummyeval[0]) < 0.0000010000000000  )
{
{
IkReal evalcond[9];
IkReal x2134=((cj5)*(sj4));
IkReal x2135=((IkReal(1.00000000000000))*(sj6));
IkReal x2136=((r10)*(sj0));
IkReal x2137=((sj4)*(sj5));
IkReal x2138=((cj5)*(cj6));
IkReal x2139=((r01)*(sj0));
IkReal x2140=((IkReal(1.00000000000000))*(r02));
IkReal x2141=((IkReal(0.374290000000000))*(cj0));
IkReal x2142=((cj5)*(r12));
IkReal x2143=((cj6)*(sj5));
IkReal x2144=((cj0)*(r11));
IkReal x2145=((cj5)*(sj0));
IkReal x2146=((r20)*(sj6));
IkReal x2147=((IkReal(1.00000000000000))*(sj0));
IkReal x2148=((cj4)*(cj5));
IkReal x2149=((IkReal(1.00000000000000))*(cj6));
IkReal x2150=((IkReal(0.0100000000000000))*(sj5));
IkReal x2151=((sj5)*(sj6));
IkReal x2152=((cj0)*(r10));
IkReal x2153=((cj4)*(cj6));
IkReal x2154=((cj0)*(r01));
IkReal x2155=((IkReal(1.00000000000000))*(cj4));
IkReal x2156=((cj0)*(r00));
IkReal x2157=((IkReal(0.374290000000000))*(sj0));
IkReal x2158=((cj0)*(r12));
IkReal x2159=((IkReal(0.374290000000000))*(sj5));
IkReal x2160=((cj4)*(sj6));
IkReal x2161=((IkReal(1.00000000000000))*(cj0));
IkReal x2162=((r02)*(sj0));
IkReal x2163=((IkReal(0.0100000000000000))*(cj5));
IkReal x2164=((r11)*(sj0));
IkReal x2165=((r00)*(sj0)*(sj6));
IkReal x2166=((r00)*(x2153));
IkReal x2167=((sj6)*(x2163));
evalcond[0]=((IkReal(-3.14159265358979))+(IKfmod(((IkReal(3.14159265358979))+(j2)), IkReal(6.28318530717959))));
evalcond[1]=((((r22)*(x2137)))+(((x2134)*(x2146)))+(((cj6)*(r21)*(x2134)))+(((r21)*(x2160)))+(((IkReal(-1.00000000000000))*(cj4)*(r20)*(x2149))));
evalcond[2]=((IkReal(-0.0690000000000000))+(((IkReal(-0.374290000000000))*(cj5)*(r22)))+(((IkReal(0.374290000000000))*(r21)*(x2143)))+(pz)+(((IkReal(-1.00000000000000))*(r22)*(x2150)))+(((x2146)*(x2159)))+(((IkReal(-1.00000000000000))*(x2146)*(x2163)))+(((IkReal(-0.0100000000000000))*(r21)*(x2138))));
evalcond[3]=((((IkReal(-1.00000000000000))*(x2143)*(x2144)))+(((r00)*(sj0)*(x2151)))+(((IkReal(-1.00000000000000))*(x2140)*(x2145)))+(((x2139)*(x2143)))+(((cj0)*(x2142)))+(((IkReal(-1.00000000000000))*(sj5)*(x2135)*(x2152))));
evalcond[4]=((IkReal(1.00000000000000))+(((IkReal(-1.00000000000000))*(x2147)*(x2166)))+(((IkReal(-1.00000000000000))*(cj4)*(x2135)*(x2144)))+(((IkReal(-1.00000000000000))*(x2134)*(x2144)*(x2149)))+(((IkReal(-1.00000000000000))*(x2137)*(x2158)))+(((x2139)*(x2160)))+(((cj6)*(x2134)*(x2139)))+(((x2134)*(x2165)))+(((x2152)*(x2153)))+(((x2137)*(x2162)))+(((IkReal(-1.00000000000000))*(x2134)*(x2135)*(x2152))));
evalcond[5]=((((IkReal(-1.00000000000000))*(sj4)*(x2135)*(x2139)))+(((sj4)*(sj6)*(x2144)))+(((cj4)*(sj5)*(x2162)))+(((cj6)*(r00)*(sj0)*(sj4)))+(((IkReal(-1.00000000000000))*(x2135)*(x2148)*(x2152)))+(((IkReal(-1.00000000000000))*(sj4)*(x2149)*(x2152)))+(((IkReal(-1.00000000000000))*(x2138)*(x2144)*(x2155)))+(((cj4)*(x2138)*(x2139)))+(((r00)*(x2145)*(x2160)))+(((IkReal(-1.00000000000000))*(sj5)*(x2155)*(x2158))));
evalcond[6]=((((IkReal(-1.00000000000000))*(x2134)*(x2135)*(x2136)))+(((IkReal(-1.00000000000000))*(r12)*(x2137)*(x2147)))+(((IkReal(-1.00000000000000))*(cj6)*(r11)*(x2134)*(x2147)))+(((x2136)*(x2153)))+(((x2153)*(x2156)))+(((IkReal(-1.00000000000000))*(cj4)*(x2135)*(x2154)))+(((IkReal(-1.00000000000000))*(x2134)*(x2135)*(x2156)))+(((IkReal(-1.00000000000000))*(cj0)*(x2137)*(x2140)))+(((IkReal(-1.00000000000000))*(x2134)*(x2149)*(x2154)))+(((IkReal(-1.00000000000000))*(cj4)*(x2135)*(x2164))));
evalcond[7]=((((IkReal(-1.00000000000000))*(r11)*(x2141)*(x2143)))+(((IkReal(-0.374290000000000))*(r02)*(x2145)))+(((IkReal(0.374290000000000))*(x2139)*(x2143)))+(((x2152)*(x2167)))+(((IkReal(0.0100000000000000))*(x2138)*(x2144)))+(((x2150)*(x2158)))+(((IkReal(-1.00000000000000))*(py)*(x2161)))+(((IkReal(-1.00000000000000))*(r10)*(x2141)*(x2151)))+(((IkReal(-0.0100000000000000))*(x2138)*(x2139)))+(((x2141)*(x2142)))+(((px)*(sj0)))+(((r00)*(x2151)*(x2157)))+(((IkReal(-0.0100000000000000))*(r00)*(sj6)*(x2145)))+(((IkReal(-1.00000000000000))*(x2150)*(x2162))));
evalcond[8]=((IkReal(-0.295420000000000))+(((x2136)*(x2167)))+(((cj5)*(r02)*(x2141)))+(((IkReal(-1.00000000000000))*(py)*(x2147)))+(((IkReal(0.0100000000000000))*(x2138)*(x2164)))+(((r12)*(sj0)*(x2150)))+(((IkReal(0.0100000000000000))*(x2138)*(x2154)))+(((IkReal(-1.00000000000000))*(r01)*(x2141)*(x2143)))+(((x2142)*(x2157)))+(((IkReal(-1.00000000000000))*(r00)*(x2141)*(x2151)))+(((IkReal(-1.00000000000000))*(r11)*(x2143)*(x2157)))+(((IkReal(-0.374290000000000))*(x2136)*(x2151)))+(((cj0)*(r02)*(x2150)))+(((x2156)*(x2167)))+(((IkReal(-1.00000000000000))*(px)*(x2161))));
if( IKabs(evalcond[0]) < 0.0000010000000000  && IKabs(evalcond[1]) < 0.0000010000000000  && IKabs(evalcond[2]) < 0.0000010000000000  && IKabs(evalcond[3]) < 0.0000010000000000  && IKabs(evalcond[4]) < 0.0000010000000000  && IKabs(evalcond[5]) < 0.0000010000000000  && IKabs(evalcond[6]) < 0.0000010000000000  && IKabs(evalcond[7]) < 0.0000010000000000  && IKabs(evalcond[8]) < 0.0000010000000000  )
{
{
IkReal j3array[1], cj3array[1], sj3array[1];
bool j3valid[1]={false};
_nj3 = 1;
IkReal x2168=((IkReal(1.00000000000000))*(r21));
IkReal x2169=((cj4)*(cj5));
IkReal x2170=((r20)*(sj6));
if( IKabs(((((IkReal(-1.00000000000000))*(sj5)*(x2170)))+(((cj5)*(r22)))+(((IkReal(-1.00000000000000))*(cj6)*(sj5)*(x2168))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(((((cj6)*(r20)*(sj4)))+(((IkReal(-1.00000000000000))*(sj4)*(sj6)*(x2168)))+(((cj4)*(r22)*(sj5)))+(((x2169)*(x2170)))+(((cj6)*(r21)*(x2169))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(IKsqr(((((IkReal(-1.00000000000000))*(sj5)*(x2170)))+(((cj5)*(r22)))+(((IkReal(-1.00000000000000))*(cj6)*(sj5)*(x2168)))))+IKsqr(((((cj6)*(r20)*(sj4)))+(((IkReal(-1.00000000000000))*(sj4)*(sj6)*(x2168)))+(((cj4)*(r22)*(sj5)))+(((x2169)*(x2170)))+(((cj6)*(r21)*(x2169)))))-1) <= IKFAST_SINCOS_THRESH )
    continue;
j3array[0]=IKatan2(((((IkReal(-1.00000000000000))*(sj5)*(x2170)))+(((cj5)*(r22)))+(((IkReal(-1.00000000000000))*(cj6)*(sj5)*(x2168)))), ((((cj6)*(r20)*(sj4)))+(((IkReal(-1.00000000000000))*(sj4)*(sj6)*(x2168)))+(((cj4)*(r22)*(sj5)))+(((x2169)*(x2170)))+(((cj6)*(r21)*(x2169)))));
sj3array[0]=IKsin(j3array[0]);
cj3array[0]=IKcos(j3array[0]);
if( j3array[0] > IKPI )
{
    j3array[0]-=IK2PI;
}
else if( j3array[0] < -IKPI )
{    j3array[0]+=IK2PI;
}
j3valid[0] = true;
for(int ij3 = 0; ij3 < 1; ++ij3)
{
if( !j3valid[ij3] )
{
    continue;
}
_ij3[0] = ij3; _ij3[1] = -1;
for(int iij3 = ij3+1; iij3 < 1; ++iij3)
{
if( j3valid[iij3] && IKabs(cj3array[ij3]-cj3array[iij3]) < IKFAST_SOLUTION_THRESH && IKabs(sj3array[ij3]-sj3array[iij3]) < IKFAST_SOLUTION_THRESH )
{
    j3valid[iij3]=false; _ij3[1] = iij3; break; 
}
}
j3 = j3array[ij3]; cj3 = cj3array[ij3]; sj3 = sj3array[ij3];
{
IkReal evalcond[4];
IkReal x2171=IKcos(j3);
IkReal x2172=IKsin(j3);
IkReal x2173=((IkReal(1.00000000000000))*(cj4));
IkReal x2174=((sj0)*(sj5));
IkReal x2175=((cj0)*(cj5));
IkReal x2176=((cj6)*(r01));
IkReal x2177=((r00)*(sj6));
IkReal x2178=((cj6)*(r11));
IkReal x2179=((cj5)*(sj0));
IkReal x2180=((cj6)*(sj4));
IkReal x2181=((sj4)*(sj6));
IkReal x2182=((cj4)*(cj5));
IkReal x2183=((cj6)*(r21));
IkReal x2184=((r20)*(sj6));
IkReal x2185=((r10)*(sj6));
IkReal x2186=((IkReal(1.00000000000000))*(cj0)*(sj5));
evalcond[0]=((x2172)+(((IkReal(-1.00000000000000))*(cj5)*(r22)))+(((sj5)*(x2184)))+(((sj5)*(x2183))));
evalcond[1]=((((IkReal(-1.00000000000000))*(r21)*(x2181)))+(((cj4)*(r22)*(sj5)))+(((IkReal(-1.00000000000000))*(x2171)))+(((x2182)*(x2183)))+(((x2182)*(x2184)))+(((r20)*(x2180))));
evalcond[2]=((x2171)+(((IkReal(-1.00000000000000))*(x2176)*(x2186)))+(((r02)*(x2175)))+(((IkReal(-1.00000000000000))*(x2174)*(x2185)))+(((IkReal(-1.00000000000000))*(x2174)*(x2178)))+(((r12)*(x2179)))+(((IkReal(-1.00000000000000))*(x2177)*(x2186))));
evalcond[3]=((((cj0)*(r01)*(x2181)))+(x2172)+(((r11)*(sj0)*(x2181)))+(((IkReal(-1.00000000000000))*(x2173)*(x2179)*(x2185)))+(((IkReal(-1.00000000000000))*(x2173)*(x2175)*(x2177)))+(((IkReal(-1.00000000000000))*(cj0)*(r00)*(x2180)))+(((IkReal(-1.00000000000000))*(x2173)*(x2178)*(x2179)))+(((IkReal(-1.00000000000000))*(cj0)*(r02)*(sj5)*(x2173)))+(((IkReal(-1.00000000000000))*(r12)*(x2173)*(x2174)))+(((IkReal(-1.00000000000000))*(r10)*(sj0)*(x2180)))+(((IkReal(-1.00000000000000))*(x2173)*(x2175)*(x2176))));
if( IKabs(evalcond[0]) > 0.000001  || IKabs(evalcond[1]) > 0.000001  || IKabs(evalcond[2]) > 0.000001  || IKabs(evalcond[3]) > 0.000001  )
{
continue;
}
}

{
std::vector<IkSingleDOFSolutionBase<IkReal> > vinfos(7);
vinfos[0].jointtype = 1;
vinfos[0].foffset = j0;
vinfos[0].indices[0] = _ij0[0];
vinfos[0].indices[1] = _ij0[1];
vinfos[0].maxsolutions = _nj0;
vinfos[1].jointtype = 1;
vinfos[1].foffset = j1;
vinfos[1].indices[0] = _ij1[0];
vinfos[1].indices[1] = _ij1[1];
vinfos[1].maxsolutions = _nj1;
vinfos[2].jointtype = 1;
vinfos[2].foffset = j2;
vinfos[2].indices[0] = _ij2[0];
vinfos[2].indices[1] = _ij2[1];
vinfos[2].maxsolutions = _nj2;
vinfos[3].jointtype = 1;
vinfos[3].foffset = j3;
vinfos[3].indices[0] = _ij3[0];
vinfos[3].indices[1] = _ij3[1];
vinfos[3].maxsolutions = _nj3;
vinfos[4].jointtype = 1;
vinfos[4].foffset = j4;
vinfos[4].indices[0] = _ij4[0];
vinfos[4].indices[1] = _ij4[1];
vinfos[4].maxsolutions = _nj4;
vinfos[5].jointtype = 1;
vinfos[5].foffset = j5;
vinfos[5].indices[0] = _ij5[0];
vinfos[5].indices[1] = _ij5[1];
vinfos[5].maxsolutions = _nj5;
vinfos[6].jointtype = 1;
vinfos[6].foffset = j6;
vinfos[6].indices[0] = _ij6[0];
vinfos[6].indices[1] = _ij6[1];
vinfos[6].maxsolutions = _nj6;
std::vector<int> vfree(0);
solutions.AddSolution(vinfos,vfree);
}
}
}

} else
{
IkReal x2187=((cj5)*(sj4));
IkReal x2188=((IkReal(1.00000000000000))*(sj6));
IkReal x2189=((r10)*(sj0));
IkReal x2190=((sj4)*(sj5));
IkReal x2191=((cj5)*(cj6));
IkReal x2192=((r01)*(sj0));
IkReal x2193=((IkReal(1.00000000000000))*(r02));
IkReal x2194=((IkReal(0.374290000000000))*(cj0));
IkReal x2195=((cj5)*(r12));
IkReal x2196=((cj6)*(sj5));
IkReal x2197=((cj0)*(r11));
IkReal x2198=((cj5)*(sj0));
IkReal x2199=((r20)*(sj6));
IkReal x2200=((IkReal(1.00000000000000))*(sj0));
IkReal x2201=((cj4)*(cj5));
IkReal x2202=((IkReal(1.00000000000000))*(cj6));
IkReal x2203=((IkReal(0.0100000000000000))*(sj5));
IkReal x2204=((sj5)*(sj6));
IkReal x2205=((cj0)*(r10));
IkReal x2206=((cj4)*(cj6));
IkReal x2207=((cj0)*(r01));
IkReal x2208=((IkReal(1.00000000000000))*(cj4));
IkReal x2209=((cj0)*(r00));
IkReal x2210=((IkReal(0.374290000000000))*(sj0));
IkReal x2211=((cj0)*(r12));
IkReal x2212=((IkReal(0.374290000000000))*(sj5));
IkReal x2213=((cj4)*(sj6));
IkReal x2214=((IkReal(1.00000000000000))*(cj0));
IkReal x2215=((r02)*(sj0));
IkReal x2216=((IkReal(0.0100000000000000))*(cj5));
IkReal x2217=((r11)*(sj0));
IkReal x2218=((r00)*(sj0)*(sj6));
IkReal x2219=((r00)*(x2206));
IkReal x2220=((sj6)*(x2216));
evalcond[0]=((IkReal(-3.14159265358979))+(IKfmod(j2, IkReal(6.28318530717959))));
evalcond[1]=((((r22)*(x2190)))+(((r21)*(x2213)))+(((IkReal(-1.00000000000000))*(cj4)*(r20)*(x2202)))+(((x2187)*(x2199)))+(((cj6)*(r21)*(x2187))));
evalcond[2]=((IkReal(0.0690000000000000))+(((IkReal(-1.00000000000000))*(r22)*(x2203)))+(((IkReal(-0.374290000000000))*(cj5)*(r22)))+(((IkReal(-0.0100000000000000))*(r21)*(x2191)))+(((IkReal(0.374290000000000))*(r21)*(x2196)))+(((IkReal(-1.00000000000000))*(x2199)*(x2216)))+(((x2199)*(x2212)))+(pz));
evalcond[3]=((((cj0)*(x2195)))+(((IkReal(-1.00000000000000))*(x2196)*(x2197)))+(((r00)*(sj0)*(x2204)))+(((x2192)*(x2196)))+(((IkReal(-1.00000000000000))*(x2193)*(x2198)))+(((IkReal(-1.00000000000000))*(sj5)*(x2188)*(x2205))));
evalcond[4]=((IkReal(-1.00000000000000))+(((x2192)*(x2213)))+(((IkReal(-1.00000000000000))*(x2187)*(x2197)*(x2202)))+(((IkReal(-1.00000000000000))*(x2190)*(x2211)))+(((IkReal(-1.00000000000000))*(x2200)*(x2219)))+(((x2187)*(x2218)))+(((IkReal(-1.00000000000000))*(cj4)*(x2188)*(x2197)))+(((x2190)*(x2215)))+(((IkReal(-1.00000000000000))*(x2187)*(x2188)*(x2205)))+(((cj6)*(x2187)*(x2192)))+(((x2205)*(x2206))));
evalcond[5]=((((IkReal(-1.00000000000000))*(sj4)*(x2202)*(x2205)))+(((IkReal(-1.00000000000000))*(x2191)*(x2197)*(x2208)))+(((sj4)*(sj6)*(x2197)))+(((cj6)*(r00)*(sj0)*(sj4)))+(((IkReal(-1.00000000000000))*(sj4)*(x2188)*(x2192)))+(((cj4)*(x2191)*(x2192)))+(((cj4)*(sj5)*(x2215)))+(((r00)*(x2198)*(x2213)))+(((IkReal(-1.00000000000000))*(x2188)*(x2201)*(x2205)))+(((IkReal(-1.00000000000000))*(sj5)*(x2208)*(x2211))));
evalcond[6]=((((x2189)*(x2206)))+(((IkReal(-1.00000000000000))*(cj4)*(x2188)*(x2217)))+(((IkReal(-1.00000000000000))*(cj0)*(x2190)*(x2193)))+(((IkReal(-1.00000000000000))*(cj6)*(r11)*(x2187)*(x2200)))+(((x2206)*(x2209)))+(((IkReal(-1.00000000000000))*(cj4)*(x2188)*(x2207)))+(((IkReal(-1.00000000000000))*(x2187)*(x2202)*(x2207)))+(((IkReal(-1.00000000000000))*(x2187)*(x2188)*(x2209)))+(((IkReal(-1.00000000000000))*(r12)*(x2190)*(x2200)))+(((IkReal(-1.00000000000000))*(x2187)*(x2188)*(x2189))));
evalcond[7]=((((x2205)*(x2220)))+(((IkReal(-0.374290000000000))*(r02)*(x2198)))+(((IkReal(-0.0100000000000000))*(r00)*(sj6)*(x2198)))+(((IkReal(-1.00000000000000))*(r11)*(x2194)*(x2196)))+(((x2203)*(x2211)))+(((IkReal(0.0100000000000000))*(x2191)*(x2197)))+(((IkReal(-1.00000000000000))*(r10)*(x2194)*(x2204)))+(((IkReal(-1.00000000000000))*(py)*(x2214)))+(((IkReal(-0.0100000000000000))*(x2191)*(x2192)))+(((IkReal(0.374290000000000))*(x2192)*(x2196)))+(((r00)*(x2204)*(x2210)))+(((IkReal(-1.00000000000000))*(x2203)*(x2215)))+(((px)*(sj0)))+(((x2194)*(x2195))));
evalcond[8]=((IkReal(-0.295420000000000))+(((IkReal(-1.00000000000000))*(r00)*(x2194)*(x2204)))+(((cj5)*(r02)*(x2194)))+(((cj0)*(r02)*(x2203)))+(((r12)*(sj0)*(x2203)))+(((IkReal(-0.374290000000000))*(x2189)*(x2204)))+(((x2195)*(x2210)))+(((x2209)*(x2220)))+(((IkReal(-1.00000000000000))*(r01)*(x2194)*(x2196)))+(((IkReal(0.0100000000000000))*(x2191)*(x2217)))+(((IkReal(-1.00000000000000))*(r11)*(x2196)*(x2210)))+(((IkReal(0.0100000000000000))*(x2191)*(x2207)))+(((IkReal(-1.00000000000000))*(py)*(x2200)))+(((x2189)*(x2220)))+(((IkReal(-1.00000000000000))*(px)*(x2214))));
if( IKabs(evalcond[0]) < 0.0000010000000000  && IKabs(evalcond[1]) < 0.0000010000000000  && IKabs(evalcond[2]) < 0.0000010000000000  && IKabs(evalcond[3]) < 0.0000010000000000  && IKabs(evalcond[4]) < 0.0000010000000000  && IKabs(evalcond[5]) < 0.0000010000000000  && IKabs(evalcond[6]) < 0.0000010000000000  && IKabs(evalcond[7]) < 0.0000010000000000  && IKabs(evalcond[8]) < 0.0000010000000000  )
{
{
IkReal j3array[1], cj3array[1], sj3array[1];
bool j3valid[1]={false};
_nj3 = 1;
IkReal x2221=((IkReal(1.00000000000000))*(cj4));
IkReal x2222=((cj6)*(r21));
IkReal x2223=((r20)*(sj6));
if( IKabs(((((sj5)*(x2223)))+(((sj5)*(x2222)))+(((IkReal(-1.00000000000000))*(cj5)*(r22))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(((((IkReal(-1.00000000000000))*(cj5)*(x2221)*(x2223)))+(((IkReal(-1.00000000000000))*(cj5)*(x2221)*(x2222)))+(((r21)*(sj4)*(sj6)))+(((IkReal(-1.00000000000000))*(r22)*(sj5)*(x2221)))+(((IkReal(-1.00000000000000))*(cj6)*(r20)*(sj4))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(IKsqr(((((sj5)*(x2223)))+(((sj5)*(x2222)))+(((IkReal(-1.00000000000000))*(cj5)*(r22)))))+IKsqr(((((IkReal(-1.00000000000000))*(cj5)*(x2221)*(x2223)))+(((IkReal(-1.00000000000000))*(cj5)*(x2221)*(x2222)))+(((r21)*(sj4)*(sj6)))+(((IkReal(-1.00000000000000))*(r22)*(sj5)*(x2221)))+(((IkReal(-1.00000000000000))*(cj6)*(r20)*(sj4)))))-1) <= IKFAST_SINCOS_THRESH )
    continue;
j3array[0]=IKatan2(((((sj5)*(x2223)))+(((sj5)*(x2222)))+(((IkReal(-1.00000000000000))*(cj5)*(r22)))), ((((IkReal(-1.00000000000000))*(cj5)*(x2221)*(x2223)))+(((IkReal(-1.00000000000000))*(cj5)*(x2221)*(x2222)))+(((r21)*(sj4)*(sj6)))+(((IkReal(-1.00000000000000))*(r22)*(sj5)*(x2221)))+(((IkReal(-1.00000000000000))*(cj6)*(r20)*(sj4)))));
sj3array[0]=IKsin(j3array[0]);
cj3array[0]=IKcos(j3array[0]);
if( j3array[0] > IKPI )
{
    j3array[0]-=IK2PI;
}
else if( j3array[0] < -IKPI )
{    j3array[0]+=IK2PI;
}
j3valid[0] = true;
for(int ij3 = 0; ij3 < 1; ++ij3)
{
if( !j3valid[ij3] )
{
    continue;
}
_ij3[0] = ij3; _ij3[1] = -1;
for(int iij3 = ij3+1; iij3 < 1; ++iij3)
{
if( j3valid[iij3] && IKabs(cj3array[ij3]-cj3array[iij3]) < IKFAST_SOLUTION_THRESH && IKabs(sj3array[ij3]-sj3array[iij3]) < IKFAST_SOLUTION_THRESH )
{
    j3valid[iij3]=false; _ij3[1] = iij3; break; 
}
}
j3 = j3array[ij3]; cj3 = cj3array[ij3]; sj3 = sj3array[ij3];
{
IkReal evalcond[4];
IkReal x2224=IKcos(j3);
IkReal x2225=IKsin(j3);
IkReal x2226=((IkReal(1.00000000000000))*(cj4));
IkReal x2227=((sj0)*(sj5));
IkReal x2228=((cj0)*(cj5));
IkReal x2229=((cj6)*(r01));
IkReal x2230=((r00)*(sj6));
IkReal x2231=((cj6)*(r11));
IkReal x2232=((cj5)*(sj0));
IkReal x2233=((cj6)*(sj4));
IkReal x2234=((sj4)*(sj6));
IkReal x2235=((cj4)*(cj5));
IkReal x2236=((cj6)*(r21));
IkReal x2237=((r20)*(sj6));
IkReal x2238=((r10)*(sj6));
IkReal x2239=((IkReal(1.00000000000000))*(cj0)*(sj5));
evalcond[0]=((((sj5)*(x2236)))+(((sj5)*(x2237)))+(((IkReal(-1.00000000000000))*(cj5)*(r22)))+(((IkReal(-1.00000000000000))*(x2225))));
evalcond[1]=((x2224)+(((r20)*(x2233)))+(((IkReal(-1.00000000000000))*(r21)*(x2234)))+(((x2235)*(x2237)))+(((cj4)*(r22)*(sj5)))+(((x2235)*(x2236))));
evalcond[2]=((x2224)+(((IkReal(-1.00000000000000))*(x2230)*(x2239)))+(((IkReal(-1.00000000000000))*(x2227)*(x2238)))+(((IkReal(-1.00000000000000))*(x2227)*(x2231)))+(((IkReal(-1.00000000000000))*(x2229)*(x2239)))+(((r12)*(x2232)))+(((r02)*(x2228))));
evalcond[3]=((x2225)+(((IkReal(-1.00000000000000))*(x2226)*(x2228)*(x2229)))+(((IkReal(-1.00000000000000))*(cj0)*(r02)*(sj5)*(x2226)))+(((IkReal(-1.00000000000000))*(r10)*(sj0)*(x2233)))+(((IkReal(-1.00000000000000))*(cj0)*(r00)*(x2233)))+(((IkReal(-1.00000000000000))*(x2226)*(x2228)*(x2230)))+(((IkReal(-1.00000000000000))*(x2226)*(x2232)*(x2238)))+(((IkReal(-1.00000000000000))*(r12)*(x2226)*(x2227)))+(((IkReal(-1.00000000000000))*(x2226)*(x2231)*(x2232)))+(((cj0)*(r01)*(x2234)))+(((r11)*(sj0)*(x2234))));
if( IKabs(evalcond[0]) > 0.000001  || IKabs(evalcond[1]) > 0.000001  || IKabs(evalcond[2]) > 0.000001  || IKabs(evalcond[3]) > 0.000001  )
{
continue;
}
}

{
std::vector<IkSingleDOFSolutionBase<IkReal> > vinfos(7);
vinfos[0].jointtype = 1;
vinfos[0].foffset = j0;
vinfos[0].indices[0] = _ij0[0];
vinfos[0].indices[1] = _ij0[1];
vinfos[0].maxsolutions = _nj0;
vinfos[1].jointtype = 1;
vinfos[1].foffset = j1;
vinfos[1].indices[0] = _ij1[0];
vinfos[1].indices[1] = _ij1[1];
vinfos[1].maxsolutions = _nj1;
vinfos[2].jointtype = 1;
vinfos[2].foffset = j2;
vinfos[2].indices[0] = _ij2[0];
vinfos[2].indices[1] = _ij2[1];
vinfos[2].maxsolutions = _nj2;
vinfos[3].jointtype = 1;
vinfos[3].foffset = j3;
vinfos[3].indices[0] = _ij3[0];
vinfos[3].indices[1] = _ij3[1];
vinfos[3].maxsolutions = _nj3;
vinfos[4].jointtype = 1;
vinfos[4].foffset = j4;
vinfos[4].indices[0] = _ij4[0];
vinfos[4].indices[1] = _ij4[1];
vinfos[4].maxsolutions = _nj4;
vinfos[5].jointtype = 1;
vinfos[5].foffset = j5;
vinfos[5].indices[0] = _ij5[0];
vinfos[5].indices[1] = _ij5[1];
vinfos[5].maxsolutions = _nj5;
vinfos[6].jointtype = 1;
vinfos[6].foffset = j6;
vinfos[6].indices[0] = _ij6[0];
vinfos[6].indices[1] = _ij6[1];
vinfos[6].maxsolutions = _nj6;
std::vector<int> vfree(0);
solutions.AddSolution(vinfos,vfree);
}
}
}

} else
{
IkReal x2240=((IkReal(1.00000000000000))*(cj0));
IkReal x2241=((cj4)*(sj6));
IkReal x2242=((sj0)*(sj4));
IkReal x2243=((cj5)*(sj6));
IkReal x2244=((sj4)*(sj5));
IkReal x2245=((r12)*(sj5));
IkReal x2246=((IkReal(0.374290000000000))*(cj5));
IkReal x2247=((r02)*(sj0));
IkReal x2248=((r20)*(sj4));
IkReal x2249=((IkReal(1.00000000000000))*(sj0));
IkReal x2250=((IkReal(1.00000000000000))*(cj5));
IkReal x2251=((cj0)*(r10));
IkReal x2252=((cj4)*(cj6));
IkReal x2253=((r00)*(sj0));
IkReal x2254=((cj6)*(r21));
IkReal x2255=((IkReal(0.374290000000000))*(sj5));
IkReal x2256=((cj0)*(r00));
IkReal x2257=((IkReal(0.0100000000000000))*(sj5));
IkReal x2258=((cj0)*(r02));
IkReal x2259=((cj5)*(sj4));
IkReal x2260=((cj6)*(r01));
IkReal x2261=((cj6)*(r11));
IkReal x2262=((r01)*(sj0));
IkReal x2263=((r10)*(sj0));
IkReal x2264=((IkReal(0.0100000000000000))*(cj5)*(cj6));
IkReal x2265=((sj6)*(x2255));
IkReal x2266=((cj0)*(cj6)*(x2255));
evalcond[0]=((IkReal(-3.14159265358979))+(IKfmod(((IkReal(1.57079632679490))+(j2)), IkReal(6.28318530717959))));
evalcond[1]=((((sj5)*(x2254)))+(((IkReal(-1.00000000000000))*(r22)*(x2250)))+(((r20)*(sj5)*(sj6))));
evalcond[2]=((IkReal(1.00000000000000))+(((x2254)*(x2259)))+(((IkReal(-1.00000000000000))*(r20)*(x2252)))+(((x2243)*(x2248)))+(((r21)*(x2241)))+(((r22)*(x2244))));
evalcond[3]=((((IkReal(-0.0100000000000000))*(cj5)*(x2254)))+(((IkReal(-0.0100000000000000))*(r20)*(x2243)))+(((IkReal(-1.00000000000000))*(r22)*(x2246)))+(((r20)*(x2265)))+(((x2254)*(x2255)))+(pz)+(((IkReal(-1.00000000000000))*(r22)*(x2257))));
evalcond[4]=((((IkReal(-1.00000000000000))*(r21)*(sj4)*(sj6)))+(((cj6)*(x2248)))+(((cj4)*(r22)*(sj5)))+(((cj5)*(r20)*(x2241)))+(((cj5)*(r21)*(x2252))));
evalcond[5]=((((IkReal(-1.00000000000000))*(r11)*(x2240)*(x2241)))+(((x2241)*(x2262)))+(((r02)*(sj5)*(x2242)))+(((IkReal(-1.00000000000000))*(r12)*(x2240)*(x2244)))+(((IkReal(-1.00000000000000))*(r00)*(x2249)*(x2252)))+(((x2251)*(x2252)))+(((IkReal(-1.00000000000000))*(r10)*(sj4)*(x2240)*(x2243)))+(((IkReal(-1.00000000000000))*(x2240)*(x2259)*(x2261)))+(((r00)*(x2242)*(x2243)))+(((cj5)*(x2242)*(x2260))));
evalcond[6]=((((IkReal(-1.00000000000000))*(r01)*(x2240)*(x2241)))+(((IkReal(-1.00000000000000))*(r11)*(x2241)*(x2249)))+(((x2252)*(x2256)))+(((IkReal(-1.00000000000000))*(x2240)*(x2259)*(x2260)))+(((IkReal(-1.00000000000000))*(r10)*(x2242)*(x2243)))+(((IkReal(-1.00000000000000))*(x2242)*(x2245)))+(((x2252)*(x2263)))+(((IkReal(-1.00000000000000))*(r02)*(x2240)*(x2244)))+(((IkReal(-1.00000000000000))*(x2242)*(x2250)*(x2261)))+(((IkReal(-1.00000000000000))*(r00)*(sj4)*(x2240)*(x2243))));
evalcond[7]=((IkReal(0.0690000000000000))+(((IkReal(-1.00000000000000))*(cj0)*(x2255)*(x2261)))+(((IkReal(-1.00000000000000))*(x2246)*(x2247)))+(((IkReal(0.0100000000000000))*(x2243)*(x2251)))+(((IkReal(-0.0100000000000000))*(cj5)*(sj0)*(x2260)))+(((IkReal(-1.00000000000000))*(x2251)*(x2265)))+(((cj0)*(r12)*(x2246)))+(((IkReal(-1.00000000000000))*(x2247)*(x2257)))+(((IkReal(-0.0100000000000000))*(x2243)*(x2253)))+(((IkReal(0.0100000000000000))*(cj0)*(x2245)))+(((IkReal(0.0100000000000000))*(cj0)*(cj5)*(x2261)))+(((sj0)*(x2255)*(x2260)))+(((px)*(sj0)))+(((IkReal(-1.00000000000000))*(py)*(x2240)))+(((x2253)*(x2265))));
evalcond[8]=((IkReal(-0.295420000000000))+(((IkReal(0.0100000000000000))*(cj0)*(cj5)*(x2260)))+(((IkReal(0.0100000000000000))*(cj5)*(sj0)*(x2261)))+(((IkReal(0.0100000000000000))*(sj0)*(x2245)))+(((IkReal(-1.00000000000000))*(x2256)*(x2265)))+(((IkReal(-1.00000000000000))*(px)*(x2240)))+(((IkReal(-1.00000000000000))*(x2263)*(x2265)))+(((IkReal(-1.00000000000000))*(py)*(x2249)))+(((IkReal(0.0100000000000000))*(x2243)*(x2256)))+(((x2246)*(x2258)))+(((IkReal(-1.00000000000000))*(cj0)*(x2255)*(x2260)))+(((x2257)*(x2258)))+(((IkReal(-1.00000000000000))*(sj0)*(x2255)*(x2261)))+(((IkReal(0.0100000000000000))*(x2243)*(x2263)))+(((r12)*(sj0)*(x2246))));
if( IKabs(evalcond[0]) < 0.0000010000000000  && IKabs(evalcond[1]) < 0.0000010000000000  && IKabs(evalcond[2]) < 0.0000010000000000  && IKabs(evalcond[3]) < 0.0000010000000000  && IKabs(evalcond[4]) < 0.0000010000000000  && IKabs(evalcond[5]) < 0.0000010000000000  && IKabs(evalcond[6]) < 0.0000010000000000  && IKabs(evalcond[7]) < 0.0000010000000000  && IKabs(evalcond[8]) < 0.0000010000000000  )
{
{
IkReal j3array[1], cj3array[1], sj3array[1];
bool j3valid[1]={false};
_nj3 = 1;
IkReal x2267=((sj0)*(sj5));
IkReal x2268=((r00)*(sj6));
IkReal x2269=((IkReal(1.00000000000000))*(cj5));
IkReal x2270=((cj6)*(r11));
IkReal x2271=((cj6)*(r01));
IkReal x2272=((r10)*(sj6));
IkReal x2273=((cj0)*(sj5));
if( IKabs(((((IkReal(-1.00000000000000))*(r02)*(sj0)*(x2269)))+(((x2267)*(x2268)))+(((x2267)*(x2271)))+(((cj0)*(cj5)*(r12)))+(((IkReal(-1.00000000000000))*(x2272)*(x2273)))+(((IkReal(-1.00000000000000))*(x2270)*(x2273))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(((((x2271)*(x2273)))+(((x2267)*(x2270)))+(((IkReal(-1.00000000000000))*(r12)*(sj0)*(x2269)))+(((IkReal(-1.00000000000000))*(cj0)*(r02)*(x2269)))+(((x2268)*(x2273)))+(((x2267)*(x2272))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(IKsqr(((((IkReal(-1.00000000000000))*(r02)*(sj0)*(x2269)))+(((x2267)*(x2268)))+(((x2267)*(x2271)))+(((cj0)*(cj5)*(r12)))+(((IkReal(-1.00000000000000))*(x2272)*(x2273)))+(((IkReal(-1.00000000000000))*(x2270)*(x2273)))))+IKsqr(((((x2271)*(x2273)))+(((x2267)*(x2270)))+(((IkReal(-1.00000000000000))*(r12)*(sj0)*(x2269)))+(((IkReal(-1.00000000000000))*(cj0)*(r02)*(x2269)))+(((x2268)*(x2273)))+(((x2267)*(x2272)))))-1) <= IKFAST_SINCOS_THRESH )
    continue;
j3array[0]=IKatan2(((((IkReal(-1.00000000000000))*(r02)*(sj0)*(x2269)))+(((x2267)*(x2268)))+(((x2267)*(x2271)))+(((cj0)*(cj5)*(r12)))+(((IkReal(-1.00000000000000))*(x2272)*(x2273)))+(((IkReal(-1.00000000000000))*(x2270)*(x2273)))), ((((x2271)*(x2273)))+(((x2267)*(x2270)))+(((IkReal(-1.00000000000000))*(r12)*(sj0)*(x2269)))+(((IkReal(-1.00000000000000))*(cj0)*(r02)*(x2269)))+(((x2268)*(x2273)))+(((x2267)*(x2272)))));
sj3array[0]=IKsin(j3array[0]);
cj3array[0]=IKcos(j3array[0]);
if( j3array[0] > IKPI )
{
    j3array[0]-=IK2PI;
}
else if( j3array[0] < -IKPI )
{    j3array[0]+=IK2PI;
}
j3valid[0] = true;
for(int ij3 = 0; ij3 < 1; ++ij3)
{
if( !j3valid[ij3] )
{
    continue;
}
_ij3[0] = ij3; _ij3[1] = -1;
for(int iij3 = ij3+1; iij3 < 1; ++iij3)
{
if( j3valid[iij3] && IKabs(cj3array[ij3]-cj3array[iij3]) < IKFAST_SOLUTION_THRESH && IKabs(sj3array[ij3]-sj3array[iij3]) < IKFAST_SOLUTION_THRESH )
{
    j3valid[iij3]=false; _ij3[1] = iij3; break; 
}
}
j3 = j3array[ij3]; cj3 = cj3array[ij3]; sj3 = sj3array[ij3];
{
IkReal evalcond[4];
IkReal x2274=IKcos(j3);
IkReal x2275=IKsin(j3);
IkReal x2276=((sj0)*(sj5));
IkReal x2277=((r00)*(sj6));
IkReal x2278=((cj6)*(sj0));
IkReal x2279=((IkReal(1.00000000000000))*(cj4));
IkReal x2280=((r00)*(sj4));
IkReal x2281=((cj0)*(cj5));
IkReal x2282=((cj5)*(sj0));
IkReal x2283=((cj6)*(r11));
IkReal x2284=((r10)*(sj6));
IkReal x2285=((cj0)*(sj5));
IkReal x2286=((r10)*(sj4));
IkReal x2287=((cj4)*(cj5)*(r01));
IkReal x2288=((IkReal(1.00000000000000))*(cj0)*(cj6));
IkReal x2289=((cj0)*(sj4)*(sj6));
IkReal x2290=((sj0)*(sj4)*(sj6));
evalcond[0]=((((IkReal(-1.00000000000000))*(r02)*(x2282)))+(((cj6)*(r01)*(x2276)))+(((IkReal(-1.00000000000000))*(x2283)*(x2285)))+(((IkReal(-1.00000000000000))*(x2275)))+(((r12)*(x2281)))+(((x2276)*(x2277)))+(((IkReal(-1.00000000000000))*(x2284)*(x2285))));
evalcond[1]=((((IkReal(-1.00000000000000))*(x2277)*(x2285)))+(((IkReal(-1.00000000000000))*(x2276)*(x2283)))+(((r12)*(x2282)))+(((IkReal(-1.00000000000000))*(cj6)*(r01)*(x2285)))+(x2274)+(((r02)*(x2281)))+(((IkReal(-1.00000000000000))*(x2276)*(x2284))));
evalcond[2]=((((cj4)*(x2277)*(x2282)))+(((x2278)*(x2280)))+(((cj4)*(r02)*(x2276)))+(((IkReal(-1.00000000000000))*(x2279)*(x2281)*(x2284)))+(((r11)*(x2289)))+(((IkReal(-1.00000000000000))*(x2286)*(x2288)))+(x2274)+(((IkReal(-1.00000000000000))*(r01)*(x2290)))+(((IkReal(-1.00000000000000))*(x2279)*(x2281)*(x2283)))+(((IkReal(-1.00000000000000))*(r12)*(x2279)*(x2285)))+(((x2278)*(x2287))));
evalcond[3]=((((r01)*(x2289)))+(((r11)*(x2290)))+(((IkReal(-1.00000000000000))*(x2279)*(x2282)*(x2284)))+(((IkReal(-1.00000000000000))*(cj6)*(r01)*(x2279)*(x2281)))+(((IkReal(-1.00000000000000))*(r02)*(x2279)*(x2285)))+(((IkReal(-1.00000000000000))*(x2280)*(x2288)))+(((IkReal(-1.00000000000000))*(x2278)*(x2286)))+(x2275)+(((IkReal(-1.00000000000000))*(r12)*(x2276)*(x2279)))+(((IkReal(-1.00000000000000))*(x2277)*(x2279)*(x2281)))+(((IkReal(-1.00000000000000))*(cj5)*(r11)*(x2278)*(x2279))));
if( IKabs(evalcond[0]) > 0.000001  || IKabs(evalcond[1]) > 0.000001  || IKabs(evalcond[2]) > 0.000001  || IKabs(evalcond[3]) > 0.000001  )
{
continue;
}
}

{
std::vector<IkSingleDOFSolutionBase<IkReal> > vinfos(7);
vinfos[0].jointtype = 1;
vinfos[0].foffset = j0;
vinfos[0].indices[0] = _ij0[0];
vinfos[0].indices[1] = _ij0[1];
vinfos[0].maxsolutions = _nj0;
vinfos[1].jointtype = 1;
vinfos[1].foffset = j1;
vinfos[1].indices[0] = _ij1[0];
vinfos[1].indices[1] = _ij1[1];
vinfos[1].maxsolutions = _nj1;
vinfos[2].jointtype = 1;
vinfos[2].foffset = j2;
vinfos[2].indices[0] = _ij2[0];
vinfos[2].indices[1] = _ij2[1];
vinfos[2].maxsolutions = _nj2;
vinfos[3].jointtype = 1;
vinfos[3].foffset = j3;
vinfos[3].indices[0] = _ij3[0];
vinfos[3].indices[1] = _ij3[1];
vinfos[3].maxsolutions = _nj3;
vinfos[4].jointtype = 1;
vinfos[4].foffset = j4;
vinfos[4].indices[0] = _ij4[0];
vinfos[4].indices[1] = _ij4[1];
vinfos[4].maxsolutions = _nj4;
vinfos[5].jointtype = 1;
vinfos[5].foffset = j5;
vinfos[5].indices[0] = _ij5[0];
vinfos[5].indices[1] = _ij5[1];
vinfos[5].maxsolutions = _nj5;
vinfos[6].jointtype = 1;
vinfos[6].foffset = j6;
vinfos[6].indices[0] = _ij6[0];
vinfos[6].indices[1] = _ij6[1];
vinfos[6].maxsolutions = _nj6;
std::vector<int> vfree(0);
solutions.AddSolution(vinfos,vfree);
}
}
}

} else
{
IkReal x2291=((IkReal(1.00000000000000))*(cj0));
IkReal x2292=((cj4)*(sj6));
IkReal x2293=((sj0)*(sj4));
IkReal x2294=((cj5)*(sj6));
IkReal x2295=((sj4)*(sj5));
IkReal x2296=((r12)*(sj5));
IkReal x2297=((IkReal(0.374290000000000))*(cj5));
IkReal x2298=((r02)*(sj0));
IkReal x2299=((r20)*(sj4));
IkReal x2300=((IkReal(1.00000000000000))*(sj0));
IkReal x2301=((IkReal(1.00000000000000))*(cj5));
IkReal x2302=((cj0)*(r10));
IkReal x2303=((cj4)*(cj6));
IkReal x2304=((r00)*(sj0));
IkReal x2305=((cj6)*(r21));
IkReal x2306=((IkReal(0.374290000000000))*(sj5));
IkReal x2307=((cj0)*(r00));
IkReal x2308=((IkReal(0.0100000000000000))*(sj5));
IkReal x2309=((cj0)*(r02));
IkReal x2310=((cj5)*(sj4));
IkReal x2311=((cj6)*(r01));
IkReal x2312=((cj6)*(r11));
IkReal x2313=((r01)*(sj0));
IkReal x2314=((r10)*(sj0));
IkReal x2315=((IkReal(0.0100000000000000))*(cj5)*(cj6));
IkReal x2316=((sj6)*(x2306));
IkReal x2317=((cj0)*(cj6)*(x2306));
evalcond[0]=((IkReal(-3.14159265358979))+(IKfmod(((IkReal(4.71238898038469))+(j2)), IkReal(6.28318530717959))));
evalcond[1]=((((sj5)*(x2305)))+(((r20)*(sj5)*(sj6)))+(((IkReal(-1.00000000000000))*(r22)*(x2301))));
evalcond[2]=((IkReal(-1.00000000000000))+(((r22)*(x2295)))+(((x2294)*(x2299)))+(((r21)*(x2292)))+(((x2305)*(x2310)))+(((IkReal(-1.00000000000000))*(r20)*(x2303))));
evalcond[3]=((((x2305)*(x2306)))+(((IkReal(-1.00000000000000))*(r22)*(x2308)))+(((IkReal(-1.00000000000000))*(r22)*(x2297)))+(((r20)*(x2316)))+(((IkReal(-0.0100000000000000))*(cj5)*(x2305)))+(((IkReal(-0.0100000000000000))*(r20)*(x2294)))+(pz));
evalcond[4]=((((IkReal(-1.00000000000000))*(r21)*(sj4)*(sj6)))+(((cj5)*(r20)*(x2292)))+(((cj4)*(r22)*(sj5)))+(((cj6)*(x2299)))+(((cj5)*(r21)*(x2303))));
evalcond[5]=((((r02)*(sj5)*(x2293)))+(((x2302)*(x2303)))+(((r00)*(x2293)*(x2294)))+(((IkReal(-1.00000000000000))*(r10)*(sj4)*(x2291)*(x2294)))+(((IkReal(-1.00000000000000))*(r00)*(x2300)*(x2303)))+(((IkReal(-1.00000000000000))*(r12)*(x2291)*(x2295)))+(((IkReal(-1.00000000000000))*(x2291)*(x2310)*(x2312)))+(((cj5)*(x2293)*(x2311)))+(((IkReal(-1.00000000000000))*(r11)*(x2291)*(x2292)))+(((x2292)*(x2313))));
evalcond[6]=((((IkReal(-1.00000000000000))*(r02)*(x2291)*(x2295)))+(((IkReal(-1.00000000000000))*(r11)*(x2292)*(x2300)))+(((IkReal(-1.00000000000000))*(x2291)*(x2310)*(x2311)))+(((x2303)*(x2314)))+(((IkReal(-1.00000000000000))*(x2293)*(x2296)))+(((IkReal(-1.00000000000000))*(x2293)*(x2301)*(x2312)))+(((IkReal(-1.00000000000000))*(r00)*(sj4)*(x2291)*(x2294)))+(((IkReal(-1.00000000000000))*(r10)*(x2293)*(x2294)))+(((x2303)*(x2307)))+(((IkReal(-1.00000000000000))*(r01)*(x2291)*(x2292))));
evalcond[7]=((IkReal(-0.0690000000000000))+(((x2304)*(x2316)))+(((IkReal(-1.00000000000000))*(x2302)*(x2316)))+(((IkReal(-0.0100000000000000))*(cj5)*(sj0)*(x2311)))+(((IkReal(0.0100000000000000))*(cj0)*(cj5)*(x2312)))+(((IkReal(0.0100000000000000))*(cj0)*(x2296)))+(((sj0)*(x2306)*(x2311)))+(((cj0)*(r12)*(x2297)))+(((IkReal(-1.00000000000000))*(cj0)*(x2306)*(x2312)))+(((IkReal(0.0100000000000000))*(x2294)*(x2302)))+(((IkReal(-0.0100000000000000))*(x2294)*(x2304)))+(((IkReal(-1.00000000000000))*(py)*(x2291)))+(((IkReal(-1.00000000000000))*(x2298)*(x2308)))+(((px)*(sj0)))+(((IkReal(-1.00000000000000))*(x2297)*(x2298))));
evalcond[8]=((IkReal(-0.295420000000000))+(((IkReal(0.0100000000000000))*(x2294)*(x2314)))+(((IkReal(-1.00000000000000))*(x2314)*(x2316)))+(((IkReal(0.0100000000000000))*(sj0)*(x2296)))+(((IkReal(0.0100000000000000))*(cj5)*(sj0)*(x2312)))+(((r12)*(sj0)*(x2297)))+(((IkReal(-1.00000000000000))*(cj0)*(x2306)*(x2311)))+(((IkReal(-1.00000000000000))*(px)*(x2291)))+(((IkReal(0.0100000000000000))*(cj0)*(cj5)*(x2311)))+(((IkReal(-1.00000000000000))*(x2307)*(x2316)))+(((IkReal(-1.00000000000000))*(py)*(x2300)))+(((x2297)*(x2309)))+(((IkReal(-1.00000000000000))*(sj0)*(x2306)*(x2312)))+(((x2308)*(x2309)))+(((IkReal(0.0100000000000000))*(x2294)*(x2307))));
if( IKabs(evalcond[0]) < 0.0000010000000000  && IKabs(evalcond[1]) < 0.0000010000000000  && IKabs(evalcond[2]) < 0.0000010000000000  && IKabs(evalcond[3]) < 0.0000010000000000  && IKabs(evalcond[4]) < 0.0000010000000000  && IKabs(evalcond[5]) < 0.0000010000000000  && IKabs(evalcond[6]) < 0.0000010000000000  && IKabs(evalcond[7]) < 0.0000010000000000  && IKabs(evalcond[8]) < 0.0000010000000000  )
{
{
IkReal j3array[1], cj3array[1], sj3array[1];
bool j3valid[1]={false};
_nj3 = 1;
IkReal x2318=((IkReal(1.00000000000000))*(cj5));
IkReal x2319=((r10)*(sj5)*(sj6));
IkReal x2320=((cj6)*(sj0)*(sj5));
IkReal x2321=((r00)*(sj5)*(sj6));
IkReal x2322=((cj0)*(cj6)*(sj5));
if( IKabs(((((IkReal(-1.00000000000000))*(cj0)*(r12)*(x2318)))+(((cj5)*(r02)*(sj0)))+(((cj0)*(x2319)))+(((IkReal(-1.00000000000000))*(r01)*(x2320)))+(((IkReal(-1.00000000000000))*(sj0)*(x2321)))+(((r11)*(x2322))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(((((IkReal(-1.00000000000000))*(r12)*(sj0)*(x2318)))+(((cj0)*(x2321)))+(((IkReal(-1.00000000000000))*(cj0)*(r02)*(x2318)))+(((sj0)*(x2319)))+(((r11)*(x2320)))+(((r01)*(x2322))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(IKsqr(((((IkReal(-1.00000000000000))*(cj0)*(r12)*(x2318)))+(((cj5)*(r02)*(sj0)))+(((cj0)*(x2319)))+(((IkReal(-1.00000000000000))*(r01)*(x2320)))+(((IkReal(-1.00000000000000))*(sj0)*(x2321)))+(((r11)*(x2322)))))+IKsqr(((((IkReal(-1.00000000000000))*(r12)*(sj0)*(x2318)))+(((cj0)*(x2321)))+(((IkReal(-1.00000000000000))*(cj0)*(r02)*(x2318)))+(((sj0)*(x2319)))+(((r11)*(x2320)))+(((r01)*(x2322)))))-1) <= IKFAST_SINCOS_THRESH )
    continue;
j3array[0]=IKatan2(((((IkReal(-1.00000000000000))*(cj0)*(r12)*(x2318)))+(((cj5)*(r02)*(sj0)))+(((cj0)*(x2319)))+(((IkReal(-1.00000000000000))*(r01)*(x2320)))+(((IkReal(-1.00000000000000))*(sj0)*(x2321)))+(((r11)*(x2322)))), ((((IkReal(-1.00000000000000))*(r12)*(sj0)*(x2318)))+(((cj0)*(x2321)))+(((IkReal(-1.00000000000000))*(cj0)*(r02)*(x2318)))+(((sj0)*(x2319)))+(((r11)*(x2320)))+(((r01)*(x2322)))));
sj3array[0]=IKsin(j3array[0]);
cj3array[0]=IKcos(j3array[0]);
if( j3array[0] > IKPI )
{
    j3array[0]-=IK2PI;
}
else if( j3array[0] < -IKPI )
{    j3array[0]+=IK2PI;
}
j3valid[0] = true;
for(int ij3 = 0; ij3 < 1; ++ij3)
{
if( !j3valid[ij3] )
{
    continue;
}
_ij3[0] = ij3; _ij3[1] = -1;
for(int iij3 = ij3+1; iij3 < 1; ++iij3)
{
if( j3valid[iij3] && IKabs(cj3array[ij3]-cj3array[iij3]) < IKFAST_SOLUTION_THRESH && IKabs(sj3array[ij3]-sj3array[iij3]) < IKFAST_SOLUTION_THRESH )
{
    j3valid[iij3]=false; _ij3[1] = iij3; break; 
}
}
j3 = j3array[ij3]; cj3 = cj3array[ij3]; sj3 = sj3array[ij3];
{
IkReal evalcond[4];
IkReal x2323=IKcos(j3);
IkReal x2324=IKsin(j3);
IkReal x2325=((sj0)*(sj5));
IkReal x2326=((r00)*(sj6));
IkReal x2327=((IkReal(1.00000000000000))*(cj4));
IkReal x2328=((cj6)*(sj0));
IkReal x2329=((r00)*(sj4));
IkReal x2330=((cj0)*(cj5));
IkReal x2331=((cj6)*(r01));
IkReal x2332=((cj5)*(sj0));
IkReal x2333=((cj0)*(sj5));
IkReal x2334=((cj6)*(r11));
IkReal x2335=((r10)*(sj6));
IkReal x2336=((r10)*(sj4));
IkReal x2337=((cj0)*(sj4)*(sj6));
IkReal x2338=((sj0)*(sj4)*(sj6));
IkReal x2339=((IkReal(1.00000000000000))*(cj0)*(cj6));
evalcond[0]=((((r12)*(x2330)))+(x2324)+(((IkReal(-1.00000000000000))*(r02)*(x2332)))+(((IkReal(-1.00000000000000))*(x2333)*(x2334)))+(((x2325)*(x2326)))+(((x2325)*(x2331)))+(((IkReal(-1.00000000000000))*(x2333)*(x2335))));
evalcond[1]=((x2323)+(((IkReal(-1.00000000000000))*(x2325)*(x2335)))+(((IkReal(-1.00000000000000))*(x2331)*(x2333)))+(((IkReal(-1.00000000000000))*(x2325)*(x2334)))+(((r02)*(x2330)))+(((r12)*(x2332)))+(((IkReal(-1.00000000000000))*(x2326)*(x2333))));
evalcond[2]=((((IkReal(-1.00000000000000))*(x2336)*(x2339)))+(((IkReal(-1.00000000000000))*(r12)*(x2327)*(x2333)))+(((x2328)*(x2329)))+(((IkReal(-1.00000000000000))*(x2327)*(x2330)*(x2334)))+(((IkReal(-1.00000000000000))*(x2323)))+(((IkReal(-1.00000000000000))*(r01)*(x2338)))+(((IkReal(-1.00000000000000))*(x2327)*(x2330)*(x2335)))+(((cj4)*(x2326)*(x2332)))+(((r11)*(x2337)))+(((cj4)*(cj5)*(r01)*(x2328)))+(((cj4)*(r02)*(x2325))));
evalcond[3]=((x2324)+(((IkReal(-1.00000000000000))*(r02)*(x2327)*(x2333)))+(((IkReal(-1.00000000000000))*(x2326)*(x2327)*(x2330)))+(((IkReal(-1.00000000000000))*(x2327)*(x2330)*(x2331)))+(((IkReal(-1.00000000000000))*(x2329)*(x2339)))+(((IkReal(-1.00000000000000))*(x2328)*(x2336)))+(((IkReal(-1.00000000000000))*(x2327)*(x2332)*(x2335)))+(((IkReal(-1.00000000000000))*(r12)*(x2325)*(x2327)))+(((r11)*(x2338)))+(((r01)*(x2337)))+(((IkReal(-1.00000000000000))*(cj5)*(r11)*(x2327)*(x2328))));
if( IKabs(evalcond[0]) > 0.000001  || IKabs(evalcond[1]) > 0.000001  || IKabs(evalcond[2]) > 0.000001  || IKabs(evalcond[3]) > 0.000001  )
{
continue;
}
}

{
std::vector<IkSingleDOFSolutionBase<IkReal> > vinfos(7);
vinfos[0].jointtype = 1;
vinfos[0].foffset = j0;
vinfos[0].indices[0] = _ij0[0];
vinfos[0].indices[1] = _ij0[1];
vinfos[0].maxsolutions = _nj0;
vinfos[1].jointtype = 1;
vinfos[1].foffset = j1;
vinfos[1].indices[0] = _ij1[0];
vinfos[1].indices[1] = _ij1[1];
vinfos[1].maxsolutions = _nj1;
vinfos[2].jointtype = 1;
vinfos[2].foffset = j2;
vinfos[2].indices[0] = _ij2[0];
vinfos[2].indices[1] = _ij2[1];
vinfos[2].maxsolutions = _nj2;
vinfos[3].jointtype = 1;
vinfos[3].foffset = j3;
vinfos[3].indices[0] = _ij3[0];
vinfos[3].indices[1] = _ij3[1];
vinfos[3].maxsolutions = _nj3;
vinfos[4].jointtype = 1;
vinfos[4].foffset = j4;
vinfos[4].indices[0] = _ij4[0];
vinfos[4].indices[1] = _ij4[1];
vinfos[4].maxsolutions = _nj4;
vinfos[5].jointtype = 1;
vinfos[5].foffset = j5;
vinfos[5].indices[0] = _ij5[0];
vinfos[5].indices[1] = _ij5[1];
vinfos[5].maxsolutions = _nj5;
vinfos[6].jointtype = 1;
vinfos[6].foffset = j6;
vinfos[6].indices[0] = _ij6[0];
vinfos[6].indices[1] = _ij6[1];
vinfos[6].maxsolutions = _nj6;
std::vector<int> vfree(0);
solutions.AddSolution(vinfos,vfree);
}
}
}

} else
{
if( 1 )
{
continue;

} else
{
}
}
}
}
}
}

} else
{
{
IkReal j3array[1], cj3array[1], sj3array[1];
bool j3valid[1]={false};
_nj3 = 1;
IkReal x2340=((sj0)*(sj5));
IkReal x2341=((r00)*(sj6));
IkReal x2342=((IkReal(1.00000000000000))*(cj5));
IkReal x2343=((cj6)*(r11));
IkReal x2344=((cj6)*(r01));
IkReal x2345=((cj0)*(sj5));
IkReal x2346=((r10)*(sj6));
if( IKabs(((((IKabs(sj2) != 0)?((IkReal)1/(sj2)):(IkReal)1.0e30))*(((((x2340)*(x2341)))+(((IkReal(-1.00000000000000))*(r02)*(sj0)*(x2342)))+(((IkReal(-1.00000000000000))*(x2343)*(x2345)))+(((cj0)*(cj5)*(r12)))+(((IkReal(-1.00000000000000))*(x2345)*(x2346)))+(((x2340)*(x2344))))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(((((IkReal(-1.00000000000000))*(r12)*(sj0)*(x2342)))+(((x2341)*(x2345)))+(((x2340)*(x2343)))+(((IkReal(-1.00000000000000))*(cj0)*(r02)*(x2342)))+(((x2340)*(x2346)))+(((x2344)*(x2345))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(IKsqr(((((IKabs(sj2) != 0)?((IkReal)1/(sj2)):(IkReal)1.0e30))*(((((x2340)*(x2341)))+(((IkReal(-1.00000000000000))*(r02)*(sj0)*(x2342)))+(((IkReal(-1.00000000000000))*(x2343)*(x2345)))+(((cj0)*(cj5)*(r12)))+(((IkReal(-1.00000000000000))*(x2345)*(x2346)))+(((x2340)*(x2344)))))))+IKsqr(((((IkReal(-1.00000000000000))*(r12)*(sj0)*(x2342)))+(((x2341)*(x2345)))+(((x2340)*(x2343)))+(((IkReal(-1.00000000000000))*(cj0)*(r02)*(x2342)))+(((x2340)*(x2346)))+(((x2344)*(x2345)))))-1) <= IKFAST_SINCOS_THRESH )
    continue;
j3array[0]=IKatan2(((((IKabs(sj2) != 0)?((IkReal)1/(sj2)):(IkReal)1.0e30))*(((((x2340)*(x2341)))+(((IkReal(-1.00000000000000))*(r02)*(sj0)*(x2342)))+(((IkReal(-1.00000000000000))*(x2343)*(x2345)))+(((cj0)*(cj5)*(r12)))+(((IkReal(-1.00000000000000))*(x2345)*(x2346)))+(((x2340)*(x2344)))))), ((((IkReal(-1.00000000000000))*(r12)*(sj0)*(x2342)))+(((x2341)*(x2345)))+(((x2340)*(x2343)))+(((IkReal(-1.00000000000000))*(cj0)*(r02)*(x2342)))+(((x2340)*(x2346)))+(((x2344)*(x2345)))));
sj3array[0]=IKsin(j3array[0]);
cj3array[0]=IKcos(j3array[0]);
if( j3array[0] > IKPI )
{
    j3array[0]-=IK2PI;
}
else if( j3array[0] < -IKPI )
{    j3array[0]+=IK2PI;
}
j3valid[0] = true;
for(int ij3 = 0; ij3 < 1; ++ij3)
{
if( !j3valid[ij3] )
{
    continue;
}
_ij3[0] = ij3; _ij3[1] = -1;
for(int iij3 = ij3+1; iij3 < 1; ++iij3)
{
if( j3valid[iij3] && IKabs(cj3array[ij3]-cj3array[iij3]) < IKFAST_SOLUTION_THRESH && IKabs(sj3array[ij3]-sj3array[iij3]) < IKFAST_SOLUTION_THRESH )
{
    j3valid[iij3]=false; _ij3[1] = iij3; break; 
}
}
j3 = j3array[ij3]; cj3 = cj3array[ij3]; sj3 = sj3array[ij3];
{
IkReal evalcond[6];
IkReal x2347=IKsin(j3);
IkReal x2348=IKcos(j3);
IkReal x2349=((sj0)*(sj5));
IkReal x2350=((r00)*(sj6));
IkReal x2351=((IkReal(1.00000000000000))*(cj4));
IkReal x2352=((cj6)*(r01));
IkReal x2353=((cj0)*(cj5));
IkReal x2354=((cj5)*(sj0));
IkReal x2355=((cj6)*(r11));
IkReal x2356=((cj6)*(sj4));
IkReal x2357=((cj0)*(sj5));
IkReal x2358=((cj4)*(cj5));
IkReal x2359=((cj6)*(r21));
IkReal x2360=((r20)*(sj6));
IkReal x2361=((r10)*(sj6));
IkReal x2362=((IkReal(1.00000000000000))*(cj0));
IkReal x2363=((cj0)*(sj4)*(sj6));
IkReal x2364=((sj0)*(sj4)*(sj6));
evalcond[0]=((((cj2)*(x2347)))+(((sj5)*(x2360)))+(((sj5)*(x2359)))+(((IkReal(-1.00000000000000))*(cj5)*(r22))));
evalcond[1]=((((IkReal(-1.00000000000000))*(cj2)*(x2348)))+(((IkReal(-1.00000000000000))*(r21)*(sj4)*(sj6)))+(((r20)*(x2356)))+(((cj4)*(r22)*(sj5)))+(((x2358)*(x2359)))+(((x2358)*(x2360))));
evalcond[2]=((((IkReal(-1.00000000000000))*(x2357)*(x2361)))+(((IkReal(-1.00000000000000))*(sj2)*(x2347)))+(((IkReal(-1.00000000000000))*(x2355)*(x2357)))+(((r12)*(x2353)))+(((x2349)*(x2350)))+(((IkReal(-1.00000000000000))*(r02)*(x2354)))+(((x2349)*(x2352))));
evalcond[3]=((((r02)*(x2353)))+(((IkReal(-1.00000000000000))*(x2349)*(x2361)))+(((IkReal(-1.00000000000000))*(x2350)*(x2357)))+(x2348)+(((r12)*(x2354)))+(((IkReal(-1.00000000000000))*(x2349)*(x2355)))+(((IkReal(-1.00000000000000))*(x2352)*(x2357))));
evalcond[4]=((((IkReal(-1.00000000000000))*(r12)*(x2351)*(x2357)))+(((cj4)*(x2350)*(x2354)))+(((IkReal(-1.00000000000000))*(x2351)*(x2353)*(x2361)))+(((r00)*(sj0)*(x2356)))+(((IkReal(-1.00000000000000))*(r10)*(x2356)*(x2362)))+(((cj4)*(x2352)*(x2354)))+(((IkReal(-1.00000000000000))*(x2351)*(x2353)*(x2355)))+(((r11)*(x2363)))+(((cj4)*(r02)*(x2349)))+(((sj2)*(x2348)))+(((IkReal(-1.00000000000000))*(r01)*(x2364))));
evalcond[5]=((((IkReal(-1.00000000000000))*(x2351)*(x2354)*(x2355)))+(((IkReal(-1.00000000000000))*(x2351)*(x2354)*(x2361)))+(((r11)*(x2364)))+(((IkReal(-1.00000000000000))*(r12)*(x2349)*(x2351)))+(x2347)+(((IkReal(-1.00000000000000))*(r10)*(sj0)*(x2356)))+(((IkReal(-1.00000000000000))*(x2351)*(x2352)*(x2353)))+(((IkReal(-1.00000000000000))*(r02)*(x2351)*(x2357)))+(((IkReal(-1.00000000000000))*(r00)*(x2356)*(x2362)))+(((r01)*(x2363)))+(((IkReal(-1.00000000000000))*(x2350)*(x2351)*(x2353))));
if( IKabs(evalcond[0]) > 0.000001  || IKabs(evalcond[1]) > 0.000001  || IKabs(evalcond[2]) > 0.000001  || IKabs(evalcond[3]) > 0.000001  || IKabs(evalcond[4]) > 0.000001  || IKabs(evalcond[5]) > 0.000001  )
{
continue;
}
}

{
std::vector<IkSingleDOFSolutionBase<IkReal> > vinfos(7);
vinfos[0].jointtype = 1;
vinfos[0].foffset = j0;
vinfos[0].indices[0] = _ij0[0];
vinfos[0].indices[1] = _ij0[1];
vinfos[0].maxsolutions = _nj0;
vinfos[1].jointtype = 1;
vinfos[1].foffset = j1;
vinfos[1].indices[0] = _ij1[0];
vinfos[1].indices[1] = _ij1[1];
vinfos[1].maxsolutions = _nj1;
vinfos[2].jointtype = 1;
vinfos[2].foffset = j2;
vinfos[2].indices[0] = _ij2[0];
vinfos[2].indices[1] = _ij2[1];
vinfos[2].maxsolutions = _nj2;
vinfos[3].jointtype = 1;
vinfos[3].foffset = j3;
vinfos[3].indices[0] = _ij3[0];
vinfos[3].indices[1] = _ij3[1];
vinfos[3].maxsolutions = _nj3;
vinfos[4].jointtype = 1;
vinfos[4].foffset = j4;
vinfos[4].indices[0] = _ij4[0];
vinfos[4].indices[1] = _ij4[1];
vinfos[4].maxsolutions = _nj4;
vinfos[5].jointtype = 1;
vinfos[5].foffset = j5;
vinfos[5].indices[0] = _ij5[0];
vinfos[5].indices[1] = _ij5[1];
vinfos[5].maxsolutions = _nj5;
vinfos[6].jointtype = 1;
vinfos[6].foffset = j6;
vinfos[6].indices[0] = _ij6[0];
vinfos[6].indices[1] = _ij6[1];
vinfos[6].maxsolutions = _nj6;
std::vector<int> vfree(0);
solutions.AddSolution(vinfos,vfree);
}
}
}

}

}

} else
{
{
IkReal j3array[1], cj3array[1], sj3array[1];
bool j3valid[1]={false};
_nj3 = 1;
IkReal x2365=((cj6)*(sj5));
IkReal x2366=((IkReal(1.00000000000000))*(cj5));
IkReal x2367=((sj5)*(sj6));
if( IKabs(((((IKabs(cj2) != 0)?((IkReal)1/(cj2)):(IkReal)1.0e30))*(((((IkReal(-1.00000000000000))*(r21)*(x2365)))+(((IkReal(-1.00000000000000))*(r20)*(x2367)))+(((cj5)*(r22))))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(((((cj0)*(r01)*(x2365)))+(((r10)*(sj0)*(x2367)))+(((IkReal(-1.00000000000000))*(cj0)*(r02)*(x2366)))+(((r11)*(sj0)*(x2365)))+(((cj0)*(r00)*(x2367)))+(((IkReal(-1.00000000000000))*(r12)*(sj0)*(x2366))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(IKsqr(((((IKabs(cj2) != 0)?((IkReal)1/(cj2)):(IkReal)1.0e30))*(((((IkReal(-1.00000000000000))*(r21)*(x2365)))+(((IkReal(-1.00000000000000))*(r20)*(x2367)))+(((cj5)*(r22)))))))+IKsqr(((((cj0)*(r01)*(x2365)))+(((r10)*(sj0)*(x2367)))+(((IkReal(-1.00000000000000))*(cj0)*(r02)*(x2366)))+(((r11)*(sj0)*(x2365)))+(((cj0)*(r00)*(x2367)))+(((IkReal(-1.00000000000000))*(r12)*(sj0)*(x2366)))))-1) <= IKFAST_SINCOS_THRESH )
    continue;
j3array[0]=IKatan2(((((IKabs(cj2) != 0)?((IkReal)1/(cj2)):(IkReal)1.0e30))*(((((IkReal(-1.00000000000000))*(r21)*(x2365)))+(((IkReal(-1.00000000000000))*(r20)*(x2367)))+(((cj5)*(r22)))))), ((((cj0)*(r01)*(x2365)))+(((r10)*(sj0)*(x2367)))+(((IkReal(-1.00000000000000))*(cj0)*(r02)*(x2366)))+(((r11)*(sj0)*(x2365)))+(((cj0)*(r00)*(x2367)))+(((IkReal(-1.00000000000000))*(r12)*(sj0)*(x2366)))));
sj3array[0]=IKsin(j3array[0]);
cj3array[0]=IKcos(j3array[0]);
if( j3array[0] > IKPI )
{
    j3array[0]-=IK2PI;
}
else if( j3array[0] < -IKPI )
{    j3array[0]+=IK2PI;
}
j3valid[0] = true;
for(int ij3 = 0; ij3 < 1; ++ij3)
{
if( !j3valid[ij3] )
{
    continue;
}
_ij3[0] = ij3; _ij3[1] = -1;
for(int iij3 = ij3+1; iij3 < 1; ++iij3)
{
if( j3valid[iij3] && IKabs(cj3array[ij3]-cj3array[iij3]) < IKFAST_SOLUTION_THRESH && IKabs(sj3array[ij3]-sj3array[iij3]) < IKFAST_SOLUTION_THRESH )
{
    j3valid[iij3]=false; _ij3[1] = iij3; break; 
}
}
j3 = j3array[ij3]; cj3 = cj3array[ij3]; sj3 = sj3array[ij3];
{
IkReal evalcond[6];
IkReal x2368=IKsin(j3);
IkReal x2369=IKcos(j3);
IkReal x2370=((sj0)*(sj5));
IkReal x2371=((r00)*(sj6));
IkReal x2372=((IkReal(1.00000000000000))*(cj4));
IkReal x2373=((cj6)*(r01));
IkReal x2374=((cj0)*(cj5));
IkReal x2375=((cj5)*(sj0));
IkReal x2376=((cj6)*(r11));
IkReal x2377=((cj6)*(sj4));
IkReal x2378=((cj0)*(sj5));
IkReal x2379=((cj4)*(cj5));
IkReal x2380=((cj6)*(r21));
IkReal x2381=((r20)*(sj6));
IkReal x2382=((r10)*(sj6));
IkReal x2383=((IkReal(1.00000000000000))*(cj0));
IkReal x2384=((cj0)*(sj4)*(sj6));
IkReal x2385=((sj0)*(sj4)*(sj6));
evalcond[0]=((((IkReal(-1.00000000000000))*(cj5)*(r22)))+(((sj5)*(x2380)))+(((sj5)*(x2381)))+(((cj2)*(x2368))));
evalcond[1]=((((IkReal(-1.00000000000000))*(r21)*(sj4)*(sj6)))+(((IkReal(-1.00000000000000))*(cj2)*(x2369)))+(((cj4)*(r22)*(sj5)))+(((r20)*(x2377)))+(((x2379)*(x2381)))+(((x2379)*(x2380))));
evalcond[2]=((((IkReal(-1.00000000000000))*(x2376)*(x2378)))+(((r12)*(x2374)))+(((x2370)*(x2373)))+(((IkReal(-1.00000000000000))*(x2378)*(x2382)))+(((IkReal(-1.00000000000000))*(r02)*(x2375)))+(((x2370)*(x2371)))+(((IkReal(-1.00000000000000))*(sj2)*(x2368))));
evalcond[3]=((x2369)+(((IkReal(-1.00000000000000))*(x2370)*(x2382)))+(((r02)*(x2374)))+(((IkReal(-1.00000000000000))*(x2371)*(x2378)))+(((IkReal(-1.00000000000000))*(x2370)*(x2376)))+(((r12)*(x2375)))+(((IkReal(-1.00000000000000))*(x2373)*(x2378))));
evalcond[4]=((((IkReal(-1.00000000000000))*(r12)*(x2372)*(x2378)))+(((IkReal(-1.00000000000000))*(x2372)*(x2374)*(x2376)))+(((r11)*(x2384)))+(((cj4)*(x2373)*(x2375)))+(((cj4)*(r02)*(x2370)))+(((sj2)*(x2369)))+(((IkReal(-1.00000000000000))*(r01)*(x2385)))+(((r00)*(sj0)*(x2377)))+(((IkReal(-1.00000000000000))*(r10)*(x2377)*(x2383)))+(((IkReal(-1.00000000000000))*(x2372)*(x2374)*(x2382)))+(((cj4)*(x2371)*(x2375))));
evalcond[5]=((((IkReal(-1.00000000000000))*(x2372)*(x2373)*(x2374)))+(x2368)+(((IkReal(-1.00000000000000))*(r10)*(sj0)*(x2377)))+(((IkReal(-1.00000000000000))*(x2372)*(x2375)*(x2382)))+(((IkReal(-1.00000000000000))*(r00)*(x2377)*(x2383)))+(((r01)*(x2384)))+(((IkReal(-1.00000000000000))*(x2371)*(x2372)*(x2374)))+(((IkReal(-1.00000000000000))*(x2372)*(x2375)*(x2376)))+(((IkReal(-1.00000000000000))*(r12)*(x2370)*(x2372)))+(((IkReal(-1.00000000000000))*(r02)*(x2372)*(x2378)))+(((r11)*(x2385))));
if( IKabs(evalcond[0]) > 0.000001  || IKabs(evalcond[1]) > 0.000001  || IKabs(evalcond[2]) > 0.000001  || IKabs(evalcond[3]) > 0.000001  || IKabs(evalcond[4]) > 0.000001  || IKabs(evalcond[5]) > 0.000001  )
{
continue;
}
}

{
std::vector<IkSingleDOFSolutionBase<IkReal> > vinfos(7);
vinfos[0].jointtype = 1;
vinfos[0].foffset = j0;
vinfos[0].indices[0] = _ij0[0];
vinfos[0].indices[1] = _ij0[1];
vinfos[0].maxsolutions = _nj0;
vinfos[1].jointtype = 1;
vinfos[1].foffset = j1;
vinfos[1].indices[0] = _ij1[0];
vinfos[1].indices[1] = _ij1[1];
vinfos[1].maxsolutions = _nj1;
vinfos[2].jointtype = 1;
vinfos[2].foffset = j2;
vinfos[2].indices[0] = _ij2[0];
vinfos[2].indices[1] = _ij2[1];
vinfos[2].maxsolutions = _nj2;
vinfos[3].jointtype = 1;
vinfos[3].foffset = j3;
vinfos[3].indices[0] = _ij3[0];
vinfos[3].indices[1] = _ij3[1];
vinfos[3].maxsolutions = _nj3;
vinfos[4].jointtype = 1;
vinfos[4].foffset = j4;
vinfos[4].indices[0] = _ij4[0];
vinfos[4].indices[1] = _ij4[1];
vinfos[4].maxsolutions = _nj4;
vinfos[5].jointtype = 1;
vinfos[5].foffset = j5;
vinfos[5].indices[0] = _ij5[0];
vinfos[5].indices[1] = _ij5[1];
vinfos[5].maxsolutions = _nj5;
vinfos[6].jointtype = 1;
vinfos[6].foffset = j6;
vinfos[6].indices[0] = _ij6[0];
vinfos[6].indices[1] = _ij6[1];
vinfos[6].maxsolutions = _nj6;
std::vector<int> vfree(0);
solutions.AddSolution(vinfos,vfree);
}
}
}

}

}

} else
{
{
IkReal j3array[1], cj3array[1], sj3array[1];
bool j3valid[1]={false};
_nj3 = 1;
IkReal x2386=((IkReal(1.00000000000000))*(r21));
IkReal x2387=((cj4)*(cj5));
IkReal x2388=((r20)*(sj6));
if( IKabs(((gconst56)*(((((IkReal(-1.00000000000000))*(sj5)*(x2388)))+(((IkReal(-1.00000000000000))*(cj6)*(sj5)*(x2386)))+(((cj5)*(r22))))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(((gconst56)*(((((cj6)*(r20)*(sj4)))+(((cj4)*(r22)*(sj5)))+(((cj6)*(r21)*(x2387)))+(((x2387)*(x2388)))+(((IkReal(-1.00000000000000))*(sj4)*(sj6)*(x2386))))))) < IKFAST_ATAN2_MAGTHRESH )
    continue;
j3array[0]=IKatan2(((gconst56)*(((((IkReal(-1.00000000000000))*(sj5)*(x2388)))+(((IkReal(-1.00000000000000))*(cj6)*(sj5)*(x2386)))+(((cj5)*(r22)))))), ((gconst56)*(((((cj6)*(r20)*(sj4)))+(((cj4)*(r22)*(sj5)))+(((cj6)*(r21)*(x2387)))+(((x2387)*(x2388)))+(((IkReal(-1.00000000000000))*(sj4)*(sj6)*(x2386)))))));
sj3array[0]=IKsin(j3array[0]);
cj3array[0]=IKcos(j3array[0]);
if( j3array[0] > IKPI )
{
    j3array[0]-=IK2PI;
}
else if( j3array[0] < -IKPI )
{    j3array[0]+=IK2PI;
}
j3valid[0] = true;
for(int ij3 = 0; ij3 < 1; ++ij3)
{
if( !j3valid[ij3] )
{
    continue;
}
_ij3[0] = ij3; _ij3[1] = -1;
for(int iij3 = ij3+1; iij3 < 1; ++iij3)
{
if( j3valid[iij3] && IKabs(cj3array[ij3]-cj3array[iij3]) < IKFAST_SOLUTION_THRESH && IKabs(sj3array[ij3]-sj3array[iij3]) < IKFAST_SOLUTION_THRESH )
{
    j3valid[iij3]=false; _ij3[1] = iij3; break; 
}
}
j3 = j3array[ij3]; cj3 = cj3array[ij3]; sj3 = sj3array[ij3];
{
IkReal evalcond[6];
IkReal x2389=IKsin(j3);
IkReal x2390=IKcos(j3);
IkReal x2391=((sj0)*(sj5));
IkReal x2392=((r00)*(sj6));
IkReal x2393=((IkReal(1.00000000000000))*(cj4));
IkReal x2394=((cj6)*(r01));
IkReal x2395=((cj0)*(cj5));
IkReal x2396=((cj5)*(sj0));
IkReal x2397=((cj6)*(r11));
IkReal x2398=((cj6)*(sj4));
IkReal x2399=((cj0)*(sj5));
IkReal x2400=((cj4)*(cj5));
IkReal x2401=((cj6)*(r21));
IkReal x2402=((r20)*(sj6));
IkReal x2403=((r10)*(sj6));
IkReal x2404=((IkReal(1.00000000000000))*(cj0));
IkReal x2405=((cj0)*(sj4)*(sj6));
IkReal x2406=((sj0)*(sj4)*(sj6));
evalcond[0]=((((IkReal(-1.00000000000000))*(cj5)*(r22)))+(((cj2)*(x2389)))+(((sj5)*(x2401)))+(((sj5)*(x2402))));
evalcond[1]=((((IkReal(-1.00000000000000))*(r21)*(sj4)*(sj6)))+(((r20)*(x2398)))+(((x2400)*(x2402)))+(((cj4)*(r22)*(sj5)))+(((IkReal(-1.00000000000000))*(cj2)*(x2390)))+(((x2400)*(x2401))));
evalcond[2]=((((x2391)*(x2392)))+(((IkReal(-1.00000000000000))*(r02)*(x2396)))+(((IkReal(-1.00000000000000))*(x2399)*(x2403)))+(((IkReal(-1.00000000000000))*(sj2)*(x2389)))+(((IkReal(-1.00000000000000))*(x2397)*(x2399)))+(((r12)*(x2395)))+(((x2391)*(x2394))));
evalcond[3]=((((IkReal(-1.00000000000000))*(x2391)*(x2403)))+(((r12)*(x2396)))+(((r02)*(x2395)))+(((IkReal(-1.00000000000000))*(x2392)*(x2399)))+(x2390)+(((IkReal(-1.00000000000000))*(x2394)*(x2399)))+(((IkReal(-1.00000000000000))*(x2391)*(x2397))));
evalcond[4]=((((cj4)*(r02)*(x2391)))+(((sj2)*(x2390)))+(((cj4)*(x2392)*(x2396)))+(((IkReal(-1.00000000000000))*(r01)*(x2406)))+(((cj4)*(x2394)*(x2396)))+(((IkReal(-1.00000000000000))*(x2393)*(x2395)*(x2397)))+(((r11)*(x2405)))+(((IkReal(-1.00000000000000))*(r10)*(x2398)*(x2404)))+(((IkReal(-1.00000000000000))*(x2393)*(x2395)*(x2403)))+(((IkReal(-1.00000000000000))*(r12)*(x2393)*(x2399)))+(((r00)*(sj0)*(x2398))));
evalcond[5]=((x2389)+(((IkReal(-1.00000000000000))*(r00)*(x2398)*(x2404)))+(((r01)*(x2405)))+(((IkReal(-1.00000000000000))*(x2393)*(x2394)*(x2395)))+(((IkReal(-1.00000000000000))*(r12)*(x2391)*(x2393)))+(((IkReal(-1.00000000000000))*(x2393)*(x2396)*(x2397)))+(((IkReal(-1.00000000000000))*(x2393)*(x2396)*(x2403)))+(((r11)*(x2406)))+(((IkReal(-1.00000000000000))*(r10)*(sj0)*(x2398)))+(((IkReal(-1.00000000000000))*(x2392)*(x2393)*(x2395)))+(((IkReal(-1.00000000000000))*(r02)*(x2393)*(x2399))));
if( IKabs(evalcond[0]) > 0.000001  || IKabs(evalcond[1]) > 0.000001  || IKabs(evalcond[2]) > 0.000001  || IKabs(evalcond[3]) > 0.000001  || IKabs(evalcond[4]) > 0.000001  || IKabs(evalcond[5]) > 0.000001  )
{
continue;
}
}

{
std::vector<IkSingleDOFSolutionBase<IkReal> > vinfos(7);
vinfos[0].jointtype = 1;
vinfos[0].foffset = j0;
vinfos[0].indices[0] = _ij0[0];
vinfos[0].indices[1] = _ij0[1];
vinfos[0].maxsolutions = _nj0;
vinfos[1].jointtype = 1;
vinfos[1].foffset = j1;
vinfos[1].indices[0] = _ij1[0];
vinfos[1].indices[1] = _ij1[1];
vinfos[1].maxsolutions = _nj1;
vinfos[2].jointtype = 1;
vinfos[2].foffset = j2;
vinfos[2].indices[0] = _ij2[0];
vinfos[2].indices[1] = _ij2[1];
vinfos[2].maxsolutions = _nj2;
vinfos[3].jointtype = 1;
vinfos[3].foffset = j3;
vinfos[3].indices[0] = _ij3[0];
vinfos[3].indices[1] = _ij3[1];
vinfos[3].maxsolutions = _nj3;
vinfos[4].jointtype = 1;
vinfos[4].foffset = j4;
vinfos[4].indices[0] = _ij4[0];
vinfos[4].indices[1] = _ij4[1];
vinfos[4].maxsolutions = _nj4;
vinfos[5].jointtype = 1;
vinfos[5].foffset = j5;
vinfos[5].indices[0] = _ij5[0];
vinfos[5].indices[1] = _ij5[1];
vinfos[5].maxsolutions = _nj5;
vinfos[6].jointtype = 1;
vinfos[6].foffset = j6;
vinfos[6].indices[0] = _ij6[0];
vinfos[6].indices[1] = _ij6[1];
vinfos[6].maxsolutions = _nj6;
std::vector<int> vfree(0);
solutions.AddSolution(vinfos,vfree);
}
}
}

}

}
}
}

}

}
}
}

} else
{
IkReal x2407=((r20)*(sj6));
IkReal x2408=((IkReal(0.0100000000000000))*(cj5));
IkReal x2409=((IkReal(0.374290000000000))*(sj5));
IkReal x2410=((cj6)*(r21));
evalcond[0]=((IkReal(-3.14159265358979))+(IKfmod(((IkReal(1.57079632679490))+(j1)), IkReal(6.28318530717959))));
evalcond[1]=((IkReal(0.364420000000000))+(((IkReal(-1.00000000000000))*(x2408)*(x2410)))+(((IkReal(-1.00000000000000))*(x2407)*(x2408)))+(((x2407)*(x2409)))+(((IkReal(-0.0100000000000000))*(r22)*(sj5)))+(((IkReal(-0.374290000000000))*(cj5)*(r22)))+(pz)+(((x2409)*(x2410))));
if( IKabs(evalcond[0]) < 0.0000010000000000  && IKabs(evalcond[1]) < 0.0000010000000000  )
{
{
IkReal j2array[1], cj2array[1], sj2array[1];
bool j2valid[1]={false};
_nj2 = 1;
IkReal x2411=((IkReal(0.144927536231884))*(cj0));
IkReal x2412=((r02)*(sj5));
IkReal x2413=((IkReal(14.4927536231884))*(cj0));
IkReal x2414=((cj5)*(cj6));
IkReal x2415=((cj5)*(sj6));
IkReal x2416=((IkReal(5.42449275362319))*(sj0));
IkReal x2417=((cj5)*(r12));
IkReal x2418=((IkReal(14.4927536231884))*(sj0));
IkReal x2419=((IkReal(0.144927536231884))*(sj0));
IkReal x2420=((sj5)*(sj6));
IkReal x2421=((IkReal(5.42449275362319))*(cj0));
IkReal x2422=((r12)*(sj5));
IkReal x2423=((cj5)*(r02));
IkReal x2424=((cj6)*(r11)*(sj5));
IkReal x2425=((IkReal(5.42449275362319))*(cj6)*(r01)*(sj5));
if( IKabs(((((r10)*(x2420)*(x2421)))+(((IkReal(-1.00000000000000))*(r00)*(x2416)*(x2420)))+(((IkReal(-1.00000000000000))*(px)*(x2418)))+(((IkReal(-1.00000000000000))*(x2411)*(x2422)))+(((r01)*(x2414)*(x2419)))+(((py)*(x2413)))+(((x2421)*(x2424)))+(((x2412)*(x2419)))+(((IkReal(-1.00000000000000))*(r11)*(x2411)*(x2414)))+(((IkReal(-1.00000000000000))*(cj6)*(r01)*(sj5)*(x2416)))+(((IkReal(-1.00000000000000))*(r10)*(x2411)*(x2415)))+(((r00)*(x2415)*(x2419)))+(((IkReal(-1.00000000000000))*(x2417)*(x2421)))+(((x2416)*(x2423))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(((IkReal(1.00000000000000))+(((x2411)*(x2412)))+(((IkReal(-1.00000000000000))*(px)*(x2413)))+(((r00)*(x2411)*(x2415)))+(((r11)*(x2414)*(x2419)))+(((r10)*(x2415)*(x2419)))+(((x2421)*(x2423)))+(((x2416)*(x2417)))+(((r01)*(x2411)*(x2414)))+(((IkReal(-1.00000000000000))*(cj6)*(r01)*(sj5)*(x2421)))+(((IkReal(-1.00000000000000))*(r00)*(x2420)*(x2421)))+(((IkReal(-1.00000000000000))*(x2416)*(x2424)))+(((x2419)*(x2422)))+(((IkReal(-1.00000000000000))*(r10)*(x2416)*(x2420)))+(((IkReal(-1.00000000000000))*(py)*(x2418))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(IKsqr(((((r10)*(x2420)*(x2421)))+(((IkReal(-1.00000000000000))*(r00)*(x2416)*(x2420)))+(((IkReal(-1.00000000000000))*(px)*(x2418)))+(((IkReal(-1.00000000000000))*(x2411)*(x2422)))+(((r01)*(x2414)*(x2419)))+(((py)*(x2413)))+(((x2421)*(x2424)))+(((x2412)*(x2419)))+(((IkReal(-1.00000000000000))*(r11)*(x2411)*(x2414)))+(((IkReal(-1.00000000000000))*(cj6)*(r01)*(sj5)*(x2416)))+(((IkReal(-1.00000000000000))*(r10)*(x2411)*(x2415)))+(((r00)*(x2415)*(x2419)))+(((IkReal(-1.00000000000000))*(x2417)*(x2421)))+(((x2416)*(x2423)))))+IKsqr(((IkReal(1.00000000000000))+(((x2411)*(x2412)))+(((IkReal(-1.00000000000000))*(px)*(x2413)))+(((r00)*(x2411)*(x2415)))+(((r11)*(x2414)*(x2419)))+(((r10)*(x2415)*(x2419)))+(((x2421)*(x2423)))+(((x2416)*(x2417)))+(((r01)*(x2411)*(x2414)))+(((IkReal(-1.00000000000000))*(cj6)*(r01)*(sj5)*(x2421)))+(((IkReal(-1.00000000000000))*(r00)*(x2420)*(x2421)))+(((IkReal(-1.00000000000000))*(x2416)*(x2424)))+(((x2419)*(x2422)))+(((IkReal(-1.00000000000000))*(r10)*(x2416)*(x2420)))+(((IkReal(-1.00000000000000))*(py)*(x2418)))))-1) <= IKFAST_SINCOS_THRESH )
    continue;
j2array[0]=IKatan2(((((r10)*(x2420)*(x2421)))+(((IkReal(-1.00000000000000))*(r00)*(x2416)*(x2420)))+(((IkReal(-1.00000000000000))*(px)*(x2418)))+(((IkReal(-1.00000000000000))*(x2411)*(x2422)))+(((r01)*(x2414)*(x2419)))+(((py)*(x2413)))+(((x2421)*(x2424)))+(((x2412)*(x2419)))+(((IkReal(-1.00000000000000))*(r11)*(x2411)*(x2414)))+(((IkReal(-1.00000000000000))*(cj6)*(r01)*(sj5)*(x2416)))+(((IkReal(-1.00000000000000))*(r10)*(x2411)*(x2415)))+(((r00)*(x2415)*(x2419)))+(((IkReal(-1.00000000000000))*(x2417)*(x2421)))+(((x2416)*(x2423)))), ((IkReal(1.00000000000000))+(((x2411)*(x2412)))+(((IkReal(-1.00000000000000))*(px)*(x2413)))+(((r00)*(x2411)*(x2415)))+(((r11)*(x2414)*(x2419)))+(((r10)*(x2415)*(x2419)))+(((x2421)*(x2423)))+(((x2416)*(x2417)))+(((r01)*(x2411)*(x2414)))+(((IkReal(-1.00000000000000))*(cj6)*(r01)*(sj5)*(x2421)))+(((IkReal(-1.00000000000000))*(r00)*(x2420)*(x2421)))+(((IkReal(-1.00000000000000))*(x2416)*(x2424)))+(((x2419)*(x2422)))+(((IkReal(-1.00000000000000))*(r10)*(x2416)*(x2420)))+(((IkReal(-1.00000000000000))*(py)*(x2418)))));
sj2array[0]=IKsin(j2array[0]);
cj2array[0]=IKcos(j2array[0]);
if( j2array[0] > IKPI )
{
    j2array[0]-=IK2PI;
}
else if( j2array[0] < -IKPI )
{    j2array[0]+=IK2PI;
}
j2valid[0] = true;
for(int ij2 = 0; ij2 < 1; ++ij2)
{
if( !j2valid[ij2] )
{
    continue;
}
_ij2[0] = ij2; _ij2[1] = -1;
for(int iij2 = ij2+1; iij2 < 1; ++iij2)
{
if( j2valid[iij2] && IKabs(cj2array[ij2]-cj2array[iij2]) < IKFAST_SOLUTION_THRESH && IKabs(sj2array[ij2]-sj2array[iij2]) < IKFAST_SOLUTION_THRESH )
{
    j2valid[iij2]=false; _ij2[1] = iij2; break; 
}
}
j2 = j2array[ij2]; cj2 = cj2array[ij2]; sj2 = sj2array[ij2];
{
IkReal evalcond[2];
IkReal x2426=((IkReal(0.374290000000000))*(sj0));
IkReal x2427=((cj5)*(r02));
IkReal x2428=((IkReal(0.0100000000000000))*(cj0));
IkReal x2429=((cj5)*(cj6));
IkReal x2430=((r02)*(sj5));
IkReal x2431=((cj5)*(sj6));
IkReal x2432=((IkReal(1.00000000000000))*(py));
IkReal x2433=((cj6)*(sj5));
IkReal x2434=((IkReal(0.0100000000000000))*(sj0));
IkReal x2435=((sj5)*(sj6));
IkReal x2436=((cj5)*(r12));
IkReal x2437=((IkReal(0.374290000000000))*(cj0));
IkReal x2438=((r12)*(sj5));
IkReal x2439=((x2433)*(x2437));
IkReal x2440=((x2435)*(x2437));
evalcond[0]=((((x2428)*(x2438)))+(((IkReal(-1.00000000000000))*(r10)*(x2440)))+(((IkReal(-1.00000000000000))*(r00)*(x2431)*(x2434)))+(((IkReal(-1.00000000000000))*(r11)*(x2439)))+(((IkReal(-1.00000000000000))*(r01)*(x2429)*(x2434)))+(((r01)*(x2426)*(x2433)))+(((IkReal(-1.00000000000000))*(x2426)*(x2427)))+(((IkReal(0.0690000000000000))*(IKsin(j2))))+(((r10)*(x2428)*(x2431)))+(((r00)*(x2426)*(x2435)))+(((px)*(sj0)))+(((r11)*(x2428)*(x2429)))+(((IkReal(-1.00000000000000))*(cj0)*(x2432)))+(((IkReal(-1.00000000000000))*(x2430)*(x2434)))+(((x2436)*(x2437))));
evalcond[1]=((IkReal(0.0690000000000000))+(((IkReal(-1.00000000000000))*(cj0)*(px)))+(((x2434)*(x2438)))+(((IkReal(-0.0690000000000000))*(IKcos(j2))))+(((r00)*(x2428)*(x2431)))+(((x2426)*(x2436)))+(((r10)*(x2431)*(x2434)))+(((x2427)*(x2437)))+(((IkReal(-1.00000000000000))*(r00)*(x2440)))+(((IkReal(-1.00000000000000))*(r01)*(x2439)))+(((IkReal(-1.00000000000000))*(r10)*(x2426)*(x2435)))+(((r11)*(x2429)*(x2434)))+(((x2428)*(x2430)))+(((r01)*(x2428)*(x2429)))+(((IkReal(-1.00000000000000))*(r11)*(x2426)*(x2433)))+(((IkReal(-1.00000000000000))*(sj0)*(x2432))));
if( IKabs(evalcond[0]) > 0.000001  || IKabs(evalcond[1]) > 0.000001  )
{
continue;
}
}

{
IkReal dummyeval[1];
IkReal gconst65;
IkReal x2441=(cj6)*(cj6);
IkReal x2442=(sj6)*(sj6);
IkReal x2443=((IkReal(1.00000000000000))*(r21));
IkReal x2444=((cj6)*(r20));
IkReal x2445=((r22)*(sj5));
IkReal x2446=((r01)*(sj0));
IkReal x2447=((r00)*(sj0));
IkReal x2448=((cj0)*(r10));
IkReal x2449=((r02)*(sj0)*(sj5));
IkReal x2450=((cj5)*(x2441));
IkReal x2451=((cj0)*(r12)*(sj5));
IkReal x2452=((IkReal(1.00000000000000))*(cj0)*(r11));
IkReal x2453=((cj5)*(x2442));
IkReal x2454=((r20)*(x2453));
gconst65=IKsign(((((IkReal(-1.00000000000000))*(cj6)*(x2445)*(x2447)))+(((sj6)*(x2445)*(x2446)))+(((r21)*(x2448)*(x2450)))+(((IkReal(-1.00000000000000))*(x2443)*(x2447)*(x2453)))+(((x2446)*(x2454)))+(((IkReal(-1.00000000000000))*(x2443)*(x2447)*(x2450)))+(((r21)*(x2448)*(x2453)))+(((IkReal(-1.00000000000000))*(x2444)*(x2451)))+(((IkReal(-1.00000000000000))*(sj6)*(x2445)*(x2452)))+(((r20)*(x2446)*(x2450)))+(((IkReal(-1.00000000000000))*(x2452)*(x2454)))+(((IkReal(-1.00000000000000))*(r20)*(x2450)*(x2452)))+(((x2444)*(x2449)))+(((IkReal(-1.00000000000000))*(sj6)*(x2443)*(x2449)))+(((r21)*(sj6)*(x2451)))+(((cj6)*(x2445)*(x2448)))));
IkReal x2455=(cj6)*(cj6);
IkReal x2456=(sj6)*(sj6);
IkReal x2457=((IkReal(1.00000000000000))*(r21));
IkReal x2458=((cj6)*(r20));
IkReal x2459=((r22)*(sj5));
IkReal x2460=((r01)*(sj0));
IkReal x2461=((r00)*(sj0));
IkReal x2462=((cj0)*(r10));
IkReal x2463=((r02)*(sj0)*(sj5));
IkReal x2464=((cj5)*(x2455));
IkReal x2465=((cj0)*(r12)*(sj5));
IkReal x2466=((IkReal(1.00000000000000))*(cj0)*(r11));
IkReal x2467=((cj5)*(x2456));
IkReal x2468=((r20)*(x2467));
dummyeval[0]=((((IkReal(-1.00000000000000))*(x2458)*(x2465)))+(((r21)*(sj6)*(x2465)))+(((IkReal(-1.00000000000000))*(x2457)*(x2461)*(x2467)))+(((x2458)*(x2463)))+(((IkReal(-1.00000000000000))*(sj6)*(x2459)*(x2466)))+(((IkReal(-1.00000000000000))*(x2466)*(x2468)))+(((cj6)*(x2459)*(x2462)))+(((IkReal(-1.00000000000000))*(x2457)*(x2461)*(x2464)))+(((r20)*(x2460)*(x2464)))+(((r21)*(x2462)*(x2467)))+(((sj6)*(x2459)*(x2460)))+(((IkReal(-1.00000000000000))*(cj6)*(x2459)*(x2461)))+(((IkReal(-1.00000000000000))*(r20)*(x2464)*(x2466)))+(((IkReal(-1.00000000000000))*(sj6)*(x2457)*(x2463)))+(((r21)*(x2462)*(x2464)))+(((x2460)*(x2468))));
if( IKabs(dummyeval[0]) < 0.0000010000000000  )
{
{
IkReal dummyeval[1];
IkReal gconst66;
IkReal x2469=(sj6)*(sj6);
IkReal x2470=(cj6)*(cj6);
IkReal x2471=((r10)*(sj0));
IkReal x2472=((r22)*(sj5));
IkReal x2473=((cj0)*(cj5));
IkReal x2474=((IkReal(1.00000000000000))*(r20));
IkReal x2475=((cj0)*(sj6));
IkReal x2476=((r21)*(sj5));
IkReal x2477=((sj0)*(sj6));
IkReal x2478=((cj6)*(sj5));
IkReal x2479=((r21)*(x2470));
IkReal x2480=((cj5)*(r11)*(sj0));
IkReal x2481=((r21)*(x2469));
gconst66=IKsign(((((r12)*(x2476)*(x2477)))+(((IkReal(-1.00000000000000))*(x2470)*(x2474)*(x2480)))+(((IkReal(-1.00000000000000))*(r01)*(x2469)*(x2473)*(x2474)))+(((IkReal(-1.00000000000000))*(r01)*(x2472)*(x2475)))+(((r00)*(x2473)*(x2481)))+(((cj5)*(x2471)*(x2481)))+(((IkReal(-1.00000000000000))*(cj0)*(r02)*(x2474)*(x2478)))+(((r02)*(x2475)*(x2476)))+(((IkReal(-1.00000000000000))*(x2469)*(x2474)*(x2480)))+(((cj5)*(x2471)*(x2479)))+(((r00)*(x2473)*(x2479)))+(((IkReal(-1.00000000000000))*(r11)*(x2472)*(x2477)))+(((cj0)*(cj6)*(r00)*(x2472)))+(((IkReal(-1.00000000000000))*(r12)*(sj0)*(x2474)*(x2478)))+(((IkReal(-1.00000000000000))*(r01)*(x2470)*(x2473)*(x2474)))+(((cj6)*(x2471)*(x2472)))));
IkReal x2482=(sj6)*(sj6);
IkReal x2483=(cj6)*(cj6);
IkReal x2484=((r10)*(sj0));
IkReal x2485=((r22)*(sj5));
IkReal x2486=((cj0)*(cj5));
IkReal x2487=((IkReal(1.00000000000000))*(r20));
IkReal x2488=((cj0)*(sj6));
IkReal x2489=((r21)*(sj5));
IkReal x2490=((sj0)*(sj6));
IkReal x2491=((cj6)*(sj5));
IkReal x2492=((r21)*(x2483));
IkReal x2493=((cj5)*(r11)*(sj0));
IkReal x2494=((r21)*(x2482));
dummyeval[0]=((((cj6)*(x2484)*(x2485)))+(((r02)*(x2488)*(x2489)))+(((r00)*(x2486)*(x2494)))+(((cj5)*(x2484)*(x2494)))+(((IkReal(-1.00000000000000))*(r01)*(x2483)*(x2486)*(x2487)))+(((IkReal(-1.00000000000000))*(x2482)*(x2487)*(x2493)))+(((IkReal(-1.00000000000000))*(x2483)*(x2487)*(x2493)))+(((IkReal(-1.00000000000000))*(r01)*(x2485)*(x2488)))+(((IkReal(-1.00000000000000))*(r01)*(x2482)*(x2486)*(x2487)))+(((cj5)*(x2484)*(x2492)))+(((IkReal(-1.00000000000000))*(r11)*(x2485)*(x2490)))+(((IkReal(-1.00000000000000))*(cj0)*(r02)*(x2487)*(x2491)))+(((IkReal(-1.00000000000000))*(r12)*(sj0)*(x2487)*(x2491)))+(((cj0)*(cj6)*(r00)*(x2485)))+(((r00)*(x2486)*(x2492)))+(((r12)*(x2489)*(x2490))));
if( IKabs(dummyeval[0]) < 0.0000010000000000  )
{
{
IkReal dummyeval[1];
dummyeval[0]=cj2;
if( IKabs(dummyeval[0]) < 0.0000010000000000  )
{
{
IkReal evalcond[5];
IkReal x2495=((cj0)*(r11));
IkReal x2496=((r01)*(sj0));
IkReal x2497=((cj0)*(r01));
IkReal x2498=((IkReal(0.374290000000000))*(sj0));
IkReal x2499=((cj5)*(r02));
IkReal x2500=((IkReal(0.374290000000000))*(cj0));
IkReal x2501=((r11)*(sj0));
IkReal x2502=((IkReal(0.0100000000000000))*(cj0));
IkReal x2503=((r02)*(sj5));
IkReal x2504=((cj5)*(sj6));
IkReal x2505=((IkReal(1.00000000000000))*(sj0));
IkReal x2506=((cj5)*(r12));
IkReal x2507=((IkReal(0.0100000000000000))*(sj5));
IkReal x2508=((sj5)*(sj6));
IkReal x2509=((IkReal(1.00000000000000))*(cj0));
IkReal x2510=((IkReal(0.0100000000000000))*(sj0));
IkReal x2511=((IkReal(0.374290000000000))*(cj6)*(sj5));
IkReal x2512=((IkReal(0.0100000000000000))*(cj5)*(cj6));
IkReal x2513=((r10)*(x2508));
IkReal x2514=((IkReal(1.00000000000000))*(cj6)*(sj5));
evalcond[0]=((IkReal(-3.14159265358979))+(IKfmod(((IkReal(1.57079632679490))+(j2)), IkReal(6.28318530717959))));
evalcond[1]=((IkReal(0.364420000000000))+(((IkReal(0.374290000000000))*(r20)*(x2508)))+(((IkReal(-0.0100000000000000))*(r20)*(x2504)))+(((IkReal(-1.00000000000000))*(r21)*(x2512)))+(((r21)*(x2511)))+(((IkReal(-0.374290000000000))*(cj5)*(r22)))+(((IkReal(-1.00000000000000))*(r22)*(x2507)))+(pz));
evalcond[2]=((((sj0)*(x2506)))+(((IkReal(-1.00000000000000))*(x2501)*(x2514)))+(((IkReal(-1.00000000000000))*(r00)*(x2508)*(x2509)))+(((IkReal(-1.00000000000000))*(x2505)*(x2513)))+(((cj0)*(x2499)))+(((IkReal(-1.00000000000000))*(x2497)*(x2514))));
evalcond[3]=((IkReal(0.0690000000000000))+(((IkReal(-1.00000000000000))*(x2500)*(x2513)))+(((r10)*(x2502)*(x2504)))+(((IkReal(-1.00000000000000))*(x2495)*(x2511)))+(((IkReal(-1.00000000000000))*(py)*(x2509)))+(((x2500)*(x2506)))+(((IkReal(-1.00000000000000))*(x2498)*(x2499)))+(((x2495)*(x2512)))+(((IkReal(-1.00000000000000))*(r00)*(x2504)*(x2510)))+(((x2496)*(x2511)))+(((px)*(sj0)))+(((IkReal(-1.00000000000000))*(x2503)*(x2510)))+(((r12)*(sj5)*(x2502)))+(((r00)*(x2498)*(x2508)))+(((IkReal(-1.00000000000000))*(x2496)*(x2512))));
evalcond[4]=((IkReal(0.0690000000000000))+(((r00)*(x2502)*(x2504)))+(((IkReal(-1.00000000000000))*(cj6)*(r11)*(sj5)*(x2498)))+(((x2498)*(x2506)))+(((x2502)*(x2503)))+(((IkReal(-1.00000000000000))*(r00)*(x2500)*(x2508)))+(((r12)*(sj0)*(x2507)))+(((IkReal(-1.00000000000000))*(px)*(x2509)))+(((IkReal(-1.00000000000000))*(x2497)*(x2511)))+(((x2501)*(x2512)))+(((x2499)*(x2500)))+(((x2497)*(x2512)))+(((IkReal(-1.00000000000000))*(py)*(x2505)))+(((r10)*(x2504)*(x2510)))+(((IkReal(-1.00000000000000))*(x2498)*(x2513))));
if( IKabs(evalcond[0]) < 0.0000010000000000  && IKabs(evalcond[1]) < 0.0000010000000000  && IKabs(evalcond[2]) < 0.0000010000000000  && IKabs(evalcond[3]) < 0.0000010000000000  && IKabs(evalcond[4]) < 0.0000010000000000  )
{
{
IkReal j3array[1], cj3array[1], sj3array[1];
bool j3valid[1]={false};
_nj3 = 1;
IkReal x2515=((sj5)*(sj6));
IkReal x2516=((cj6)*(sj5));
IkReal x2517=((IkReal(1.00000000000000))*(cj0));
IkReal x2518=((IkReal(1.00000000000000))*(cj5));
if( IKabs(((((IkReal(-1.00000000000000))*(r11)*(x2516)*(x2517)))+(((r00)*(sj0)*(x2515)))+(((IkReal(-1.00000000000000))*(r10)*(x2515)*(x2517)))+(((IkReal(-1.00000000000000))*(r02)*(sj0)*(x2518)))+(((cj0)*(cj5)*(r12)))+(((r01)*(sj0)*(x2516))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(((((r20)*(x2515)))+(((r21)*(x2516)))+(((IkReal(-1.00000000000000))*(r22)*(x2518))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(IKsqr(((((IkReal(-1.00000000000000))*(r11)*(x2516)*(x2517)))+(((r00)*(sj0)*(x2515)))+(((IkReal(-1.00000000000000))*(r10)*(x2515)*(x2517)))+(((IkReal(-1.00000000000000))*(r02)*(sj0)*(x2518)))+(((cj0)*(cj5)*(r12)))+(((r01)*(sj0)*(x2516)))))+IKsqr(((((r20)*(x2515)))+(((r21)*(x2516)))+(((IkReal(-1.00000000000000))*(r22)*(x2518)))))-1) <= IKFAST_SINCOS_THRESH )
    continue;
j3array[0]=IKatan2(((((IkReal(-1.00000000000000))*(r11)*(x2516)*(x2517)))+(((r00)*(sj0)*(x2515)))+(((IkReal(-1.00000000000000))*(r10)*(x2515)*(x2517)))+(((IkReal(-1.00000000000000))*(r02)*(sj0)*(x2518)))+(((cj0)*(cj5)*(r12)))+(((r01)*(sj0)*(x2516)))), ((((r20)*(x2515)))+(((r21)*(x2516)))+(((IkReal(-1.00000000000000))*(r22)*(x2518)))));
sj3array[0]=IKsin(j3array[0]);
cj3array[0]=IKcos(j3array[0]);
if( j3array[0] > IKPI )
{
    j3array[0]-=IK2PI;
}
else if( j3array[0] < -IKPI )
{    j3array[0]+=IK2PI;
}
j3valid[0] = true;
for(int ij3 = 0; ij3 < 1; ++ij3)
{
if( !j3valid[ij3] )
{
    continue;
}
_ij3[0] = ij3; _ij3[1] = -1;
for(int iij3 = ij3+1; iij3 < 1; ++iij3)
{
if( j3valid[iij3] && IKabs(cj3array[ij3]-cj3array[iij3]) < IKFAST_SOLUTION_THRESH && IKabs(sj3array[ij3]-sj3array[iij3]) < IKFAST_SOLUTION_THRESH )
{
    j3valid[iij3]=false; _ij3[1] = iij3; break; 
}
}
j3 = j3array[ij3]; cj3 = cj3array[ij3]; sj3 = sj3array[ij3];
{
IkReal evalcond[2];
IkReal x2519=((sj5)*(sj6));
IkReal x2520=((cj6)*(sj5));
IkReal x2521=((IkReal(1.00000000000000))*(cj0));
IkReal x2522=((IkReal(1.00000000000000))*(cj5));
evalcond[0]=((((r21)*(x2520)))+(((IkReal(-1.00000000000000))*(IKcos(j3))))+(((r20)*(x2519)))+(((IkReal(-1.00000000000000))*(r22)*(x2522))));
evalcond[1]=((((IkReal(-1.00000000000000))*(r02)*(sj0)*(x2522)))+(((IkReal(-1.00000000000000))*(r11)*(x2520)*(x2521)))+(((r01)*(sj0)*(x2520)))+(((cj0)*(cj5)*(r12)))+(((IkReal(-1.00000000000000))*(r10)*(x2519)*(x2521)))+(((r00)*(sj0)*(x2519)))+(((IkReal(-1.00000000000000))*(IKsin(j3)))));
if( IKabs(evalcond[0]) > 0.000001  || IKabs(evalcond[1]) > 0.000001  )
{
continue;
}
}

{
IkReal dummyeval[1];
IkReal gconst71;
IkReal x2523=(r21)*(r21);
IkReal x2524=(cj5)*(cj5);
IkReal x2525=(sj6)*(sj6);
IkReal x2526=(cj6)*(cj6);
IkReal x2527=(r20)*(r20);
IkReal x2528=((cj6)*(r21));
IkReal x2529=((IkReal(2.00000000000000))*(r20)*(sj6));
IkReal x2530=((cj5)*(r22)*(sj5));
IkReal x2531=((IkReal(1.00000000000000))*(x2525));
IkReal x2532=((IkReal(1.00000000000000))*(x2526));
gconst71=IKsign(((((IkReal(-1.00000000000000))*(x2523)*(x2531)))+(((IkReal(-2.00000000000000))*(x2528)*(x2530)))+(((IkReal(-1.00000000000000))*((r22)*(r22))*((sj5)*(sj5))))+(((IkReal(-1.00000000000000))*(x2523)*(x2524)*(x2532)))+(((IkReal(-1.00000000000000))*(x2527)*(x2532)))+(((IkReal(-1.00000000000000))*(x2524)*(x2527)*(x2531)))+(((x2528)*(x2529)))+(((IkReal(-1.00000000000000))*(x2524)*(x2528)*(x2529)))+(((IkReal(-1.00000000000000))*(x2529)*(x2530)))));
IkReal x2533=(r21)*(r21);
IkReal x2534=(cj5)*(cj5);
IkReal x2535=(sj6)*(sj6);
IkReal x2536=(cj6)*(cj6);
IkReal x2537=(r20)*(r20);
IkReal x2538=((cj6)*(r21));
IkReal x2539=((IkReal(2.00000000000000))*(r20)*(sj6));
IkReal x2540=((cj5)*(r22)*(sj5));
IkReal x2541=((IkReal(1.00000000000000))*(x2535));
IkReal x2542=((IkReal(1.00000000000000))*(x2536));
dummyeval[0]=((((IkReal(-1.00000000000000))*(x2533)*(x2534)*(x2542)))+(((IkReal(-2.00000000000000))*(x2538)*(x2540)))+(((IkReal(-1.00000000000000))*(x2533)*(x2541)))+(((IkReal(-1.00000000000000))*(x2534)*(x2537)*(x2541)))+(((IkReal(-1.00000000000000))*((r22)*(r22))*((sj5)*(sj5))))+(((IkReal(-1.00000000000000))*(x2534)*(x2538)*(x2539)))+(((x2538)*(x2539)))+(((IkReal(-1.00000000000000))*(x2537)*(x2542)))+(((IkReal(-1.00000000000000))*(x2539)*(x2540))));
if( IKabs(dummyeval[0]) < 0.0000010000000000  )
{
{
IkReal dummyeval[1];
IkReal gconst72;
IkReal x2543=(sj6)*(sj6);
IkReal x2544=(cj5)*(cj5);
IkReal x2545=(cj6)*(cj6);
IkReal x2546=(sj5)*(sj5);
IkReal x2547=((r01)*(sj0));
IkReal x2548=((cj0)*(sj6));
IkReal x2549=((cj6)*(r21));
IkReal x2550=((r22)*(sj0));
IkReal x2551=((cj5)*(sj5));
IkReal x2552=((r00)*(sj6));
IkReal x2553=((IkReal(1.00000000000000))*(cj0));
IkReal x2554=((cj6)*(r22));
IkReal x2555=((r02)*(sj0));
IkReal x2556=((r20)*(sj6));
IkReal x2557=((IkReal(1.00000000000000))*(cj6));
IkReal x2558=((r00)*(sj0));
IkReal x2559=((r21)*(x2544));
IkReal x2560=((IkReal(1.00000000000000))*(x2551));
IkReal x2561=((r21)*(x2543));
IkReal x2562=((cj6)*(r11)*(r20));
IkReal x2563=((r20)*(x2545));
IkReal x2564=((r20)*(x2543)*(x2544));
gconst72=IKsign(((((IkReal(-1.00000000000000))*(r11)*(x2551)*(x2553)*(x2554)))+(((x2558)*(x2563)))+(((x2558)*(x2564)))+(((cj6)*(x2544)*(x2547)*(x2556)))+(((IkReal(-1.00000000000000))*(x2547)*(x2556)*(x2557)))+(((x2547)*(x2561)))+(((x2550)*(x2551)*(x2552)))+(((r10)*(x2548)*(x2549)))+(((IkReal(-1.00000000000000))*(r11)*(r20)*(x2544)*(x2548)*(x2557)))+(((r02)*(x2546)*(x2550)))+(((IkReal(-1.00000000000000))*(r12)*(x2549)*(x2551)*(x2553)))+(((IkReal(-1.00000000000000))*(r11)*(x2545)*(x2553)*(x2559)))+(((IkReal(-1.00000000000000))*(r12)*(r20)*(x2548)*(x2560)))+(((x2549)*(x2551)*(x2555)))+(((x2547)*(x2551)*(x2554)))+(((IkReal(-1.00000000000000))*(r12)*(r22)*(x2546)*(x2553)))+(((x2548)*(x2562)))+(((sj0)*(x2544)*(x2549)*(x2552)))+(((IkReal(-1.00000000000000))*(r10)*(x2544)*(x2548)*(x2549)))+(((IkReal(-1.00000000000000))*(r10)*(x2553)*(x2563)))+(((IkReal(-1.00000000000000))*(r10)*(x2553)*(x2564)))+(((IkReal(-1.00000000000000))*(r10)*(r22)*(x2548)*(x2560)))+(((x2545)*(x2547)*(x2559)))+(((IkReal(-1.00000000000000))*(sj0)*(x2549)*(x2552)))+(((x2551)*(x2555)*(x2556)))+(((IkReal(-1.00000000000000))*(r11)*(x2553)*(x2561)))));
IkReal x2565=(sj6)*(sj6);
IkReal x2566=(cj5)*(cj5);
IkReal x2567=(cj6)*(cj6);
IkReal x2568=(sj5)*(sj5);
IkReal x2569=((r01)*(sj0));
IkReal x2570=((cj0)*(sj6));
IkReal x2571=((cj6)*(r21));
IkReal x2572=((r22)*(sj0));
IkReal x2573=((cj5)*(sj5));
IkReal x2574=((r00)*(sj6));
IkReal x2575=((IkReal(1.00000000000000))*(cj0));
IkReal x2576=((cj6)*(r22));
IkReal x2577=((r02)*(sj0));
IkReal x2578=((r20)*(sj6));
IkReal x2579=((IkReal(1.00000000000000))*(cj6));
IkReal x2580=((r00)*(sj0));
IkReal x2581=((r21)*(x2566));
IkReal x2582=((IkReal(1.00000000000000))*(x2573));
IkReal x2583=((r21)*(x2565));
IkReal x2584=((cj6)*(r11)*(r20));
IkReal x2585=((r20)*(x2567));
IkReal x2586=((r20)*(x2565)*(x2566));
dummyeval[0]=((((IkReal(-1.00000000000000))*(r11)*(x2567)*(x2575)*(x2581)))+(((x2580)*(x2585)))+(((cj6)*(x2566)*(x2569)*(x2578)))+(((IkReal(-1.00000000000000))*(sj0)*(x2571)*(x2574)))+(((x2569)*(x2583)))+(((IkReal(-1.00000000000000))*(r12)*(x2571)*(x2573)*(x2575)))+(((IkReal(-1.00000000000000))*(r12)*(r20)*(x2570)*(x2582)))+(((IkReal(-1.00000000000000))*(r11)*(r20)*(x2566)*(x2570)*(x2579)))+(((IkReal(-1.00000000000000))*(r10)*(x2575)*(x2585)))+(((x2570)*(x2584)))+(((x2580)*(x2586)))+(((x2567)*(x2569)*(x2581)))+(((IkReal(-1.00000000000000))*(x2569)*(x2578)*(x2579)))+(((x2571)*(x2573)*(x2577)))+(((x2572)*(x2573)*(x2574)))+(((sj0)*(x2566)*(x2571)*(x2574)))+(((IkReal(-1.00000000000000))*(r12)*(r22)*(x2568)*(x2575)))+(((IkReal(-1.00000000000000))*(r10)*(r22)*(x2570)*(x2582)))+(((IkReal(-1.00000000000000))*(r10)*(x2566)*(x2570)*(x2571)))+(((r02)*(x2568)*(x2572)))+(((IkReal(-1.00000000000000))*(r11)*(x2573)*(x2575)*(x2576)))+(((x2569)*(x2573)*(x2576)))+(((x2573)*(x2577)*(x2578)))+(((IkReal(-1.00000000000000))*(r11)*(x2575)*(x2583)))+(((IkReal(-1.00000000000000))*(r10)*(x2575)*(x2586)))+(((r10)*(x2570)*(x2571))));
if( IKabs(dummyeval[0]) < 0.0000010000000000  )
{
continue;

} else
{
{
IkReal j4array[1], cj4array[1], sj4array[1];
bool j4valid[1]={false};
_nj4 = 1;
IkReal x2587=((IkReal(1.00000000000000))*(cj3));
IkReal x2588=((cj5)*(x2587));
if( IKabs(((gconst72)*(((((IkReal(-1.00000000000000))*(cj6)*(r20)*(x2587)))+(((cj3)*(r21)*(sj6))))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(((gconst72)*(((((IkReal(-1.00000000000000))*(cj6)*(r21)*(x2588)))+(((IkReal(-1.00000000000000))*(r20)*(sj6)*(x2588)))+(((IkReal(-1.00000000000000))*(r22)*(sj5)*(x2587))))))) < IKFAST_ATAN2_MAGTHRESH )
    continue;
j4array[0]=IKatan2(((gconst72)*(((((IkReal(-1.00000000000000))*(cj6)*(r20)*(x2587)))+(((cj3)*(r21)*(sj6)))))), ((gconst72)*(((((IkReal(-1.00000000000000))*(cj6)*(r21)*(x2588)))+(((IkReal(-1.00000000000000))*(r20)*(sj6)*(x2588)))+(((IkReal(-1.00000000000000))*(r22)*(sj5)*(x2587)))))));
sj4array[0]=IKsin(j4array[0]);
cj4array[0]=IKcos(j4array[0]);
if( j4array[0] > IKPI )
{
    j4array[0]-=IK2PI;
}
else if( j4array[0] < -IKPI )
{    j4array[0]+=IK2PI;
}
j4valid[0] = true;
for(int ij4 = 0; ij4 < 1; ++ij4)
{
if( !j4valid[ij4] )
{
    continue;
}
_ij4[0] = ij4; _ij4[1] = -1;
for(int iij4 = ij4+1; iij4 < 1; ++iij4)
{
if( j4valid[iij4] && IKabs(cj4array[ij4]-cj4array[iij4]) < IKFAST_SOLUTION_THRESH && IKabs(sj4array[ij4]-sj4array[iij4]) < IKFAST_SOLUTION_THRESH )
{
    j4valid[iij4]=false; _ij4[1] = iij4; break; 
}
}
j4 = j4array[ij4]; cj4 = cj4array[ij4]; sj4 = sj4array[ij4];
{
IkReal evalcond[6];
IkReal x2589=IKsin(j4);
IkReal x2590=IKcos(j4);
IkReal x2591=((r22)*(sj5));
IkReal x2592=((IkReal(1.00000000000000))*(cj6));
IkReal x2593=((IkReal(1.00000000000000))*(cj0));
IkReal x2594=((cj5)*(r11));
IkReal x2595=((cj5)*(cj6));
IkReal x2596=((r11)*(sj6));
IkReal x2597=((IkReal(1.00000000000000))*(sj6));
IkReal x2598=((cj6)*(r00));
IkReal x2599=((r12)*(sj5));
IkReal x2600=((r02)*(sj5));
IkReal x2601=((cj6)*(r10));
IkReal x2602=((cj5)*(sj6));
IkReal x2603=((cj5)*(r01));
IkReal x2604=((sj0)*(x2589));
IkReal x2605=((r00)*(x2602));
IkReal x2606=((cj0)*(x2589));
IkReal x2607=((sj0)*(x2590));
IkReal x2608=((r20)*(x2590));
IkReal x2609=((cj0)*(x2590));
IkReal x2610=((r21)*(x2589));
IkReal x2611=((r21)*(x2590));
IkReal x2612=((r20)*(x2589));
IkReal x2613=((x2590)*(x2599));
IkReal x2614=((r01)*(sj6)*(x2590));
IkReal x2615=((cj5)*(r10)*(x2597));
evalcond[0]=((((sj6)*(x2611)))+(((IkReal(-1.00000000000000))*(x2592)*(x2608)))+(((x2602)*(x2612)))+(((x2595)*(x2610)))+(((x2589)*(x2591))));
evalcond[1]=((((x2602)*(x2608)))+(((x2590)*(x2591)))+(((IkReal(-1.00000000000000))*(x2597)*(x2610)))+(((cj6)*(x2612)))+(((IkReal(-1.00000000000000))*(sj3)))+(((x2595)*(x2611))));
evalcond[2]=((((IkReal(-1.00000000000000))*(x2589)*(x2593)*(x2599)))+(((IkReal(-1.00000000000000))*(r10)*(x2589)*(x2593)*(x2602)))+(((x2600)*(x2604)))+(((x2604)*(x2605)))+(((IkReal(-1.00000000000000))*(r00)*(x2592)*(x2607)))+(((r01)*(x2595)*(x2604)))+(((IkReal(-1.00000000000000))*(x2592)*(x2594)*(x2606)))+(((IkReal(-1.00000000000000))*(x2590)*(x2593)*(x2596)))+(((x2601)*(x2609)))+(((r01)*(sj6)*(x2607))));
evalcond[3]=((((IkReal(-1.00000000000000))*(r10)*(x2592)*(x2606)))+(((IkReal(-1.00000000000000))*(x2593)*(x2613)))+(((IkReal(-1.00000000000000))*(r10)*(x2590)*(x2593)*(x2602)))+(((IkReal(-1.00000000000000))*(x2592)*(x2594)*(x2609)))+(cj3)+(((x2600)*(x2607)))+(((x2598)*(x2604)))+(((IkReal(-1.00000000000000))*(r01)*(x2597)*(x2604)))+(((r01)*(x2595)*(x2607)))+(((x2605)*(x2607)))+(((x2596)*(x2606))));
evalcond[4]=((IkReal(1.00000000000000))+(((IkReal(-1.00000000000000))*(x2604)*(x2615)))+(((IkReal(-1.00000000000000))*(x2589)*(x2593)*(x2600)))+(((IkReal(-1.00000000000000))*(x2589)*(x2593)*(x2605)))+(((IkReal(-1.00000000000000))*(x2592)*(x2594)*(x2604)))+(((IkReal(-1.00000000000000))*(x2592)*(x2603)*(x2606)))+(((IkReal(-1.00000000000000))*(x2599)*(x2604)))+(((x2601)*(x2607)))+(((IkReal(-1.00000000000000))*(x2596)*(x2607)))+(((x2598)*(x2609)))+(((IkReal(-1.00000000000000))*(x2593)*(x2614))));
evalcond[5]=((((IkReal(-1.00000000000000))*(x2607)*(x2615)))+(((r01)*(sj6)*(x2606)))+(((IkReal(-1.00000000000000))*(r00)*(x2592)*(x2606)))+(((IkReal(-1.00000000000000))*(x2592)*(x2603)*(x2609)))+(((IkReal(-1.00000000000000))*(x2590)*(x2593)*(x2600)))+(((IkReal(-1.00000000000000))*(x2599)*(x2607)))+(((IkReal(-1.00000000000000))*(x2590)*(x2593)*(x2605)))+(((IkReal(-1.00000000000000))*(x2592)*(x2594)*(x2607)))+(((x2596)*(x2604)))+(((IkReal(-1.00000000000000))*(r10)*(x2592)*(x2604))));
if( IKabs(evalcond[0]) > 0.000001  || IKabs(evalcond[1]) > 0.000001  || IKabs(evalcond[2]) > 0.000001  || IKabs(evalcond[3]) > 0.000001  || IKabs(evalcond[4]) > 0.000001  || IKabs(evalcond[5]) > 0.000001  )
{
continue;
}
}

{
std::vector<IkSingleDOFSolutionBase<IkReal> > vinfos(7);
vinfos[0].jointtype = 1;
vinfos[0].foffset = j0;
vinfos[0].indices[0] = _ij0[0];
vinfos[0].indices[1] = _ij0[1];
vinfos[0].maxsolutions = _nj0;
vinfos[1].jointtype = 1;
vinfos[1].foffset = j1;
vinfos[1].indices[0] = _ij1[0];
vinfos[1].indices[1] = _ij1[1];
vinfos[1].maxsolutions = _nj1;
vinfos[2].jointtype = 1;
vinfos[2].foffset = j2;
vinfos[2].indices[0] = _ij2[0];
vinfos[2].indices[1] = _ij2[1];
vinfos[2].maxsolutions = _nj2;
vinfos[3].jointtype = 1;
vinfos[3].foffset = j3;
vinfos[3].indices[0] = _ij3[0];
vinfos[3].indices[1] = _ij3[1];
vinfos[3].maxsolutions = _nj3;
vinfos[4].jointtype = 1;
vinfos[4].foffset = j4;
vinfos[4].indices[0] = _ij4[0];
vinfos[4].indices[1] = _ij4[1];
vinfos[4].maxsolutions = _nj4;
vinfos[5].jointtype = 1;
vinfos[5].foffset = j5;
vinfos[5].indices[0] = _ij5[0];
vinfos[5].indices[1] = _ij5[1];
vinfos[5].maxsolutions = _nj5;
vinfos[6].jointtype = 1;
vinfos[6].foffset = j6;
vinfos[6].indices[0] = _ij6[0];
vinfos[6].indices[1] = _ij6[1];
vinfos[6].maxsolutions = _nj6;
std::vector<int> vfree(0);
solutions.AddSolution(vinfos,vfree);
}
}
}

}

}

} else
{
{
IkReal j4array[1], cj4array[1], sj4array[1];
bool j4valid[1]={false};
_nj4 = 1;
IkReal x2616=((r21)*(sj3));
IkReal x2617=((IkReal(1.00000000000000))*(r20)*(sj3));
if( IKabs(((gconst71)*(((((IkReal(-1.00000000000000))*(cj6)*(x2617)))+(((sj6)*(x2616))))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(((gconst71)*(((((IkReal(-1.00000000000000))*(cj5)*(sj6)*(x2617)))+(((IkReal(-1.00000000000000))*(cj5)*(cj6)*(x2616)))+(((IkReal(-1.00000000000000))*(r22)*(sj3)*(sj5))))))) < IKFAST_ATAN2_MAGTHRESH )
    continue;
j4array[0]=IKatan2(((gconst71)*(((((IkReal(-1.00000000000000))*(cj6)*(x2617)))+(((sj6)*(x2616)))))), ((gconst71)*(((((IkReal(-1.00000000000000))*(cj5)*(sj6)*(x2617)))+(((IkReal(-1.00000000000000))*(cj5)*(cj6)*(x2616)))+(((IkReal(-1.00000000000000))*(r22)*(sj3)*(sj5)))))));
sj4array[0]=IKsin(j4array[0]);
cj4array[0]=IKcos(j4array[0]);
if( j4array[0] > IKPI )
{
    j4array[0]-=IK2PI;
}
else if( j4array[0] < -IKPI )
{    j4array[0]+=IK2PI;
}
j4valid[0] = true;
for(int ij4 = 0; ij4 < 1; ++ij4)
{
if( !j4valid[ij4] )
{
    continue;
}
_ij4[0] = ij4; _ij4[1] = -1;
for(int iij4 = ij4+1; iij4 < 1; ++iij4)
{
if( j4valid[iij4] && IKabs(cj4array[ij4]-cj4array[iij4]) < IKFAST_SOLUTION_THRESH && IKabs(sj4array[ij4]-sj4array[iij4]) < IKFAST_SOLUTION_THRESH )
{
    j4valid[iij4]=false; _ij4[1] = iij4; break; 
}
}
j4 = j4array[ij4]; cj4 = cj4array[ij4]; sj4 = sj4array[ij4];
{
IkReal evalcond[6];
IkReal x2618=IKsin(j4);
IkReal x2619=IKcos(j4);
IkReal x2620=((r22)*(sj5));
IkReal x2621=((IkReal(1.00000000000000))*(cj6));
IkReal x2622=((IkReal(1.00000000000000))*(cj0));
IkReal x2623=((cj5)*(r11));
IkReal x2624=((cj5)*(cj6));
IkReal x2625=((r11)*(sj6));
IkReal x2626=((IkReal(1.00000000000000))*(sj6));
IkReal x2627=((cj6)*(r00));
IkReal x2628=((r12)*(sj5));
IkReal x2629=((r02)*(sj5));
IkReal x2630=((cj6)*(r10));
IkReal x2631=((cj5)*(sj6));
IkReal x2632=((cj5)*(r01));
IkReal x2633=((sj0)*(x2618));
IkReal x2634=((r00)*(x2631));
IkReal x2635=((cj0)*(x2618));
IkReal x2636=((sj0)*(x2619));
IkReal x2637=((r20)*(x2619));
IkReal x2638=((cj0)*(x2619));
IkReal x2639=((r21)*(x2618));
IkReal x2640=((r21)*(x2619));
IkReal x2641=((r20)*(x2618));
IkReal x2642=((x2619)*(x2628));
IkReal x2643=((r01)*(sj6)*(x2619));
IkReal x2644=((cj5)*(r10)*(x2626));
evalcond[0]=((((sj6)*(x2640)))+(((IkReal(-1.00000000000000))*(x2621)*(x2637)))+(((x2631)*(x2641)))+(((x2618)*(x2620)))+(((x2624)*(x2639))));
evalcond[1]=((((x2624)*(x2640)))+(((IkReal(-1.00000000000000))*(x2626)*(x2639)))+(((x2619)*(x2620)))+(((x2631)*(x2637)))+(((cj6)*(x2641)))+(((IkReal(-1.00000000000000))*(sj3))));
evalcond[2]=((((IkReal(-1.00000000000000))*(x2618)*(x2622)*(x2628)))+(((IkReal(-1.00000000000000))*(x2621)*(x2623)*(x2635)))+(((IkReal(-1.00000000000000))*(r00)*(x2621)*(x2636)))+(((r01)*(sj6)*(x2636)))+(((x2633)*(x2634)))+(((x2630)*(x2638)))+(((IkReal(-1.00000000000000))*(x2619)*(x2622)*(x2625)))+(((r01)*(x2624)*(x2633)))+(((x2629)*(x2633)))+(((IkReal(-1.00000000000000))*(r10)*(x2618)*(x2622)*(x2631))));
evalcond[3]=((((IkReal(-1.00000000000000))*(r10)*(x2621)*(x2635)))+(((IkReal(-1.00000000000000))*(r01)*(x2626)*(x2633)))+(((r01)*(x2624)*(x2636)))+(((x2629)*(x2636)))+(((IkReal(-1.00000000000000))*(x2622)*(x2642)))+(((x2634)*(x2636)))+(cj3)+(((x2627)*(x2633)))+(((x2625)*(x2635)))+(((IkReal(-1.00000000000000))*(x2621)*(x2623)*(x2638)))+(((IkReal(-1.00000000000000))*(r10)*(x2619)*(x2622)*(x2631))));
evalcond[4]=((IkReal(1.00000000000000))+(((IkReal(-1.00000000000000))*(x2618)*(x2622)*(x2629)))+(((x2630)*(x2636)))+(((IkReal(-1.00000000000000))*(x2628)*(x2633)))+(((IkReal(-1.00000000000000))*(x2621)*(x2623)*(x2633)))+(((IkReal(-1.00000000000000))*(x2625)*(x2636)))+(((x2627)*(x2638)))+(((IkReal(-1.00000000000000))*(x2633)*(x2644)))+(((IkReal(-1.00000000000000))*(x2621)*(x2632)*(x2635)))+(((IkReal(-1.00000000000000))*(x2622)*(x2643)))+(((IkReal(-1.00000000000000))*(x2618)*(x2622)*(x2634))));
evalcond[5]=((((IkReal(-1.00000000000000))*(r00)*(x2621)*(x2635)))+(((x2625)*(x2633)))+(((IkReal(-1.00000000000000))*(r10)*(x2621)*(x2633)))+(((IkReal(-1.00000000000000))*(x2621)*(x2632)*(x2638)))+(((IkReal(-1.00000000000000))*(x2636)*(x2644)))+(((IkReal(-1.00000000000000))*(x2619)*(x2622)*(x2629)))+(((IkReal(-1.00000000000000))*(x2619)*(x2622)*(x2634)))+(((IkReal(-1.00000000000000))*(x2621)*(x2623)*(x2636)))+(((r01)*(sj6)*(x2635)))+(((IkReal(-1.00000000000000))*(x2628)*(x2636))));
if( IKabs(evalcond[0]) > 0.000001  || IKabs(evalcond[1]) > 0.000001  || IKabs(evalcond[2]) > 0.000001  || IKabs(evalcond[3]) > 0.000001  || IKabs(evalcond[4]) > 0.000001  || IKabs(evalcond[5]) > 0.000001  )
{
continue;
}
}

{
std::vector<IkSingleDOFSolutionBase<IkReal> > vinfos(7);
vinfos[0].jointtype = 1;
vinfos[0].foffset = j0;
vinfos[0].indices[0] = _ij0[0];
vinfos[0].indices[1] = _ij0[1];
vinfos[0].maxsolutions = _nj0;
vinfos[1].jointtype = 1;
vinfos[1].foffset = j1;
vinfos[1].indices[0] = _ij1[0];
vinfos[1].indices[1] = _ij1[1];
vinfos[1].maxsolutions = _nj1;
vinfos[2].jointtype = 1;
vinfos[2].foffset = j2;
vinfos[2].indices[0] = _ij2[0];
vinfos[2].indices[1] = _ij2[1];
vinfos[2].maxsolutions = _nj2;
vinfos[3].jointtype = 1;
vinfos[3].foffset = j3;
vinfos[3].indices[0] = _ij3[0];
vinfos[3].indices[1] = _ij3[1];
vinfos[3].maxsolutions = _nj3;
vinfos[4].jointtype = 1;
vinfos[4].foffset = j4;
vinfos[4].indices[0] = _ij4[0];
vinfos[4].indices[1] = _ij4[1];
vinfos[4].maxsolutions = _nj4;
vinfos[5].jointtype = 1;
vinfos[5].foffset = j5;
vinfos[5].indices[0] = _ij5[0];
vinfos[5].indices[1] = _ij5[1];
vinfos[5].maxsolutions = _nj5;
vinfos[6].jointtype = 1;
vinfos[6].foffset = j6;
vinfos[6].indices[0] = _ij6[0];
vinfos[6].indices[1] = _ij6[1];
vinfos[6].maxsolutions = _nj6;
std::vector<int> vfree(0);
solutions.AddSolution(vinfos,vfree);
}
}
}

}

}
}
}

} else
{
IkReal x2645=((cj0)*(r11));
IkReal x2646=((r01)*(sj0));
IkReal x2647=((cj0)*(r01));
IkReal x2648=((IkReal(0.374290000000000))*(sj0));
IkReal x2649=((cj5)*(r02));
IkReal x2650=((IkReal(0.374290000000000))*(cj0));
IkReal x2651=((r11)*(sj0));
IkReal x2652=((IkReal(0.0100000000000000))*(cj0));
IkReal x2653=((r02)*(sj5));
IkReal x2654=((cj5)*(sj6));
IkReal x2655=((IkReal(1.00000000000000))*(sj0));
IkReal x2656=((cj5)*(r12));
IkReal x2657=((IkReal(0.0100000000000000))*(sj5));
IkReal x2658=((sj5)*(sj6));
IkReal x2659=((IkReal(1.00000000000000))*(cj0));
IkReal x2660=((IkReal(0.0100000000000000))*(sj0));
IkReal x2661=((IkReal(0.374290000000000))*(cj6)*(sj5));
IkReal x2662=((IkReal(0.0100000000000000))*(cj5)*(cj6));
IkReal x2663=((r10)*(x2658));
IkReal x2664=((IkReal(1.00000000000000))*(cj6)*(sj5));
evalcond[0]=((IkReal(-3.14159265358979))+(IKfmod(((IkReal(4.71238898038469))+(j2)), IkReal(6.28318530717959))));
evalcond[1]=((IkReal(0.364420000000000))+(((IkReal(-0.0100000000000000))*(r20)*(x2654)))+(((IkReal(-1.00000000000000))*(r21)*(x2662)))+(((IkReal(-0.374290000000000))*(cj5)*(r22)))+(((IkReal(0.374290000000000))*(r20)*(x2658)))+(((IkReal(-1.00000000000000))*(r22)*(x2657)))+(pz)+(((r21)*(x2661))));
evalcond[2]=((((IkReal(-1.00000000000000))*(x2651)*(x2664)))+(((IkReal(-1.00000000000000))*(r00)*(x2658)*(x2659)))+(((IkReal(-1.00000000000000))*(x2647)*(x2664)))+(((sj0)*(x2656)))+(((cj0)*(x2649)))+(((IkReal(-1.00000000000000))*(x2655)*(x2663))));
evalcond[3]=((IkReal(-0.0690000000000000))+(((IkReal(-1.00000000000000))*(x2648)*(x2649)))+(((r10)*(x2652)*(x2654)))+(((IkReal(-1.00000000000000))*(x2650)*(x2663)))+(((x2645)*(x2662)))+(((IkReal(-1.00000000000000))*(x2646)*(x2662)))+(((IkReal(-1.00000000000000))*(x2645)*(x2661)))+(((IkReal(-1.00000000000000))*(r00)*(x2654)*(x2660)))+(((IkReal(-1.00000000000000))*(py)*(x2659)))+(((r12)*(sj5)*(x2652)))+(((x2650)*(x2656)))+(((r00)*(x2648)*(x2658)))+(((px)*(sj0)))+(((IkReal(-1.00000000000000))*(x2653)*(x2660)))+(((x2646)*(x2661))));
evalcond[4]=((IkReal(0.0690000000000000))+(((IkReal(-1.00000000000000))*(x2648)*(x2663)))+(((x2648)*(x2656)))+(((x2651)*(x2662)))+(((x2652)*(x2653)))+(((IkReal(-1.00000000000000))*(px)*(x2659)))+(((x2649)*(x2650)))+(((r10)*(x2654)*(x2660)))+(((r12)*(sj0)*(x2657)))+(((x2647)*(x2662)))+(((IkReal(-1.00000000000000))*(cj6)*(r11)*(sj5)*(x2648)))+(((r00)*(x2652)*(x2654)))+(((IkReal(-1.00000000000000))*(r00)*(x2650)*(x2658)))+(((IkReal(-1.00000000000000))*(x2647)*(x2661)))+(((IkReal(-1.00000000000000))*(py)*(x2655))));
if( IKabs(evalcond[0]) < 0.0000010000000000  && IKabs(evalcond[1]) < 0.0000010000000000  && IKabs(evalcond[2]) < 0.0000010000000000  && IKabs(evalcond[3]) < 0.0000010000000000  && IKabs(evalcond[4]) < 0.0000010000000000  )
{
{
IkReal j3array[1], cj3array[1], sj3array[1];
bool j3valid[1]={false};
_nj3 = 1;
IkReal x2665=((sj5)*(sj6));
IkReal x2666=((IkReal(1.00000000000000))*(cj5));
IkReal x2667=((IkReal(1.00000000000000))*(sj0));
IkReal x2668=((cj6)*(sj5));
if( IKabs(((((IkReal(-1.00000000000000))*(cj0)*(r12)*(x2666)))+(((cj0)*(r11)*(x2668)))+(((cj5)*(r02)*(sj0)))+(((IkReal(-1.00000000000000))*(r01)*(x2667)*(x2668)))+(((cj0)*(r10)*(x2665)))+(((IkReal(-1.00000000000000))*(r00)*(x2665)*(x2667))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(((((r20)*(x2665)))+(((IkReal(-1.00000000000000))*(r22)*(x2666)))+(((r21)*(x2668))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(IKsqr(((((IkReal(-1.00000000000000))*(cj0)*(r12)*(x2666)))+(((cj0)*(r11)*(x2668)))+(((cj5)*(r02)*(sj0)))+(((IkReal(-1.00000000000000))*(r01)*(x2667)*(x2668)))+(((cj0)*(r10)*(x2665)))+(((IkReal(-1.00000000000000))*(r00)*(x2665)*(x2667)))))+IKsqr(((((r20)*(x2665)))+(((IkReal(-1.00000000000000))*(r22)*(x2666)))+(((r21)*(x2668)))))-1) <= IKFAST_SINCOS_THRESH )
    continue;
j3array[0]=IKatan2(((((IkReal(-1.00000000000000))*(cj0)*(r12)*(x2666)))+(((cj0)*(r11)*(x2668)))+(((cj5)*(r02)*(sj0)))+(((IkReal(-1.00000000000000))*(r01)*(x2667)*(x2668)))+(((cj0)*(r10)*(x2665)))+(((IkReal(-1.00000000000000))*(r00)*(x2665)*(x2667)))), ((((r20)*(x2665)))+(((IkReal(-1.00000000000000))*(r22)*(x2666)))+(((r21)*(x2668)))));
sj3array[0]=IKsin(j3array[0]);
cj3array[0]=IKcos(j3array[0]);
if( j3array[0] > IKPI )
{
    j3array[0]-=IK2PI;
}
else if( j3array[0] < -IKPI )
{    j3array[0]+=IK2PI;
}
j3valid[0] = true;
for(int ij3 = 0; ij3 < 1; ++ij3)
{
if( !j3valid[ij3] )
{
    continue;
}
_ij3[0] = ij3; _ij3[1] = -1;
for(int iij3 = ij3+1; iij3 < 1; ++iij3)
{
if( j3valid[iij3] && IKabs(cj3array[ij3]-cj3array[iij3]) < IKFAST_SOLUTION_THRESH && IKabs(sj3array[ij3]-sj3array[iij3]) < IKFAST_SOLUTION_THRESH )
{
    j3valid[iij3]=false; _ij3[1] = iij3; break; 
}
}
j3 = j3array[ij3]; cj3 = cj3array[ij3]; sj3 = sj3array[ij3];
{
IkReal evalcond[2];
IkReal x2669=((sj5)*(sj6));
IkReal x2670=((cj6)*(sj5));
IkReal x2671=((IkReal(1.00000000000000))*(cj0));
IkReal x2672=((IkReal(1.00000000000000))*(cj5));
evalcond[0]=((((IkReal(-1.00000000000000))*(IKcos(j3))))+(((r21)*(x2670)))+(((IkReal(-1.00000000000000))*(r22)*(x2672)))+(((r20)*(x2669))));
evalcond[1]=((((r00)*(sj0)*(x2669)))+(((IkReal(-1.00000000000000))*(r10)*(x2669)*(x2671)))+(((cj0)*(cj5)*(r12)))+(((IkReal(-1.00000000000000))*(r02)*(sj0)*(x2672)))+(((r01)*(sj0)*(x2670)))+(((IkReal(-1.00000000000000))*(r11)*(x2670)*(x2671)))+(IKsin(j3)));
if( IKabs(evalcond[0]) > 0.000001  || IKabs(evalcond[1]) > 0.000001  )
{
continue;
}
}

{
IkReal dummyeval[1];
IkReal gconst75;
IkReal x2673=(r21)*(r21);
IkReal x2674=(cj5)*(cj5);
IkReal x2675=(sj6)*(sj6);
IkReal x2676=(cj6)*(cj6);
IkReal x2677=(r20)*(r20);
IkReal x2678=((cj6)*(r21));
IkReal x2679=((IkReal(2.00000000000000))*(r20)*(sj6));
IkReal x2680=((cj5)*(r22)*(sj5));
IkReal x2681=((IkReal(1.00000000000000))*(x2675));
IkReal x2682=((IkReal(1.00000000000000))*(x2676));
gconst75=IKsign(((((x2678)*(x2679)))+(((IkReal(-1.00000000000000))*(x2674)*(x2677)*(x2681)))+(((IkReal(-1.00000000000000))*(x2673)*(x2681)))+(((IkReal(-1.00000000000000))*((r22)*(r22))*((sj5)*(sj5))))+(((IkReal(-1.00000000000000))*(x2679)*(x2680)))+(((IkReal(-2.00000000000000))*(x2678)*(x2680)))+(((IkReal(-1.00000000000000))*(x2674)*(x2678)*(x2679)))+(((IkReal(-1.00000000000000))*(x2677)*(x2682)))+(((IkReal(-1.00000000000000))*(x2673)*(x2674)*(x2682)))));
IkReal x2683=(r21)*(r21);
IkReal x2684=(cj5)*(cj5);
IkReal x2685=(sj6)*(sj6);
IkReal x2686=(cj6)*(cj6);
IkReal x2687=(r20)*(r20);
IkReal x2688=((cj6)*(r21));
IkReal x2689=((IkReal(2.00000000000000))*(r20)*(sj6));
IkReal x2690=((cj5)*(r22)*(sj5));
IkReal x2691=((IkReal(1.00000000000000))*(x2685));
IkReal x2692=((IkReal(1.00000000000000))*(x2686));
dummyeval[0]=((((IkReal(-1.00000000000000))*(x2689)*(x2690)))+(((IkReal(-1.00000000000000))*(x2683)*(x2691)))+(((IkReal(-1.00000000000000))*((r22)*(r22))*((sj5)*(sj5))))+(((x2688)*(x2689)))+(((IkReal(-1.00000000000000))*(x2683)*(x2684)*(x2692)))+(((IkReal(-2.00000000000000))*(x2688)*(x2690)))+(((IkReal(-1.00000000000000))*(x2684)*(x2687)*(x2691)))+(((IkReal(-1.00000000000000))*(x2684)*(x2688)*(x2689)))+(((IkReal(-1.00000000000000))*(x2687)*(x2692))));
if( IKabs(dummyeval[0]) < 0.0000010000000000  )
{
{
IkReal dummyeval[1];
IkReal gconst76;
IkReal x2693=(cj6)*(cj6);
IkReal x2694=(cj5)*(cj5);
IkReal x2695=(sj6)*(sj6);
IkReal x2696=(sj5)*(sj5);
IkReal x2697=((cj0)*(r12));
IkReal x2698=((cj6)*(sj6));
IkReal x2699=((cj0)*(r21));
IkReal x2700=((cj0)*(r11));
IkReal x2701=((IkReal(1.00000000000000))*(r20));
IkReal x2702=((r01)*(sj0));
IkReal x2703=((r00)*(sj0));
IkReal x2704=((IkReal(1.00000000000000))*(r22));
IkReal x2705=((cj0)*(r10));
IkReal x2706=((r02)*(sj0));
IkReal x2707=((r22)*(x2696));
IkReal x2708=((IkReal(1.00000000000000))*(r21)*(sj0));
IkReal x2709=((cj5)*(cj6)*(sj5));
IkReal x2710=((cj5)*(sj5)*(sj6));
IkReal x2711=((cj0)*(r20)*(x2694));
IkReal x2712=((x2693)*(x2694));
gconst76=IKsign(((((IkReal(-1.00000000000000))*(r10)*(x2698)*(x2699)))+(((x2697)*(x2707)))+(((r21)*(x2698)*(x2703)))+(((IkReal(-1.00000000000000))*(x2698)*(x2700)*(x2701)))+(((r20)*(x2694)*(x2698)*(x2700)))+(((r20)*(x2694)*(x2695)*(x2705)))+(((IkReal(-1.00000000000000))*(x2696)*(x2704)*(x2706)))+(((IkReal(-1.00000000000000))*(x2701)*(x2706)*(x2710)))+(((r20)*(x2693)*(x2705)))+(((IkReal(-1.00000000000000))*(r21)*(x2706)*(x2709)))+(((IkReal(-1.00000000000000))*(x2693)*(x2701)*(x2703)))+(((r22)*(x2705)*(x2710)))+(((IkReal(-1.00000000000000))*(x2694)*(x2698)*(x2701)*(x2702)))+(((r21)*(x2697)*(x2709)))+(((IkReal(-1.00000000000000))*(x2703)*(x2704)*(x2710)))+(((IkReal(-1.00000000000000))*(x2694)*(x2695)*(x2701)*(x2703)))+(((IkReal(-1.00000000000000))*(x2702)*(x2704)*(x2709)))+(((r20)*(x2698)*(x2702)))+(((r10)*(x2694)*(x2698)*(x2699)))+(((r11)*(x2695)*(x2699)))+(((IkReal(-1.00000000000000))*(r21)*(x2702)*(x2712)))+(((IkReal(-1.00000000000000))*(r21)*(x2694)*(x2698)*(x2703)))+(((r20)*(x2697)*(x2710)))+(((r22)*(x2700)*(x2709)))+(((IkReal(-1.00000000000000))*(r21)*(x2695)*(x2702)))+(((r11)*(x2699)*(x2712)))));
IkReal x2713=(cj6)*(cj6);
IkReal x2714=(cj5)*(cj5);
IkReal x2715=(sj6)*(sj6);
IkReal x2716=(sj5)*(sj5);
IkReal x2717=((cj0)*(r12));
IkReal x2718=((cj6)*(sj6));
IkReal x2719=((cj0)*(r21));
IkReal x2720=((cj0)*(r11));
IkReal x2721=((IkReal(1.00000000000000))*(r20));
IkReal x2722=((r01)*(sj0));
IkReal x2723=((r00)*(sj0));
IkReal x2724=((IkReal(1.00000000000000))*(r22));
IkReal x2725=((cj0)*(r10));
IkReal x2726=((r02)*(sj0));
IkReal x2727=((r22)*(x2716));
IkReal x2728=((IkReal(1.00000000000000))*(r21)*(sj0));
IkReal x2729=((cj5)*(cj6)*(sj5));
IkReal x2730=((cj5)*(sj5)*(sj6));
IkReal x2731=((cj0)*(r20)*(x2714));
IkReal x2732=((x2713)*(x2714));
dummyeval[0]=((((IkReal(-1.00000000000000))*(x2714)*(x2715)*(x2721)*(x2723)))+(((r22)*(x2725)*(x2730)))+(((IkReal(-1.00000000000000))*(x2714)*(x2718)*(x2721)*(x2722)))+(((IkReal(-1.00000000000000))*(r21)*(x2715)*(x2722)))+(((r11)*(x2715)*(x2719)))+(((x2717)*(x2727)))+(((IkReal(-1.00000000000000))*(x2723)*(x2724)*(x2730)))+(((IkReal(-1.00000000000000))*(x2722)*(x2724)*(x2729)))+(((r21)*(x2717)*(x2729)))+(((IkReal(-1.00000000000000))*(r10)*(x2718)*(x2719)))+(((r11)*(x2719)*(x2732)))+(((r21)*(x2718)*(x2723)))+(((IkReal(-1.00000000000000))*(x2713)*(x2721)*(x2723)))+(((IkReal(-1.00000000000000))*(x2716)*(x2724)*(x2726)))+(((r20)*(x2714)*(x2715)*(x2725)))+(((r10)*(x2714)*(x2718)*(x2719)))+(((r20)*(x2713)*(x2725)))+(((IkReal(-1.00000000000000))*(x2718)*(x2720)*(x2721)))+(((r20)*(x2718)*(x2722)))+(((IkReal(-1.00000000000000))*(r21)*(x2714)*(x2718)*(x2723)))+(((IkReal(-1.00000000000000))*(r21)*(x2726)*(x2729)))+(((IkReal(-1.00000000000000))*(x2721)*(x2726)*(x2730)))+(((r20)*(x2714)*(x2718)*(x2720)))+(((r20)*(x2717)*(x2730)))+(((r22)*(x2720)*(x2729)))+(((IkReal(-1.00000000000000))*(r21)*(x2722)*(x2732))));
if( IKabs(dummyeval[0]) < 0.0000010000000000  )
{
continue;

} else
{
{
IkReal j4array[1], cj4array[1], sj4array[1];
bool j4valid[1]={false};
_nj4 = 1;
IkReal x2733=((IkReal(1.00000000000000))*(cj3));
IkReal x2734=((cj5)*(x2733));
if( IKabs(((gconst76)*(((((IkReal(-1.00000000000000))*(cj6)*(r20)*(x2733)))+(((cj3)*(r21)*(sj6))))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(((gconst76)*(((((IkReal(-1.00000000000000))*(r20)*(sj6)*(x2734)))+(((IkReal(-1.00000000000000))*(r22)*(sj5)*(x2733)))+(((IkReal(-1.00000000000000))*(cj6)*(r21)*(x2734))))))) < IKFAST_ATAN2_MAGTHRESH )
    continue;
j4array[0]=IKatan2(((gconst76)*(((((IkReal(-1.00000000000000))*(cj6)*(r20)*(x2733)))+(((cj3)*(r21)*(sj6)))))), ((gconst76)*(((((IkReal(-1.00000000000000))*(r20)*(sj6)*(x2734)))+(((IkReal(-1.00000000000000))*(r22)*(sj5)*(x2733)))+(((IkReal(-1.00000000000000))*(cj6)*(r21)*(x2734)))))));
sj4array[0]=IKsin(j4array[0]);
cj4array[0]=IKcos(j4array[0]);
if( j4array[0] > IKPI )
{
    j4array[0]-=IK2PI;
}
else if( j4array[0] < -IKPI )
{    j4array[0]+=IK2PI;
}
j4valid[0] = true;
for(int ij4 = 0; ij4 < 1; ++ij4)
{
if( !j4valid[ij4] )
{
    continue;
}
_ij4[0] = ij4; _ij4[1] = -1;
for(int iij4 = ij4+1; iij4 < 1; ++iij4)
{
if( j4valid[iij4] && IKabs(cj4array[ij4]-cj4array[iij4]) < IKFAST_SOLUTION_THRESH && IKabs(sj4array[ij4]-sj4array[iij4]) < IKFAST_SOLUTION_THRESH )
{
    j4valid[iij4]=false; _ij4[1] = iij4; break; 
}
}
j4 = j4array[ij4]; cj4 = cj4array[ij4]; sj4 = sj4array[ij4];
{
IkReal evalcond[6];
IkReal x2735=IKsin(j4);
IkReal x2736=IKcos(j4);
IkReal x2737=((r22)*(sj5));
IkReal x2738=((IkReal(1.00000000000000))*(cj6));
IkReal x2739=((IkReal(1.00000000000000))*(cj0));
IkReal x2740=((cj5)*(r11));
IkReal x2741=((cj5)*(cj6));
IkReal x2742=((r11)*(sj6));
IkReal x2743=((IkReal(1.00000000000000))*(sj6));
IkReal x2744=((cj6)*(r00));
IkReal x2745=((r12)*(sj5));
IkReal x2746=((r02)*(sj5));
IkReal x2747=((cj6)*(r10));
IkReal x2748=((cj5)*(sj6));
IkReal x2749=((cj5)*(r01));
IkReal x2750=((sj0)*(x2735));
IkReal x2751=((r00)*(x2748));
IkReal x2752=((cj0)*(x2735));
IkReal x2753=((sj0)*(x2736));
IkReal x2754=((r20)*(x2736));
IkReal x2755=((cj0)*(x2736));
IkReal x2756=((r21)*(x2735));
IkReal x2757=((r21)*(x2736));
IkReal x2758=((r20)*(x2735));
IkReal x2759=((x2736)*(x2745));
IkReal x2760=((r01)*(sj6)*(x2736));
IkReal x2761=((cj5)*(r10)*(x2743));
evalcond[0]=((((x2748)*(x2758)))+(((x2735)*(x2737)))+(((x2741)*(x2756)))+(((IkReal(-1.00000000000000))*(x2738)*(x2754)))+(((sj6)*(x2757))));
evalcond[1]=((((x2736)*(x2737)))+(((x2741)*(x2757)))+(((x2748)*(x2754)))+(((cj6)*(x2758)))+(((IkReal(-1.00000000000000))*(sj3)))+(((IkReal(-1.00000000000000))*(x2743)*(x2756))));
evalcond[2]=((((IkReal(-1.00000000000000))*(x2736)*(x2739)*(x2742)))+(((IkReal(-1.00000000000000))*(r00)*(x2738)*(x2753)))+(((x2750)*(x2751)))+(((r01)*(x2741)*(x2750)))+(((IkReal(-1.00000000000000))*(r10)*(x2735)*(x2739)*(x2748)))+(((IkReal(-1.00000000000000))*(x2738)*(x2740)*(x2752)))+(((x2746)*(x2750)))+(((x2747)*(x2755)))+(((IkReal(-1.00000000000000))*(x2735)*(x2739)*(x2745)))+(((r01)*(sj6)*(x2753))));
evalcond[3]=((((x2751)*(x2753)))+(((IkReal(-1.00000000000000))*(x2738)*(x2740)*(x2755)))+(((IkReal(-1.00000000000000))*(x2739)*(x2759)))+(((IkReal(-1.00000000000000))*(r10)*(x2738)*(x2752)))+(((IkReal(-1.00000000000000))*(r10)*(x2736)*(x2739)*(x2748)))+(((x2744)*(x2750)))+(((x2746)*(x2753)))+(((r01)*(x2741)*(x2753)))+(((x2742)*(x2752)))+(((IkReal(-1.00000000000000))*(cj3)))+(((IkReal(-1.00000000000000))*(r01)*(x2743)*(x2750))));
evalcond[4]=((IkReal(-1.00000000000000))+(((IkReal(-1.00000000000000))*(x2739)*(x2760)))+(((IkReal(-1.00000000000000))*(x2745)*(x2750)))+(((IkReal(-1.00000000000000))*(x2735)*(x2739)*(x2746)))+(((IkReal(-1.00000000000000))*(x2742)*(x2753)))+(((IkReal(-1.00000000000000))*(x2735)*(x2739)*(x2751)))+(((IkReal(-1.00000000000000))*(x2738)*(x2740)*(x2750)))+(((IkReal(-1.00000000000000))*(x2750)*(x2761)))+(((IkReal(-1.00000000000000))*(x2738)*(x2749)*(x2752)))+(((x2744)*(x2755)))+(((x2747)*(x2753))));
evalcond[5]=((((IkReal(-1.00000000000000))*(x2736)*(x2739)*(x2751)))+(((r01)*(sj6)*(x2752)))+(((IkReal(-1.00000000000000))*(x2738)*(x2740)*(x2753)))+(((x2742)*(x2750)))+(((IkReal(-1.00000000000000))*(x2745)*(x2753)))+(((IkReal(-1.00000000000000))*(x2738)*(x2749)*(x2755)))+(((IkReal(-1.00000000000000))*(x2736)*(x2739)*(x2746)))+(((IkReal(-1.00000000000000))*(x2753)*(x2761)))+(((IkReal(-1.00000000000000))*(r00)*(x2738)*(x2752)))+(((IkReal(-1.00000000000000))*(r10)*(x2738)*(x2750))));
if( IKabs(evalcond[0]) > 0.000001  || IKabs(evalcond[1]) > 0.000001  || IKabs(evalcond[2]) > 0.000001  || IKabs(evalcond[3]) > 0.000001  || IKabs(evalcond[4]) > 0.000001  || IKabs(evalcond[5]) > 0.000001  )
{
continue;
}
}

{
std::vector<IkSingleDOFSolutionBase<IkReal> > vinfos(7);
vinfos[0].jointtype = 1;
vinfos[0].foffset = j0;
vinfos[0].indices[0] = _ij0[0];
vinfos[0].indices[1] = _ij0[1];
vinfos[0].maxsolutions = _nj0;
vinfos[1].jointtype = 1;
vinfos[1].foffset = j1;
vinfos[1].indices[0] = _ij1[0];
vinfos[1].indices[1] = _ij1[1];
vinfos[1].maxsolutions = _nj1;
vinfos[2].jointtype = 1;
vinfos[2].foffset = j2;
vinfos[2].indices[0] = _ij2[0];
vinfos[2].indices[1] = _ij2[1];
vinfos[2].maxsolutions = _nj2;
vinfos[3].jointtype = 1;
vinfos[3].foffset = j3;
vinfos[3].indices[0] = _ij3[0];
vinfos[3].indices[1] = _ij3[1];
vinfos[3].maxsolutions = _nj3;
vinfos[4].jointtype = 1;
vinfos[4].foffset = j4;
vinfos[4].indices[0] = _ij4[0];
vinfos[4].indices[1] = _ij4[1];
vinfos[4].maxsolutions = _nj4;
vinfos[5].jointtype = 1;
vinfos[5].foffset = j5;
vinfos[5].indices[0] = _ij5[0];
vinfos[5].indices[1] = _ij5[1];
vinfos[5].maxsolutions = _nj5;
vinfos[6].jointtype = 1;
vinfos[6].foffset = j6;
vinfos[6].indices[0] = _ij6[0];
vinfos[6].indices[1] = _ij6[1];
vinfos[6].maxsolutions = _nj6;
std::vector<int> vfree(0);
solutions.AddSolution(vinfos,vfree);
}
}
}

}

}

} else
{
{
IkReal j4array[1], cj4array[1], sj4array[1];
bool j4valid[1]={false};
_nj4 = 1;
IkReal x2762=((r21)*(sj3));
IkReal x2763=((IkReal(1.00000000000000))*(r20)*(sj3));
if( IKabs(((gconst75)*(((((IkReal(-1.00000000000000))*(cj6)*(x2763)))+(((sj6)*(x2762))))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(((gconst75)*(((((IkReal(-1.00000000000000))*(cj5)*(cj6)*(x2762)))+(((IkReal(-1.00000000000000))*(cj5)*(sj6)*(x2763)))+(((IkReal(-1.00000000000000))*(r22)*(sj3)*(sj5))))))) < IKFAST_ATAN2_MAGTHRESH )
    continue;
j4array[0]=IKatan2(((gconst75)*(((((IkReal(-1.00000000000000))*(cj6)*(x2763)))+(((sj6)*(x2762)))))), ((gconst75)*(((((IkReal(-1.00000000000000))*(cj5)*(cj6)*(x2762)))+(((IkReal(-1.00000000000000))*(cj5)*(sj6)*(x2763)))+(((IkReal(-1.00000000000000))*(r22)*(sj3)*(sj5)))))));
sj4array[0]=IKsin(j4array[0]);
cj4array[0]=IKcos(j4array[0]);
if( j4array[0] > IKPI )
{
    j4array[0]-=IK2PI;
}
else if( j4array[0] < -IKPI )
{    j4array[0]+=IK2PI;
}
j4valid[0] = true;
for(int ij4 = 0; ij4 < 1; ++ij4)
{
if( !j4valid[ij4] )
{
    continue;
}
_ij4[0] = ij4; _ij4[1] = -1;
for(int iij4 = ij4+1; iij4 < 1; ++iij4)
{
if( j4valid[iij4] && IKabs(cj4array[ij4]-cj4array[iij4]) < IKFAST_SOLUTION_THRESH && IKabs(sj4array[ij4]-sj4array[iij4]) < IKFAST_SOLUTION_THRESH )
{
    j4valid[iij4]=false; _ij4[1] = iij4; break; 
}
}
j4 = j4array[ij4]; cj4 = cj4array[ij4]; sj4 = sj4array[ij4];
{
IkReal evalcond[6];
IkReal x2764=IKsin(j4);
IkReal x2765=IKcos(j4);
IkReal x2766=((r22)*(sj5));
IkReal x2767=((IkReal(1.00000000000000))*(cj6));
IkReal x2768=((IkReal(1.00000000000000))*(cj0));
IkReal x2769=((cj5)*(r11));
IkReal x2770=((cj5)*(cj6));
IkReal x2771=((r11)*(sj6));
IkReal x2772=((IkReal(1.00000000000000))*(sj6));
IkReal x2773=((cj6)*(r00));
IkReal x2774=((r12)*(sj5));
IkReal x2775=((r02)*(sj5));
IkReal x2776=((cj6)*(r10));
IkReal x2777=((cj5)*(sj6));
IkReal x2778=((cj5)*(r01));
IkReal x2779=((sj0)*(x2764));
IkReal x2780=((r00)*(x2777));
IkReal x2781=((cj0)*(x2764));
IkReal x2782=((sj0)*(x2765));
IkReal x2783=((r20)*(x2765));
IkReal x2784=((cj0)*(x2765));
IkReal x2785=((r21)*(x2764));
IkReal x2786=((r21)*(x2765));
IkReal x2787=((r20)*(x2764));
IkReal x2788=((x2765)*(x2774));
IkReal x2789=((r01)*(sj6)*(x2765));
IkReal x2790=((cj5)*(r10)*(x2772));
evalcond[0]=((((sj6)*(x2786)))+(((x2777)*(x2787)))+(((IkReal(-1.00000000000000))*(x2767)*(x2783)))+(((x2764)*(x2766)))+(((x2770)*(x2785))));
evalcond[1]=((((x2770)*(x2786)))+(((x2765)*(x2766)))+(((x2777)*(x2783)))+(((IkReal(-1.00000000000000))*(sj3)))+(((cj6)*(x2787)))+(((IkReal(-1.00000000000000))*(x2772)*(x2785))));
evalcond[2]=((((IkReal(-1.00000000000000))*(x2767)*(x2769)*(x2781)))+(((IkReal(-1.00000000000000))*(x2764)*(x2768)*(x2774)))+(((r01)*(sj6)*(x2782)))+(((IkReal(-1.00000000000000))*(x2765)*(x2768)*(x2771)))+(((IkReal(-1.00000000000000))*(r10)*(x2764)*(x2768)*(x2777)))+(((x2779)*(x2780)))+(((x2775)*(x2779)))+(((r01)*(x2770)*(x2779)))+(((x2776)*(x2784)))+(((IkReal(-1.00000000000000))*(r00)*(x2767)*(x2782))));
evalcond[3]=((((r01)*(x2770)*(x2782)))+(((x2773)*(x2779)))+(((IkReal(-1.00000000000000))*(x2767)*(x2769)*(x2784)))+(((IkReal(-1.00000000000000))*(r10)*(x2767)*(x2781)))+(((IkReal(-1.00000000000000))*(r10)*(x2765)*(x2768)*(x2777)))+(((x2780)*(x2782)))+(((IkReal(-1.00000000000000))*(cj3)))+(((x2775)*(x2782)))+(((IkReal(-1.00000000000000))*(r01)*(x2772)*(x2779)))+(((x2771)*(x2781)))+(((IkReal(-1.00000000000000))*(x2768)*(x2788))));
evalcond[4]=((IkReal(-1.00000000000000))+(((x2776)*(x2782)))+(((IkReal(-1.00000000000000))*(x2764)*(x2768)*(x2775)))+(((IkReal(-1.00000000000000))*(x2774)*(x2779)))+(((IkReal(-1.00000000000000))*(x2764)*(x2768)*(x2780)))+(((IkReal(-1.00000000000000))*(x2767)*(x2778)*(x2781)))+(((x2773)*(x2784)))+(((IkReal(-1.00000000000000))*(x2771)*(x2782)))+(((IkReal(-1.00000000000000))*(x2768)*(x2789)))+(((IkReal(-1.00000000000000))*(x2779)*(x2790)))+(((IkReal(-1.00000000000000))*(x2767)*(x2769)*(x2779))));
evalcond[5]=((((IkReal(-1.00000000000000))*(x2767)*(x2778)*(x2784)))+(((r01)*(sj6)*(x2781)))+(((IkReal(-1.00000000000000))*(r10)*(x2767)*(x2779)))+(((IkReal(-1.00000000000000))*(x2765)*(x2768)*(x2780)))+(((IkReal(-1.00000000000000))*(x2767)*(x2769)*(x2782)))+(((IkReal(-1.00000000000000))*(x2774)*(x2782)))+(((x2771)*(x2779)))+(((IkReal(-1.00000000000000))*(x2782)*(x2790)))+(((IkReal(-1.00000000000000))*(r00)*(x2767)*(x2781)))+(((IkReal(-1.00000000000000))*(x2765)*(x2768)*(x2775))));
if( IKabs(evalcond[0]) > 0.000001  || IKabs(evalcond[1]) > 0.000001  || IKabs(evalcond[2]) > 0.000001  || IKabs(evalcond[3]) > 0.000001  || IKabs(evalcond[4]) > 0.000001  || IKabs(evalcond[5]) > 0.000001  )
{
continue;
}
}

{
std::vector<IkSingleDOFSolutionBase<IkReal> > vinfos(7);
vinfos[0].jointtype = 1;
vinfos[0].foffset = j0;
vinfos[0].indices[0] = _ij0[0];
vinfos[0].indices[1] = _ij0[1];
vinfos[0].maxsolutions = _nj0;
vinfos[1].jointtype = 1;
vinfos[1].foffset = j1;
vinfos[1].indices[0] = _ij1[0];
vinfos[1].indices[1] = _ij1[1];
vinfos[1].maxsolutions = _nj1;
vinfos[2].jointtype = 1;
vinfos[2].foffset = j2;
vinfos[2].indices[0] = _ij2[0];
vinfos[2].indices[1] = _ij2[1];
vinfos[2].maxsolutions = _nj2;
vinfos[3].jointtype = 1;
vinfos[3].foffset = j3;
vinfos[3].indices[0] = _ij3[0];
vinfos[3].indices[1] = _ij3[1];
vinfos[3].maxsolutions = _nj3;
vinfos[4].jointtype = 1;
vinfos[4].foffset = j4;
vinfos[4].indices[0] = _ij4[0];
vinfos[4].indices[1] = _ij4[1];
vinfos[4].maxsolutions = _nj4;
vinfos[5].jointtype = 1;
vinfos[5].foffset = j5;
vinfos[5].indices[0] = _ij5[0];
vinfos[5].indices[1] = _ij5[1];
vinfos[5].maxsolutions = _nj5;
vinfos[6].jointtype = 1;
vinfos[6].foffset = j6;
vinfos[6].indices[0] = _ij6[0];
vinfos[6].indices[1] = _ij6[1];
vinfos[6].maxsolutions = _nj6;
std::vector<int> vfree(0);
solutions.AddSolution(vinfos,vfree);
}
}
}

}

}
}
}

} else
{
if( 1 )
{
continue;

} else
{
}
}
}
}

} else
{
{
IkReal j3array[1], cj3array[1], sj3array[1];
bool j3valid[1]={false};
_nj3 = 1;
IkReal x2791=((sj5)*(sj6));
IkReal x2792=((IkReal(1.00000000000000))*(cj5));
IkReal x2793=((cj6)*(sj5));
if( IKabs(((((IKabs(cj2) != 0)?((IkReal)1/(cj2)):(IkReal)1.0e30))*(((((cj0)*(r00)*(x2791)))+(((IkReal(-1.00000000000000))*(cj0)*(r02)*(x2792)))+(((r11)*(sj0)*(x2793)))+(((IkReal(-1.00000000000000))*(r12)*(sj0)*(x2792)))+(((r10)*(sj0)*(x2791)))+(((cj0)*(r01)*(x2793))))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(((((IkReal(-1.00000000000000))*(r22)*(x2792)))+(((r21)*(x2793)))+(((r20)*(x2791))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(IKsqr(((((IKabs(cj2) != 0)?((IkReal)1/(cj2)):(IkReal)1.0e30))*(((((cj0)*(r00)*(x2791)))+(((IkReal(-1.00000000000000))*(cj0)*(r02)*(x2792)))+(((r11)*(sj0)*(x2793)))+(((IkReal(-1.00000000000000))*(r12)*(sj0)*(x2792)))+(((r10)*(sj0)*(x2791)))+(((cj0)*(r01)*(x2793)))))))+IKsqr(((((IkReal(-1.00000000000000))*(r22)*(x2792)))+(((r21)*(x2793)))+(((r20)*(x2791)))))-1) <= IKFAST_SINCOS_THRESH )
    continue;
j3array[0]=IKatan2(((((IKabs(cj2) != 0)?((IkReal)1/(cj2)):(IkReal)1.0e30))*(((((cj0)*(r00)*(x2791)))+(((IkReal(-1.00000000000000))*(cj0)*(r02)*(x2792)))+(((r11)*(sj0)*(x2793)))+(((IkReal(-1.00000000000000))*(r12)*(sj0)*(x2792)))+(((r10)*(sj0)*(x2791)))+(((cj0)*(r01)*(x2793)))))), ((((IkReal(-1.00000000000000))*(r22)*(x2792)))+(((r21)*(x2793)))+(((r20)*(x2791)))));
sj3array[0]=IKsin(j3array[0]);
cj3array[0]=IKcos(j3array[0]);
if( j3array[0] > IKPI )
{
    j3array[0]-=IK2PI;
}
else if( j3array[0] < -IKPI )
{    j3array[0]+=IK2PI;
}
j3valid[0] = true;
for(int ij3 = 0; ij3 < 1; ++ij3)
{
if( !j3valid[ij3] )
{
    continue;
}
_ij3[0] = ij3; _ij3[1] = -1;
for(int iij3 = ij3+1; iij3 < 1; ++iij3)
{
if( j3valid[iij3] && IKabs(cj3array[ij3]-cj3array[iij3]) < IKFAST_SOLUTION_THRESH && IKabs(sj3array[ij3]-sj3array[iij3]) < IKFAST_SOLUTION_THRESH )
{
    j3valid[iij3]=false; _ij3[1] = iij3; break; 
}
}
j3 = j3array[ij3]; cj3 = cj3array[ij3]; sj3 = sj3array[ij3];
{
IkReal evalcond[3];
IkReal x2794=IKsin(j3);
IkReal x2795=((sj5)*(sj6));
IkReal x2796=((cj0)*(cj5));
IkReal x2797=((IkReal(1.00000000000000))*(cj0));
IkReal x2798=((IkReal(1.00000000000000))*(sj0));
IkReal x2799=((cj6)*(r01)*(sj5));
IkReal x2800=((cj6)*(r11)*(sj5));
evalcond[0]=((((cj6)*(r21)*(sj5)))+(((r20)*(x2795)))+(((IkReal(-1.00000000000000))*(IKcos(j3))))+(((IkReal(-1.00000000000000))*(cj5)*(r22))));
evalcond[1]=((((IkReal(-1.00000000000000))*(r10)*(x2795)*(x2797)))+(((sj0)*(x2799)))+(((r12)*(x2796)))+(((IkReal(-1.00000000000000))*(x2797)*(x2800)))+(((r00)*(sj0)*(x2795)))+(((IkReal(-1.00000000000000))*(cj5)*(r02)*(x2798)))+(((IkReal(-1.00000000000000))*(sj2)*(x2794))));
evalcond[2]=((((cj2)*(x2794)))+(((IkReal(-1.00000000000000))*(x2797)*(x2799)))+(((cj5)*(r12)*(sj0)))+(((IkReal(-1.00000000000000))*(r00)*(x2795)*(x2797)))+(((IkReal(-1.00000000000000))*(x2798)*(x2800)))+(((IkReal(-1.00000000000000))*(r10)*(x2795)*(x2798)))+(((r02)*(x2796))));
if( IKabs(evalcond[0]) > 0.000001  || IKabs(evalcond[1]) > 0.000001  || IKabs(evalcond[2]) > 0.000001  )
{
continue;
}
}

{
IkReal dummyeval[1];
IkReal gconst67;
IkReal x2801=(r21)*(r21);
IkReal x2802=(cj5)*(cj5);
IkReal x2803=(sj6)*(sj6);
IkReal x2804=(cj6)*(cj6);
IkReal x2805=(r20)*(r20);
IkReal x2806=((cj6)*(r21));
IkReal x2807=((IkReal(2.00000000000000))*(r20)*(sj6));
IkReal x2808=((cj5)*(r22)*(sj5));
IkReal x2809=((IkReal(1.00000000000000))*(x2803));
IkReal x2810=((IkReal(1.00000000000000))*(x2804));
gconst67=IKsign(((((IkReal(-1.00000000000000))*(x2807)*(x2808)))+(((IkReal(-1.00000000000000))*((r22)*(r22))*((sj5)*(sj5))))+(((IkReal(-1.00000000000000))*(x2802)*(x2805)*(x2809)))+(((IkReal(-1.00000000000000))*(x2805)*(x2810)))+(((IkReal(-1.00000000000000))*(x2801)*(x2809)))+(((IkReal(-1.00000000000000))*(x2802)*(x2806)*(x2807)))+(((x2806)*(x2807)))+(((IkReal(-2.00000000000000))*(x2806)*(x2808)))+(((IkReal(-1.00000000000000))*(x2801)*(x2802)*(x2810)))));
IkReal x2811=(r21)*(r21);
IkReal x2812=(cj5)*(cj5);
IkReal x2813=(sj6)*(sj6);
IkReal x2814=(cj6)*(cj6);
IkReal x2815=(r20)*(r20);
IkReal x2816=((cj6)*(r21));
IkReal x2817=((IkReal(2.00000000000000))*(r20)*(sj6));
IkReal x2818=((cj5)*(r22)*(sj5));
IkReal x2819=((IkReal(1.00000000000000))*(x2813));
IkReal x2820=((IkReal(1.00000000000000))*(x2814));
dummyeval[0]=((((IkReal(-1.00000000000000))*(x2817)*(x2818)))+(((IkReal(-1.00000000000000))*((r22)*(r22))*((sj5)*(sj5))))+(((IkReal(-1.00000000000000))*(x2811)*(x2819)))+(((IkReal(-1.00000000000000))*(x2815)*(x2820)))+(((IkReal(-1.00000000000000))*(x2812)*(x2816)*(x2817)))+(((IkReal(-1.00000000000000))*(x2812)*(x2815)*(x2819)))+(((x2816)*(x2817)))+(((IkReal(-1.00000000000000))*(x2811)*(x2812)*(x2820)))+(((IkReal(-2.00000000000000))*(x2816)*(x2818))));
if( IKabs(dummyeval[0]) < 0.0000010000000000  )
{
{
IkReal dummyeval[1];
IkReal gconst68;
IkReal x2821=(cj6)*(cj6);
IkReal x2822=(sj6)*(sj6);
IkReal x2823=((IkReal(1.00000000000000))*(r21));
IkReal x2824=((cj6)*(r20));
IkReal x2825=((r22)*(sj5));
IkReal x2826=((r01)*(sj0));
IkReal x2827=((r00)*(sj0));
IkReal x2828=((cj0)*(r10));
IkReal x2829=((r02)*(sj0)*(sj5));
IkReal x2830=((cj5)*(x2821));
IkReal x2831=((cj0)*(r12)*(sj5));
IkReal x2832=((IkReal(1.00000000000000))*(cj0)*(r11));
IkReal x2833=((cj5)*(x2822));
IkReal x2834=((r20)*(x2833));
gconst68=IKsign(((((cj6)*(x2825)*(x2828)))+(((IkReal(-1.00000000000000))*(x2823)*(x2827)*(x2833)))+(((IkReal(-1.00000000000000))*(sj6)*(x2823)*(x2829)))+(((IkReal(-1.00000000000000))*(sj6)*(x2825)*(x2832)))+(((IkReal(-1.00000000000000))*(x2832)*(x2834)))+(((IkReal(-1.00000000000000))*(cj6)*(x2825)*(x2827)))+(((x2826)*(x2834)))+(((r20)*(x2826)*(x2830)))+(((IkReal(-1.00000000000000))*(x2824)*(x2831)))+(((x2824)*(x2829)))+(((r21)*(x2828)*(x2833)))+(((IkReal(-1.00000000000000))*(x2823)*(x2827)*(x2830)))+(((sj6)*(x2825)*(x2826)))+(((r21)*(sj6)*(x2831)))+(((r21)*(x2828)*(x2830)))+(((IkReal(-1.00000000000000))*(r20)*(x2830)*(x2832)))));
IkReal x2835=(cj6)*(cj6);
IkReal x2836=(sj6)*(sj6);
IkReal x2837=((IkReal(1.00000000000000))*(r21));
IkReal x2838=((cj6)*(r20));
IkReal x2839=((r22)*(sj5));
IkReal x2840=((r01)*(sj0));
IkReal x2841=((r00)*(sj0));
IkReal x2842=((cj0)*(r10));
IkReal x2843=((r02)*(sj0)*(sj5));
IkReal x2844=((cj5)*(x2835));
IkReal x2845=((cj0)*(r12)*(sj5));
IkReal x2846=((IkReal(1.00000000000000))*(cj0)*(r11));
IkReal x2847=((cj5)*(x2836));
IkReal x2848=((r20)*(x2847));
dummyeval[0]=((((x2838)*(x2843)))+(((IkReal(-1.00000000000000))*(sj6)*(x2839)*(x2846)))+(((r21)*(x2842)*(x2847)))+(((cj6)*(x2839)*(x2842)))+(((IkReal(-1.00000000000000))*(cj6)*(x2839)*(x2841)))+(((r21)*(x2842)*(x2844)))+(((IkReal(-1.00000000000000))*(x2837)*(x2841)*(x2844)))+(((r20)*(x2840)*(x2844)))+(((sj6)*(x2839)*(x2840)))+(((x2840)*(x2848)))+(((IkReal(-1.00000000000000))*(x2838)*(x2845)))+(((IkReal(-1.00000000000000))*(sj6)*(x2837)*(x2843)))+(((r21)*(sj6)*(x2845)))+(((IkReal(-1.00000000000000))*(x2846)*(x2848)))+(((IkReal(-1.00000000000000))*(r20)*(x2844)*(x2846)))+(((IkReal(-1.00000000000000))*(x2837)*(x2841)*(x2847))));
if( IKabs(dummyeval[0]) < 0.0000010000000000  )
{
continue;

} else
{
{
IkReal j4array[1], cj4array[1], sj4array[1];
bool j4valid[1]={false};
_nj4 = 1;
IkReal x2849=((cj2)*(sj6));
IkReal x2850=((IkReal(1.00000000000000))*(r20));
IkReal x2851=((cj2)*(cj6));
if( IKabs(((gconst68)*(((((r21)*(x2849)))+(((IkReal(-1.00000000000000))*(x2850)*(x2851))))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(((gconst68)*(((((IkReal(-1.00000000000000))*(cj5)*(r21)*(x2851)))+(((IkReal(-1.00000000000000))*(cj2)*(r22)*(sj5)))+(((IkReal(-1.00000000000000))*(cj5)*(x2849)*(x2850))))))) < IKFAST_ATAN2_MAGTHRESH )
    continue;
j4array[0]=IKatan2(((gconst68)*(((((r21)*(x2849)))+(((IkReal(-1.00000000000000))*(x2850)*(x2851)))))), ((gconst68)*(((((IkReal(-1.00000000000000))*(cj5)*(r21)*(x2851)))+(((IkReal(-1.00000000000000))*(cj2)*(r22)*(sj5)))+(((IkReal(-1.00000000000000))*(cj5)*(x2849)*(x2850)))))));
sj4array[0]=IKsin(j4array[0]);
cj4array[0]=IKcos(j4array[0]);
if( j4array[0] > IKPI )
{
    j4array[0]-=IK2PI;
}
else if( j4array[0] < -IKPI )
{    j4array[0]+=IK2PI;
}
j4valid[0] = true;
for(int ij4 = 0; ij4 < 1; ++ij4)
{
if( !j4valid[ij4] )
{
    continue;
}
_ij4[0] = ij4; _ij4[1] = -1;
for(int iij4 = ij4+1; iij4 < 1; ++iij4)
{
if( j4valid[iij4] && IKabs(cj4array[ij4]-cj4array[iij4]) < IKFAST_SOLUTION_THRESH && IKabs(sj4array[ij4]-sj4array[iij4]) < IKFAST_SOLUTION_THRESH )
{
    j4valid[iij4]=false; _ij4[1] = iij4; break; 
}
}
j4 = j4array[ij4]; cj4 = cj4array[ij4]; sj4 = sj4array[ij4];
{
IkReal evalcond[6];
IkReal x2852=IKsin(j4);
IkReal x2853=IKcos(j4);
IkReal x2854=((r00)*(sj6));
IkReal x2855=((IkReal(1.00000000000000))*(r12));
IkReal x2856=((IkReal(1.00000000000000))*(cj6));
IkReal x2857=((cj6)*(r01));
IkReal x2858=((r11)*(sj6));
IkReal x2859=((r01)*(sj6));
IkReal x2860=((IkReal(1.00000000000000))*(cj5));
IkReal x2861=((r10)*(sj6));
IkReal x2862=((cj5)*(r11));
IkReal x2863=((cj6)*(r00));
IkReal x2864=((r21)*(sj6));
IkReal x2865=((r02)*(sj5));
IkReal x2866=((cj6)*(r10));
IkReal x2867=((cj5)*(sj6));
IkReal x2868=((cj5)*(r01));
IkReal x2869=((sj5)*(x2852));
IkReal x2870=((cj0)*(x2853));
IkReal x2871=((cj0)*(x2852));
IkReal x2872=((sj0)*(x2853));
IkReal x2873=((sj0)*(x2852));
IkReal x2874=((r20)*(x2853));
IkReal x2875=((cj5)*(cj6)*(r21));
IkReal x2876=((r20)*(x2852));
IkReal x2877=((cj5)*(x2873));
evalcond[0]=((((r22)*(x2869)))+(((x2852)*(x2875)))+(((IkReal(-1.00000000000000))*(x2856)*(x2874)))+(((x2853)*(x2864)))+(((x2867)*(x2876))));
evalcond[1]=((((cj6)*(x2876)))+(((IkReal(-1.00000000000000))*(x2852)*(x2864)))+(((x2867)*(x2874)))+(((IkReal(-1.00000000000000))*(sj3)))+(((r22)*(sj5)*(x2853)))+(((x2853)*(x2875))));
evalcond[2]=((((IkReal(-1.00000000000000))*(r00)*(x2856)*(x2872)))+(((IkReal(-1.00000000000000))*(cj0)*(x2855)*(x2869)))+(((IkReal(-1.00000000000000))*(x2858)*(x2870)))+(((x2857)*(x2877)))+(((x2865)*(x2873)))+(((IkReal(-1.00000000000000))*(x2856)*(x2862)*(x2871)))+(cj2)+(((x2859)*(x2872)))+(((x2854)*(x2877)))+(((IkReal(-1.00000000000000))*(x2860)*(x2861)*(x2871)))+(((x2866)*(x2870))));
evalcond[3]=((((x2865)*(x2872)))+(((x2858)*(x2871)))+(((IkReal(-1.00000000000000))*(x2856)*(x2862)*(x2870)))+(((cj5)*(x2857)*(x2872)))+(((x2863)*(x2873)))+(((IkReal(-1.00000000000000))*(x2859)*(x2873)))+(((cj3)*(sj2)))+(((cj5)*(x2854)*(x2872)))+(((IkReal(-1.00000000000000))*(r10)*(x2856)*(x2871)))+(((IkReal(-1.00000000000000))*(sj5)*(x2855)*(x2870)))+(((IkReal(-1.00000000000000))*(x2860)*(x2861)*(x2870))));
evalcond[4]=((((x2866)*(x2872)))+(((IkReal(-1.00000000000000))*(x2856)*(x2868)*(x2871)))+(sj2)+(((IkReal(-1.00000000000000))*(x2859)*(x2870)))+(((IkReal(-1.00000000000000))*(x2860)*(x2861)*(x2873)))+(((IkReal(-1.00000000000000))*(x2854)*(x2860)*(x2871)))+(((IkReal(-1.00000000000000))*(x2856)*(x2862)*(x2873)))+(((IkReal(-1.00000000000000))*(x2858)*(x2872)))+(((x2863)*(x2870)))+(((IkReal(-1.00000000000000))*(sj0)*(x2855)*(x2869)))+(((IkReal(-1.00000000000000))*(x2865)*(x2871))));
evalcond[5]=((((IkReal(-1.00000000000000))*(r10)*(x2856)*(x2873)))+(((IkReal(-1.00000000000000))*(r00)*(x2856)*(x2871)))+(((IkReal(-1.00000000000000))*(x2860)*(x2861)*(x2872)))+(((IkReal(-1.00000000000000))*(sj5)*(x2855)*(x2872)))+(((IkReal(-1.00000000000000))*(x2856)*(x2868)*(x2870)))+(((x2859)*(x2871)))+(((IkReal(-1.00000000000000))*(x2865)*(x2870)))+(((x2858)*(x2873)))+(((IkReal(-1.00000000000000))*(x2854)*(x2860)*(x2870)))+(((IkReal(-1.00000000000000))*(x2856)*(x2862)*(x2872)))+(((IkReal(-1.00000000000000))*(cj2)*(cj3))));
if( IKabs(evalcond[0]) > 0.000001  || IKabs(evalcond[1]) > 0.000001  || IKabs(evalcond[2]) > 0.000001  || IKabs(evalcond[3]) > 0.000001  || IKabs(evalcond[4]) > 0.000001  || IKabs(evalcond[5]) > 0.000001  )
{
continue;
}
}

{
std::vector<IkSingleDOFSolutionBase<IkReal> > vinfos(7);
vinfos[0].jointtype = 1;
vinfos[0].foffset = j0;
vinfos[0].indices[0] = _ij0[0];
vinfos[0].indices[1] = _ij0[1];
vinfos[0].maxsolutions = _nj0;
vinfos[1].jointtype = 1;
vinfos[1].foffset = j1;
vinfos[1].indices[0] = _ij1[0];
vinfos[1].indices[1] = _ij1[1];
vinfos[1].maxsolutions = _nj1;
vinfos[2].jointtype = 1;
vinfos[2].foffset = j2;
vinfos[2].indices[0] = _ij2[0];
vinfos[2].indices[1] = _ij2[1];
vinfos[2].maxsolutions = _nj2;
vinfos[3].jointtype = 1;
vinfos[3].foffset = j3;
vinfos[3].indices[0] = _ij3[0];
vinfos[3].indices[1] = _ij3[1];
vinfos[3].maxsolutions = _nj3;
vinfos[4].jointtype = 1;
vinfos[4].foffset = j4;
vinfos[4].indices[0] = _ij4[0];
vinfos[4].indices[1] = _ij4[1];
vinfos[4].maxsolutions = _nj4;
vinfos[5].jointtype = 1;
vinfos[5].foffset = j5;
vinfos[5].indices[0] = _ij5[0];
vinfos[5].indices[1] = _ij5[1];
vinfos[5].maxsolutions = _nj5;
vinfos[6].jointtype = 1;
vinfos[6].foffset = j6;
vinfos[6].indices[0] = _ij6[0];
vinfos[6].indices[1] = _ij6[1];
vinfos[6].maxsolutions = _nj6;
std::vector<int> vfree(0);
solutions.AddSolution(vinfos,vfree);
}
}
}

}

}

} else
{
{
IkReal j4array[1], cj4array[1], sj4array[1];
bool j4valid[1]={false};
_nj4 = 1;
IkReal x2878=((r21)*(sj3));
IkReal x2879=((IkReal(1.00000000000000))*(r20)*(sj3));
if( IKabs(((gconst67)*(((((IkReal(-1.00000000000000))*(cj6)*(x2879)))+(((sj6)*(x2878))))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(((gconst67)*(((((IkReal(-1.00000000000000))*(cj5)*(cj6)*(x2878)))+(((IkReal(-1.00000000000000))*(cj5)*(sj6)*(x2879)))+(((IkReal(-1.00000000000000))*(r22)*(sj3)*(sj5))))))) < IKFAST_ATAN2_MAGTHRESH )
    continue;
j4array[0]=IKatan2(((gconst67)*(((((IkReal(-1.00000000000000))*(cj6)*(x2879)))+(((sj6)*(x2878)))))), ((gconst67)*(((((IkReal(-1.00000000000000))*(cj5)*(cj6)*(x2878)))+(((IkReal(-1.00000000000000))*(cj5)*(sj6)*(x2879)))+(((IkReal(-1.00000000000000))*(r22)*(sj3)*(sj5)))))));
sj4array[0]=IKsin(j4array[0]);
cj4array[0]=IKcos(j4array[0]);
if( j4array[0] > IKPI )
{
    j4array[0]-=IK2PI;
}
else if( j4array[0] < -IKPI )
{    j4array[0]+=IK2PI;
}
j4valid[0] = true;
for(int ij4 = 0; ij4 < 1; ++ij4)
{
if( !j4valid[ij4] )
{
    continue;
}
_ij4[0] = ij4; _ij4[1] = -1;
for(int iij4 = ij4+1; iij4 < 1; ++iij4)
{
if( j4valid[iij4] && IKabs(cj4array[ij4]-cj4array[iij4]) < IKFAST_SOLUTION_THRESH && IKabs(sj4array[ij4]-sj4array[iij4]) < IKFAST_SOLUTION_THRESH )
{
    j4valid[iij4]=false; _ij4[1] = iij4; break; 
}
}
j4 = j4array[ij4]; cj4 = cj4array[ij4]; sj4 = sj4array[ij4];
{
IkReal evalcond[6];
IkReal x2880=IKsin(j4);
IkReal x2881=IKcos(j4);
IkReal x2882=((r00)*(sj6));
IkReal x2883=((IkReal(1.00000000000000))*(r12));
IkReal x2884=((IkReal(1.00000000000000))*(cj6));
IkReal x2885=((cj6)*(r01));
IkReal x2886=((r11)*(sj6));
IkReal x2887=((r01)*(sj6));
IkReal x2888=((IkReal(1.00000000000000))*(cj5));
IkReal x2889=((r10)*(sj6));
IkReal x2890=((cj5)*(r11));
IkReal x2891=((cj6)*(r00));
IkReal x2892=((r21)*(sj6));
IkReal x2893=((r02)*(sj5));
IkReal x2894=((cj6)*(r10));
IkReal x2895=((cj5)*(sj6));
IkReal x2896=((cj5)*(r01));
IkReal x2897=((sj5)*(x2880));
IkReal x2898=((cj0)*(x2881));
IkReal x2899=((cj0)*(x2880));
IkReal x2900=((sj0)*(x2881));
IkReal x2901=((sj0)*(x2880));
IkReal x2902=((r20)*(x2881));
IkReal x2903=((cj5)*(cj6)*(r21));
IkReal x2904=((r20)*(x2880));
IkReal x2905=((cj5)*(x2901));
evalcond[0]=((((IkReal(-1.00000000000000))*(x2884)*(x2902)))+(((r22)*(x2897)))+(((x2895)*(x2904)))+(((x2880)*(x2903)))+(((x2881)*(x2892))));
evalcond[1]=((((x2881)*(x2903)))+(((x2895)*(x2902)))+(((cj6)*(x2904)))+(((r22)*(sj5)*(x2881)))+(((IkReal(-1.00000000000000))*(sj3)))+(((IkReal(-1.00000000000000))*(x2880)*(x2892))));
evalcond[2]=((((IkReal(-1.00000000000000))*(x2886)*(x2898)))+(((IkReal(-1.00000000000000))*(r00)*(x2884)*(x2900)))+(((x2894)*(x2898)))+(((x2885)*(x2905)))+(((IkReal(-1.00000000000000))*(x2888)*(x2889)*(x2899)))+(((IkReal(-1.00000000000000))*(x2884)*(x2890)*(x2899)))+(((x2893)*(x2901)))+(cj2)+(((IkReal(-1.00000000000000))*(cj0)*(x2883)*(x2897)))+(((x2882)*(x2905)))+(((x2887)*(x2900))));
evalcond[3]=((((x2893)*(x2900)))+(((cj5)*(x2885)*(x2900)))+(((IkReal(-1.00000000000000))*(x2888)*(x2889)*(x2898)))+(((cj5)*(x2882)*(x2900)))+(((IkReal(-1.00000000000000))*(x2887)*(x2901)))+(((IkReal(-1.00000000000000))*(sj5)*(x2883)*(x2898)))+(((IkReal(-1.00000000000000))*(x2884)*(x2890)*(x2898)))+(((x2886)*(x2899)))+(((cj3)*(sj2)))+(((IkReal(-1.00000000000000))*(r10)*(x2884)*(x2899)))+(((x2891)*(x2901))));
evalcond[4]=((((IkReal(-1.00000000000000))*(x2886)*(x2900)))+(((IkReal(-1.00000000000000))*(sj0)*(x2883)*(x2897)))+(((IkReal(-1.00000000000000))*(x2882)*(x2888)*(x2899)))+(sj2)+(((IkReal(-1.00000000000000))*(x2888)*(x2889)*(x2901)))+(((IkReal(-1.00000000000000))*(x2893)*(x2899)))+(((IkReal(-1.00000000000000))*(x2887)*(x2898)))+(((IkReal(-1.00000000000000))*(x2884)*(x2896)*(x2899)))+(((x2891)*(x2898)))+(((x2894)*(x2900)))+(((IkReal(-1.00000000000000))*(x2884)*(x2890)*(x2901))));
evalcond[5]=((((IkReal(-1.00000000000000))*(r10)*(x2884)*(x2901)))+(((IkReal(-1.00000000000000))*(sj5)*(x2883)*(x2900)))+(((IkReal(-1.00000000000000))*(x2884)*(x2890)*(x2900)))+(((IkReal(-1.00000000000000))*(x2888)*(x2889)*(x2900)))+(((IkReal(-1.00000000000000))*(x2884)*(x2896)*(x2898)))+(((IkReal(-1.00000000000000))*(r00)*(x2884)*(x2899)))+(((x2887)*(x2899)))+(((IkReal(-1.00000000000000))*(x2882)*(x2888)*(x2898)))+(((x2886)*(x2901)))+(((IkReal(-1.00000000000000))*(x2893)*(x2898)))+(((IkReal(-1.00000000000000))*(cj2)*(cj3))));
if( IKabs(evalcond[0]) > 0.000001  || IKabs(evalcond[1]) > 0.000001  || IKabs(evalcond[2]) > 0.000001  || IKabs(evalcond[3]) > 0.000001  || IKabs(evalcond[4]) > 0.000001  || IKabs(evalcond[5]) > 0.000001  )
{
continue;
}
}

{
std::vector<IkSingleDOFSolutionBase<IkReal> > vinfos(7);
vinfos[0].jointtype = 1;
vinfos[0].foffset = j0;
vinfos[0].indices[0] = _ij0[0];
vinfos[0].indices[1] = _ij0[1];
vinfos[0].maxsolutions = _nj0;
vinfos[1].jointtype = 1;
vinfos[1].foffset = j1;
vinfos[1].indices[0] = _ij1[0];
vinfos[1].indices[1] = _ij1[1];
vinfos[1].maxsolutions = _nj1;
vinfos[2].jointtype = 1;
vinfos[2].foffset = j2;
vinfos[2].indices[0] = _ij2[0];
vinfos[2].indices[1] = _ij2[1];
vinfos[2].maxsolutions = _nj2;
vinfos[3].jointtype = 1;
vinfos[3].foffset = j3;
vinfos[3].indices[0] = _ij3[0];
vinfos[3].indices[1] = _ij3[1];
vinfos[3].maxsolutions = _nj3;
vinfos[4].jointtype = 1;
vinfos[4].foffset = j4;
vinfos[4].indices[0] = _ij4[0];
vinfos[4].indices[1] = _ij4[1];
vinfos[4].maxsolutions = _nj4;
vinfos[5].jointtype = 1;
vinfos[5].foffset = j5;
vinfos[5].indices[0] = _ij5[0];
vinfos[5].indices[1] = _ij5[1];
vinfos[5].maxsolutions = _nj5;
vinfos[6].jointtype = 1;
vinfos[6].foffset = j6;
vinfos[6].indices[0] = _ij6[0];
vinfos[6].indices[1] = _ij6[1];
vinfos[6].maxsolutions = _nj6;
std::vector<int> vfree(0);
solutions.AddSolution(vinfos,vfree);
}
}
}

}

}
}
}

}

}

} else
{
{
IkReal j4array[1], cj4array[1], sj4array[1];
bool j4valid[1]={false};
_nj4 = 1;
IkReal x2906=((IkReal(1.00000000000000))*(sj2));
if( IKabs(((gconst66)*(((((IkReal(-1.00000000000000))*(cj6)*(r20)*(x2906)))+(((r21)*(sj2)*(sj6))))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(((gconst66)*(((((IkReal(-1.00000000000000))*(r22)*(sj5)*(x2906)))+(((IkReal(-1.00000000000000))*(cj5)*(cj6)*(r21)*(x2906)))+(((IkReal(-1.00000000000000))*(cj5)*(r20)*(sj6)*(x2906))))))) < IKFAST_ATAN2_MAGTHRESH )
    continue;
j4array[0]=IKatan2(((gconst66)*(((((IkReal(-1.00000000000000))*(cj6)*(r20)*(x2906)))+(((r21)*(sj2)*(sj6)))))), ((gconst66)*(((((IkReal(-1.00000000000000))*(r22)*(sj5)*(x2906)))+(((IkReal(-1.00000000000000))*(cj5)*(cj6)*(r21)*(x2906)))+(((IkReal(-1.00000000000000))*(cj5)*(r20)*(sj6)*(x2906)))))));
sj4array[0]=IKsin(j4array[0]);
cj4array[0]=IKcos(j4array[0]);
if( j4array[0] > IKPI )
{
    j4array[0]-=IK2PI;
}
else if( j4array[0] < -IKPI )
{    j4array[0]+=IK2PI;
}
j4valid[0] = true;
for(int ij4 = 0; ij4 < 1; ++ij4)
{
if( !j4valid[ij4] )
{
    continue;
}
_ij4[0] = ij4; _ij4[1] = -1;
for(int iij4 = ij4+1; iij4 < 1; ++iij4)
{
if( j4valid[iij4] && IKabs(cj4array[ij4]-cj4array[iij4]) < IKFAST_SOLUTION_THRESH && IKabs(sj4array[ij4]-sj4array[iij4]) < IKFAST_SOLUTION_THRESH )
{
    j4valid[iij4]=false; _ij4[1] = iij4; break; 
}
}
j4 = j4array[ij4]; cj4 = cj4array[ij4]; sj4 = sj4array[ij4];
{
IkReal evalcond[3];
IkReal x2907=IKsin(j4);
IkReal x2908=IKcos(j4);
IkReal x2909=((r00)*(sj6));
IkReal x2910=((cj6)*(r01));
IkReal x2911=((IkReal(1.00000000000000))*(cj0));
IkReal x2912=((IkReal(1.00000000000000))*(sj0));
IkReal x2913=((r10)*(sj6));
IkReal x2914=((sj5)*(x2907));
IkReal x2915=((IkReal(1.00000000000000))*(cj6)*(r11));
IkReal x2916=((cj5)*(x2907));
IkReal x2917=((cj6)*(x2908));
IkReal x2918=((sj0)*(x2916));
IkReal x2919=((r01)*(sj6)*(x2908));
IkReal x2920=((r11)*(sj6)*(x2908));
evalcond[0]=((((cj6)*(r21)*(x2916)))+(((IkReal(-1.00000000000000))*(r20)*(x2917)))+(((r22)*(x2914)))+(((r21)*(sj6)*(x2908)))+(((r20)*(sj6)*(x2916))));
evalcond[1]=((((IkReal(-1.00000000000000))*(x2911)*(x2913)*(x2916)))+(((IkReal(-1.00000000000000))*(x2911)*(x2920)))+(((cj0)*(r10)*(x2917)))+(((IkReal(-1.00000000000000))*(cj6)*(r11)*(x2911)*(x2916)))+(((IkReal(-1.00000000000000))*(r00)*(x2912)*(x2917)))+(((x2910)*(x2918)))+(cj2)+(((IkReal(-1.00000000000000))*(r12)*(x2911)*(x2914)))+(((r02)*(sj0)*(x2914)))+(((sj0)*(x2919)))+(((x2909)*(x2918))));
evalcond[2]=((((IkReal(-1.00000000000000))*(x2909)*(x2911)*(x2916)))+(((IkReal(-1.00000000000000))*(x2912)*(x2920)))+(((cj0)*(r00)*(x2917)))+(sj2)+(((IkReal(-1.00000000000000))*(x2910)*(x2911)*(x2916)))+(((IkReal(-1.00000000000000))*(r02)*(x2911)*(x2914)))+(((IkReal(-1.00000000000000))*(x2912)*(x2913)*(x2916)))+(((IkReal(-1.00000000000000))*(x2911)*(x2919)))+(((IkReal(-1.00000000000000))*(cj6)*(r11)*(x2912)*(x2916)))+(((IkReal(-1.00000000000000))*(r12)*(x2912)*(x2914)))+(((r10)*(sj0)*(x2917))));
if( IKabs(evalcond[0]) > 0.000001  || IKabs(evalcond[1]) > 0.000001  || IKabs(evalcond[2]) > 0.000001  )
{
continue;
}
}

{
IkReal j3array[1], cj3array[1], sj3array[1];
bool j3valid[1]={false};
_nj3 = 1;
IkReal x2921=((r20)*(sj6));
IkReal x2922=((cj4)*(cj5));
IkReal x2923=((cj6)*(r21));
if( IKabs(((((x2922)*(x2923)))+(((IkReal(-1.00000000000000))*(r21)*(sj4)*(sj6)))+(((cj6)*(r20)*(sj4)))+(((cj4)*(r22)*(sj5)))+(((x2921)*(x2922))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(((((sj5)*(x2923)))+(((sj5)*(x2921)))+(((IkReal(-1.00000000000000))*(cj5)*(r22))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(IKsqr(((((x2922)*(x2923)))+(((IkReal(-1.00000000000000))*(r21)*(sj4)*(sj6)))+(((cj6)*(r20)*(sj4)))+(((cj4)*(r22)*(sj5)))+(((x2921)*(x2922)))))+IKsqr(((((sj5)*(x2923)))+(((sj5)*(x2921)))+(((IkReal(-1.00000000000000))*(cj5)*(r22)))))-1) <= IKFAST_SINCOS_THRESH )
    continue;
j3array[0]=IKatan2(((((x2922)*(x2923)))+(((IkReal(-1.00000000000000))*(r21)*(sj4)*(sj6)))+(((cj6)*(r20)*(sj4)))+(((cj4)*(r22)*(sj5)))+(((x2921)*(x2922)))), ((((sj5)*(x2923)))+(((sj5)*(x2921)))+(((IkReal(-1.00000000000000))*(cj5)*(r22)))));
sj3array[0]=IKsin(j3array[0]);
cj3array[0]=IKcos(j3array[0]);
if( j3array[0] > IKPI )
{
    j3array[0]-=IK2PI;
}
else if( j3array[0] < -IKPI )
{    j3array[0]+=IK2PI;
}
j3valid[0] = true;
for(int ij3 = 0; ij3 < 1; ++ij3)
{
if( !j3valid[ij3] )
{
    continue;
}
_ij3[0] = ij3; _ij3[1] = -1;
for(int iij3 = ij3+1; iij3 < 1; ++iij3)
{
if( j3valid[iij3] && IKabs(cj3array[ij3]-cj3array[iij3]) < IKFAST_SOLUTION_THRESH && IKabs(sj3array[ij3]-sj3array[iij3]) < IKFAST_SOLUTION_THRESH )
{
    j3valid[iij3]=false; _ij3[1] = iij3; break; 
}
}
j3 = j3array[ij3]; cj3 = cj3array[ij3]; sj3 = sj3array[ij3];
{
IkReal evalcond[6];
IkReal x2924=IKsin(j3);
IkReal x2925=IKcos(j3);
IkReal x2926=((sj0)*(sj5));
IkReal x2927=((r00)*(sj6));
IkReal x2928=((cj6)*(r01));
IkReal x2929=((cj4)*(cj5));
IkReal x2930=((IkReal(1.00000000000000))*(cj0));
IkReal x2931=((cj5)*(r12));
IkReal x2932=((IkReal(1.00000000000000))*(sj0));
IkReal x2933=((cj6)*(r11));
IkReal x2934=((cj6)*(sj4));
IkReal x2935=((cj5)*(r02));
IkReal x2936=((cj6)*(r21));
IkReal x2937=((r20)*(sj6));
IkReal x2938=((r10)*(sj6));
IkReal x2939=((sj4)*(sj6));
IkReal x2940=((cj4)*(r02));
IkReal x2941=((IkReal(1.00000000000000))*(cj4)*(r12));
IkReal x2942=((cj0)*(x2939));
IkReal x2943=((IkReal(1.00000000000000))*(x2924));
IkReal x2944=((IkReal(1.00000000000000))*(x2925));
evalcond[0]=((((sj5)*(x2937)))+(((IkReal(-1.00000000000000))*(cj5)*(r22)))+(((IkReal(-1.00000000000000))*(x2944)))+(((sj5)*(x2936))));
evalcond[1]=((((IkReal(-1.00000000000000))*(r21)*(x2939)))+(((x2929)*(x2936)))+(((cj4)*(r22)*(sj5)))+(((IkReal(-1.00000000000000))*(x2943)))+(((r20)*(x2934)))+(((x2929)*(x2937))));
evalcond[2]=((((x2926)*(x2927)))+(((cj0)*(x2931)))+(((IkReal(-1.00000000000000))*(sj5)*(x2930)*(x2938)))+(((IkReal(-1.00000000000000))*(x2932)*(x2935)))+(((IkReal(-1.00000000000000))*(sj5)*(x2930)*(x2933)))+(((x2926)*(x2928)))+(((IkReal(-1.00000000000000))*(sj2)*(x2943))));
evalcond[3]=((((IkReal(-1.00000000000000))*(x2926)*(x2938)))+(((cj2)*(x2924)))+(((IkReal(-1.00000000000000))*(sj5)*(x2928)*(x2930)))+(((IkReal(-1.00000000000000))*(x2926)*(x2933)))+(((cj0)*(x2935)))+(((sj0)*(x2931)))+(((IkReal(-1.00000000000000))*(sj5)*(x2927)*(x2930))));
evalcond[4]=((((x2926)*(x2940)))+(((IkReal(-1.00000000000000))*(r01)*(x2932)*(x2939)))+(((r11)*(x2942)))+(((sj0)*(x2928)*(x2929)))+(((IkReal(-1.00000000000000))*(cj4)*(r12)*(sj5)*(x2930)))+(((r00)*(sj0)*(x2934)))+(((sj0)*(x2927)*(x2929)))+(((IkReal(-1.00000000000000))*(x2929)*(x2930)*(x2933)))+(((IkReal(-1.00000000000000))*(r10)*(x2930)*(x2934)))+(((IkReal(-1.00000000000000))*(x2929)*(x2930)*(x2938)))+(((sj2)*(x2925))));
evalcond[5]=((((r11)*(sj0)*(x2939)))+(((IkReal(-1.00000000000000))*(x2927)*(x2929)*(x2930)))+(((r01)*(x2942)))+(((IkReal(-1.00000000000000))*(r10)*(x2932)*(x2934)))+(((IkReal(-1.00000000000000))*(x2926)*(x2941)))+(((IkReal(-1.00000000000000))*(r00)*(x2930)*(x2934)))+(((IkReal(-1.00000000000000))*(sj5)*(x2930)*(x2940)))+(((IkReal(-1.00000000000000))*(x2929)*(x2932)*(x2933)))+(((IkReal(-1.00000000000000))*(x2928)*(x2929)*(x2930)))+(((IkReal(-1.00000000000000))*(cj2)*(x2944)))+(((IkReal(-1.00000000000000))*(x2929)*(x2932)*(x2938))));
if( IKabs(evalcond[0]) > 0.000001  || IKabs(evalcond[1]) > 0.000001  || IKabs(evalcond[2]) > 0.000001  || IKabs(evalcond[3]) > 0.000001  || IKabs(evalcond[4]) > 0.000001  || IKabs(evalcond[5]) > 0.000001  )
{
continue;
}
}

{
std::vector<IkSingleDOFSolutionBase<IkReal> > vinfos(7);
vinfos[0].jointtype = 1;
vinfos[0].foffset = j0;
vinfos[0].indices[0] = _ij0[0];
vinfos[0].indices[1] = _ij0[1];
vinfos[0].maxsolutions = _nj0;
vinfos[1].jointtype = 1;
vinfos[1].foffset = j1;
vinfos[1].indices[0] = _ij1[0];
vinfos[1].indices[1] = _ij1[1];
vinfos[1].maxsolutions = _nj1;
vinfos[2].jointtype = 1;
vinfos[2].foffset = j2;
vinfos[2].indices[0] = _ij2[0];
vinfos[2].indices[1] = _ij2[1];
vinfos[2].maxsolutions = _nj2;
vinfos[3].jointtype = 1;
vinfos[3].foffset = j3;
vinfos[3].indices[0] = _ij3[0];
vinfos[3].indices[1] = _ij3[1];
vinfos[3].maxsolutions = _nj3;
vinfos[4].jointtype = 1;
vinfos[4].foffset = j4;
vinfos[4].indices[0] = _ij4[0];
vinfos[4].indices[1] = _ij4[1];
vinfos[4].maxsolutions = _nj4;
vinfos[5].jointtype = 1;
vinfos[5].foffset = j5;
vinfos[5].indices[0] = _ij5[0];
vinfos[5].indices[1] = _ij5[1];
vinfos[5].maxsolutions = _nj5;
vinfos[6].jointtype = 1;
vinfos[6].foffset = j6;
vinfos[6].indices[0] = _ij6[0];
vinfos[6].indices[1] = _ij6[1];
vinfos[6].maxsolutions = _nj6;
std::vector<int> vfree(0);
solutions.AddSolution(vinfos,vfree);
}
}
}
}
}

}

}

} else
{
{
IkReal j4array[1], cj4array[1], sj4array[1];
bool j4valid[1]={false};
_nj4 = 1;
IkReal x2945=((cj2)*(sj6));
IkReal x2946=((IkReal(1.00000000000000))*(r20));
IkReal x2947=((cj2)*(cj6));
if( IKabs(((gconst65)*(((((IkReal(-1.00000000000000))*(x2946)*(x2947)))+(((r21)*(x2945))))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(((gconst65)*(((((IkReal(-1.00000000000000))*(cj5)*(r21)*(x2947)))+(((IkReal(-1.00000000000000))*(cj2)*(r22)*(sj5)))+(((IkReal(-1.00000000000000))*(cj5)*(x2945)*(x2946))))))) < IKFAST_ATAN2_MAGTHRESH )
    continue;
j4array[0]=IKatan2(((gconst65)*(((((IkReal(-1.00000000000000))*(x2946)*(x2947)))+(((r21)*(x2945)))))), ((gconst65)*(((((IkReal(-1.00000000000000))*(cj5)*(r21)*(x2947)))+(((IkReal(-1.00000000000000))*(cj2)*(r22)*(sj5)))+(((IkReal(-1.00000000000000))*(cj5)*(x2945)*(x2946)))))));
sj4array[0]=IKsin(j4array[0]);
cj4array[0]=IKcos(j4array[0]);
if( j4array[0] > IKPI )
{
    j4array[0]-=IK2PI;
}
else if( j4array[0] < -IKPI )
{    j4array[0]+=IK2PI;
}
j4valid[0] = true;
for(int ij4 = 0; ij4 < 1; ++ij4)
{
if( !j4valid[ij4] )
{
    continue;
}
_ij4[0] = ij4; _ij4[1] = -1;
for(int iij4 = ij4+1; iij4 < 1; ++iij4)
{
if( j4valid[iij4] && IKabs(cj4array[ij4]-cj4array[iij4]) < IKFAST_SOLUTION_THRESH && IKabs(sj4array[ij4]-sj4array[iij4]) < IKFAST_SOLUTION_THRESH )
{
    j4valid[iij4]=false; _ij4[1] = iij4; break; 
}
}
j4 = j4array[ij4]; cj4 = cj4array[ij4]; sj4 = sj4array[ij4];
{
IkReal evalcond[3];
IkReal x2948=IKsin(j4);
IkReal x2949=IKcos(j4);
IkReal x2950=((r00)*(sj6));
IkReal x2951=((cj6)*(r01));
IkReal x2952=((IkReal(1.00000000000000))*(cj0));
IkReal x2953=((IkReal(1.00000000000000))*(sj0));
IkReal x2954=((r10)*(sj6));
IkReal x2955=((sj5)*(x2948));
IkReal x2956=((IkReal(1.00000000000000))*(cj6)*(r11));
IkReal x2957=((cj5)*(x2948));
IkReal x2958=((cj6)*(x2949));
IkReal x2959=((sj0)*(x2957));
IkReal x2960=((r01)*(sj6)*(x2949));
IkReal x2961=((r11)*(sj6)*(x2949));
evalcond[0]=((((r20)*(sj6)*(x2957)))+(((cj6)*(r21)*(x2957)))+(((r22)*(x2955)))+(((IkReal(-1.00000000000000))*(r20)*(x2958)))+(((r21)*(sj6)*(x2949))));
evalcond[1]=((((IkReal(-1.00000000000000))*(x2952)*(x2954)*(x2957)))+(((IkReal(-1.00000000000000))*(r12)*(x2952)*(x2955)))+(((IkReal(-1.00000000000000))*(r00)*(x2953)*(x2958)))+(((x2950)*(x2959)))+(((x2951)*(x2959)))+(cj2)+(((sj0)*(x2960)))+(((IkReal(-1.00000000000000))*(cj6)*(r11)*(x2952)*(x2957)))+(((IkReal(-1.00000000000000))*(x2952)*(x2961)))+(((cj0)*(r10)*(x2958)))+(((r02)*(sj0)*(x2955))));
evalcond[2]=((sj2)+(((IkReal(-1.00000000000000))*(x2950)*(x2952)*(x2957)))+(((IkReal(-1.00000000000000))*(x2951)*(x2952)*(x2957)))+(((cj0)*(r00)*(x2958)))+(((IkReal(-1.00000000000000))*(cj6)*(r11)*(x2953)*(x2957)))+(((IkReal(-1.00000000000000))*(r12)*(x2953)*(x2955)))+(((IkReal(-1.00000000000000))*(x2953)*(x2961)))+(((r10)*(sj0)*(x2958)))+(((IkReal(-1.00000000000000))*(x2952)*(x2960)))+(((IkReal(-1.00000000000000))*(x2953)*(x2954)*(x2957)))+(((IkReal(-1.00000000000000))*(r02)*(x2952)*(x2955))));
if( IKabs(evalcond[0]) > 0.000001  || IKabs(evalcond[1]) > 0.000001  || IKabs(evalcond[2]) > 0.000001  )
{
continue;
}
}

{
IkReal j3array[1], cj3array[1], sj3array[1];
bool j3valid[1]={false};
_nj3 = 1;
IkReal x2962=((r20)*(sj6));
IkReal x2963=((cj4)*(cj5));
IkReal x2964=((cj6)*(r21));
if( IKabs(((((IkReal(-1.00000000000000))*(r21)*(sj4)*(sj6)))+(((x2962)*(x2963)))+(((cj6)*(r20)*(sj4)))+(((cj4)*(r22)*(sj5)))+(((x2963)*(x2964))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(((((sj5)*(x2962)))+(((IkReal(-1.00000000000000))*(cj5)*(r22)))+(((sj5)*(x2964))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(IKsqr(((((IkReal(-1.00000000000000))*(r21)*(sj4)*(sj6)))+(((x2962)*(x2963)))+(((cj6)*(r20)*(sj4)))+(((cj4)*(r22)*(sj5)))+(((x2963)*(x2964)))))+IKsqr(((((sj5)*(x2962)))+(((IkReal(-1.00000000000000))*(cj5)*(r22)))+(((sj5)*(x2964)))))-1) <= IKFAST_SINCOS_THRESH )
    continue;
j3array[0]=IKatan2(((((IkReal(-1.00000000000000))*(r21)*(sj4)*(sj6)))+(((x2962)*(x2963)))+(((cj6)*(r20)*(sj4)))+(((cj4)*(r22)*(sj5)))+(((x2963)*(x2964)))), ((((sj5)*(x2962)))+(((IkReal(-1.00000000000000))*(cj5)*(r22)))+(((sj5)*(x2964)))));
sj3array[0]=IKsin(j3array[0]);
cj3array[0]=IKcos(j3array[0]);
if( j3array[0] > IKPI )
{
    j3array[0]-=IK2PI;
}
else if( j3array[0] < -IKPI )
{    j3array[0]+=IK2PI;
}
j3valid[0] = true;
for(int ij3 = 0; ij3 < 1; ++ij3)
{
if( !j3valid[ij3] )
{
    continue;
}
_ij3[0] = ij3; _ij3[1] = -1;
for(int iij3 = ij3+1; iij3 < 1; ++iij3)
{
if( j3valid[iij3] && IKabs(cj3array[ij3]-cj3array[iij3]) < IKFAST_SOLUTION_THRESH && IKabs(sj3array[ij3]-sj3array[iij3]) < IKFAST_SOLUTION_THRESH )
{
    j3valid[iij3]=false; _ij3[1] = iij3; break; 
}
}
j3 = j3array[ij3]; cj3 = cj3array[ij3]; sj3 = sj3array[ij3];
{
IkReal evalcond[6];
IkReal x2965=IKsin(j3);
IkReal x2966=IKcos(j3);
IkReal x2967=((sj0)*(sj5));
IkReal x2968=((r00)*(sj6));
IkReal x2969=((cj6)*(r01));
IkReal x2970=((cj4)*(cj5));
IkReal x2971=((IkReal(1.00000000000000))*(cj0));
IkReal x2972=((cj5)*(r12));
IkReal x2973=((IkReal(1.00000000000000))*(sj0));
IkReal x2974=((cj6)*(r11));
IkReal x2975=((cj6)*(sj4));
IkReal x2976=((cj5)*(r02));
IkReal x2977=((cj6)*(r21));
IkReal x2978=((r20)*(sj6));
IkReal x2979=((r10)*(sj6));
IkReal x2980=((sj4)*(sj6));
IkReal x2981=((cj4)*(r02));
IkReal x2982=((IkReal(1.00000000000000))*(cj4)*(r12));
IkReal x2983=((cj0)*(x2980));
IkReal x2984=((IkReal(1.00000000000000))*(x2965));
IkReal x2985=((IkReal(1.00000000000000))*(x2966));
evalcond[0]=((((sj5)*(x2978)))+(((IkReal(-1.00000000000000))*(cj5)*(r22)))+(((IkReal(-1.00000000000000))*(x2985)))+(((sj5)*(x2977))));
evalcond[1]=((((IkReal(-1.00000000000000))*(x2984)))+(((cj4)*(r22)*(sj5)))+(((x2970)*(x2977)))+(((IkReal(-1.00000000000000))*(r21)*(x2980)))+(((r20)*(x2975)))+(((x2970)*(x2978))));
evalcond[2]=((((IkReal(-1.00000000000000))*(sj2)*(x2984)))+(((IkReal(-1.00000000000000))*(x2973)*(x2976)))+(((IkReal(-1.00000000000000))*(sj5)*(x2971)*(x2979)))+(((cj0)*(x2972)))+(((x2967)*(x2968)))+(((x2967)*(x2969)))+(((IkReal(-1.00000000000000))*(sj5)*(x2971)*(x2974))));
evalcond[3]=((((IkReal(-1.00000000000000))*(sj5)*(x2968)*(x2971)))+(((IkReal(-1.00000000000000))*(x2967)*(x2974)))+(((IkReal(-1.00000000000000))*(sj5)*(x2969)*(x2971)))+(((sj0)*(x2972)))+(((cj0)*(x2976)))+(((IkReal(-1.00000000000000))*(x2967)*(x2979)))+(((cj2)*(x2965))));
evalcond[4]=((((sj0)*(x2969)*(x2970)))+(((IkReal(-1.00000000000000))*(r01)*(x2973)*(x2980)))+(((r11)*(x2983)))+(((IkReal(-1.00000000000000))*(r10)*(x2971)*(x2975)))+(((IkReal(-1.00000000000000))*(x2970)*(x2971)*(x2979)))+(((x2967)*(x2981)))+(((sj0)*(x2968)*(x2970)))+(((IkReal(-1.00000000000000))*(x2970)*(x2971)*(x2974)))+(((r00)*(sj0)*(x2975)))+(((sj2)*(x2966)))+(((IkReal(-1.00000000000000))*(cj4)*(r12)*(sj5)*(x2971))));
evalcond[5]=((((r01)*(x2983)))+(((IkReal(-1.00000000000000))*(sj5)*(x2971)*(x2981)))+(((IkReal(-1.00000000000000))*(r10)*(x2973)*(x2975)))+(((IkReal(-1.00000000000000))*(r00)*(x2971)*(x2975)))+(((IkReal(-1.00000000000000))*(x2967)*(x2982)))+(((IkReal(-1.00000000000000))*(x2970)*(x2973)*(x2979)))+(((IkReal(-1.00000000000000))*(x2969)*(x2970)*(x2971)))+(((r11)*(sj0)*(x2980)))+(((IkReal(-1.00000000000000))*(x2968)*(x2970)*(x2971)))+(((IkReal(-1.00000000000000))*(cj2)*(x2985)))+(((IkReal(-1.00000000000000))*(x2970)*(x2973)*(x2974))));
if( IKabs(evalcond[0]) > 0.000001  || IKabs(evalcond[1]) > 0.000001  || IKabs(evalcond[2]) > 0.000001  || IKabs(evalcond[3]) > 0.000001  || IKabs(evalcond[4]) > 0.000001  || IKabs(evalcond[5]) > 0.000001  )
{
continue;
}
}

{
std::vector<IkSingleDOFSolutionBase<IkReal> > vinfos(7);
vinfos[0].jointtype = 1;
vinfos[0].foffset = j0;
vinfos[0].indices[0] = _ij0[0];
vinfos[0].indices[1] = _ij0[1];
vinfos[0].maxsolutions = _nj0;
vinfos[1].jointtype = 1;
vinfos[1].foffset = j1;
vinfos[1].indices[0] = _ij1[0];
vinfos[1].indices[1] = _ij1[1];
vinfos[1].maxsolutions = _nj1;
vinfos[2].jointtype = 1;
vinfos[2].foffset = j2;
vinfos[2].indices[0] = _ij2[0];
vinfos[2].indices[1] = _ij2[1];
vinfos[2].maxsolutions = _nj2;
vinfos[3].jointtype = 1;
vinfos[3].foffset = j3;
vinfos[3].indices[0] = _ij3[0];
vinfos[3].indices[1] = _ij3[1];
vinfos[3].maxsolutions = _nj3;
vinfos[4].jointtype = 1;
vinfos[4].foffset = j4;
vinfos[4].indices[0] = _ij4[0];
vinfos[4].indices[1] = _ij4[1];
vinfos[4].maxsolutions = _nj4;
vinfos[5].jointtype = 1;
vinfos[5].foffset = j5;
vinfos[5].indices[0] = _ij5[0];
vinfos[5].indices[1] = _ij5[1];
vinfos[5].maxsolutions = _nj5;
vinfos[6].jointtype = 1;
vinfos[6].foffset = j6;
vinfos[6].indices[0] = _ij6[0];
vinfos[6].indices[1] = _ij6[1];
vinfos[6].maxsolutions = _nj6;
std::vector<int> vfree(0);
solutions.AddSolution(vinfos,vfree);
}
}
}
}
}

}

}
}
}

} else
{
IkReal x2986=((r20)*(sj6));
IkReal x2987=((IkReal(0.0100000000000000))*(cj5));
IkReal x2988=((IkReal(0.374290000000000))*(sj5));
IkReal x2989=((cj6)*(r21));
evalcond[0]=((IkReal(-3.14159265358979))+(IKfmod(((IkReal(4.71238898038469))+(j1)), IkReal(6.28318530717959))));
evalcond[1]=((IkReal(-0.364420000000000))+(((x2988)*(x2989)))+(((IkReal(-1.00000000000000))*(x2986)*(x2987)))+(((IkReal(-0.0100000000000000))*(r22)*(sj5)))+(((IkReal(-1.00000000000000))*(x2987)*(x2989)))+(((IkReal(-0.374290000000000))*(cj5)*(r22)))+(pz)+(((x2986)*(x2988))));
if( IKabs(evalcond[0]) < 0.0000010000000000  && IKabs(evalcond[1]) < 0.0000010000000000  )
{
{
IkReal j2array[1], cj2array[1], sj2array[1];
bool j2valid[1]={false};
_nj2 = 1;
IkReal x2990=((r00)*(sj6));
IkReal x2991=((IkReal(14.4927536231884))*(cj0));
IkReal x2992=((cj6)*(r11));
IkReal x2993=((cj0)*(sj5));
IkReal x2994=((IkReal(0.144927536231884))*(r02));
IkReal x2995=((r10)*(sj6));
IkReal x2996=((cj5)*(sj0));
IkReal x2997=((IkReal(5.42449275362319))*(r12));
IkReal x2998=((IkReal(14.4927536231884))*(sj0));
IkReal x2999=((cj6)*(r01));
IkReal x3000=((sj0)*(sj5));
IkReal x3001=((IkReal(0.144927536231884))*(r12));
IkReal x3002=((IkReal(5.42449275362319))*(r02));
IkReal x3003=((cj0)*(cj5));
IkReal x3004=((IkReal(0.144927536231884))*(x3003));
IkReal x3005=((IkReal(5.42449275362319))*(sj5)*(x2999));
if( IKabs(((((IkReal(0.144927536231884))*(x2990)*(x2996)))+(((IkReal(5.42449275362319))*(x2993)*(x2995)))+(((IkReal(-1.00000000000000))*(px)*(x2998)))+(((IkReal(-1.00000000000000))*(x2997)*(x3003)))+(((x2996)*(x3002)))+(((IkReal(-5.42449275362319))*(x2999)*(x3000)))+(((py)*(x2991)))+(((IkReal(0.144927536231884))*(x2996)*(x2999)))+(((IkReal(5.42449275362319))*(x2992)*(x2993)))+(((IkReal(-1.00000000000000))*(x2993)*(x3001)))+(((IkReal(-1.00000000000000))*(x2995)*(x3004)))+(((x2994)*(x3000)))+(((IkReal(-1.00000000000000))*(x2992)*(x3004)))+(((IkReal(-5.42449275362319))*(x2990)*(x3000))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(((IkReal(-1.00000000000000))+(((IkReal(-1.00000000000000))*(x2990)*(x3004)))+(((IkReal(5.42449275362319))*(x2993)*(x2999)))+(((IkReal(5.42449275362319))*(x2992)*(x3000)))+(((IkReal(-1.00000000000000))*(x3000)*(x3001)))+(((IkReal(5.42449275362319))*(x2990)*(x2993)))+(((IkReal(5.42449275362319))*(x2995)*(x3000)))+(((IkReal(-1.00000000000000))*(x2999)*(x3004)))+(((px)*(x2991)))+(((IkReal(-1.00000000000000))*(x3002)*(x3003)))+(((IkReal(-1.00000000000000))*(x2993)*(x2994)))+(((py)*(x2998)))+(((IkReal(-0.144927536231884))*(x2992)*(x2996)))+(((IkReal(-0.144927536231884))*(x2995)*(x2996)))+(((IkReal(-1.00000000000000))*(x2996)*(x2997))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(IKsqr(((((IkReal(0.144927536231884))*(x2990)*(x2996)))+(((IkReal(5.42449275362319))*(x2993)*(x2995)))+(((IkReal(-1.00000000000000))*(px)*(x2998)))+(((IkReal(-1.00000000000000))*(x2997)*(x3003)))+(((x2996)*(x3002)))+(((IkReal(-5.42449275362319))*(x2999)*(x3000)))+(((py)*(x2991)))+(((IkReal(0.144927536231884))*(x2996)*(x2999)))+(((IkReal(5.42449275362319))*(x2992)*(x2993)))+(((IkReal(-1.00000000000000))*(x2993)*(x3001)))+(((IkReal(-1.00000000000000))*(x2995)*(x3004)))+(((x2994)*(x3000)))+(((IkReal(-1.00000000000000))*(x2992)*(x3004)))+(((IkReal(-5.42449275362319))*(x2990)*(x3000)))))+IKsqr(((IkReal(-1.00000000000000))+(((IkReal(-1.00000000000000))*(x2990)*(x3004)))+(((IkReal(5.42449275362319))*(x2993)*(x2999)))+(((IkReal(5.42449275362319))*(x2992)*(x3000)))+(((IkReal(-1.00000000000000))*(x3000)*(x3001)))+(((IkReal(5.42449275362319))*(x2990)*(x2993)))+(((IkReal(5.42449275362319))*(x2995)*(x3000)))+(((IkReal(-1.00000000000000))*(x2999)*(x3004)))+(((px)*(x2991)))+(((IkReal(-1.00000000000000))*(x3002)*(x3003)))+(((IkReal(-1.00000000000000))*(x2993)*(x2994)))+(((py)*(x2998)))+(((IkReal(-0.144927536231884))*(x2992)*(x2996)))+(((IkReal(-0.144927536231884))*(x2995)*(x2996)))+(((IkReal(-1.00000000000000))*(x2996)*(x2997)))))-1) <= IKFAST_SINCOS_THRESH )
    continue;
j2array[0]=IKatan2(((((IkReal(0.144927536231884))*(x2990)*(x2996)))+(((IkReal(5.42449275362319))*(x2993)*(x2995)))+(((IkReal(-1.00000000000000))*(px)*(x2998)))+(((IkReal(-1.00000000000000))*(x2997)*(x3003)))+(((x2996)*(x3002)))+(((IkReal(-5.42449275362319))*(x2999)*(x3000)))+(((py)*(x2991)))+(((IkReal(0.144927536231884))*(x2996)*(x2999)))+(((IkReal(5.42449275362319))*(x2992)*(x2993)))+(((IkReal(-1.00000000000000))*(x2993)*(x3001)))+(((IkReal(-1.00000000000000))*(x2995)*(x3004)))+(((x2994)*(x3000)))+(((IkReal(-1.00000000000000))*(x2992)*(x3004)))+(((IkReal(-5.42449275362319))*(x2990)*(x3000)))), ((IkReal(-1.00000000000000))+(((IkReal(-1.00000000000000))*(x2990)*(x3004)))+(((IkReal(5.42449275362319))*(x2993)*(x2999)))+(((IkReal(5.42449275362319))*(x2992)*(x3000)))+(((IkReal(-1.00000000000000))*(x3000)*(x3001)))+(((IkReal(5.42449275362319))*(x2990)*(x2993)))+(((IkReal(5.42449275362319))*(x2995)*(x3000)))+(((IkReal(-1.00000000000000))*(x2999)*(x3004)))+(((px)*(x2991)))+(((IkReal(-1.00000000000000))*(x3002)*(x3003)))+(((IkReal(-1.00000000000000))*(x2993)*(x2994)))+(((py)*(x2998)))+(((IkReal(-0.144927536231884))*(x2992)*(x2996)))+(((IkReal(-0.144927536231884))*(x2995)*(x2996)))+(((IkReal(-1.00000000000000))*(x2996)*(x2997)))));
sj2array[0]=IKsin(j2array[0]);
cj2array[0]=IKcos(j2array[0]);
if( j2array[0] > IKPI )
{
    j2array[0]-=IK2PI;
}
else if( j2array[0] < -IKPI )
{    j2array[0]+=IK2PI;
}
j2valid[0] = true;
for(int ij2 = 0; ij2 < 1; ++ij2)
{
if( !j2valid[ij2] )
{
    continue;
}
_ij2[0] = ij2; _ij2[1] = -1;
for(int iij2 = ij2+1; iij2 < 1; ++iij2)
{
if( j2valid[iij2] && IKabs(cj2array[ij2]-cj2array[iij2]) < IKFAST_SOLUTION_THRESH && IKabs(sj2array[ij2]-sj2array[iij2]) < IKFAST_SOLUTION_THRESH )
{
    j2valid[iij2]=false; _ij2[1] = iij2; break; 
}
}
j2 = j2array[ij2]; cj2 = cj2array[ij2]; sj2 = sj2array[ij2];
{
IkReal evalcond[2];
IkReal x3006=((IkReal(0.374290000000000))*(sj0));
IkReal x3007=((cj5)*(r02));
IkReal x3008=((IkReal(0.0100000000000000))*(cj0));
IkReal x3009=((cj5)*(cj6));
IkReal x3010=((r02)*(sj5));
IkReal x3011=((cj5)*(sj6));
IkReal x3012=((IkReal(1.00000000000000))*(py));
IkReal x3013=((cj6)*(sj5));
IkReal x3014=((IkReal(0.0100000000000000))*(sj0));
IkReal x3015=((sj5)*(sj6));
IkReal x3016=((cj5)*(r12));
IkReal x3017=((IkReal(0.374290000000000))*(cj0));
IkReal x3018=((r12)*(sj5));
IkReal x3019=((x3013)*(x3017));
IkReal x3020=((x3015)*(x3017));
evalcond[0]=((((IkReal(-1.00000000000000))*(cj0)*(x3012)))+(((IkReal(-1.00000000000000))*(r10)*(x3020)))+(((IkReal(-1.00000000000000))*(x3006)*(x3007)))+(((r10)*(x3008)*(x3011)))+(((r00)*(x3006)*(x3015)))+(((IkReal(-1.00000000000000))*(r01)*(x3009)*(x3014)))+(((IkReal(-1.00000000000000))*(r11)*(x3019)))+(((IkReal(0.0690000000000000))*(IKsin(j2))))+(((IkReal(-1.00000000000000))*(r00)*(x3011)*(x3014)))+(((x3016)*(x3017)))+(((x3008)*(x3018)))+(((r01)*(x3006)*(x3013)))+(((px)*(sj0)))+(((r11)*(x3008)*(x3009)))+(((IkReal(-1.00000000000000))*(x3010)*(x3014))));
evalcond[1]=((IkReal(0.0690000000000000))+(((IkReal(-1.00000000000000))*(r10)*(x3006)*(x3015)))+(((r01)*(x3008)*(x3009)))+(((IkReal(-1.00000000000000))*(cj0)*(px)))+(((IkReal(-1.00000000000000))*(sj0)*(x3012)))+(((x3007)*(x3017)))+(((x3008)*(x3010)))+(((IkReal(-1.00000000000000))*(r00)*(x3020)))+(((IkReal(0.0690000000000000))*(IKcos(j2))))+(((IkReal(-1.00000000000000))*(r11)*(x3006)*(x3013)))+(((r00)*(x3008)*(x3011)))+(((x3006)*(x3016)))+(((IkReal(-1.00000000000000))*(r01)*(x3019)))+(((r10)*(x3011)*(x3014)))+(((r11)*(x3009)*(x3014)))+(((x3014)*(x3018))));
if( IKabs(evalcond[0]) > 0.000001  || IKabs(evalcond[1]) > 0.000001  )
{
continue;
}
}

{
IkReal dummyeval[1];
IkReal gconst77;
IkReal x3021=(cj6)*(cj6);
IkReal x3022=(sj6)*(sj6);
IkReal x3023=((IkReal(1.00000000000000))*(r21));
IkReal x3024=((cj6)*(r20));
IkReal x3025=((r22)*(sj5));
IkReal x3026=((r01)*(sj0));
IkReal x3027=((r00)*(sj0));
IkReal x3028=((cj0)*(r10));
IkReal x3029=((r02)*(sj0)*(sj5));
IkReal x3030=((cj5)*(x3021));
IkReal x3031=((cj0)*(r12)*(sj5));
IkReal x3032=((IkReal(1.00000000000000))*(cj0)*(r11));
IkReal x3033=((cj5)*(x3022));
IkReal x3034=((r20)*(x3033));
gconst77=IKsign(((((IkReal(-1.00000000000000))*(sj6)*(x3023)*(x3029)))+(((sj6)*(x3025)*(x3026)))+(((x3026)*(x3034)))+(((r20)*(x3026)*(x3030)))+(((r21)*(sj6)*(x3031)))+(((IkReal(-1.00000000000000))*(sj6)*(x3025)*(x3032)))+(((IkReal(-1.00000000000000))*(x3024)*(x3031)))+(((IkReal(-1.00000000000000))*(x3023)*(x3027)*(x3030)))+(((IkReal(-1.00000000000000))*(cj6)*(x3025)*(x3027)))+(((IkReal(-1.00000000000000))*(x3032)*(x3034)))+(((x3024)*(x3029)))+(((IkReal(-1.00000000000000))*(r20)*(x3030)*(x3032)))+(((r21)*(x3028)*(x3030)))+(((IkReal(-1.00000000000000))*(x3023)*(x3027)*(x3033)))+(((cj6)*(x3025)*(x3028)))+(((r21)*(x3028)*(x3033)))));
IkReal x3035=(cj6)*(cj6);
IkReal x3036=(sj6)*(sj6);
IkReal x3037=((IkReal(1.00000000000000))*(r21));
IkReal x3038=((cj6)*(r20));
IkReal x3039=((r22)*(sj5));
IkReal x3040=((r01)*(sj0));
IkReal x3041=((r00)*(sj0));
IkReal x3042=((cj0)*(r10));
IkReal x3043=((r02)*(sj0)*(sj5));
IkReal x3044=((cj5)*(x3035));
IkReal x3045=((cj0)*(r12)*(sj5));
IkReal x3046=((IkReal(1.00000000000000))*(cj0)*(r11));
IkReal x3047=((cj5)*(x3036));
IkReal x3048=((r20)*(x3047));
dummyeval[0]=((((IkReal(-1.00000000000000))*(x3046)*(x3048)))+(((IkReal(-1.00000000000000))*(x3037)*(x3041)*(x3047)))+(((r20)*(x3040)*(x3044)))+(((r21)*(x3042)*(x3044)))+(((x3040)*(x3048)))+(((cj6)*(x3039)*(x3042)))+(((IkReal(-1.00000000000000))*(sj6)*(x3039)*(x3046)))+(((r21)*(sj6)*(x3045)))+(((IkReal(-1.00000000000000))*(cj6)*(x3039)*(x3041)))+(((IkReal(-1.00000000000000))*(r20)*(x3044)*(x3046)))+(((r21)*(x3042)*(x3047)))+(((IkReal(-1.00000000000000))*(x3038)*(x3045)))+(((x3038)*(x3043)))+(((sj6)*(x3039)*(x3040)))+(((IkReal(-1.00000000000000))*(x3037)*(x3041)*(x3044)))+(((IkReal(-1.00000000000000))*(sj6)*(x3037)*(x3043))));
if( IKabs(dummyeval[0]) < 0.0000010000000000  )
{
{
IkReal dummyeval[1];
IkReal gconst78;
IkReal x3049=(cj6)*(cj6);
IkReal x3050=(sj6)*(sj6);
IkReal x3051=((sj5)*(sj6));
IkReal x3052=((IkReal(1.00000000000000))*(cj0));
IkReal x3053=((cj6)*(sj5));
IkReal x3054=((r20)*(sj0));
IkReal x3055=((cj0)*(r20));
IkReal x3056=((r00)*(r21));
IkReal x3057=((r22)*(sj0));
IkReal x3058=((IkReal(1.00000000000000))*(r21)*(sj0));
IkReal x3059=((cj5)*(x3050));
IkReal x3060=((cj5)*(x3049));
gconst78=IKsign(((((r12)*(x3053)*(x3054)))+(((r01)*(x3055)*(x3060)))+(((IkReal(-1.00000000000000))*(x3052)*(x3056)*(x3060)))+(((IkReal(-1.00000000000000))*(r00)*(r22)*(x3052)*(x3053)))+(((IkReal(-1.00000000000000))*(x3052)*(x3056)*(x3059)))+(((IkReal(-1.00000000000000))*(r12)*(x3051)*(x3058)))+(((IkReal(-1.00000000000000))*(r10)*(x3058)*(x3060)))+(((IkReal(-1.00000000000000))*(r02)*(r21)*(x3051)*(x3052)))+(((IkReal(-1.00000000000000))*(r10)*(x3053)*(x3057)))+(((r02)*(x3053)*(x3055)))+(((cj0)*(r01)*(r22)*(x3051)))+(((r11)*(x3054)*(x3059)))+(((IkReal(-1.00000000000000))*(r10)*(x3058)*(x3059)))+(((r11)*(x3051)*(x3057)))+(((r11)*(x3054)*(x3060)))+(((r01)*(x3055)*(x3059)))));
IkReal x3061=(cj6)*(cj6);
IkReal x3062=(sj6)*(sj6);
IkReal x3063=((sj5)*(sj6));
IkReal x3064=((IkReal(1.00000000000000))*(cj0));
IkReal x3065=((cj6)*(sj5));
IkReal x3066=((r20)*(sj0));
IkReal x3067=((cj0)*(r20));
IkReal x3068=((r00)*(r21));
IkReal x3069=((r22)*(sj0));
IkReal x3070=((IkReal(1.00000000000000))*(r21)*(sj0));
IkReal x3071=((cj5)*(x3062));
IkReal x3072=((cj5)*(x3061));
dummyeval[0]=((((r12)*(x3065)*(x3066)))+(((IkReal(-1.00000000000000))*(r10)*(x3070)*(x3071)))+(((IkReal(-1.00000000000000))*(r00)*(r22)*(x3064)*(x3065)))+(((r01)*(x3067)*(x3072)))+(((IkReal(-1.00000000000000))*(r12)*(x3063)*(x3070)))+(((cj0)*(r01)*(r22)*(x3063)))+(((r11)*(x3063)*(x3069)))+(((IkReal(-1.00000000000000))*(r10)*(x3070)*(x3072)))+(((r02)*(x3065)*(x3067)))+(((r01)*(x3067)*(x3071)))+(((r11)*(x3066)*(x3072)))+(((r11)*(x3066)*(x3071)))+(((IkReal(-1.00000000000000))*(r02)*(r21)*(x3063)*(x3064)))+(((IkReal(-1.00000000000000))*(x3064)*(x3068)*(x3071)))+(((IkReal(-1.00000000000000))*(x3064)*(x3068)*(x3072)))+(((IkReal(-1.00000000000000))*(r10)*(x3065)*(x3069))));
if( IKabs(dummyeval[0]) < 0.0000010000000000  )
{
{
IkReal dummyeval[1];
dummyeval[0]=sj2;
if( IKabs(dummyeval[0]) < 0.0000010000000000  )
{
{
IkReal evalcond[5];
IkReal x3073=((sj0)*(sj5));
IkReal x3074=((r00)*(sj6));
IkReal x3075=((cj6)*(r01));
IkReal x3076=((cj0)*(cj5));
IkReal x3077=((cj0)*(sj5));
IkReal x3078=((r10)*(sj6));
IkReal x3079=((cj6)*(r11));
IkReal x3080=((IkReal(0.374290000000000))*(sj5));
IkReal x3081=((IkReal(0.0100000000000000))*(r02));
IkReal x3082=((IkReal(1.00000000000000))*(py));
IkReal x3083=((cj5)*(sj0));
IkReal x3084=((IkReal(0.374290000000000))*(r12));
IkReal x3085=((r20)*(sj6));
IkReal x3086=((IkReal(0.0100000000000000))*(r12));
IkReal x3087=((IkReal(0.0100000000000000))*(cj5)*(cj6));
IkReal x3088=((r02)*(x3083));
IkReal x3089=((IkReal(0.374290000000000))*(cj6)*(x3077));
evalcond[0]=((IkReal(-3.14159265358979))+(IKfmod(((IkReal(3.14159265358979))+(j2)), IkReal(6.28318530717959))));
evalcond[1]=((IkReal(-0.364420000000000))+(((IkReal(-0.0100000000000000))*(cj5)*(x3085)))+(((cj6)*(r21)*(x3080)))+(((IkReal(-0.0100000000000000))*(r22)*(sj5)))+(((IkReal(-0.374290000000000))*(cj5)*(r22)))+(((x3080)*(x3085)))+(pz)+(((IkReal(-1.00000000000000))*(r21)*(x3087))));
evalcond[2]=((((IkReal(-1.00000000000000))*(x3077)*(x3078)))+(((IkReal(-1.00000000000000))*(x3077)*(x3079)))+(((x3073)*(x3075)))+(((x3073)*(x3074)))+(((r12)*(x3076)))+(((IkReal(-1.00000000000000))*(x3088))));
evalcond[3]=((((x3076)*(x3084)))+(((IkReal(-1.00000000000000))*(cj0)*(x3082)))+(((IkReal(-0.374290000000000))*(x3077)*(x3078)))+(((IkReal(0.0100000000000000))*(x3076)*(x3079)))+(((IkReal(0.374290000000000))*(x3073)*(x3075)))+(((IkReal(-1.00000000000000))*(x3073)*(x3081)))+(((IkReal(-0.0100000000000000))*(x3075)*(x3083)))+(((IkReal(-0.0100000000000000))*(x3074)*(x3083)))+(((IkReal(-0.374290000000000))*(x3077)*(x3079)))+(((x3077)*(x3086)))+(((px)*(sj0)))+(((IkReal(-0.374290000000000))*(x3088)))+(((IkReal(0.0100000000000000))*(x3076)*(x3078)))+(((IkReal(0.374290000000000))*(x3073)*(x3074))));
evalcond[4]=((IkReal(0.138000000000000))+(((IkReal(-1.00000000000000))*(cj0)*(px)))+(((x3073)*(x3086)))+(((IkReal(0.0100000000000000))*(x3075)*(x3076)))+(((x3083)*(x3084)))+(((IkReal(-0.374290000000000))*(x3074)*(x3077)))+(((IkReal(-1.00000000000000))*(sj0)*(x3082)))+(((IkReal(0.0100000000000000))*(x3079)*(x3083)))+(((IkReal(0.374290000000000))*(r02)*(x3076)))+(((x3077)*(x3081)))+(((IkReal(-0.374290000000000))*(x3073)*(x3078)))+(((IkReal(0.0100000000000000))*(x3074)*(x3076)))+(((IkReal(0.0100000000000000))*(x3078)*(x3083)))+(((IkReal(-0.374290000000000))*(x3073)*(x3079)))+(((IkReal(-0.374290000000000))*(x3075)*(x3077))));
if( IKabs(evalcond[0]) < 0.0000010000000000  && IKabs(evalcond[1]) < 0.0000010000000000  && IKabs(evalcond[2]) < 0.0000010000000000  && IKabs(evalcond[3]) < 0.0000010000000000  && IKabs(evalcond[4]) < 0.0000010000000000  )
{
{
IkReal j3array[1], cj3array[1], sj3array[1];
bool j3valid[1]={false};
_nj3 = 1;
IkReal x3090=((IkReal(1.00000000000000))*(cj6)*(sj5));
IkReal x3091=((IkReal(1.00000000000000))*(sj5)*(sj6));
if( IKabs(((((cj0)*(cj5)*(r02)))+(((IkReal(-1.00000000000000))*(cj0)*(r01)*(x3090)))+(((cj5)*(r12)*(sj0)))+(((IkReal(-1.00000000000000))*(cj0)*(r00)*(x3091)))+(((IkReal(-1.00000000000000))*(r10)*(sj0)*(x3091)))+(((IkReal(-1.00000000000000))*(r11)*(sj0)*(x3090))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(((((IkReal(-1.00000000000000))*(r20)*(x3091)))+(((IkReal(-1.00000000000000))*(r21)*(x3090)))+(((cj5)*(r22))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(IKsqr(((((cj0)*(cj5)*(r02)))+(((IkReal(-1.00000000000000))*(cj0)*(r01)*(x3090)))+(((cj5)*(r12)*(sj0)))+(((IkReal(-1.00000000000000))*(cj0)*(r00)*(x3091)))+(((IkReal(-1.00000000000000))*(r10)*(sj0)*(x3091)))+(((IkReal(-1.00000000000000))*(r11)*(sj0)*(x3090)))))+IKsqr(((((IkReal(-1.00000000000000))*(r20)*(x3091)))+(((IkReal(-1.00000000000000))*(r21)*(x3090)))+(((cj5)*(r22)))))-1) <= IKFAST_SINCOS_THRESH )
    continue;
j3array[0]=IKatan2(((((cj0)*(cj5)*(r02)))+(((IkReal(-1.00000000000000))*(cj0)*(r01)*(x3090)))+(((cj5)*(r12)*(sj0)))+(((IkReal(-1.00000000000000))*(cj0)*(r00)*(x3091)))+(((IkReal(-1.00000000000000))*(r10)*(sj0)*(x3091)))+(((IkReal(-1.00000000000000))*(r11)*(sj0)*(x3090)))), ((((IkReal(-1.00000000000000))*(r20)*(x3091)))+(((IkReal(-1.00000000000000))*(r21)*(x3090)))+(((cj5)*(r22)))));
sj3array[0]=IKsin(j3array[0]);
cj3array[0]=IKcos(j3array[0]);
if( j3array[0] > IKPI )
{
    j3array[0]-=IK2PI;
}
else if( j3array[0] < -IKPI )
{    j3array[0]+=IK2PI;
}
j3valid[0] = true;
for(int ij3 = 0; ij3 < 1; ++ij3)
{
if( !j3valid[ij3] )
{
    continue;
}
_ij3[0] = ij3; _ij3[1] = -1;
for(int iij3 = ij3+1; iij3 < 1; ++iij3)
{
if( j3valid[iij3] && IKabs(cj3array[ij3]-cj3array[iij3]) < IKFAST_SOLUTION_THRESH && IKabs(sj3array[ij3]-sj3array[iij3]) < IKFAST_SOLUTION_THRESH )
{
    j3valid[iij3]=false; _ij3[1] = iij3; break; 
}
}
j3 = j3array[ij3]; cj3 = cj3array[ij3]; sj3 = sj3array[ij3];
{
IkReal evalcond[2];
IkReal x3092=((sj5)*(sj6));
IkReal x3093=((IkReal(1.00000000000000))*(cj6)*(sj5));
evalcond[0]=((((cj6)*(r21)*(sj5)))+(((IkReal(-1.00000000000000))*(cj5)*(r22)))+(IKcos(j3))+(((r20)*(x3092))));
evalcond[1]=((((cj0)*(cj5)*(r02)))+(((IkReal(-1.00000000000000))*(cj0)*(r01)*(x3093)))+(((cj5)*(r12)*(sj0)))+(((IkReal(-1.00000000000000))*(r10)*(sj0)*(x3092)))+(((IkReal(-1.00000000000000))*(cj0)*(r00)*(x3092)))+(((IkReal(-1.00000000000000))*(r11)*(sj0)*(x3093)))+(((IkReal(-1.00000000000000))*(IKsin(j3)))));
if( IKabs(evalcond[0]) > 0.000001  || IKabs(evalcond[1]) > 0.000001  )
{
continue;
}
}

{
IkReal dummyeval[1];
IkReal gconst83;
IkReal x3094=(cj5)*(cj5);
IkReal x3095=(r20)*(r20);
IkReal x3096=(sj6)*(sj6);
IkReal x3097=(cj6)*(cj6);
IkReal x3098=(r21)*(r21);
IkReal x3099=((cj6)*(r21));
IkReal x3100=((IkReal(2.00000000000000))*(r20)*(sj6));
IkReal x3101=((cj5)*(r22)*(sj5));
gconst83=IKsign(((((x3100)*(x3101)))+(((x3094)*(x3095)*(x3096)))+((((r22)*(r22))*((sj5)*(sj5))))+(((x3096)*(x3098)))+(((x3094)*(x3097)*(x3098)))+(((x3095)*(x3097)))+(((IkReal(2.00000000000000))*(x3099)*(x3101)))+(((x3094)*(x3099)*(x3100)))+(((IkReal(-1.00000000000000))*(x3099)*(x3100)))));
IkReal x3102=(cj5)*(cj5);
IkReal x3103=(r20)*(r20);
IkReal x3104=(sj6)*(sj6);
IkReal x3105=(cj6)*(cj6);
IkReal x3106=(r21)*(r21);
IkReal x3107=((cj6)*(r21));
IkReal x3108=((IkReal(2.00000000000000))*(r20)*(sj6));
IkReal x3109=((cj5)*(r22)*(sj5));
dummyeval[0]=((((x3104)*(x3106)))+(((x3103)*(x3105)))+((((r22)*(r22))*((sj5)*(sj5))))+(((x3102)*(x3105)*(x3106)))+(((x3102)*(x3103)*(x3104)))+(((x3102)*(x3107)*(x3108)))+(((IkReal(2.00000000000000))*(x3107)*(x3109)))+(((x3108)*(x3109)))+(((IkReal(-1.00000000000000))*(x3107)*(x3108))));
if( IKabs(dummyeval[0]) < 0.0000010000000000  )
{
{
IkReal dummyeval[1];
IkReal gconst84;
IkReal x3110=(cj6)*(cj6);
IkReal x3111=(sj6)*(sj6);
IkReal x3112=((IkReal(1.00000000000000))*(r21));
IkReal x3113=((cj6)*(r20));
IkReal x3114=((r22)*(sj5));
IkReal x3115=((r01)*(sj0));
IkReal x3116=((r00)*(sj0));
IkReal x3117=((cj0)*(r10));
IkReal x3118=((r02)*(sj0)*(sj5));
IkReal x3119=((cj5)*(x3110));
IkReal x3120=((cj0)*(r12)*(sj5));
IkReal x3121=((IkReal(1.00000000000000))*(cj0)*(r11));
IkReal x3122=((cj5)*(x3111));
IkReal x3123=((r20)*(x3122));
gconst84=IKsign(((((IkReal(-1.00000000000000))*(x3112)*(x3116)*(x3122)))+(((IkReal(-1.00000000000000))*(x3112)*(x3116)*(x3119)))+(((IkReal(-1.00000000000000))*(x3113)*(x3120)))+(((r21)*(sj6)*(x3120)))+(((r20)*(x3115)*(x3119)))+(((IkReal(-1.00000000000000))*(x3121)*(x3123)))+(((IkReal(-1.00000000000000))*(cj6)*(x3114)*(x3116)))+(((IkReal(-1.00000000000000))*(sj6)*(x3114)*(x3121)))+(((x3115)*(x3123)))+(((IkReal(-1.00000000000000))*(sj6)*(x3112)*(x3118)))+(((x3113)*(x3118)))+(((sj6)*(x3114)*(x3115)))+(((IkReal(-1.00000000000000))*(r20)*(x3119)*(x3121)))+(((r21)*(x3117)*(x3119)))+(((cj6)*(x3114)*(x3117)))+(((r21)*(x3117)*(x3122)))));
IkReal x3124=(cj6)*(cj6);
IkReal x3125=(sj6)*(sj6);
IkReal x3126=((IkReal(1.00000000000000))*(r21));
IkReal x3127=((cj6)*(r20));
IkReal x3128=((r22)*(sj5));
IkReal x3129=((r01)*(sj0));
IkReal x3130=((r00)*(sj0));
IkReal x3131=((cj0)*(r10));
IkReal x3132=((r02)*(sj0)*(sj5));
IkReal x3133=((cj5)*(x3124));
IkReal x3134=((cj0)*(r12)*(sj5));
IkReal x3135=((IkReal(1.00000000000000))*(cj0)*(r11));
IkReal x3136=((cj5)*(x3125));
IkReal x3137=((r20)*(x3136));
dummyeval[0]=((((cj6)*(x3128)*(x3131)))+(((sj6)*(x3128)*(x3129)))+(((IkReal(-1.00000000000000))*(x3135)*(x3137)))+(((r21)*(x3131)*(x3136)))+(((IkReal(-1.00000000000000))*(x3127)*(x3134)))+(((r21)*(sj6)*(x3134)))+(((r21)*(x3131)*(x3133)))+(((r20)*(x3129)*(x3133)))+(((IkReal(-1.00000000000000))*(r20)*(x3133)*(x3135)))+(((IkReal(-1.00000000000000))*(cj6)*(x3128)*(x3130)))+(((IkReal(-1.00000000000000))*(x3126)*(x3130)*(x3133)))+(((IkReal(-1.00000000000000))*(sj6)*(x3128)*(x3135)))+(((x3129)*(x3137)))+(((IkReal(-1.00000000000000))*(sj6)*(x3126)*(x3132)))+(((IkReal(-1.00000000000000))*(x3126)*(x3130)*(x3136)))+(((x3127)*(x3132))));
if( IKabs(dummyeval[0]) < 0.0000010000000000  )
{
continue;

} else
{
{
IkReal j4array[1], cj4array[1], sj4array[1];
bool j4valid[1]={false};
_nj4 = 1;
IkReal x3138=((IkReal(1.00000000000000))*(cj5));
if( IKabs(((gconst84)*(((((r21)*(sj6)))+(((IkReal(-1.00000000000000))*(cj6)*(r20))))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(((gconst84)*(((((IkReal(-1.00000000000000))*(cj6)*(r21)*(x3138)))+(((IkReal(-1.00000000000000))*(r20)*(sj6)*(x3138)))+(((IkReal(-1.00000000000000))*(r22)*(sj5))))))) < IKFAST_ATAN2_MAGTHRESH )
    continue;
j4array[0]=IKatan2(((gconst84)*(((((r21)*(sj6)))+(((IkReal(-1.00000000000000))*(cj6)*(r20)))))), ((gconst84)*(((((IkReal(-1.00000000000000))*(cj6)*(r21)*(x3138)))+(((IkReal(-1.00000000000000))*(r20)*(sj6)*(x3138)))+(((IkReal(-1.00000000000000))*(r22)*(sj5)))))));
sj4array[0]=IKsin(j4array[0]);
cj4array[0]=IKcos(j4array[0]);
if( j4array[0] > IKPI )
{
    j4array[0]-=IK2PI;
}
else if( j4array[0] < -IKPI )
{    j4array[0]+=IK2PI;
}
j4valid[0] = true;
for(int ij4 = 0; ij4 < 1; ++ij4)
{
if( !j4valid[ij4] )
{
    continue;
}
_ij4[0] = ij4; _ij4[1] = -1;
for(int iij4 = ij4+1; iij4 < 1; ++iij4)
{
if( j4valid[iij4] && IKabs(cj4array[ij4]-cj4array[iij4]) < IKFAST_SOLUTION_THRESH && IKabs(sj4array[ij4]-sj4array[iij4]) < IKFAST_SOLUTION_THRESH )
{
    j4valid[iij4]=false; _ij4[1] = iij4; break; 
}
}
j4 = j4array[ij4]; cj4 = cj4array[ij4]; sj4 = sj4array[ij4];
{
IkReal evalcond[6];
IkReal x3139=IKsin(j4);
IkReal x3140=IKcos(j4);
IkReal x3141=((r22)*(sj5));
IkReal x3142=((IkReal(1.00000000000000))*(cj6));
IkReal x3143=((IkReal(1.00000000000000))*(cj0));
IkReal x3144=((cj5)*(r11));
IkReal x3145=((cj5)*(cj6));
IkReal x3146=((r11)*(sj6));
IkReal x3147=((IkReal(1.00000000000000))*(sj6));
IkReal x3148=((cj6)*(r00));
IkReal x3149=((r12)*(sj5));
IkReal x3150=((r02)*(sj5));
IkReal x3151=((cj6)*(r10));
IkReal x3152=((cj5)*(sj6));
IkReal x3153=((cj5)*(r01));
IkReal x3154=((sj0)*(x3139));
IkReal x3155=((r00)*(x3152));
IkReal x3156=((cj0)*(x3139));
IkReal x3157=((sj0)*(x3140));
IkReal x3158=((r20)*(x3140));
IkReal x3159=((cj0)*(x3140));
IkReal x3160=((r21)*(x3139));
IkReal x3161=((r21)*(x3140));
IkReal x3162=((r20)*(x3139));
IkReal x3163=((x3140)*(x3149));
IkReal x3164=((r01)*(sj6)*(x3140));
IkReal x3165=((cj5)*(r10)*(x3147));
evalcond[0]=((((x3139)*(x3141)))+(((IkReal(-1.00000000000000))*(x3142)*(x3158)))+(((sj6)*(x3161)))+(((x3152)*(x3162)))+(((x3145)*(x3160))));
evalcond[1]=((((x3152)*(x3158)))+(sj3)+(((cj6)*(x3162)))+(((IkReal(-1.00000000000000))*(x3147)*(x3160)))+(((x3145)*(x3161)))+(((x3140)*(x3141))));
evalcond[2]=((IkReal(1.00000000000000))+(((IkReal(-1.00000000000000))*(x3139)*(x3143)*(x3149)))+(((IkReal(-1.00000000000000))*(r00)*(x3142)*(x3157)))+(((r01)*(sj6)*(x3157)))+(((x3150)*(x3154)))+(((IkReal(-1.00000000000000))*(r10)*(x3139)*(x3143)*(x3152)))+(((IkReal(-1.00000000000000))*(x3140)*(x3143)*(x3146)))+(((IkReal(-1.00000000000000))*(x3142)*(x3144)*(x3156)))+(((r01)*(x3145)*(x3154)))+(((x3151)*(x3159)))+(((x3154)*(x3155))));
evalcond[3]=((((r01)*(x3145)*(x3157)))+(((x3155)*(x3157)))+(((x3146)*(x3156)))+(((IkReal(-1.00000000000000))*(x3142)*(x3144)*(x3159)))+(((IkReal(-1.00000000000000))*(x3143)*(x3163)))+(((IkReal(-1.00000000000000))*(r10)*(x3142)*(x3156)))+(((IkReal(-1.00000000000000))*(r01)*(x3147)*(x3154)))+(((x3148)*(x3154)))+(((IkReal(-1.00000000000000))*(r10)*(x3140)*(x3143)*(x3152)))+(((x3150)*(x3157))));
evalcond[4]=((((IkReal(-1.00000000000000))*(x3154)*(x3165)))+(((IkReal(-1.00000000000000))*(x3142)*(x3153)*(x3156)))+(((IkReal(-1.00000000000000))*(x3146)*(x3157)))+(((IkReal(-1.00000000000000))*(x3143)*(x3164)))+(((IkReal(-1.00000000000000))*(x3142)*(x3144)*(x3154)))+(((IkReal(-1.00000000000000))*(x3149)*(x3154)))+(((x3151)*(x3157)))+(((IkReal(-1.00000000000000))*(x3139)*(x3143)*(x3155)))+(((IkReal(-1.00000000000000))*(x3139)*(x3143)*(x3150)))+(((x3148)*(x3159))));
evalcond[5]=((((IkReal(-1.00000000000000))*(x3142)*(x3153)*(x3159)))+(((IkReal(-1.00000000000000))*(r00)*(x3142)*(x3156)))+(((x3146)*(x3154)))+(((IkReal(-1.00000000000000))*(x3140)*(x3143)*(x3150)))+(cj3)+(((IkReal(-1.00000000000000))*(x3149)*(x3157)))+(((IkReal(-1.00000000000000))*(r10)*(x3142)*(x3154)))+(((IkReal(-1.00000000000000))*(x3157)*(x3165)))+(((IkReal(-1.00000000000000))*(x3142)*(x3144)*(x3157)))+(((r01)*(sj6)*(x3156)))+(((IkReal(-1.00000000000000))*(x3140)*(x3143)*(x3155))));
if( IKabs(evalcond[0]) > 0.000001  || IKabs(evalcond[1]) > 0.000001  || IKabs(evalcond[2]) > 0.000001  || IKabs(evalcond[3]) > 0.000001  || IKabs(evalcond[4]) > 0.000001  || IKabs(evalcond[5]) > 0.000001  )
{
continue;
}
}

{
std::vector<IkSingleDOFSolutionBase<IkReal> > vinfos(7);
vinfos[0].jointtype = 1;
vinfos[0].foffset = j0;
vinfos[0].indices[0] = _ij0[0];
vinfos[0].indices[1] = _ij0[1];
vinfos[0].maxsolutions = _nj0;
vinfos[1].jointtype = 1;
vinfos[1].foffset = j1;
vinfos[1].indices[0] = _ij1[0];
vinfos[1].indices[1] = _ij1[1];
vinfos[1].maxsolutions = _nj1;
vinfos[2].jointtype = 1;
vinfos[2].foffset = j2;
vinfos[2].indices[0] = _ij2[0];
vinfos[2].indices[1] = _ij2[1];
vinfos[2].maxsolutions = _nj2;
vinfos[3].jointtype = 1;
vinfos[3].foffset = j3;
vinfos[3].indices[0] = _ij3[0];
vinfos[3].indices[1] = _ij3[1];
vinfos[3].maxsolutions = _nj3;
vinfos[4].jointtype = 1;
vinfos[4].foffset = j4;
vinfos[4].indices[0] = _ij4[0];
vinfos[4].indices[1] = _ij4[1];
vinfos[4].maxsolutions = _nj4;
vinfos[5].jointtype = 1;
vinfos[5].foffset = j5;
vinfos[5].indices[0] = _ij5[0];
vinfos[5].indices[1] = _ij5[1];
vinfos[5].maxsolutions = _nj5;
vinfos[6].jointtype = 1;
vinfos[6].foffset = j6;
vinfos[6].indices[0] = _ij6[0];
vinfos[6].indices[1] = _ij6[1];
vinfos[6].maxsolutions = _nj6;
std::vector<int> vfree(0);
solutions.AddSolution(vinfos,vfree);
}
}
}

}

}

} else
{
{
IkReal j4array[1], cj4array[1], sj4array[1];
bool j4valid[1]={false};
_nj4 = 1;
IkReal x3166=((r21)*(sj3));
IkReal x3167=((IkReal(1.00000000000000))*(r20)*(sj3));
if( IKabs(((gconst83)*(((((IkReal(-1.00000000000000))*(cj6)*(x3167)))+(((sj6)*(x3166))))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(((gconst83)*(((((IkReal(-1.00000000000000))*(cj5)*(cj6)*(x3166)))+(((IkReal(-1.00000000000000))*(cj5)*(sj6)*(x3167)))+(((IkReal(-1.00000000000000))*(r22)*(sj3)*(sj5))))))) < IKFAST_ATAN2_MAGTHRESH )
    continue;
j4array[0]=IKatan2(((gconst83)*(((((IkReal(-1.00000000000000))*(cj6)*(x3167)))+(((sj6)*(x3166)))))), ((gconst83)*(((((IkReal(-1.00000000000000))*(cj5)*(cj6)*(x3166)))+(((IkReal(-1.00000000000000))*(cj5)*(sj6)*(x3167)))+(((IkReal(-1.00000000000000))*(r22)*(sj3)*(sj5)))))));
sj4array[0]=IKsin(j4array[0]);
cj4array[0]=IKcos(j4array[0]);
if( j4array[0] > IKPI )
{
    j4array[0]-=IK2PI;
}
else if( j4array[0] < -IKPI )
{    j4array[0]+=IK2PI;
}
j4valid[0] = true;
for(int ij4 = 0; ij4 < 1; ++ij4)
{
if( !j4valid[ij4] )
{
    continue;
}
_ij4[0] = ij4; _ij4[1] = -1;
for(int iij4 = ij4+1; iij4 < 1; ++iij4)
{
if( j4valid[iij4] && IKabs(cj4array[ij4]-cj4array[iij4]) < IKFAST_SOLUTION_THRESH && IKabs(sj4array[ij4]-sj4array[iij4]) < IKFAST_SOLUTION_THRESH )
{
    j4valid[iij4]=false; _ij4[1] = iij4; break; 
}
}
j4 = j4array[ij4]; cj4 = cj4array[ij4]; sj4 = sj4array[ij4];
{
IkReal evalcond[6];
IkReal x3168=IKsin(j4);
IkReal x3169=IKcos(j4);
IkReal x3170=((r22)*(sj5));
IkReal x3171=((IkReal(1.00000000000000))*(cj6));
IkReal x3172=((IkReal(1.00000000000000))*(cj0));
IkReal x3173=((cj5)*(r11));
IkReal x3174=((cj5)*(cj6));
IkReal x3175=((r11)*(sj6));
IkReal x3176=((IkReal(1.00000000000000))*(sj6));
IkReal x3177=((cj6)*(r00));
IkReal x3178=((r12)*(sj5));
IkReal x3179=((r02)*(sj5));
IkReal x3180=((cj6)*(r10));
IkReal x3181=((cj5)*(sj6));
IkReal x3182=((cj5)*(r01));
IkReal x3183=((sj0)*(x3168));
IkReal x3184=((r00)*(x3181));
IkReal x3185=((cj0)*(x3168));
IkReal x3186=((sj0)*(x3169));
IkReal x3187=((r20)*(x3169));
IkReal x3188=((cj0)*(x3169));
IkReal x3189=((r21)*(x3168));
IkReal x3190=((r21)*(x3169));
IkReal x3191=((r20)*(x3168));
IkReal x3192=((x3169)*(x3178));
IkReal x3193=((r01)*(sj6)*(x3169));
IkReal x3194=((cj5)*(r10)*(x3176));
evalcond[0]=((((sj6)*(x3190)))+(((x3181)*(x3191)))+(((x3168)*(x3170)))+(((IkReal(-1.00000000000000))*(x3171)*(x3187)))+(((x3174)*(x3189))));
evalcond[1]=((((x3169)*(x3170)))+(sj3)+(((cj6)*(x3191)))+(((x3174)*(x3190)))+(((x3181)*(x3187)))+(((IkReal(-1.00000000000000))*(x3176)*(x3189))));
evalcond[2]=((IkReal(1.00000000000000))+(((IkReal(-1.00000000000000))*(r10)*(x3168)*(x3172)*(x3181)))+(((x3180)*(x3188)))+(((IkReal(-1.00000000000000))*(r00)*(x3171)*(x3186)))+(((x3183)*(x3184)))+(((r01)*(x3174)*(x3183)))+(((r01)*(sj6)*(x3186)))+(((IkReal(-1.00000000000000))*(x3168)*(x3172)*(x3178)))+(((IkReal(-1.00000000000000))*(x3169)*(x3172)*(x3175)))+(((x3179)*(x3183)))+(((IkReal(-1.00000000000000))*(x3171)*(x3173)*(x3185))));
evalcond[3]=((((IkReal(-1.00000000000000))*(x3171)*(x3173)*(x3188)))+(((x3175)*(x3185)))+(((IkReal(-1.00000000000000))*(r10)*(x3169)*(x3172)*(x3181)))+(((x3184)*(x3186)))+(((x3179)*(x3186)))+(((IkReal(-1.00000000000000))*(x3172)*(x3192)))+(((IkReal(-1.00000000000000))*(r01)*(x3176)*(x3183)))+(((IkReal(-1.00000000000000))*(r10)*(x3171)*(x3185)))+(((x3177)*(x3183)))+(((r01)*(x3174)*(x3186))));
evalcond[4]=((((IkReal(-1.00000000000000))*(x3171)*(x3173)*(x3183)))+(((x3180)*(x3186)))+(((x3177)*(x3188)))+(((IkReal(-1.00000000000000))*(x3168)*(x3172)*(x3184)))+(((IkReal(-1.00000000000000))*(x3172)*(x3193)))+(((IkReal(-1.00000000000000))*(x3168)*(x3172)*(x3179)))+(((IkReal(-1.00000000000000))*(x3183)*(x3194)))+(((IkReal(-1.00000000000000))*(x3175)*(x3186)))+(((IkReal(-1.00000000000000))*(x3178)*(x3183)))+(((IkReal(-1.00000000000000))*(x3171)*(x3182)*(x3185))));
evalcond[5]=((((r01)*(sj6)*(x3185)))+(((IkReal(-1.00000000000000))*(x3178)*(x3186)))+(((IkReal(-1.00000000000000))*(x3169)*(x3172)*(x3184)))+(((IkReal(-1.00000000000000))*(x3186)*(x3194)))+(((IkReal(-1.00000000000000))*(x3171)*(x3173)*(x3186)))+(cj3)+(((IkReal(-1.00000000000000))*(x3171)*(x3182)*(x3188)))+(((x3175)*(x3183)))+(((IkReal(-1.00000000000000))*(x3169)*(x3172)*(x3179)))+(((IkReal(-1.00000000000000))*(r00)*(x3171)*(x3185)))+(((IkReal(-1.00000000000000))*(r10)*(x3171)*(x3183))));
if( IKabs(evalcond[0]) > 0.000001  || IKabs(evalcond[1]) > 0.000001  || IKabs(evalcond[2]) > 0.000001  || IKabs(evalcond[3]) > 0.000001  || IKabs(evalcond[4]) > 0.000001  || IKabs(evalcond[5]) > 0.000001  )
{
continue;
}
}

{
std::vector<IkSingleDOFSolutionBase<IkReal> > vinfos(7);
vinfos[0].jointtype = 1;
vinfos[0].foffset = j0;
vinfos[0].indices[0] = _ij0[0];
vinfos[0].indices[1] = _ij0[1];
vinfos[0].maxsolutions = _nj0;
vinfos[1].jointtype = 1;
vinfos[1].foffset = j1;
vinfos[1].indices[0] = _ij1[0];
vinfos[1].indices[1] = _ij1[1];
vinfos[1].maxsolutions = _nj1;
vinfos[2].jointtype = 1;
vinfos[2].foffset = j2;
vinfos[2].indices[0] = _ij2[0];
vinfos[2].indices[1] = _ij2[1];
vinfos[2].maxsolutions = _nj2;
vinfos[3].jointtype = 1;
vinfos[3].foffset = j3;
vinfos[3].indices[0] = _ij3[0];
vinfos[3].indices[1] = _ij3[1];
vinfos[3].maxsolutions = _nj3;
vinfos[4].jointtype = 1;
vinfos[4].foffset = j4;
vinfos[4].indices[0] = _ij4[0];
vinfos[4].indices[1] = _ij4[1];
vinfos[4].maxsolutions = _nj4;
vinfos[5].jointtype = 1;
vinfos[5].foffset = j5;
vinfos[5].indices[0] = _ij5[0];
vinfos[5].indices[1] = _ij5[1];
vinfos[5].maxsolutions = _nj5;
vinfos[6].jointtype = 1;
vinfos[6].foffset = j6;
vinfos[6].indices[0] = _ij6[0];
vinfos[6].indices[1] = _ij6[1];
vinfos[6].maxsolutions = _nj6;
std::vector<int> vfree(0);
solutions.AddSolution(vinfos,vfree);
}
}
}

}

}
}
}

} else
{
IkReal x3195=((sj0)*(sj5));
IkReal x3196=((r00)*(sj6));
IkReal x3197=((cj6)*(r01));
IkReal x3198=((cj0)*(cj5));
IkReal x3199=((cj0)*(sj5));
IkReal x3200=((r10)*(sj6));
IkReal x3201=((cj6)*(r11));
IkReal x3202=((IkReal(0.374290000000000))*(sj5));
IkReal x3203=((IkReal(0.0100000000000000))*(r02));
IkReal x3204=((IkReal(1.00000000000000))*(py));
IkReal x3205=((cj5)*(sj0));
IkReal x3206=((IkReal(0.374290000000000))*(r12));
IkReal x3207=((r20)*(sj6));
IkReal x3208=((IkReal(0.0100000000000000))*(r12));
IkReal x3209=((IkReal(0.0100000000000000))*(cj5)*(cj6));
IkReal x3210=((r02)*(x3205));
IkReal x3211=((IkReal(0.374290000000000))*(cj6)*(x3199));
evalcond[0]=((IkReal(-3.14159265358979))+(IKfmod(j2, IkReal(6.28318530717959))));
evalcond[1]=((IkReal(-0.364420000000000))+(((IkReal(-0.0100000000000000))*(cj5)*(x3207)))+(((IkReal(-0.0100000000000000))*(r22)*(sj5)))+(((IkReal(-0.374290000000000))*(cj5)*(r22)))+(((IkReal(-1.00000000000000))*(r21)*(x3209)))+(pz)+(((x3202)*(x3207)))+(((cj6)*(r21)*(x3202))));
evalcond[2]=((((r12)*(x3198)))+(((IkReal(-1.00000000000000))*(x3210)))+(((IkReal(-1.00000000000000))*(x3199)*(x3201)))+(((IkReal(-1.00000000000000))*(x3199)*(x3200)))+(((x3195)*(x3197)))+(((x3195)*(x3196))));
evalcond[3]=((((IkReal(0.374290000000000))*(x3195)*(x3196)))+(((IkReal(-0.374290000000000))*(x3199)*(x3200)))+(((IkReal(0.374290000000000))*(x3195)*(x3197)))+(((IkReal(0.0100000000000000))*(x3198)*(x3200)))+(((IkReal(-1.00000000000000))*(cj0)*(x3204)))+(((IkReal(-1.00000000000000))*(x3195)*(x3203)))+(((x3198)*(x3206)))+(((x3199)*(x3208)))+(((IkReal(0.0100000000000000))*(x3198)*(x3201)))+(((IkReal(-0.374290000000000))*(x3199)*(x3201)))+(((px)*(sj0)))+(((IkReal(-0.0100000000000000))*(x3197)*(x3205)))+(((IkReal(-0.374290000000000))*(x3210)))+(((IkReal(-0.0100000000000000))*(x3196)*(x3205))));
evalcond[4]=((((IkReal(0.0100000000000000))*(x3197)*(x3198)))+(((IkReal(-1.00000000000000))*(cj0)*(px)))+(((IkReal(-0.374290000000000))*(x3196)*(x3199)))+(((x3195)*(x3208)))+(((IkReal(0.374290000000000))*(r02)*(x3198)))+(((IkReal(-0.374290000000000))*(x3197)*(x3199)))+(((IkReal(-0.374290000000000))*(x3195)*(x3200)))+(((x3199)*(x3203)))+(((IkReal(-1.00000000000000))*(sj0)*(x3204)))+(((x3205)*(x3206)))+(((IkReal(0.0100000000000000))*(x3200)*(x3205)))+(((IkReal(-0.374290000000000))*(x3195)*(x3201)))+(((IkReal(0.0100000000000000))*(x3201)*(x3205)))+(((IkReal(0.0100000000000000))*(x3196)*(x3198))));
if( IKabs(evalcond[0]) < 0.0000010000000000  && IKabs(evalcond[1]) < 0.0000010000000000  && IKabs(evalcond[2]) < 0.0000010000000000  && IKabs(evalcond[3]) < 0.0000010000000000  && IKabs(evalcond[4]) < 0.0000010000000000  )
{
{
IkReal j3array[1], cj3array[1], sj3array[1];
bool j3valid[1]={false};
_nj3 = 1;
IkReal x3212=((IkReal(1.00000000000000))*(cj5));
IkReal x3213=((cj6)*(sj5));
IkReal x3214=((sj5)*(sj6));
if( IKabs(((((r10)*(sj0)*(x3214)))+(((IkReal(-1.00000000000000))*(cj0)*(r02)*(x3212)))+(((r11)*(sj0)*(x3213)))+(((cj0)*(r00)*(x3214)))+(((IkReal(-1.00000000000000))*(r12)*(sj0)*(x3212)))+(((cj0)*(r01)*(x3213))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(((((IkReal(-1.00000000000000))*(r21)*(x3213)))+(((IkReal(-1.00000000000000))*(r20)*(x3214)))+(((cj5)*(r22))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(IKsqr(((((r10)*(sj0)*(x3214)))+(((IkReal(-1.00000000000000))*(cj0)*(r02)*(x3212)))+(((r11)*(sj0)*(x3213)))+(((cj0)*(r00)*(x3214)))+(((IkReal(-1.00000000000000))*(r12)*(sj0)*(x3212)))+(((cj0)*(r01)*(x3213)))))+IKsqr(((((IkReal(-1.00000000000000))*(r21)*(x3213)))+(((IkReal(-1.00000000000000))*(r20)*(x3214)))+(((cj5)*(r22)))))-1) <= IKFAST_SINCOS_THRESH )
    continue;
j3array[0]=IKatan2(((((r10)*(sj0)*(x3214)))+(((IkReal(-1.00000000000000))*(cj0)*(r02)*(x3212)))+(((r11)*(sj0)*(x3213)))+(((cj0)*(r00)*(x3214)))+(((IkReal(-1.00000000000000))*(r12)*(sj0)*(x3212)))+(((cj0)*(r01)*(x3213)))), ((((IkReal(-1.00000000000000))*(r21)*(x3213)))+(((IkReal(-1.00000000000000))*(r20)*(x3214)))+(((cj5)*(r22)))));
sj3array[0]=IKsin(j3array[0]);
cj3array[0]=IKcos(j3array[0]);
if( j3array[0] > IKPI )
{
    j3array[0]-=IK2PI;
}
else if( j3array[0] < -IKPI )
{    j3array[0]+=IK2PI;
}
j3valid[0] = true;
for(int ij3 = 0; ij3 < 1; ++ij3)
{
if( !j3valid[ij3] )
{
    continue;
}
_ij3[0] = ij3; _ij3[1] = -1;
for(int iij3 = ij3+1; iij3 < 1; ++iij3)
{
if( j3valid[iij3] && IKabs(cj3array[ij3]-cj3array[iij3]) < IKFAST_SOLUTION_THRESH && IKabs(sj3array[ij3]-sj3array[iij3]) < IKFAST_SOLUTION_THRESH )
{
    j3valid[iij3]=false; _ij3[1] = iij3; break; 
}
}
j3 = j3array[ij3]; cj3 = cj3array[ij3]; sj3 = sj3array[ij3];
{
IkReal evalcond[2];
IkReal x3215=((sj5)*(sj6));
IkReal x3216=((IkReal(1.00000000000000))*(cj6)*(sj5));
evalcond[0]=((((cj6)*(r21)*(sj5)))+(((r20)*(x3215)))+(((IkReal(-1.00000000000000))*(cj5)*(r22)))+(IKcos(j3)));
evalcond[1]=((((cj0)*(cj5)*(r02)))+(((IkReal(-1.00000000000000))*(cj0)*(r00)*(x3215)))+(((IkReal(-1.00000000000000))*(r11)*(sj0)*(x3216)))+(((cj5)*(r12)*(sj0)))+(((IkReal(-1.00000000000000))*(r10)*(sj0)*(x3215)))+(IKsin(j3))+(((IkReal(-1.00000000000000))*(cj0)*(r01)*(x3216))));
if( IKabs(evalcond[0]) > 0.000001  || IKabs(evalcond[1]) > 0.000001  )
{
continue;
}
}

{
IkReal dummyeval[1];
IkReal gconst87;
IkReal x3217=(cj5)*(cj5);
IkReal x3218=(r20)*(r20);
IkReal x3219=(sj6)*(sj6);
IkReal x3220=(cj6)*(cj6);
IkReal x3221=(r21)*(r21);
IkReal x3222=((cj6)*(r21));
IkReal x3223=((IkReal(2.00000000000000))*(r20)*(sj6));
IkReal x3224=((cj5)*(r22)*(sj5));
gconst87=IKsign(((((IkReal(-1.00000000000000))*(x3222)*(x3223)))+(((x3217)*(x3218)*(x3219)))+((((r22)*(r22))*((sj5)*(sj5))))+(((x3219)*(x3221)))+(((x3218)*(x3220)))+(((x3217)*(x3222)*(x3223)))+(((x3223)*(x3224)))+(((x3217)*(x3220)*(x3221)))+(((IkReal(2.00000000000000))*(x3222)*(x3224)))));
IkReal x3225=(cj5)*(cj5);
IkReal x3226=(r20)*(r20);
IkReal x3227=(sj6)*(sj6);
IkReal x3228=(cj6)*(cj6);
IkReal x3229=(r21)*(r21);
IkReal x3230=((cj6)*(r21));
IkReal x3231=((IkReal(2.00000000000000))*(r20)*(sj6));
IkReal x3232=((cj5)*(r22)*(sj5));
dummyeval[0]=((((x3227)*(x3229)))+(((x3231)*(x3232)))+((((r22)*(r22))*((sj5)*(sj5))))+(((x3225)*(x3228)*(x3229)))+(((IkReal(-1.00000000000000))*(x3230)*(x3231)))+(((x3226)*(x3228)))+(((x3225)*(x3230)*(x3231)))+(((x3225)*(x3226)*(x3227)))+(((IkReal(2.00000000000000))*(x3230)*(x3232))));
if( IKabs(dummyeval[0]) < 0.0000010000000000  )
{
{
IkReal dummyeval[1];
IkReal gconst88;
IkReal x3233=(cj6)*(cj6);
IkReal x3234=(sj6)*(sj6);
IkReal x3235=((IkReal(1.00000000000000))*(r01));
IkReal x3236=((sj0)*(sj5));
IkReal x3237=((cj6)*(r22));
IkReal x3238=((r21)*(sj6));
IkReal x3239=((r00)*(r21));
IkReal x3240=((cj0)*(sj5));
IkReal x3241=((cj6)*(r20));
IkReal x3242=((r22)*(sj6));
IkReal x3243=((cj0)*(cj5));
IkReal x3244=((IkReal(1.00000000000000))*(r10));
IkReal x3245=((cj5)*(sj0));
IkReal x3246=((r20)*(x3234));
IkReal x3247=((x3233)*(x3245));
gconst88=IKsign(((((IkReal(-1.00000000000000))*(r21)*(x3234)*(x3243)*(x3244)))+(((r11)*(x3240)*(x3242)))+(((x3234)*(x3239)*(x3245)))+(((r12)*(x3240)*(x3241)))+(((IkReal(-1.00000000000000))*(r21)*(x3233)*(x3243)*(x3244)))+(((r00)*(x3236)*(x3237)))+(((IkReal(-1.00000000000000))*(x3237)*(x3240)*(x3244)))+(((r11)*(r20)*(x3233)*(x3243)))+(((r02)*(x3236)*(x3238)))+(((IkReal(-1.00000000000000))*(x3235)*(x3245)*(x3246)))+(((IkReal(-1.00000000000000))*(x3235)*(x3236)*(x3242)))+(((IkReal(-1.00000000000000))*(r20)*(x3235)*(x3247)))+(((IkReal(-1.00000000000000))*(r02)*(x3236)*(x3241)))+(((IkReal(-1.00000000000000))*(r12)*(x3238)*(x3240)))+(((x3239)*(x3247)))+(((r11)*(x3243)*(x3246)))));
IkReal x3248=(cj6)*(cj6);
IkReal x3249=(sj6)*(sj6);
IkReal x3250=((IkReal(1.00000000000000))*(r01));
IkReal x3251=((sj0)*(sj5));
IkReal x3252=((cj6)*(r22));
IkReal x3253=((r21)*(sj6));
IkReal x3254=((r00)*(r21));
IkReal x3255=((cj0)*(sj5));
IkReal x3256=((cj6)*(r20));
IkReal x3257=((r22)*(sj6));
IkReal x3258=((cj0)*(cj5));
IkReal x3259=((IkReal(1.00000000000000))*(r10));
IkReal x3260=((cj5)*(sj0));
IkReal x3261=((r20)*(x3249));
IkReal x3262=((x3248)*(x3260));
dummyeval[0]=((((r11)*(x3258)*(x3261)))+(((IkReal(-1.00000000000000))*(x3252)*(x3255)*(x3259)))+(((IkReal(-1.00000000000000))*(x3250)*(x3251)*(x3257)))+(((IkReal(-1.00000000000000))*(r12)*(x3253)*(x3255)))+(((IkReal(-1.00000000000000))*(r02)*(x3251)*(x3256)))+(((r02)*(x3251)*(x3253)))+(((r11)*(r20)*(x3248)*(x3258)))+(((IkReal(-1.00000000000000))*(r21)*(x3248)*(x3258)*(x3259)))+(((r00)*(x3251)*(x3252)))+(((x3249)*(x3254)*(x3260)))+(((r11)*(x3255)*(x3257)))+(((IkReal(-1.00000000000000))*(r21)*(x3249)*(x3258)*(x3259)))+(((IkReal(-1.00000000000000))*(r20)*(x3250)*(x3262)))+(((IkReal(-1.00000000000000))*(x3250)*(x3260)*(x3261)))+(((r12)*(x3255)*(x3256)))+(((x3254)*(x3262))));
if( IKabs(dummyeval[0]) < 0.0000010000000000  )
{
continue;

} else
{
{
IkReal j4array[1], cj4array[1], sj4array[1];
bool j4valid[1]={false};
_nj4 = 1;
IkReal x3263=((IkReal(1.00000000000000))*(cj5));
if( IKabs(((gconst88)*(((((r21)*(sj6)))+(((IkReal(-1.00000000000000))*(cj6)*(r20))))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(((gconst88)*(((((IkReal(-1.00000000000000))*(r22)*(sj5)))+(((IkReal(-1.00000000000000))*(r20)*(sj6)*(x3263)))+(((IkReal(-1.00000000000000))*(cj6)*(r21)*(x3263))))))) < IKFAST_ATAN2_MAGTHRESH )
    continue;
j4array[0]=IKatan2(((gconst88)*(((((r21)*(sj6)))+(((IkReal(-1.00000000000000))*(cj6)*(r20)))))), ((gconst88)*(((((IkReal(-1.00000000000000))*(r22)*(sj5)))+(((IkReal(-1.00000000000000))*(r20)*(sj6)*(x3263)))+(((IkReal(-1.00000000000000))*(cj6)*(r21)*(x3263)))))));
sj4array[0]=IKsin(j4array[0]);
cj4array[0]=IKcos(j4array[0]);
if( j4array[0] > IKPI )
{
    j4array[0]-=IK2PI;
}
else if( j4array[0] < -IKPI )
{    j4array[0]+=IK2PI;
}
j4valid[0] = true;
for(int ij4 = 0; ij4 < 1; ++ij4)
{
if( !j4valid[ij4] )
{
    continue;
}
_ij4[0] = ij4; _ij4[1] = -1;
for(int iij4 = ij4+1; iij4 < 1; ++iij4)
{
if( j4valid[iij4] && IKabs(cj4array[ij4]-cj4array[iij4]) < IKFAST_SOLUTION_THRESH && IKabs(sj4array[ij4]-sj4array[iij4]) < IKFAST_SOLUTION_THRESH )
{
    j4valid[iij4]=false; _ij4[1] = iij4; break; 
}
}
j4 = j4array[ij4]; cj4 = cj4array[ij4]; sj4 = sj4array[ij4];
{
IkReal evalcond[6];
IkReal x3264=IKsin(j4);
IkReal x3265=IKcos(j4);
IkReal x3266=((r22)*(sj5));
IkReal x3267=((IkReal(1.00000000000000))*(cj6));
IkReal x3268=((IkReal(1.00000000000000))*(cj0));
IkReal x3269=((cj5)*(r11));
IkReal x3270=((cj5)*(cj6));
IkReal x3271=((r11)*(sj6));
IkReal x3272=((IkReal(1.00000000000000))*(sj6));
IkReal x3273=((cj6)*(r00));
IkReal x3274=((r12)*(sj5));
IkReal x3275=((r02)*(sj5));
IkReal x3276=((cj6)*(r10));
IkReal x3277=((cj5)*(sj6));
IkReal x3278=((cj5)*(r01));
IkReal x3279=((sj0)*(x3264));
IkReal x3280=((r00)*(x3277));
IkReal x3281=((cj0)*(x3264));
IkReal x3282=((sj0)*(x3265));
IkReal x3283=((r20)*(x3265));
IkReal x3284=((cj0)*(x3265));
IkReal x3285=((r21)*(x3264));
IkReal x3286=((r21)*(x3265));
IkReal x3287=((r20)*(x3264));
IkReal x3288=((x3265)*(x3274));
IkReal x3289=((r01)*(sj6)*(x3265));
IkReal x3290=((cj5)*(r10)*(x3272));
evalcond[0]=((((x3277)*(x3287)))+(((x3264)*(x3266)))+(((IkReal(-1.00000000000000))*(x3267)*(x3283)))+(((x3270)*(x3285)))+(((sj6)*(x3286))));
evalcond[1]=((sj3)+(((cj6)*(x3287)))+(((IkReal(-1.00000000000000))*(x3272)*(x3285)))+(((x3277)*(x3283)))+(((x3270)*(x3286)))+(((x3265)*(x3266))));
evalcond[2]=((IkReal(-1.00000000000000))+(((r01)*(sj6)*(x3282)))+(((r01)*(x3270)*(x3279)))+(((x3275)*(x3279)))+(((IkReal(-1.00000000000000))*(x3264)*(x3268)*(x3274)))+(((IkReal(-1.00000000000000))*(x3267)*(x3269)*(x3281)))+(((IkReal(-1.00000000000000))*(r10)*(x3264)*(x3268)*(x3277)))+(((x3276)*(x3284)))+(((IkReal(-1.00000000000000))*(r00)*(x3267)*(x3282)))+(((x3279)*(x3280)))+(((IkReal(-1.00000000000000))*(x3265)*(x3268)*(x3271))));
evalcond[3]=((((x3273)*(x3279)))+(((x3275)*(x3282)))+(((IkReal(-1.00000000000000))*(r10)*(x3265)*(x3268)*(x3277)))+(((r01)*(x3270)*(x3282)))+(((x3280)*(x3282)))+(((IkReal(-1.00000000000000))*(r10)*(x3267)*(x3281)))+(((IkReal(-1.00000000000000))*(x3267)*(x3269)*(x3284)))+(((IkReal(-1.00000000000000))*(x3268)*(x3288)))+(((x3271)*(x3281)))+(((IkReal(-1.00000000000000))*(r01)*(x3272)*(x3279))));
evalcond[4]=((((IkReal(-1.00000000000000))*(x3274)*(x3279)))+(((x3273)*(x3284)))+(((IkReal(-1.00000000000000))*(x3279)*(x3290)))+(((IkReal(-1.00000000000000))*(x3267)*(x3278)*(x3281)))+(((IkReal(-1.00000000000000))*(x3267)*(x3269)*(x3279)))+(((IkReal(-1.00000000000000))*(x3264)*(x3268)*(x3280)))+(((x3276)*(x3282)))+(((IkReal(-1.00000000000000))*(x3264)*(x3268)*(x3275)))+(((IkReal(-1.00000000000000))*(x3271)*(x3282)))+(((IkReal(-1.00000000000000))*(x3268)*(x3289))));
evalcond[5]=((((IkReal(-1.00000000000000))*(r10)*(x3267)*(x3279)))+(((IkReal(-1.00000000000000))*(r00)*(x3267)*(x3281)))+(((IkReal(-1.00000000000000))*(x3274)*(x3282)))+(((x3271)*(x3279)))+(((IkReal(-1.00000000000000))*(x3267)*(x3278)*(x3284)))+(((IkReal(-1.00000000000000))*(cj3)))+(((IkReal(-1.00000000000000))*(x3265)*(x3268)*(x3280)))+(((IkReal(-1.00000000000000))*(x3265)*(x3268)*(x3275)))+(((IkReal(-1.00000000000000))*(x3267)*(x3269)*(x3282)))+(((r01)*(sj6)*(x3281)))+(((IkReal(-1.00000000000000))*(x3282)*(x3290))));
if( IKabs(evalcond[0]) > 0.000001  || IKabs(evalcond[1]) > 0.000001  || IKabs(evalcond[2]) > 0.000001  || IKabs(evalcond[3]) > 0.000001  || IKabs(evalcond[4]) > 0.000001  || IKabs(evalcond[5]) > 0.000001  )
{
continue;
}
}

{
std::vector<IkSingleDOFSolutionBase<IkReal> > vinfos(7);
vinfos[0].jointtype = 1;
vinfos[0].foffset = j0;
vinfos[0].indices[0] = _ij0[0];
vinfos[0].indices[1] = _ij0[1];
vinfos[0].maxsolutions = _nj0;
vinfos[1].jointtype = 1;
vinfos[1].foffset = j1;
vinfos[1].indices[0] = _ij1[0];
vinfos[1].indices[1] = _ij1[1];
vinfos[1].maxsolutions = _nj1;
vinfos[2].jointtype = 1;
vinfos[2].foffset = j2;
vinfos[2].indices[0] = _ij2[0];
vinfos[2].indices[1] = _ij2[1];
vinfos[2].maxsolutions = _nj2;
vinfos[3].jointtype = 1;
vinfos[3].foffset = j3;
vinfos[3].indices[0] = _ij3[0];
vinfos[3].indices[1] = _ij3[1];
vinfos[3].maxsolutions = _nj3;
vinfos[4].jointtype = 1;
vinfos[4].foffset = j4;
vinfos[4].indices[0] = _ij4[0];
vinfos[4].indices[1] = _ij4[1];
vinfos[4].maxsolutions = _nj4;
vinfos[5].jointtype = 1;
vinfos[5].foffset = j5;
vinfos[5].indices[0] = _ij5[0];
vinfos[5].indices[1] = _ij5[1];
vinfos[5].maxsolutions = _nj5;
vinfos[6].jointtype = 1;
vinfos[6].foffset = j6;
vinfos[6].indices[0] = _ij6[0];
vinfos[6].indices[1] = _ij6[1];
vinfos[6].maxsolutions = _nj6;
std::vector<int> vfree(0);
solutions.AddSolution(vinfos,vfree);
}
}
}

}

}

} else
{
{
IkReal j4array[1], cj4array[1], sj4array[1];
bool j4valid[1]={false};
_nj4 = 1;
IkReal x3291=((r21)*(sj3));
IkReal x3292=((IkReal(1.00000000000000))*(r20)*(sj3));
if( IKabs(((gconst87)*(((((sj6)*(x3291)))+(((IkReal(-1.00000000000000))*(cj6)*(x3292))))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(((gconst87)*(((((IkReal(-1.00000000000000))*(cj5)*(sj6)*(x3292)))+(((IkReal(-1.00000000000000))*(cj5)*(cj6)*(x3291)))+(((IkReal(-1.00000000000000))*(r22)*(sj3)*(sj5))))))) < IKFAST_ATAN2_MAGTHRESH )
    continue;
j4array[0]=IKatan2(((gconst87)*(((((sj6)*(x3291)))+(((IkReal(-1.00000000000000))*(cj6)*(x3292)))))), ((gconst87)*(((((IkReal(-1.00000000000000))*(cj5)*(sj6)*(x3292)))+(((IkReal(-1.00000000000000))*(cj5)*(cj6)*(x3291)))+(((IkReal(-1.00000000000000))*(r22)*(sj3)*(sj5)))))));
sj4array[0]=IKsin(j4array[0]);
cj4array[0]=IKcos(j4array[0]);
if( j4array[0] > IKPI )
{
    j4array[0]-=IK2PI;
}
else if( j4array[0] < -IKPI )
{    j4array[0]+=IK2PI;
}
j4valid[0] = true;
for(int ij4 = 0; ij4 < 1; ++ij4)
{
if( !j4valid[ij4] )
{
    continue;
}
_ij4[0] = ij4; _ij4[1] = -1;
for(int iij4 = ij4+1; iij4 < 1; ++iij4)
{
if( j4valid[iij4] && IKabs(cj4array[ij4]-cj4array[iij4]) < IKFAST_SOLUTION_THRESH && IKabs(sj4array[ij4]-sj4array[iij4]) < IKFAST_SOLUTION_THRESH )
{
    j4valid[iij4]=false; _ij4[1] = iij4; break; 
}
}
j4 = j4array[ij4]; cj4 = cj4array[ij4]; sj4 = sj4array[ij4];
{
IkReal evalcond[6];
IkReal x3293=IKsin(j4);
IkReal x3294=IKcos(j4);
IkReal x3295=((r22)*(sj5));
IkReal x3296=((IkReal(1.00000000000000))*(cj6));
IkReal x3297=((IkReal(1.00000000000000))*(cj0));
IkReal x3298=((cj5)*(r11));
IkReal x3299=((cj5)*(cj6));
IkReal x3300=((r11)*(sj6));
IkReal x3301=((IkReal(1.00000000000000))*(sj6));
IkReal x3302=((cj6)*(r00));
IkReal x3303=((r12)*(sj5));
IkReal x3304=((r02)*(sj5));
IkReal x3305=((cj6)*(r10));
IkReal x3306=((cj5)*(sj6));
IkReal x3307=((cj5)*(r01));
IkReal x3308=((sj0)*(x3293));
IkReal x3309=((r00)*(x3306));
IkReal x3310=((cj0)*(x3293));
IkReal x3311=((sj0)*(x3294));
IkReal x3312=((r20)*(x3294));
IkReal x3313=((cj0)*(x3294));
IkReal x3314=((r21)*(x3293));
IkReal x3315=((r21)*(x3294));
IkReal x3316=((r20)*(x3293));
IkReal x3317=((x3294)*(x3303));
IkReal x3318=((r01)*(sj6)*(x3294));
IkReal x3319=((cj5)*(r10)*(x3301));
evalcond[0]=((((IkReal(-1.00000000000000))*(x3296)*(x3312)))+(((x3299)*(x3314)))+(((x3293)*(x3295)))+(((x3306)*(x3316)))+(((sj6)*(x3315))));
evalcond[1]=((((cj6)*(x3316)))+(sj3)+(((x3306)*(x3312)))+(((IkReal(-1.00000000000000))*(x3301)*(x3314)))+(((x3294)*(x3295)))+(((x3299)*(x3315))));
evalcond[2]=((IkReal(-1.00000000000000))+(((IkReal(-1.00000000000000))*(x3294)*(x3297)*(x3300)))+(((r01)*(x3299)*(x3308)))+(((IkReal(-1.00000000000000))*(x3296)*(x3298)*(x3310)))+(((x3305)*(x3313)))+(((IkReal(-1.00000000000000))*(r00)*(x3296)*(x3311)))+(((x3308)*(x3309)))+(((IkReal(-1.00000000000000))*(r10)*(x3293)*(x3297)*(x3306)))+(((x3304)*(x3308)))+(((r01)*(sj6)*(x3311)))+(((IkReal(-1.00000000000000))*(x3293)*(x3297)*(x3303))));
evalcond[3]=((((x3300)*(x3310)))+(((IkReal(-1.00000000000000))*(x3296)*(x3298)*(x3313)))+(((IkReal(-1.00000000000000))*(x3297)*(x3317)))+(((IkReal(-1.00000000000000))*(r10)*(x3294)*(x3297)*(x3306)))+(((x3304)*(x3311)))+(((x3309)*(x3311)))+(((IkReal(-1.00000000000000))*(r01)*(x3301)*(x3308)))+(((IkReal(-1.00000000000000))*(r10)*(x3296)*(x3310)))+(((r01)*(x3299)*(x3311)))+(((x3302)*(x3308))));
evalcond[4]=((((IkReal(-1.00000000000000))*(x3300)*(x3311)))+(((x3305)*(x3311)))+(((x3302)*(x3313)))+(((IkReal(-1.00000000000000))*(x3308)*(x3319)))+(((IkReal(-1.00000000000000))*(x3296)*(x3298)*(x3308)))+(((IkReal(-1.00000000000000))*(x3293)*(x3297)*(x3304)))+(((IkReal(-1.00000000000000))*(x3296)*(x3307)*(x3310)))+(((IkReal(-1.00000000000000))*(x3293)*(x3297)*(x3309)))+(((IkReal(-1.00000000000000))*(x3303)*(x3308)))+(((IkReal(-1.00000000000000))*(x3297)*(x3318))));
evalcond[5]=((((IkReal(-1.00000000000000))*(r10)*(x3296)*(x3308)))+(((r01)*(sj6)*(x3310)))+(((IkReal(-1.00000000000000))*(r00)*(x3296)*(x3310)))+(((IkReal(-1.00000000000000))*(x3296)*(x3307)*(x3313)))+(((IkReal(-1.00000000000000))*(x3311)*(x3319)))+(((x3300)*(x3308)))+(((IkReal(-1.00000000000000))*(cj3)))+(((IkReal(-1.00000000000000))*(x3294)*(x3297)*(x3304)))+(((IkReal(-1.00000000000000))*(x3303)*(x3311)))+(((IkReal(-1.00000000000000))*(x3296)*(x3298)*(x3311)))+(((IkReal(-1.00000000000000))*(x3294)*(x3297)*(x3309))));
if( IKabs(evalcond[0]) > 0.000001  || IKabs(evalcond[1]) > 0.000001  || IKabs(evalcond[2]) > 0.000001  || IKabs(evalcond[3]) > 0.000001  || IKabs(evalcond[4]) > 0.000001  || IKabs(evalcond[5]) > 0.000001  )
{
continue;
}
}

{
std::vector<IkSingleDOFSolutionBase<IkReal> > vinfos(7);
vinfos[0].jointtype = 1;
vinfos[0].foffset = j0;
vinfos[0].indices[0] = _ij0[0];
vinfos[0].indices[1] = _ij0[1];
vinfos[0].maxsolutions = _nj0;
vinfos[1].jointtype = 1;
vinfos[1].foffset = j1;
vinfos[1].indices[0] = _ij1[0];
vinfos[1].indices[1] = _ij1[1];
vinfos[1].maxsolutions = _nj1;
vinfos[2].jointtype = 1;
vinfos[2].foffset = j2;
vinfos[2].indices[0] = _ij2[0];
vinfos[2].indices[1] = _ij2[1];
vinfos[2].maxsolutions = _nj2;
vinfos[3].jointtype = 1;
vinfos[3].foffset = j3;
vinfos[3].indices[0] = _ij3[0];
vinfos[3].indices[1] = _ij3[1];
vinfos[3].maxsolutions = _nj3;
vinfos[4].jointtype = 1;
vinfos[4].foffset = j4;
vinfos[4].indices[0] = _ij4[0];
vinfos[4].indices[1] = _ij4[1];
vinfos[4].maxsolutions = _nj4;
vinfos[5].jointtype = 1;
vinfos[5].foffset = j5;
vinfos[5].indices[0] = _ij5[0];
vinfos[5].indices[1] = _ij5[1];
vinfos[5].maxsolutions = _nj5;
vinfos[6].jointtype = 1;
vinfos[6].foffset = j6;
vinfos[6].indices[0] = _ij6[0];
vinfos[6].indices[1] = _ij6[1];
vinfos[6].maxsolutions = _nj6;
std::vector<int> vfree(0);
solutions.AddSolution(vinfos,vfree);
}
}
}

}

}
}
}

} else
{
if( 1 )
{
continue;

} else
{
}
}
}
}

} else
{
{
IkReal j3array[1], cj3array[1], sj3array[1];
bool j3valid[1]={false};
_nj3 = 1;
IkReal x3320=((sj0)*(sj5));
IkReal x3321=((IkReal(1.00000000000000))*(cj6)*(sj5));
IkReal x3322=((IkReal(1.00000000000000))*(sj5)*(sj6));
if( IKabs(((((IKabs(sj2) != 0)?((IkReal)1/(sj2)):(IkReal)1.0e30))*(((((cj6)*(r01)*(x3320)))+(((IkReal(-1.00000000000000))*(cj0)*(r11)*(x3321)))+(((cj0)*(cj5)*(r12)))+(((r00)*(sj6)*(x3320)))+(((IkReal(-1.00000000000000))*(cj0)*(r10)*(x3322)))+(((IkReal(-1.00000000000000))*(cj5)*(r02)*(sj0))))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(((((IkReal(-1.00000000000000))*(r20)*(x3322)))+(((IkReal(-1.00000000000000))*(r21)*(x3321)))+(((cj5)*(r22))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(IKsqr(((((IKabs(sj2) != 0)?((IkReal)1/(sj2)):(IkReal)1.0e30))*(((((cj6)*(r01)*(x3320)))+(((IkReal(-1.00000000000000))*(cj0)*(r11)*(x3321)))+(((cj0)*(cj5)*(r12)))+(((r00)*(sj6)*(x3320)))+(((IkReal(-1.00000000000000))*(cj0)*(r10)*(x3322)))+(((IkReal(-1.00000000000000))*(cj5)*(r02)*(sj0)))))))+IKsqr(((((IkReal(-1.00000000000000))*(r20)*(x3322)))+(((IkReal(-1.00000000000000))*(r21)*(x3321)))+(((cj5)*(r22)))))-1) <= IKFAST_SINCOS_THRESH )
    continue;
j3array[0]=IKatan2(((((IKabs(sj2) != 0)?((IkReal)1/(sj2)):(IkReal)1.0e30))*(((((cj6)*(r01)*(x3320)))+(((IkReal(-1.00000000000000))*(cj0)*(r11)*(x3321)))+(((cj0)*(cj5)*(r12)))+(((r00)*(sj6)*(x3320)))+(((IkReal(-1.00000000000000))*(cj0)*(r10)*(x3322)))+(((IkReal(-1.00000000000000))*(cj5)*(r02)*(sj0)))))), ((((IkReal(-1.00000000000000))*(r20)*(x3322)))+(((IkReal(-1.00000000000000))*(r21)*(x3321)))+(((cj5)*(r22)))));
sj3array[0]=IKsin(j3array[0]);
cj3array[0]=IKcos(j3array[0]);
if( j3array[0] > IKPI )
{
    j3array[0]-=IK2PI;
}
else if( j3array[0] < -IKPI )
{    j3array[0]+=IK2PI;
}
j3valid[0] = true;
for(int ij3 = 0; ij3 < 1; ++ij3)
{
if( !j3valid[ij3] )
{
    continue;
}
_ij3[0] = ij3; _ij3[1] = -1;
for(int iij3 = ij3+1; iij3 < 1; ++iij3)
{
if( j3valid[iij3] && IKabs(cj3array[ij3]-cj3array[iij3]) < IKFAST_SOLUTION_THRESH && IKabs(sj3array[ij3]-sj3array[iij3]) < IKFAST_SOLUTION_THRESH )
{
    j3valid[iij3]=false; _ij3[1] = iij3; break; 
}
}
j3 = j3array[ij3]; cj3 = cj3array[ij3]; sj3 = sj3array[ij3];
{
IkReal evalcond[3];
IkReal x3323=IKsin(j3);
IkReal x3324=((sj5)*(sj6));
IkReal x3325=((cj0)*(cj5));
IkReal x3326=((IkReal(1.00000000000000))*(cj0));
IkReal x3327=((IkReal(1.00000000000000))*(sj0));
IkReal x3328=((IkReal(1.00000000000000))*(x3323));
IkReal x3329=((cj6)*(r01)*(sj5));
IkReal x3330=((cj6)*(r11)*(sj5));
evalcond[0]=((((cj6)*(r21)*(sj5)))+(((IkReal(-1.00000000000000))*(cj5)*(r22)))+(((r20)*(x3324)))+(IKcos(j3)));
evalcond[1]=((((IkReal(-1.00000000000000))*(x3326)*(x3330)))+(((r12)*(x3325)))+(((r00)*(sj0)*(x3324)))+(((IkReal(-1.00000000000000))*(sj2)*(x3328)))+(((IkReal(-1.00000000000000))*(r10)*(x3324)*(x3326)))+(((sj0)*(x3329)))+(((IkReal(-1.00000000000000))*(cj5)*(r02)*(x3327))));
evalcond[2]=((((IkReal(-1.00000000000000))*(r00)*(x3324)*(x3326)))+(((r02)*(x3325)))+(((IkReal(-1.00000000000000))*(x3327)*(x3330)))+(((IkReal(-1.00000000000000))*(r10)*(x3324)*(x3327)))+(((cj5)*(r12)*(sj0)))+(((IkReal(-1.00000000000000))*(cj2)*(x3328)))+(((IkReal(-1.00000000000000))*(x3326)*(x3329))));
if( IKabs(evalcond[0]) > 0.000001  || IKabs(evalcond[1]) > 0.000001  || IKabs(evalcond[2]) > 0.000001  )
{
continue;
}
}

{
IkReal dummyeval[1];
IkReal gconst79;
IkReal x3331=(cj5)*(cj5);
IkReal x3332=(r20)*(r20);
IkReal x3333=(sj6)*(sj6);
IkReal x3334=(cj6)*(cj6);
IkReal x3335=(r21)*(r21);
IkReal x3336=((cj6)*(r21));
IkReal x3337=((IkReal(2.00000000000000))*(r20)*(sj6));
IkReal x3338=((cj5)*(r22)*(sj5));
gconst79=IKsign(((((x3337)*(x3338)))+(((IkReal(-1.00000000000000))*(x3336)*(x3337)))+((((r22)*(r22))*((sj5)*(sj5))))+(((x3331)*(x3334)*(x3335)))+(((x3331)*(x3336)*(x3337)))+(((x3331)*(x3332)*(x3333)))+(((x3333)*(x3335)))+(((IkReal(2.00000000000000))*(x3336)*(x3338)))+(((x3332)*(x3334)))));
IkReal x3339=(cj5)*(cj5);
IkReal x3340=(r20)*(r20);
IkReal x3341=(sj6)*(sj6);
IkReal x3342=(cj6)*(cj6);
IkReal x3343=(r21)*(r21);
IkReal x3344=((cj6)*(r21));
IkReal x3345=((IkReal(2.00000000000000))*(r20)*(sj6));
IkReal x3346=((cj5)*(r22)*(sj5));
dummyeval[0]=((((IkReal(-1.00000000000000))*(x3344)*(x3345)))+((((r22)*(r22))*((sj5)*(sj5))))+(((x3340)*(x3342)))+(((x3341)*(x3343)))+(((x3339)*(x3340)*(x3341)))+(((x3339)*(x3342)*(x3343)))+(((x3345)*(x3346)))+(((IkReal(2.00000000000000))*(x3344)*(x3346)))+(((x3339)*(x3344)*(x3345))));
if( IKabs(dummyeval[0]) < 0.0000010000000000  )
{
{
IkReal dummyeval[1];
IkReal gconst80;
IkReal x3347=(cj6)*(cj6);
IkReal x3348=(sj6)*(sj6);
IkReal x3349=((IkReal(1.00000000000000))*(r21));
IkReal x3350=((cj6)*(r20));
IkReal x3351=((r22)*(sj5));
IkReal x3352=((r01)*(sj0));
IkReal x3353=((r00)*(sj0));
IkReal x3354=((cj0)*(r10));
IkReal x3355=((r02)*(sj0)*(sj5));
IkReal x3356=((cj5)*(x3347));
IkReal x3357=((cj0)*(r12)*(sj5));
IkReal x3358=((IkReal(1.00000000000000))*(cj0)*(r11));
IkReal x3359=((cj5)*(x3348));
IkReal x3360=((r20)*(x3359));
gconst80=IKsign(((((x3352)*(x3360)))+(((IkReal(-1.00000000000000))*(x3349)*(x3353)*(x3359)))+(((r20)*(x3352)*(x3356)))+(((IkReal(-1.00000000000000))*(x3358)*(x3360)))+(((x3350)*(x3355)))+(((cj6)*(x3351)*(x3354)))+(((IkReal(-1.00000000000000))*(sj6)*(x3351)*(x3358)))+(((IkReal(-1.00000000000000))*(cj6)*(x3351)*(x3353)))+(((r21)*(sj6)*(x3357)))+(((r21)*(x3354)*(x3356)))+(((sj6)*(x3351)*(x3352)))+(((r21)*(x3354)*(x3359)))+(((IkReal(-1.00000000000000))*(r20)*(x3356)*(x3358)))+(((IkReal(-1.00000000000000))*(x3349)*(x3353)*(x3356)))+(((IkReal(-1.00000000000000))*(x3350)*(x3357)))+(((IkReal(-1.00000000000000))*(sj6)*(x3349)*(x3355)))));
IkReal x3361=(cj6)*(cj6);
IkReal x3362=(sj6)*(sj6);
IkReal x3363=((IkReal(1.00000000000000))*(r21));
IkReal x3364=((cj6)*(r20));
IkReal x3365=((r22)*(sj5));
IkReal x3366=((r01)*(sj0));
IkReal x3367=((r00)*(sj0));
IkReal x3368=((cj0)*(r10));
IkReal x3369=((r02)*(sj0)*(sj5));
IkReal x3370=((cj5)*(x3361));
IkReal x3371=((cj0)*(r12)*(sj5));
IkReal x3372=((IkReal(1.00000000000000))*(cj0)*(r11));
IkReal x3373=((cj5)*(x3362));
IkReal x3374=((r20)*(x3373));
dummyeval[0]=((((IkReal(-1.00000000000000))*(r20)*(x3370)*(x3372)))+(((x3366)*(x3374)))+(((x3364)*(x3369)))+(((r21)*(x3368)*(x3370)))+(((IkReal(-1.00000000000000))*(x3363)*(x3367)*(x3370)))+(((r21)*(sj6)*(x3371)))+(((r21)*(x3368)*(x3373)))+(((IkReal(-1.00000000000000))*(x3364)*(x3371)))+(((IkReal(-1.00000000000000))*(sj6)*(x3363)*(x3369)))+(((IkReal(-1.00000000000000))*(x3372)*(x3374)))+(((cj6)*(x3365)*(x3368)))+(((r20)*(x3366)*(x3370)))+(((sj6)*(x3365)*(x3366)))+(((IkReal(-1.00000000000000))*(x3363)*(x3367)*(x3373)))+(((IkReal(-1.00000000000000))*(sj6)*(x3365)*(x3372)))+(((IkReal(-1.00000000000000))*(cj6)*(x3365)*(x3367))));
if( IKabs(dummyeval[0]) < 0.0000010000000000  )
{
continue;

} else
{
{
IkReal j4array[1], cj4array[1], sj4array[1];
bool j4valid[1]={false};
_nj4 = 1;
IkReal x3375=((cj2)*(sj6));
IkReal x3376=((IkReal(1.00000000000000))*(r20));
IkReal x3377=((cj2)*(cj6));
if( IKabs(((gconst80)*(((((r21)*(x3375)))+(((IkReal(-1.00000000000000))*(x3376)*(x3377))))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(((gconst80)*(((((IkReal(-1.00000000000000))*(cj5)*(x3375)*(x3376)))+(((IkReal(-1.00000000000000))*(cj2)*(r22)*(sj5)))+(((IkReal(-1.00000000000000))*(cj5)*(r21)*(x3377))))))) < IKFAST_ATAN2_MAGTHRESH )
    continue;
j4array[0]=IKatan2(((gconst80)*(((((r21)*(x3375)))+(((IkReal(-1.00000000000000))*(x3376)*(x3377)))))), ((gconst80)*(((((IkReal(-1.00000000000000))*(cj5)*(x3375)*(x3376)))+(((IkReal(-1.00000000000000))*(cj2)*(r22)*(sj5)))+(((IkReal(-1.00000000000000))*(cj5)*(r21)*(x3377)))))));
sj4array[0]=IKsin(j4array[0]);
cj4array[0]=IKcos(j4array[0]);
if( j4array[0] > IKPI )
{
    j4array[0]-=IK2PI;
}
else if( j4array[0] < -IKPI )
{    j4array[0]+=IK2PI;
}
j4valid[0] = true;
for(int ij4 = 0; ij4 < 1; ++ij4)
{
if( !j4valid[ij4] )
{
    continue;
}
_ij4[0] = ij4; _ij4[1] = -1;
for(int iij4 = ij4+1; iij4 < 1; ++iij4)
{
if( j4valid[iij4] && IKabs(cj4array[ij4]-cj4array[iij4]) < IKFAST_SOLUTION_THRESH && IKabs(sj4array[ij4]-sj4array[iij4]) < IKFAST_SOLUTION_THRESH )
{
    j4valid[iij4]=false; _ij4[1] = iij4; break; 
}
}
j4 = j4array[ij4]; cj4 = cj4array[ij4]; sj4 = sj4array[ij4];
{
IkReal evalcond[6];
IkReal x3378=IKsin(j4);
IkReal x3379=IKcos(j4);
IkReal x3380=((r00)*(sj6));
IkReal x3381=((IkReal(1.00000000000000))*(r12));
IkReal x3382=((IkReal(1.00000000000000))*(cj6));
IkReal x3383=((cj6)*(r01));
IkReal x3384=((r11)*(sj6));
IkReal x3385=((r01)*(sj6));
IkReal x3386=((IkReal(1.00000000000000))*(cj5));
IkReal x3387=((IkReal(1.00000000000000))*(sj6));
IkReal x3388=((cj5)*(r11));
IkReal x3389=((cj6)*(r00));
IkReal x3390=((cj5)*(cj6));
IkReal x3391=((r02)*(sj5));
IkReal x3392=((cj6)*(r10));
IkReal x3393=((cj5)*(sj6));
IkReal x3394=((r10)*(sj6));
IkReal x3395=((cj5)*(r01));
IkReal x3396=((sj5)*(x3378));
IkReal x3397=((cj0)*(x3379));
IkReal x3398=((cj0)*(x3378));
IkReal x3399=((sj0)*(x3379));
IkReal x3400=((sj0)*(x3378));
IkReal x3401=((r20)*(x3379));
IkReal x3402=((r21)*(x3378));
IkReal x3403=((r21)*(x3379));
IkReal x3404=((r20)*(x3378));
IkReal x3405=((cj5)*(x3400));
evalcond[0]=((((r22)*(x3396)))+(((IkReal(-1.00000000000000))*(x3382)*(x3401)))+(((x3393)*(x3404)))+(((x3390)*(x3402)))+(((sj6)*(x3403))));
evalcond[1]=((((cj6)*(x3404)))+(sj3)+(((IkReal(-1.00000000000000))*(x3387)*(x3402)))+(((r22)*(sj5)*(x3379)))+(((x3393)*(x3401)))+(((x3390)*(x3403))));
evalcond[2]=((((IkReal(-1.00000000000000))*(x3384)*(x3397)))+(((x3385)*(x3399)))+(((x3391)*(x3400)))+(((IkReal(-1.00000000000000))*(x3386)*(x3394)*(x3398)))+(((x3392)*(x3397)))+(((x3380)*(x3405)))+(cj2)+(((IkReal(-1.00000000000000))*(r00)*(x3382)*(x3399)))+(((IkReal(-1.00000000000000))*(x3382)*(x3388)*(x3398)))+(((IkReal(-1.00000000000000))*(cj0)*(x3381)*(x3396)))+(((x3383)*(x3405))));
evalcond[3]=((((IkReal(-1.00000000000000))*(x3382)*(x3388)*(x3397)))+(((IkReal(-1.00000000000000))*(x3386)*(x3394)*(x3397)))+(((x3389)*(x3400)))+(((IkReal(-1.00000000000000))*(sj5)*(x3381)*(x3397)))+(((cj5)*(x3380)*(x3399)))+(((IkReal(-1.00000000000000))*(r10)*(x3382)*(x3398)))+(((IkReal(-1.00000000000000))*(x3385)*(x3400)))+(((cj5)*(x3383)*(x3399)))+(((cj3)*(sj2)))+(((x3391)*(x3399)))+(((x3384)*(x3398))));
evalcond[4]=((((IkReal(-1.00000000000000))*(sj0)*(x3381)*(x3396)))+(((IkReal(-1.00000000000000))*(sj2)))+(((x3389)*(x3397)))+(((IkReal(-1.00000000000000))*(x3385)*(x3397)))+(((x3392)*(x3399)))+(((IkReal(-1.00000000000000))*(x3391)*(x3398)))+(((IkReal(-1.00000000000000))*(x3380)*(x3386)*(x3398)))+(((IkReal(-1.00000000000000))*(x3386)*(x3394)*(x3400)))+(((IkReal(-1.00000000000000))*(x3382)*(x3395)*(x3398)))+(((IkReal(-1.00000000000000))*(x3384)*(x3399)))+(((IkReal(-1.00000000000000))*(x3382)*(x3388)*(x3400))));
evalcond[5]=((((IkReal(-1.00000000000000))*(r10)*(x3382)*(x3400)))+(((IkReal(-1.00000000000000))*(x3380)*(x3386)*(x3397)))+(((IkReal(-1.00000000000000))*(x3391)*(x3397)))+(((IkReal(-1.00000000000000))*(x3386)*(x3394)*(x3399)))+(((IkReal(-1.00000000000000))*(r00)*(x3382)*(x3398)))+(((x3384)*(x3400)))+(((cj2)*(cj3)))+(((IkReal(-1.00000000000000))*(x3382)*(x3395)*(x3397)))+(((IkReal(-1.00000000000000))*(sj5)*(x3381)*(x3399)))+(((x3385)*(x3398)))+(((IkReal(-1.00000000000000))*(x3382)*(x3388)*(x3399))));
if( IKabs(evalcond[0]) > 0.000001  || IKabs(evalcond[1]) > 0.000001  || IKabs(evalcond[2]) > 0.000001  || IKabs(evalcond[3]) > 0.000001  || IKabs(evalcond[4]) > 0.000001  || IKabs(evalcond[5]) > 0.000001  )
{
continue;
}
}

{
std::vector<IkSingleDOFSolutionBase<IkReal> > vinfos(7);
vinfos[0].jointtype = 1;
vinfos[0].foffset = j0;
vinfos[0].indices[0] = _ij0[0];
vinfos[0].indices[1] = _ij0[1];
vinfos[0].maxsolutions = _nj0;
vinfos[1].jointtype = 1;
vinfos[1].foffset = j1;
vinfos[1].indices[0] = _ij1[0];
vinfos[1].indices[1] = _ij1[1];
vinfos[1].maxsolutions = _nj1;
vinfos[2].jointtype = 1;
vinfos[2].foffset = j2;
vinfos[2].indices[0] = _ij2[0];
vinfos[2].indices[1] = _ij2[1];
vinfos[2].maxsolutions = _nj2;
vinfos[3].jointtype = 1;
vinfos[3].foffset = j3;
vinfos[3].indices[0] = _ij3[0];
vinfos[3].indices[1] = _ij3[1];
vinfos[3].maxsolutions = _nj3;
vinfos[4].jointtype = 1;
vinfos[4].foffset = j4;
vinfos[4].indices[0] = _ij4[0];
vinfos[4].indices[1] = _ij4[1];
vinfos[4].maxsolutions = _nj4;
vinfos[5].jointtype = 1;
vinfos[5].foffset = j5;
vinfos[5].indices[0] = _ij5[0];
vinfos[5].indices[1] = _ij5[1];
vinfos[5].maxsolutions = _nj5;
vinfos[6].jointtype = 1;
vinfos[6].foffset = j6;
vinfos[6].indices[0] = _ij6[0];
vinfos[6].indices[1] = _ij6[1];
vinfos[6].maxsolutions = _nj6;
std::vector<int> vfree(0);
solutions.AddSolution(vinfos,vfree);
}
}
}

}

}

} else
{
{
IkReal j4array[1], cj4array[1], sj4array[1];
bool j4valid[1]={false};
_nj4 = 1;
IkReal x3406=((r21)*(sj3));
IkReal x3407=((IkReal(1.00000000000000))*(r20)*(sj3));
if( IKabs(((gconst79)*(((((sj6)*(x3406)))+(((IkReal(-1.00000000000000))*(cj6)*(x3407))))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(((gconst79)*(((((IkReal(-1.00000000000000))*(cj5)*(sj6)*(x3407)))+(((IkReal(-1.00000000000000))*(cj5)*(cj6)*(x3406)))+(((IkReal(-1.00000000000000))*(r22)*(sj3)*(sj5))))))) < IKFAST_ATAN2_MAGTHRESH )
    continue;
j4array[0]=IKatan2(((gconst79)*(((((sj6)*(x3406)))+(((IkReal(-1.00000000000000))*(cj6)*(x3407)))))), ((gconst79)*(((((IkReal(-1.00000000000000))*(cj5)*(sj6)*(x3407)))+(((IkReal(-1.00000000000000))*(cj5)*(cj6)*(x3406)))+(((IkReal(-1.00000000000000))*(r22)*(sj3)*(sj5)))))));
sj4array[0]=IKsin(j4array[0]);
cj4array[0]=IKcos(j4array[0]);
if( j4array[0] > IKPI )
{
    j4array[0]-=IK2PI;
}
else if( j4array[0] < -IKPI )
{    j4array[0]+=IK2PI;
}
j4valid[0] = true;
for(int ij4 = 0; ij4 < 1; ++ij4)
{
if( !j4valid[ij4] )
{
    continue;
}
_ij4[0] = ij4; _ij4[1] = -1;
for(int iij4 = ij4+1; iij4 < 1; ++iij4)
{
if( j4valid[iij4] && IKabs(cj4array[ij4]-cj4array[iij4]) < IKFAST_SOLUTION_THRESH && IKabs(sj4array[ij4]-sj4array[iij4]) < IKFAST_SOLUTION_THRESH )
{
    j4valid[iij4]=false; _ij4[1] = iij4; break; 
}
}
j4 = j4array[ij4]; cj4 = cj4array[ij4]; sj4 = sj4array[ij4];
{
IkReal evalcond[6];
IkReal x3408=IKsin(j4);
IkReal x3409=IKcos(j4);
IkReal x3410=((r00)*(sj6));
IkReal x3411=((IkReal(1.00000000000000))*(r12));
IkReal x3412=((IkReal(1.00000000000000))*(cj6));
IkReal x3413=((cj6)*(r01));
IkReal x3414=((r11)*(sj6));
IkReal x3415=((r01)*(sj6));
IkReal x3416=((IkReal(1.00000000000000))*(cj5));
IkReal x3417=((IkReal(1.00000000000000))*(sj6));
IkReal x3418=((cj5)*(r11));
IkReal x3419=((cj6)*(r00));
IkReal x3420=((cj5)*(cj6));
IkReal x3421=((r02)*(sj5));
IkReal x3422=((cj6)*(r10));
IkReal x3423=((cj5)*(sj6));
IkReal x3424=((r10)*(sj6));
IkReal x3425=((cj5)*(r01));
IkReal x3426=((sj5)*(x3408));
IkReal x3427=((cj0)*(x3409));
IkReal x3428=((cj0)*(x3408));
IkReal x3429=((sj0)*(x3409));
IkReal x3430=((sj0)*(x3408));
IkReal x3431=((r20)*(x3409));
IkReal x3432=((r21)*(x3408));
IkReal x3433=((r21)*(x3409));
IkReal x3434=((r20)*(x3408));
IkReal x3435=((cj5)*(x3430));
evalcond[0]=((((r22)*(x3426)))+(((sj6)*(x3433)))+(((x3420)*(x3432)))+(((IkReal(-1.00000000000000))*(x3412)*(x3431)))+(((x3423)*(x3434))));
evalcond[1]=((((r22)*(sj5)*(x3409)))+(sj3)+(((cj6)*(x3434)))+(((x3423)*(x3431)))+(((x3420)*(x3433)))+(((IkReal(-1.00000000000000))*(x3417)*(x3432))));
evalcond[2]=((((IkReal(-1.00000000000000))*(x3414)*(x3427)))+(((IkReal(-1.00000000000000))*(r00)*(x3412)*(x3429)))+(((IkReal(-1.00000000000000))*(x3416)*(x3424)*(x3428)))+(((x3422)*(x3427)))+(((x3415)*(x3429)))+(((x3413)*(x3435)))+(cj2)+(((IkReal(-1.00000000000000))*(cj0)*(x3411)*(x3426)))+(((x3410)*(x3435)))+(((IkReal(-1.00000000000000))*(x3412)*(x3418)*(x3428)))+(((x3421)*(x3430))));
evalcond[3]=((((IkReal(-1.00000000000000))*(x3415)*(x3430)))+(((IkReal(-1.00000000000000))*(x3412)*(x3418)*(x3427)))+(((x3419)*(x3430)))+(((IkReal(-1.00000000000000))*(sj5)*(x3411)*(x3427)))+(((cj5)*(x3410)*(x3429)))+(((IkReal(-1.00000000000000))*(r10)*(x3412)*(x3428)))+(((cj3)*(sj2)))+(((IkReal(-1.00000000000000))*(x3416)*(x3424)*(x3427)))+(((x3421)*(x3429)))+(((x3414)*(x3428)))+(((cj5)*(x3413)*(x3429))));
evalcond[4]=((((x3419)*(x3427)))+(((IkReal(-1.00000000000000))*(sj2)))+(((IkReal(-1.00000000000000))*(x3421)*(x3428)))+(((IkReal(-1.00000000000000))*(x3412)*(x3425)*(x3428)))+(((IkReal(-1.00000000000000))*(x3412)*(x3418)*(x3430)))+(((x3422)*(x3429)))+(((IkReal(-1.00000000000000))*(x3410)*(x3416)*(x3428)))+(((IkReal(-1.00000000000000))*(x3414)*(x3429)))+(((IkReal(-1.00000000000000))*(sj0)*(x3411)*(x3426)))+(((IkReal(-1.00000000000000))*(x3415)*(x3427)))+(((IkReal(-1.00000000000000))*(x3416)*(x3424)*(x3430))));
evalcond[5]=((((IkReal(-1.00000000000000))*(x3412)*(x3418)*(x3429)))+(((IkReal(-1.00000000000000))*(x3410)*(x3416)*(x3427)))+(((x3415)*(x3428)))+(((x3414)*(x3430)))+(((IkReal(-1.00000000000000))*(r00)*(x3412)*(x3428)))+(((IkReal(-1.00000000000000))*(x3416)*(x3424)*(x3429)))+(((cj2)*(cj3)))+(((IkReal(-1.00000000000000))*(x3412)*(x3425)*(x3427)))+(((IkReal(-1.00000000000000))*(r10)*(x3412)*(x3430)))+(((IkReal(-1.00000000000000))*(sj5)*(x3411)*(x3429)))+(((IkReal(-1.00000000000000))*(x3421)*(x3427))));
if( IKabs(evalcond[0]) > 0.000001  || IKabs(evalcond[1]) > 0.000001  || IKabs(evalcond[2]) > 0.000001  || IKabs(evalcond[3]) > 0.000001  || IKabs(evalcond[4]) > 0.000001  || IKabs(evalcond[5]) > 0.000001  )
{
continue;
}
}

{
std::vector<IkSingleDOFSolutionBase<IkReal> > vinfos(7);
vinfos[0].jointtype = 1;
vinfos[0].foffset = j0;
vinfos[0].indices[0] = _ij0[0];
vinfos[0].indices[1] = _ij0[1];
vinfos[0].maxsolutions = _nj0;
vinfos[1].jointtype = 1;
vinfos[1].foffset = j1;
vinfos[1].indices[0] = _ij1[0];
vinfos[1].indices[1] = _ij1[1];
vinfos[1].maxsolutions = _nj1;
vinfos[2].jointtype = 1;
vinfos[2].foffset = j2;
vinfos[2].indices[0] = _ij2[0];
vinfos[2].indices[1] = _ij2[1];
vinfos[2].maxsolutions = _nj2;
vinfos[3].jointtype = 1;
vinfos[3].foffset = j3;
vinfos[3].indices[0] = _ij3[0];
vinfos[3].indices[1] = _ij3[1];
vinfos[3].maxsolutions = _nj3;
vinfos[4].jointtype = 1;
vinfos[4].foffset = j4;
vinfos[4].indices[0] = _ij4[0];
vinfos[4].indices[1] = _ij4[1];
vinfos[4].maxsolutions = _nj4;
vinfos[5].jointtype = 1;
vinfos[5].foffset = j5;
vinfos[5].indices[0] = _ij5[0];
vinfos[5].indices[1] = _ij5[1];
vinfos[5].maxsolutions = _nj5;
vinfos[6].jointtype = 1;
vinfos[6].foffset = j6;
vinfos[6].indices[0] = _ij6[0];
vinfos[6].indices[1] = _ij6[1];
vinfos[6].maxsolutions = _nj6;
std::vector<int> vfree(0);
solutions.AddSolution(vinfos,vfree);
}
}
}

}

}
}
}

}

}

} else
{
{
IkReal j4array[1], cj4array[1], sj4array[1];
bool j4valid[1]={false};
_nj4 = 1;
IkReal x3436=((IkReal(1.00000000000000))*(sj2));
if( IKabs(((gconst78)*(((((IkReal(-1.00000000000000))*(cj6)*(r20)*(x3436)))+(((r21)*(sj2)*(sj6))))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(((gconst78)*(((((IkReal(-1.00000000000000))*(r22)*(sj5)*(x3436)))+(((IkReal(-1.00000000000000))*(cj5)*(cj6)*(r21)*(x3436)))+(((IkReal(-1.00000000000000))*(cj5)*(r20)*(sj6)*(x3436))))))) < IKFAST_ATAN2_MAGTHRESH )
    continue;
j4array[0]=IKatan2(((gconst78)*(((((IkReal(-1.00000000000000))*(cj6)*(r20)*(x3436)))+(((r21)*(sj2)*(sj6)))))), ((gconst78)*(((((IkReal(-1.00000000000000))*(r22)*(sj5)*(x3436)))+(((IkReal(-1.00000000000000))*(cj5)*(cj6)*(r21)*(x3436)))+(((IkReal(-1.00000000000000))*(cj5)*(r20)*(sj6)*(x3436)))))));
sj4array[0]=IKsin(j4array[0]);
cj4array[0]=IKcos(j4array[0]);
if( j4array[0] > IKPI )
{
    j4array[0]-=IK2PI;
}
else if( j4array[0] < -IKPI )
{    j4array[0]+=IK2PI;
}
j4valid[0] = true;
for(int ij4 = 0; ij4 < 1; ++ij4)
{
if( !j4valid[ij4] )
{
    continue;
}
_ij4[0] = ij4; _ij4[1] = -1;
for(int iij4 = ij4+1; iij4 < 1; ++iij4)
{
if( j4valid[iij4] && IKabs(cj4array[ij4]-cj4array[iij4]) < IKFAST_SOLUTION_THRESH && IKabs(sj4array[ij4]-sj4array[iij4]) < IKFAST_SOLUTION_THRESH )
{
    j4valid[iij4]=false; _ij4[1] = iij4; break; 
}
}
j4 = j4array[ij4]; cj4 = cj4array[ij4]; sj4 = sj4array[ij4];
{
IkReal evalcond[3];
IkReal x3437=IKsin(j4);
IkReal x3438=IKcos(j4);
IkReal x3439=((r00)*(sj6));
IkReal x3440=((cj6)*(r01));
IkReal x3441=((IkReal(1.00000000000000))*(cj0));
IkReal x3442=((IkReal(1.00000000000000))*(sj0));
IkReal x3443=((r10)*(sj6));
IkReal x3444=((sj5)*(x3437));
IkReal x3445=((IkReal(1.00000000000000))*(cj6)*(r11));
IkReal x3446=((cj5)*(x3437));
IkReal x3447=((cj6)*(x3438));
IkReal x3448=((sj0)*(x3446));
IkReal x3449=((r01)*(sj6)*(x3438));
IkReal x3450=((r11)*(sj6)*(x3438));
evalcond[0]=((((r22)*(x3444)))+(((r21)*(sj6)*(x3438)))+(((r20)*(sj6)*(x3446)))+(((cj6)*(r21)*(x3446)))+(((IkReal(-1.00000000000000))*(r20)*(x3447))));
evalcond[1]=((((IkReal(-1.00000000000000))*(r12)*(x3441)*(x3444)))+(((r02)*(sj0)*(x3444)))+(((sj0)*(x3449)))+(((x3440)*(x3448)))+(((IkReal(-1.00000000000000))*(x3441)*(x3450)))+(cj2)+(((cj0)*(r10)*(x3447)))+(((x3439)*(x3448)))+(((IkReal(-1.00000000000000))*(r00)*(x3442)*(x3447)))+(((IkReal(-1.00000000000000))*(cj6)*(r11)*(x3441)*(x3446)))+(((IkReal(-1.00000000000000))*(x3441)*(x3443)*(x3446))));
evalcond[2]=((((IkReal(-1.00000000000000))*(x3440)*(x3441)*(x3446)))+(((IkReal(-1.00000000000000))*(x3442)*(x3443)*(x3446)))+(((IkReal(-1.00000000000000))*(x3439)*(x3441)*(x3446)))+(((IkReal(-1.00000000000000))*(sj2)))+(((IkReal(-1.00000000000000))*(r02)*(x3441)*(x3444)))+(((r10)*(sj0)*(x3447)))+(((cj0)*(r00)*(x3447)))+(((IkReal(-1.00000000000000))*(x3442)*(x3450)))+(((IkReal(-1.00000000000000))*(r12)*(x3442)*(x3444)))+(((IkReal(-1.00000000000000))*(cj6)*(r11)*(x3442)*(x3446)))+(((IkReal(-1.00000000000000))*(x3441)*(x3449))));
if( IKabs(evalcond[0]) > 0.000001  || IKabs(evalcond[1]) > 0.000001  || IKabs(evalcond[2]) > 0.000001  )
{
continue;
}
}

{
IkReal j3array[1], cj3array[1], sj3array[1];
bool j3valid[1]={false};
_nj3 = 1;
IkReal x3451=((IkReal(1.00000000000000))*(sj5));
IkReal x3452=((cj6)*(r21));
IkReal x3453=((r20)*(sj6));
IkReal x3454=((IkReal(1.00000000000000))*(cj4)*(cj5));
if( IKabs(((((IkReal(-1.00000000000000))*(x3452)*(x3454)))+(((IkReal(-1.00000000000000))*(x3453)*(x3454)))+(((r21)*(sj4)*(sj6)))+(((IkReal(-1.00000000000000))*(cj4)*(r22)*(x3451)))+(((IkReal(-1.00000000000000))*(cj6)*(r20)*(sj4))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(((((IkReal(-1.00000000000000))*(x3451)*(x3452)))+(((IkReal(-1.00000000000000))*(x3451)*(x3453)))+(((cj5)*(r22))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(IKsqr(((((IkReal(-1.00000000000000))*(x3452)*(x3454)))+(((IkReal(-1.00000000000000))*(x3453)*(x3454)))+(((r21)*(sj4)*(sj6)))+(((IkReal(-1.00000000000000))*(cj4)*(r22)*(x3451)))+(((IkReal(-1.00000000000000))*(cj6)*(r20)*(sj4)))))+IKsqr(((((IkReal(-1.00000000000000))*(x3451)*(x3452)))+(((IkReal(-1.00000000000000))*(x3451)*(x3453)))+(((cj5)*(r22)))))-1) <= IKFAST_SINCOS_THRESH )
    continue;
j3array[0]=IKatan2(((((IkReal(-1.00000000000000))*(x3452)*(x3454)))+(((IkReal(-1.00000000000000))*(x3453)*(x3454)))+(((r21)*(sj4)*(sj6)))+(((IkReal(-1.00000000000000))*(cj4)*(r22)*(x3451)))+(((IkReal(-1.00000000000000))*(cj6)*(r20)*(sj4)))), ((((IkReal(-1.00000000000000))*(x3451)*(x3452)))+(((IkReal(-1.00000000000000))*(x3451)*(x3453)))+(((cj5)*(r22)))));
sj3array[0]=IKsin(j3array[0]);
cj3array[0]=IKcos(j3array[0]);
if( j3array[0] > IKPI )
{
    j3array[0]-=IK2PI;
}
else if( j3array[0] < -IKPI )
{    j3array[0]+=IK2PI;
}
j3valid[0] = true;
for(int ij3 = 0; ij3 < 1; ++ij3)
{
if( !j3valid[ij3] )
{
    continue;
}
_ij3[0] = ij3; _ij3[1] = -1;
for(int iij3 = ij3+1; iij3 < 1; ++iij3)
{
if( j3valid[iij3] && IKabs(cj3array[ij3]-cj3array[iij3]) < IKFAST_SOLUTION_THRESH && IKabs(sj3array[ij3]-sj3array[iij3]) < IKFAST_SOLUTION_THRESH )
{
    j3valid[iij3]=false; _ij3[1] = iij3; break; 
}
}
j3 = j3array[ij3]; cj3 = cj3array[ij3]; sj3 = sj3array[ij3];
{
IkReal evalcond[6];
IkReal x3455=IKsin(j3);
IkReal x3456=IKcos(j3);
IkReal x3457=((sj0)*(sj5));
IkReal x3458=((r00)*(sj6));
IkReal x3459=((IkReal(1.00000000000000))*(cj4));
IkReal x3460=((cj6)*(r01));
IkReal x3461=((cj0)*(cj5));
IkReal x3462=((cj5)*(sj0));
IkReal x3463=((cj6)*(r11));
IkReal x3464=((cj0)*(sj5));
IkReal x3465=((cj6)*(sj4));
IkReal x3466=((cj4)*(cj5));
IkReal x3467=((cj6)*(r21));
IkReal x3468=((r20)*(sj6));
IkReal x3469=((r10)*(sj6));
IkReal x3470=((IkReal(1.00000000000000))*(cj0));
IkReal x3471=((IkReal(1.00000000000000))*(x3455));
IkReal x3472=((cj0)*(sj4)*(sj6));
IkReal x3473=((sj0)*(sj4)*(sj6));
evalcond[0]=((x3456)+(((IkReal(-1.00000000000000))*(cj5)*(r22)))+(((sj5)*(x3468)))+(((sj5)*(x3467))));
evalcond[1]=((((r20)*(x3465)))+(((IkReal(-1.00000000000000))*(r21)*(sj4)*(sj6)))+(x3455)+(((cj4)*(r22)*(sj5)))+(((x3466)*(x3468)))+(((x3466)*(x3467))));
evalcond[2]=((((IkReal(-1.00000000000000))*(sj2)*(x3471)))+(((IkReal(-1.00000000000000))*(r02)*(x3462)))+(((x3457)*(x3460)))+(((IkReal(-1.00000000000000))*(x3464)*(x3469)))+(((x3457)*(x3458)))+(((IkReal(-1.00000000000000))*(x3463)*(x3464)))+(((r12)*(x3461))));
evalcond[3]=((((IkReal(-1.00000000000000))*(x3457)*(x3463)))+(((IkReal(-1.00000000000000))*(cj2)*(x3471)))+(((r02)*(x3461)))+(((IkReal(-1.00000000000000))*(x3460)*(x3464)))+(((r12)*(x3462)))+(((IkReal(-1.00000000000000))*(x3457)*(x3469)))+(((IkReal(-1.00000000000000))*(x3458)*(x3464))));
evalcond[4]=((((r00)*(sj0)*(x3465)))+(((cj4)*(x3458)*(x3462)))+(((IkReal(-1.00000000000000))*(r12)*(x3459)*(x3464)))+(((cj4)*(r02)*(x3457)))+(((IkReal(-1.00000000000000))*(r01)*(x3473)))+(((IkReal(-1.00000000000000))*(x3459)*(x3461)*(x3469)))+(((sj2)*(x3456)))+(((cj4)*(x3460)*(x3462)))+(((IkReal(-1.00000000000000))*(r10)*(x3465)*(x3470)))+(((IkReal(-1.00000000000000))*(x3459)*(x3461)*(x3463)))+(((r11)*(x3472))));
evalcond[5]=((((IkReal(-1.00000000000000))*(x3458)*(x3459)*(x3461)))+(((IkReal(-1.00000000000000))*(r10)*(sj0)*(x3465)))+(((IkReal(-1.00000000000000))*(x3459)*(x3460)*(x3461)))+(((r01)*(x3472)))+(((cj2)*(x3456)))+(((IkReal(-1.00000000000000))*(r00)*(x3465)*(x3470)))+(((IkReal(-1.00000000000000))*(r02)*(x3459)*(x3464)))+(((r11)*(x3473)))+(((IkReal(-1.00000000000000))*(r12)*(x3457)*(x3459)))+(((IkReal(-1.00000000000000))*(x3459)*(x3462)*(x3469)))+(((IkReal(-1.00000000000000))*(x3459)*(x3462)*(x3463))));
if( IKabs(evalcond[0]) > 0.000001  || IKabs(evalcond[1]) > 0.000001  || IKabs(evalcond[2]) > 0.000001  || IKabs(evalcond[3]) > 0.000001  || IKabs(evalcond[4]) > 0.000001  || IKabs(evalcond[5]) > 0.000001  )
{
continue;
}
}

{
std::vector<IkSingleDOFSolutionBase<IkReal> > vinfos(7);
vinfos[0].jointtype = 1;
vinfos[0].foffset = j0;
vinfos[0].indices[0] = _ij0[0];
vinfos[0].indices[1] = _ij0[1];
vinfos[0].maxsolutions = _nj0;
vinfos[1].jointtype = 1;
vinfos[1].foffset = j1;
vinfos[1].indices[0] = _ij1[0];
vinfos[1].indices[1] = _ij1[1];
vinfos[1].maxsolutions = _nj1;
vinfos[2].jointtype = 1;
vinfos[2].foffset = j2;
vinfos[2].indices[0] = _ij2[0];
vinfos[2].indices[1] = _ij2[1];
vinfos[2].maxsolutions = _nj2;
vinfos[3].jointtype = 1;
vinfos[3].foffset = j3;
vinfos[3].indices[0] = _ij3[0];
vinfos[3].indices[1] = _ij3[1];
vinfos[3].maxsolutions = _nj3;
vinfos[4].jointtype = 1;
vinfos[4].foffset = j4;
vinfos[4].indices[0] = _ij4[0];
vinfos[4].indices[1] = _ij4[1];
vinfos[4].maxsolutions = _nj4;
vinfos[5].jointtype = 1;
vinfos[5].foffset = j5;
vinfos[5].indices[0] = _ij5[0];
vinfos[5].indices[1] = _ij5[1];
vinfos[5].maxsolutions = _nj5;
vinfos[6].jointtype = 1;
vinfos[6].foffset = j6;
vinfos[6].indices[0] = _ij6[0];
vinfos[6].indices[1] = _ij6[1];
vinfos[6].maxsolutions = _nj6;
std::vector<int> vfree(0);
solutions.AddSolution(vinfos,vfree);
}
}
}
}
}

}

}

} else
{
{
IkReal j4array[1], cj4array[1], sj4array[1];
bool j4valid[1]={false};
_nj4 = 1;
IkReal x3474=((cj2)*(sj6));
IkReal x3475=((IkReal(1.00000000000000))*(r20));
IkReal x3476=((cj2)*(cj6));
if( IKabs(((gconst77)*(((((r21)*(x3474)))+(((IkReal(-1.00000000000000))*(x3475)*(x3476))))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(((gconst77)*(((((IkReal(-1.00000000000000))*(cj5)*(r21)*(x3476)))+(((IkReal(-1.00000000000000))*(cj5)*(x3474)*(x3475)))+(((IkReal(-1.00000000000000))*(cj2)*(r22)*(sj5))))))) < IKFAST_ATAN2_MAGTHRESH )
    continue;
j4array[0]=IKatan2(((gconst77)*(((((r21)*(x3474)))+(((IkReal(-1.00000000000000))*(x3475)*(x3476)))))), ((gconst77)*(((((IkReal(-1.00000000000000))*(cj5)*(r21)*(x3476)))+(((IkReal(-1.00000000000000))*(cj5)*(x3474)*(x3475)))+(((IkReal(-1.00000000000000))*(cj2)*(r22)*(sj5)))))));
sj4array[0]=IKsin(j4array[0]);
cj4array[0]=IKcos(j4array[0]);
if( j4array[0] > IKPI )
{
    j4array[0]-=IK2PI;
}
else if( j4array[0] < -IKPI )
{    j4array[0]+=IK2PI;
}
j4valid[0] = true;
for(int ij4 = 0; ij4 < 1; ++ij4)
{
if( !j4valid[ij4] )
{
    continue;
}
_ij4[0] = ij4; _ij4[1] = -1;
for(int iij4 = ij4+1; iij4 < 1; ++iij4)
{
if( j4valid[iij4] && IKabs(cj4array[ij4]-cj4array[iij4]) < IKFAST_SOLUTION_THRESH && IKabs(sj4array[ij4]-sj4array[iij4]) < IKFAST_SOLUTION_THRESH )
{
    j4valid[iij4]=false; _ij4[1] = iij4; break; 
}
}
j4 = j4array[ij4]; cj4 = cj4array[ij4]; sj4 = sj4array[ij4];
{
IkReal evalcond[3];
IkReal x3477=IKsin(j4);
IkReal x3478=IKcos(j4);
IkReal x3479=((r00)*(sj6));
IkReal x3480=((cj6)*(r01));
IkReal x3481=((IkReal(1.00000000000000))*(cj0));
IkReal x3482=((IkReal(1.00000000000000))*(sj0));
IkReal x3483=((r10)*(sj6));
IkReal x3484=((sj5)*(x3477));
IkReal x3485=((IkReal(1.00000000000000))*(cj6)*(r11));
IkReal x3486=((cj5)*(x3477));
IkReal x3487=((cj6)*(x3478));
IkReal x3488=((sj0)*(x3486));
IkReal x3489=((r01)*(sj6)*(x3478));
IkReal x3490=((r11)*(sj6)*(x3478));
evalcond[0]=((((r20)*(sj6)*(x3486)))+(((cj6)*(r21)*(x3486)))+(((r21)*(sj6)*(x3478)))+(((IkReal(-1.00000000000000))*(r20)*(x3487)))+(((r22)*(x3484))));
evalcond[1]=((((sj0)*(x3489)))+(((IkReal(-1.00000000000000))*(r12)*(x3481)*(x3484)))+(((IkReal(-1.00000000000000))*(x3481)*(x3483)*(x3486)))+(((r02)*(sj0)*(x3484)))+(((cj0)*(r10)*(x3487)))+(((IkReal(-1.00000000000000))*(r00)*(x3482)*(x3487)))+(cj2)+(((IkReal(-1.00000000000000))*(cj6)*(r11)*(x3481)*(x3486)))+(((x3479)*(x3488)))+(((x3480)*(x3488)))+(((IkReal(-1.00000000000000))*(x3481)*(x3490))));
evalcond[2]=((((IkReal(-1.00000000000000))*(r02)*(x3481)*(x3484)))+(((IkReal(-1.00000000000000))*(x3482)*(x3483)*(x3486)))+(((IkReal(-1.00000000000000))*(sj2)))+(((IkReal(-1.00000000000000))*(x3479)*(x3481)*(x3486)))+(((IkReal(-1.00000000000000))*(x3482)*(x3490)))+(((cj0)*(r00)*(x3487)))+(((IkReal(-1.00000000000000))*(r12)*(x3482)*(x3484)))+(((r10)*(sj0)*(x3487)))+(((IkReal(-1.00000000000000))*(cj6)*(r11)*(x3482)*(x3486)))+(((IkReal(-1.00000000000000))*(x3480)*(x3481)*(x3486)))+(((IkReal(-1.00000000000000))*(x3481)*(x3489))));
if( IKabs(evalcond[0]) > 0.000001  || IKabs(evalcond[1]) > 0.000001  || IKabs(evalcond[2]) > 0.000001  )
{
continue;
}
}

{
IkReal j3array[1], cj3array[1], sj3array[1];
bool j3valid[1]={false};
_nj3 = 1;
IkReal x3491=((IkReal(1.00000000000000))*(sj5));
IkReal x3492=((cj6)*(r21));
IkReal x3493=((r20)*(sj6));
IkReal x3494=((IkReal(1.00000000000000))*(cj4)*(cj5));
if( IKabs(((((IkReal(-1.00000000000000))*(cj4)*(r22)*(x3491)))+(((IkReal(-1.00000000000000))*(x3493)*(x3494)))+(((r21)*(sj4)*(sj6)))+(((IkReal(-1.00000000000000))*(x3492)*(x3494)))+(((IkReal(-1.00000000000000))*(cj6)*(r20)*(sj4))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(((((IkReal(-1.00000000000000))*(x3491)*(x3492)))+(((IkReal(-1.00000000000000))*(x3491)*(x3493)))+(((cj5)*(r22))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(IKsqr(((((IkReal(-1.00000000000000))*(cj4)*(r22)*(x3491)))+(((IkReal(-1.00000000000000))*(x3493)*(x3494)))+(((r21)*(sj4)*(sj6)))+(((IkReal(-1.00000000000000))*(x3492)*(x3494)))+(((IkReal(-1.00000000000000))*(cj6)*(r20)*(sj4)))))+IKsqr(((((IkReal(-1.00000000000000))*(x3491)*(x3492)))+(((IkReal(-1.00000000000000))*(x3491)*(x3493)))+(((cj5)*(r22)))))-1) <= IKFAST_SINCOS_THRESH )
    continue;
j3array[0]=IKatan2(((((IkReal(-1.00000000000000))*(cj4)*(r22)*(x3491)))+(((IkReal(-1.00000000000000))*(x3493)*(x3494)))+(((r21)*(sj4)*(sj6)))+(((IkReal(-1.00000000000000))*(x3492)*(x3494)))+(((IkReal(-1.00000000000000))*(cj6)*(r20)*(sj4)))), ((((IkReal(-1.00000000000000))*(x3491)*(x3492)))+(((IkReal(-1.00000000000000))*(x3491)*(x3493)))+(((cj5)*(r22)))));
sj3array[0]=IKsin(j3array[0]);
cj3array[0]=IKcos(j3array[0]);
if( j3array[0] > IKPI )
{
    j3array[0]-=IK2PI;
}
else if( j3array[0] < -IKPI )
{    j3array[0]+=IK2PI;
}
j3valid[0] = true;
for(int ij3 = 0; ij3 < 1; ++ij3)
{
if( !j3valid[ij3] )
{
    continue;
}
_ij3[0] = ij3; _ij3[1] = -1;
for(int iij3 = ij3+1; iij3 < 1; ++iij3)
{
if( j3valid[iij3] && IKabs(cj3array[ij3]-cj3array[iij3]) < IKFAST_SOLUTION_THRESH && IKabs(sj3array[ij3]-sj3array[iij3]) < IKFAST_SOLUTION_THRESH )
{
    j3valid[iij3]=false; _ij3[1] = iij3; break; 
}
}
j3 = j3array[ij3]; cj3 = cj3array[ij3]; sj3 = sj3array[ij3];
{
IkReal evalcond[6];
IkReal x3495=IKsin(j3);
IkReal x3496=IKcos(j3);
IkReal x3497=((sj0)*(sj5));
IkReal x3498=((r00)*(sj6));
IkReal x3499=((IkReal(1.00000000000000))*(cj4));
IkReal x3500=((cj6)*(r01));
IkReal x3501=((cj0)*(cj5));
IkReal x3502=((cj5)*(sj0));
IkReal x3503=((cj6)*(r11));
IkReal x3504=((cj0)*(sj5));
IkReal x3505=((cj6)*(sj4));
IkReal x3506=((cj4)*(cj5));
IkReal x3507=((cj6)*(r21));
IkReal x3508=((r20)*(sj6));
IkReal x3509=((r10)*(sj6));
IkReal x3510=((IkReal(1.00000000000000))*(cj0));
IkReal x3511=((IkReal(1.00000000000000))*(x3495));
IkReal x3512=((cj0)*(sj4)*(sj6));
IkReal x3513=((sj0)*(sj4)*(sj6));
evalcond[0]=((x3496)+(((sj5)*(x3508)))+(((IkReal(-1.00000000000000))*(cj5)*(r22)))+(((sj5)*(x3507))));
evalcond[1]=((((IkReal(-1.00000000000000))*(r21)*(sj4)*(sj6)))+(((x3506)*(x3507)))+(x3495)+(((cj4)*(r22)*(sj5)))+(((x3506)*(x3508)))+(((r20)*(x3505))));
evalcond[2]=((((IkReal(-1.00000000000000))*(x3503)*(x3504)))+(((IkReal(-1.00000000000000))*(x3504)*(x3509)))+(((IkReal(-1.00000000000000))*(r02)*(x3502)))+(((r12)*(x3501)))+(((x3497)*(x3500)))+(((x3497)*(x3498)))+(((IkReal(-1.00000000000000))*(sj2)*(x3511))));
evalcond[3]=((((r02)*(x3501)))+(((IkReal(-1.00000000000000))*(x3497)*(x3509)))+(((IkReal(-1.00000000000000))*(x3498)*(x3504)))+(((IkReal(-1.00000000000000))*(x3500)*(x3504)))+(((IkReal(-1.00000000000000))*(x3497)*(x3503)))+(((IkReal(-1.00000000000000))*(cj2)*(x3511)))+(((r12)*(x3502))));
evalcond[4]=((((cj4)*(r02)*(x3497)))+(((IkReal(-1.00000000000000))*(r10)*(x3505)*(x3510)))+(((IkReal(-1.00000000000000))*(x3499)*(x3501)*(x3509)))+(((r00)*(sj0)*(x3505)))+(((IkReal(-1.00000000000000))*(x3499)*(x3501)*(x3503)))+(((IkReal(-1.00000000000000))*(r01)*(x3513)))+(((r11)*(x3512)))+(((cj4)*(x3500)*(x3502)))+(((sj2)*(x3496)))+(((cj4)*(x3498)*(x3502)))+(((IkReal(-1.00000000000000))*(r12)*(x3499)*(x3504))));
evalcond[5]=((((IkReal(-1.00000000000000))*(x3499)*(x3502)*(x3509)))+(((IkReal(-1.00000000000000))*(r10)*(sj0)*(x3505)))+(((IkReal(-1.00000000000000))*(x3499)*(x3502)*(x3503)))+(((IkReal(-1.00000000000000))*(r02)*(x3499)*(x3504)))+(((IkReal(-1.00000000000000))*(x3498)*(x3499)*(x3501)))+(((r01)*(x3512)))+(((cj2)*(x3496)))+(((IkReal(-1.00000000000000))*(r12)*(x3497)*(x3499)))+(((r11)*(x3513)))+(((IkReal(-1.00000000000000))*(x3499)*(x3500)*(x3501)))+(((IkReal(-1.00000000000000))*(r00)*(x3505)*(x3510))));
if( IKabs(evalcond[0]) > 0.000001  || IKabs(evalcond[1]) > 0.000001  || IKabs(evalcond[2]) > 0.000001  || IKabs(evalcond[3]) > 0.000001  || IKabs(evalcond[4]) > 0.000001  || IKabs(evalcond[5]) > 0.000001  )
{
continue;
}
}

{
std::vector<IkSingleDOFSolutionBase<IkReal> > vinfos(7);
vinfos[0].jointtype = 1;
vinfos[0].foffset = j0;
vinfos[0].indices[0] = _ij0[0];
vinfos[0].indices[1] = _ij0[1];
vinfos[0].maxsolutions = _nj0;
vinfos[1].jointtype = 1;
vinfos[1].foffset = j1;
vinfos[1].indices[0] = _ij1[0];
vinfos[1].indices[1] = _ij1[1];
vinfos[1].maxsolutions = _nj1;
vinfos[2].jointtype = 1;
vinfos[2].foffset = j2;
vinfos[2].indices[0] = _ij2[0];
vinfos[2].indices[1] = _ij2[1];
vinfos[2].maxsolutions = _nj2;
vinfos[3].jointtype = 1;
vinfos[3].foffset = j3;
vinfos[3].indices[0] = _ij3[0];
vinfos[3].indices[1] = _ij3[1];
vinfos[3].maxsolutions = _nj3;
vinfos[4].jointtype = 1;
vinfos[4].foffset = j4;
vinfos[4].indices[0] = _ij4[0];
vinfos[4].indices[1] = _ij4[1];
vinfos[4].maxsolutions = _nj4;
vinfos[5].jointtype = 1;
vinfos[5].foffset = j5;
vinfos[5].indices[0] = _ij5[0];
vinfos[5].indices[1] = _ij5[1];
vinfos[5].maxsolutions = _nj5;
vinfos[6].jointtype = 1;
vinfos[6].foffset = j6;
vinfos[6].indices[0] = _ij6[0];
vinfos[6].indices[1] = _ij6[1];
vinfos[6].maxsolutions = _nj6;
std::vector<int> vfree(0);
solutions.AddSolution(vinfos,vfree);
}
}
}
}
}

}

}
}
}

} else
{
if( 1 )
{
continue;

} else
{
}
}
}
}
}
}

} else
{
{
IkReal j2array[1], cj2array[1], sj2array[1];
bool j2valid[1]={false};
_nj2 = 1;
IkReal x3514=((cj6)*(r01));
IkReal x3515=((cj0)*(cj5));
IkReal x3516=((sj0)*(sj5));
IkReal x3517=((cj0)*(sj5));
IkReal x3518=((cj6)*(r11));
IkReal x3519=((r10)*(sj6));
IkReal x3520=((cj5)*(sj0));
IkReal x3521=((r00)*(sj6));
if( IKabs(((((IkReal(-5.42449275362319))*(x3516)*(x3521)))+(((IkReal(14.4927536231884))*(cj0)*(py)))+(((IkReal(-14.4927536231884))*(px)*(sj0)))+(((IkReal(5.42449275362319))*(x3517)*(x3518)))+(((IkReal(-0.144927536231884))*(x3515)*(x3519)))+(((IkReal(5.42449275362319))*(x3517)*(x3519)))+(((IkReal(-0.144927536231884))*(r12)*(x3517)))+(((IkReal(0.144927536231884))*(x3514)*(x3520)))+(((IkReal(0.144927536231884))*(x3520)*(x3521)))+(((IkReal(-5.42449275362319))*(r12)*(x3515)))+(((IkReal(-0.144927536231884))*(x3515)*(x3518)))+(((IkReal(-5.42449275362319))*(x3514)*(x3516)))+(((IkReal(5.42449275362319))*(r02)*(x3520)))+(((IkReal(0.144927536231884))*(r02)*(x3516))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(((IkReal(0.0144927536231884))*(((IKabs(sj1) != 0)?((IkReal)1/(sj1)):(IkReal)1.0e30))*(((IkReal(69.0000000000000))+(((IkReal(-374.290000000000))*(x3514)*(x3517)))+(((IkReal(10.0000000000000))*(x3515)*(x3521)))+(((IkReal(10.0000000000000))*(r02)*(x3517)))+(((IkReal(10.0000000000000))*(x3519)*(x3520)))+(((IkReal(-374.290000000000))*(x3517)*(x3521)))+(((IkReal(-1000.00000000000))*(cj0)*(px)))+(((IkReal(10.0000000000000))*(x3518)*(x3520)))+(((IkReal(364.420000000000))*(cj1)))+(((IkReal(10.0000000000000))*(x3514)*(x3515)))+(((IkReal(-374.290000000000))*(x3516)*(x3519)))+(((IkReal(-374.290000000000))*(x3516)*(x3518)))+(((IkReal(374.290000000000))*(r12)*(x3520)))+(((IkReal(374.290000000000))*(r02)*(x3515)))+(((IkReal(-1000.00000000000))*(py)*(sj0)))+(((IkReal(10.0000000000000))*(r12)*(x3516))))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(IKsqr(((((IkReal(-5.42449275362319))*(x3516)*(x3521)))+(((IkReal(14.4927536231884))*(cj0)*(py)))+(((IkReal(-14.4927536231884))*(px)*(sj0)))+(((IkReal(5.42449275362319))*(x3517)*(x3518)))+(((IkReal(-0.144927536231884))*(x3515)*(x3519)))+(((IkReal(5.42449275362319))*(x3517)*(x3519)))+(((IkReal(-0.144927536231884))*(r12)*(x3517)))+(((IkReal(0.144927536231884))*(x3514)*(x3520)))+(((IkReal(0.144927536231884))*(x3520)*(x3521)))+(((IkReal(-5.42449275362319))*(r12)*(x3515)))+(((IkReal(-0.144927536231884))*(x3515)*(x3518)))+(((IkReal(-5.42449275362319))*(x3514)*(x3516)))+(((IkReal(5.42449275362319))*(r02)*(x3520)))+(((IkReal(0.144927536231884))*(r02)*(x3516)))))+IKsqr(((IkReal(0.0144927536231884))*(((IKabs(sj1) != 0)?((IkReal)1/(sj1)):(IkReal)1.0e30))*(((IkReal(69.0000000000000))+(((IkReal(-374.290000000000))*(x3514)*(x3517)))+(((IkReal(10.0000000000000))*(x3515)*(x3521)))+(((IkReal(10.0000000000000))*(r02)*(x3517)))+(((IkReal(10.0000000000000))*(x3519)*(x3520)))+(((IkReal(-374.290000000000))*(x3517)*(x3521)))+(((IkReal(-1000.00000000000))*(cj0)*(px)))+(((IkReal(10.0000000000000))*(x3518)*(x3520)))+(((IkReal(364.420000000000))*(cj1)))+(((IkReal(10.0000000000000))*(x3514)*(x3515)))+(((IkReal(-374.290000000000))*(x3516)*(x3519)))+(((IkReal(-374.290000000000))*(x3516)*(x3518)))+(((IkReal(374.290000000000))*(r12)*(x3520)))+(((IkReal(374.290000000000))*(r02)*(x3515)))+(((IkReal(-1000.00000000000))*(py)*(sj0)))+(((IkReal(10.0000000000000))*(r12)*(x3516)))))))-1) <= IKFAST_SINCOS_THRESH )
    continue;
j2array[0]=IKatan2(((((IkReal(-5.42449275362319))*(x3516)*(x3521)))+(((IkReal(14.4927536231884))*(cj0)*(py)))+(((IkReal(-14.4927536231884))*(px)*(sj0)))+(((IkReal(5.42449275362319))*(x3517)*(x3518)))+(((IkReal(-0.144927536231884))*(x3515)*(x3519)))+(((IkReal(5.42449275362319))*(x3517)*(x3519)))+(((IkReal(-0.144927536231884))*(r12)*(x3517)))+(((IkReal(0.144927536231884))*(x3514)*(x3520)))+(((IkReal(0.144927536231884))*(x3520)*(x3521)))+(((IkReal(-5.42449275362319))*(r12)*(x3515)))+(((IkReal(-0.144927536231884))*(x3515)*(x3518)))+(((IkReal(-5.42449275362319))*(x3514)*(x3516)))+(((IkReal(5.42449275362319))*(r02)*(x3520)))+(((IkReal(0.144927536231884))*(r02)*(x3516)))), ((IkReal(0.0144927536231884))*(((IKabs(sj1) != 0)?((IkReal)1/(sj1)):(IkReal)1.0e30))*(((IkReal(69.0000000000000))+(((IkReal(-374.290000000000))*(x3514)*(x3517)))+(((IkReal(10.0000000000000))*(x3515)*(x3521)))+(((IkReal(10.0000000000000))*(r02)*(x3517)))+(((IkReal(10.0000000000000))*(x3519)*(x3520)))+(((IkReal(-374.290000000000))*(x3517)*(x3521)))+(((IkReal(-1000.00000000000))*(cj0)*(px)))+(((IkReal(10.0000000000000))*(x3518)*(x3520)))+(((IkReal(364.420000000000))*(cj1)))+(((IkReal(10.0000000000000))*(x3514)*(x3515)))+(((IkReal(-374.290000000000))*(x3516)*(x3519)))+(((IkReal(-374.290000000000))*(x3516)*(x3518)))+(((IkReal(374.290000000000))*(r12)*(x3520)))+(((IkReal(374.290000000000))*(r02)*(x3515)))+(((IkReal(-1000.00000000000))*(py)*(sj0)))+(((IkReal(10.0000000000000))*(r12)*(x3516)))))));
sj2array[0]=IKsin(j2array[0]);
cj2array[0]=IKcos(j2array[0]);
if( j2array[0] > IKPI )
{
    j2array[0]-=IK2PI;
}
else if( j2array[0] < -IKPI )
{    j2array[0]+=IK2PI;
}
j2valid[0] = true;
for(int ij2 = 0; ij2 < 1; ++ij2)
{
if( !j2valid[ij2] )
{
    continue;
}
_ij2[0] = ij2; _ij2[1] = -1;
for(int iij2 = ij2+1; iij2 < 1; ++iij2)
{
if( j2valid[iij2] && IKabs(cj2array[ij2]-cj2array[iij2]) < IKFAST_SOLUTION_THRESH && IKabs(sj2array[ij2]-sj2array[iij2]) < IKFAST_SOLUTION_THRESH )
{
    j2valid[iij2]=false; _ij2[1] = iij2; break; 
}
}
j2 = j2array[ij2]; cj2 = cj2array[ij2]; sj2 = sj2array[ij2];
{
IkReal evalcond[3];
IkReal x3522=IKcos(j2);
IkReal x3523=((IkReal(0.374290000000000))*(sj5));
IkReal x3524=((cj0)*(sj6));
IkReal x3525=((IkReal(0.0100000000000000))*(sj5));
IkReal x3526=((cj0)*(r02));
IkReal x3527=((IkReal(0.0100000000000000))*(cj5));
IkReal x3528=((IkReal(1.00000000000000))*(py));
IkReal x3529=((r01)*(sj0));
IkReal x3530=((r20)*(sj6));
IkReal x3531=((r11)*(sj0));
IkReal x3532=((IkReal(0.374290000000000))*(cj5));
IkReal x3533=((cj0)*(r12));
IkReal x3534=((sj0)*(x3532));
IkReal x3535=((cj6)*(x3527));
IkReal x3536=((IkReal(0.0690000000000000))*(x3522));
IkReal x3537=((r10)*(sj0)*(sj6));
IkReal x3538=((r00)*(sj0)*(sj6));
IkReal x3539=((cj0)*(cj6)*(x3523));
evalcond[0]=((((x3523)*(x3530)))+(((IkReal(0.364420000000000))*(sj1)))+(((cj1)*(x3536)))+(((IkReal(-1.00000000000000))*(r21)*(x3535)))+(((IkReal(-1.00000000000000))*(x3527)*(x3530)))+(((IkReal(-1.00000000000000))*(r22)*(x3532)))+(((cj6)*(r21)*(x3523)))+(pz)+(((IkReal(-1.00000000000000))*(r22)*(x3525))));
evalcond[1]=((((IkReal(-1.00000000000000))*(x3529)*(x3535)))+(((x3532)*(x3533)))+(((x3525)*(x3533)))+(((r10)*(x3524)*(x3527)))+(((IkReal(-1.00000000000000))*(r11)*(x3539)))+(((IkReal(-1.00000000000000))*(r02)*(sj0)*(x3525)))+(((cj6)*(x3523)*(x3529)))+(((x3523)*(x3538)))+(((IkReal(-1.00000000000000))*(x3527)*(x3538)))+(((IkReal(0.0690000000000000))*(IKsin(j2))))+(((IkReal(-1.00000000000000))*(r10)*(x3523)*(x3524)))+(((IkReal(-1.00000000000000))*(r02)*(x3534)))+(((IkReal(-1.00000000000000))*(cj0)*(x3528)))+(((px)*(sj0)))+(((cj0)*(r11)*(x3535))));
evalcond[2]=((IkReal(0.0690000000000000))+(((x3526)*(x3532)))+(((IkReal(-1.00000000000000))*(cj0)*(px)))+(((IkReal(-1.00000000000000))*(r01)*(x3539)))+(((x3527)*(x3537)))+(((r12)*(sj0)*(x3525)))+(((IkReal(-1.00000000000000))*(cj6)*(x3523)*(x3531)))+(((r00)*(x3524)*(x3527)))+(((IkReal(-1.00000000000000))*(x3523)*(x3537)))+(((IkReal(-1.00000000000000))*(sj0)*(x3528)))+(((x3525)*(x3526)))+(((cj0)*(r01)*(x3535)))+(((IkReal(0.364420000000000))*(cj1)))+(((IkReal(-1.00000000000000))*(r00)*(x3523)*(x3524)))+(((r12)*(x3534)))+(((IkReal(-1.00000000000000))*(sj1)*(x3536)))+(((x3531)*(x3535))));
if( IKabs(evalcond[0]) > 0.000001  || IKabs(evalcond[1]) > 0.000001  || IKabs(evalcond[2]) > 0.000001  )
{
continue;
}
}

{
IkReal dummyeval[1];
IkReal gconst0;
IkReal x3540=(cj6)*(cj6);
IkReal x3541=(sj6)*(sj6);
IkReal x3542=((IkReal(1.00000000000000))*(r01));
IkReal x3543=((sj0)*(sj5));
IkReal x3544=((cj6)*(r22));
IkReal x3545=((r21)*(sj6));
IkReal x3546=((r00)*(r21));
IkReal x3547=((cj0)*(sj5));
IkReal x3548=((cj6)*(r20));
IkReal x3549=((r22)*(sj6));
IkReal x3550=((cj0)*(cj5));
IkReal x3551=((IkReal(1.00000000000000))*(r10));
IkReal x3552=((cj5)*(sj0));
IkReal x3553=((r20)*(x3541));
IkReal x3554=((x3540)*(x3552));
gconst0=IKsign(((((r00)*(x3543)*(x3544)))+(((x3546)*(x3554)))+(((IkReal(-1.00000000000000))*(x3544)*(x3547)*(x3551)))+(((IkReal(-1.00000000000000))*(r21)*(x3541)*(x3550)*(x3551)))+(((IkReal(-1.00000000000000))*(r12)*(x3545)*(x3547)))+(((IkReal(-1.00000000000000))*(r20)*(x3542)*(x3554)))+(((r11)*(x3547)*(x3549)))+(((r12)*(x3547)*(x3548)))+(((r11)*(x3550)*(x3553)))+(((r11)*(r20)*(x3540)*(x3550)))+(((IkReal(-1.00000000000000))*(x3542)*(x3552)*(x3553)))+(((IkReal(-1.00000000000000))*(r21)*(x3540)*(x3550)*(x3551)))+(((IkReal(-1.00000000000000))*(x3542)*(x3543)*(x3549)))+(((IkReal(-1.00000000000000))*(r02)*(x3543)*(x3548)))+(((r02)*(x3543)*(x3545)))+(((x3541)*(x3546)*(x3552)))));
IkReal x3555=(cj6)*(cj6);
IkReal x3556=(sj6)*(sj6);
IkReal x3557=((IkReal(1.00000000000000))*(r01));
IkReal x3558=((sj0)*(sj5));
IkReal x3559=((cj6)*(r22));
IkReal x3560=((r21)*(sj6));
IkReal x3561=((r00)*(r21));
IkReal x3562=((cj0)*(sj5));
IkReal x3563=((cj6)*(r20));
IkReal x3564=((r22)*(sj6));
IkReal x3565=((cj0)*(cj5));
IkReal x3566=((IkReal(1.00000000000000))*(r10));
IkReal x3567=((cj5)*(sj0));
IkReal x3568=((r20)*(x3556));
IkReal x3569=((x3555)*(x3567));
dummyeval[0]=((((r11)*(x3562)*(x3564)))+(((IkReal(-1.00000000000000))*(x3557)*(x3558)*(x3564)))+(((IkReal(-1.00000000000000))*(r02)*(x3558)*(x3563)))+(((IkReal(-1.00000000000000))*(r21)*(x3555)*(x3565)*(x3566)))+(((r11)*(r20)*(x3555)*(x3565)))+(((r00)*(x3558)*(x3559)))+(((IkReal(-1.00000000000000))*(r21)*(x3556)*(x3565)*(x3566)))+(((r11)*(x3565)*(x3568)))+(((x3561)*(x3569)))+(((IkReal(-1.00000000000000))*(x3559)*(x3562)*(x3566)))+(((r02)*(x3558)*(x3560)))+(((IkReal(-1.00000000000000))*(r12)*(x3560)*(x3562)))+(((IkReal(-1.00000000000000))*(r20)*(x3557)*(x3569)))+(((r12)*(x3562)*(x3563)))+(((x3556)*(x3561)*(x3567)))+(((IkReal(-1.00000000000000))*(x3557)*(x3567)*(x3568))));
if( IKabs(dummyeval[0]) < 0.0000010000000000  )
{
{
IkReal dummyeval[1];
IkReal gconst1;
IkReal x3570=(cj6)*(cj6);
IkReal x3571=(sj6)*(sj6);
IkReal x3572=((sj5)*(sj6));
IkReal x3573=((IkReal(1.00000000000000))*(cj0));
IkReal x3574=((cj6)*(sj5));
IkReal x3575=((r20)*(sj0));
IkReal x3576=((cj0)*(r20));
IkReal x3577=((r00)*(r21));
IkReal x3578=((r22)*(sj0));
IkReal x3579=((IkReal(1.00000000000000))*(r21)*(sj0));
IkReal x3580=((cj5)*(x3571));
IkReal x3581=((cj5)*(x3570));
gconst1=IKsign(((((IkReal(-1.00000000000000))*(x3573)*(x3577)*(x3580)))+(((IkReal(-1.00000000000000))*(r10)*(x3579)*(x3580)))+(((r02)*(x3574)*(x3576)))+(((r12)*(x3574)*(x3575)))+(((r11)*(x3575)*(x3580)))+(((IkReal(-1.00000000000000))*(r10)*(x3579)*(x3581)))+(((IkReal(-1.00000000000000))*(r02)*(r21)*(x3572)*(x3573)))+(((IkReal(-1.00000000000000))*(r10)*(x3574)*(x3578)))+(((r11)*(x3575)*(x3581)))+(((r01)*(x3576)*(x3580)))+(((IkReal(-1.00000000000000))*(r00)*(r22)*(x3573)*(x3574)))+(((r11)*(x3572)*(x3578)))+(((r01)*(x3576)*(x3581)))+(((cj0)*(r01)*(r22)*(x3572)))+(((IkReal(-1.00000000000000))*(r12)*(x3572)*(x3579)))+(((IkReal(-1.00000000000000))*(x3573)*(x3577)*(x3581)))));
IkReal x3582=(cj6)*(cj6);
IkReal x3583=(sj6)*(sj6);
IkReal x3584=((sj5)*(sj6));
IkReal x3585=((IkReal(1.00000000000000))*(cj0));
IkReal x3586=((cj6)*(sj5));
IkReal x3587=((r20)*(sj0));
IkReal x3588=((cj0)*(r20));
IkReal x3589=((r00)*(r21));
IkReal x3590=((r22)*(sj0));
IkReal x3591=((IkReal(1.00000000000000))*(r21)*(sj0));
IkReal x3592=((cj5)*(x3583));
IkReal x3593=((cj5)*(x3582));
dummyeval[0]=((((r02)*(x3586)*(x3588)))+(((r11)*(x3584)*(x3590)))+(((r11)*(x3587)*(x3592)))+(((IkReal(-1.00000000000000))*(r10)*(x3591)*(x3593)))+(((IkReal(-1.00000000000000))*(r10)*(x3586)*(x3590)))+(((r01)*(x3588)*(x3593)))+(((IkReal(-1.00000000000000))*(r10)*(x3591)*(x3592)))+(((cj0)*(r01)*(r22)*(x3584)))+(((IkReal(-1.00000000000000))*(r02)*(r21)*(x3584)*(x3585)))+(((IkReal(-1.00000000000000))*(x3585)*(x3589)*(x3592)))+(((IkReal(-1.00000000000000))*(r12)*(x3584)*(x3591)))+(((r01)*(x3588)*(x3592)))+(((IkReal(-1.00000000000000))*(r00)*(r22)*(x3585)*(x3586)))+(((r11)*(x3587)*(x3593)))+(((r12)*(x3586)*(x3587)))+(((IkReal(-1.00000000000000))*(x3585)*(x3589)*(x3593))));
if( IKabs(dummyeval[0]) < 0.0000010000000000  )
{
{
IkReal dummyeval[2];
IkReal x3594=(cj1)*(cj1);
IkReal x3595=(sj1)*(sj1);
dummyeval[0]=((((cj2)*(x3594)))+(((cj2)*(x3595))));
dummyeval[1]=((x3595)+(x3594));
if( IKabs(dummyeval[0]) < 0.0000010000000000  || IKabs(dummyeval[1]) < 0.0000010000000000  )
{
{
IkReal evalcond[4];
IkReal x3596=((IkReal(0.374290000000000))*(sj5));
IkReal x3597=((cj0)*(sj6));
IkReal x3598=((IkReal(0.0100000000000000))*(sj5));
IkReal x3599=((cj0)*(r02));
IkReal x3600=((IkReal(0.0100000000000000))*(cj5));
IkReal x3601=((IkReal(1.00000000000000))*(py));
IkReal x3602=((r01)*(sj0));
IkReal x3603=((r20)*(sj6));
IkReal x3604=((r11)*(sj0));
IkReal x3605=((IkReal(0.374290000000000))*(cj5));
IkReal x3606=((cj0)*(r12));
IkReal x3607=((sj0)*(x3605));
IkReal x3608=((cj6)*(x3600));
IkReal x3609=((r10)*(sj0)*(sj6));
IkReal x3610=((r00)*(sj0)*(sj6));
IkReal x3611=((cj0)*(cj6)*(x3596));
evalcond[0]=((IkReal(-3.14159265358979))+(IKfmod(((IkReal(1.57079632679490))+(j2)), IkReal(6.28318530717959))));
evalcond[1]=((((IkReal(0.364420000000000))*(sj1)))+(((IkReal(-1.00000000000000))*(r22)*(x3598)))+(((IkReal(-1.00000000000000))*(r21)*(x3608)))+(((cj6)*(r21)*(x3596)))+(((x3596)*(x3603)))+(pz)+(((IkReal(-1.00000000000000))*(r22)*(x3605)))+(((IkReal(-1.00000000000000))*(x3600)*(x3603))));
evalcond[2]=((IkReal(0.0690000000000000))+(((r10)*(x3597)*(x3600)))+(((IkReal(-1.00000000000000))*(x3600)*(x3610)))+(((IkReal(-1.00000000000000))*(cj0)*(x3601)))+(((x3596)*(x3610)))+(((cj0)*(r11)*(x3608)))+(((IkReal(-1.00000000000000))*(r02)*(sj0)*(x3598)))+(((IkReal(-1.00000000000000))*(x3602)*(x3608)))+(((x3598)*(x3606)))+(((IkReal(-1.00000000000000))*(r11)*(x3611)))+(((x3605)*(x3606)))+(((px)*(sj0)))+(((IkReal(-1.00000000000000))*(r02)*(x3607)))+(((cj6)*(x3596)*(x3602)))+(((IkReal(-1.00000000000000))*(r10)*(x3596)*(x3597))));
evalcond[3]=((IkReal(0.0690000000000000))+(((x3599)*(x3605)))+(((IkReal(-1.00000000000000))*(cj0)*(px)))+(((r12)*(sj0)*(x3598)))+(((IkReal(-1.00000000000000))*(sj0)*(x3601)))+(((x3600)*(x3609)))+(((IkReal(-1.00000000000000))*(r01)*(x3611)))+(((IkReal(-1.00000000000000))*(x3596)*(x3609)))+(((x3604)*(x3608)))+(((cj0)*(r01)*(x3608)))+(((IkReal(-1.00000000000000))*(cj6)*(x3596)*(x3604)))+(((r00)*(x3597)*(x3600)))+(((IkReal(0.364420000000000))*(cj1)))+(((r12)*(x3607)))+(((IkReal(-1.00000000000000))*(r00)*(x3596)*(x3597)))+(((x3598)*(x3599))));
if( IKabs(evalcond[0]) < 0.0000010000000000  && IKabs(evalcond[1]) < 0.0000010000000000  && IKabs(evalcond[2]) < 0.0000010000000000  && IKabs(evalcond[3]) < 0.0000010000000000  )
{
{
IkReal dummyeval[1];
IkReal gconst13;
IkReal x3612=(cj6)*(cj6);
IkReal x3613=(sj6)*(sj6);
IkReal x3614=((IkReal(1.00000000000000))*(r21));
IkReal x3615=((cj6)*(r20));
IkReal x3616=((r22)*(sj5));
IkReal x3617=((r01)*(sj0));
IkReal x3618=((r00)*(sj0));
IkReal x3619=((cj0)*(r10));
IkReal x3620=((r02)*(sj0)*(sj5));
IkReal x3621=((cj5)*(x3612));
IkReal x3622=((cj0)*(r12)*(sj5));
IkReal x3623=((IkReal(1.00000000000000))*(cj0)*(r11));
IkReal x3624=((cj5)*(x3613));
IkReal x3625=((r20)*(x3624));
gconst13=IKsign(((((r20)*(x3617)*(x3621)))+(((IkReal(-1.00000000000000))*(x3614)*(x3618)*(x3621)))+(((sj6)*(x3616)*(x3617)))+(((x3615)*(x3620)))+(((x3617)*(x3625)))+(((IkReal(-1.00000000000000))*(x3623)*(x3625)))+(((r21)*(sj6)*(x3622)))+(((r21)*(x3619)*(x3624)))+(((r21)*(x3619)*(x3621)))+(((IkReal(-1.00000000000000))*(x3614)*(x3618)*(x3624)))+(((IkReal(-1.00000000000000))*(sj6)*(x3614)*(x3620)))+(((cj6)*(x3616)*(x3619)))+(((IkReal(-1.00000000000000))*(sj6)*(x3616)*(x3623)))+(((IkReal(-1.00000000000000))*(cj6)*(x3616)*(x3618)))+(((IkReal(-1.00000000000000))*(r20)*(x3621)*(x3623)))+(((IkReal(-1.00000000000000))*(x3615)*(x3622)))));
IkReal x3626=(cj6)*(cj6);
IkReal x3627=(sj6)*(sj6);
IkReal x3628=((IkReal(1.00000000000000))*(r21));
IkReal x3629=((cj6)*(r20));
IkReal x3630=((r22)*(sj5));
IkReal x3631=((r01)*(sj0));
IkReal x3632=((r00)*(sj0));
IkReal x3633=((cj0)*(r10));
IkReal x3634=((r02)*(sj0)*(sj5));
IkReal x3635=((cj5)*(x3626));
IkReal x3636=((cj0)*(r12)*(sj5));
IkReal x3637=((IkReal(1.00000000000000))*(cj0)*(r11));
IkReal x3638=((cj5)*(x3627));
IkReal x3639=((r20)*(x3638));
dummyeval[0]=((((IkReal(-1.00000000000000))*(x3637)*(x3639)))+(((r21)*(sj6)*(x3636)))+(((IkReal(-1.00000000000000))*(sj6)*(x3630)*(x3637)))+(((sj6)*(x3630)*(x3631)))+(((IkReal(-1.00000000000000))*(x3628)*(x3632)*(x3635)))+(((cj6)*(x3630)*(x3633)))+(((IkReal(-1.00000000000000))*(x3629)*(x3636)))+(((IkReal(-1.00000000000000))*(sj6)*(x3628)*(x3634)))+(((x3631)*(x3639)))+(((r20)*(x3631)*(x3635)))+(((IkReal(-1.00000000000000))*(x3628)*(x3632)*(x3638)))+(((IkReal(-1.00000000000000))*(r20)*(x3635)*(x3637)))+(((r21)*(x3633)*(x3635)))+(((x3629)*(x3634)))+(((IkReal(-1.00000000000000))*(cj6)*(x3630)*(x3632)))+(((r21)*(x3633)*(x3638))));
if( IKabs(dummyeval[0]) < 0.0000010000000000  )
{
{
IkReal dummyeval[1];
IkReal gconst14;
IkReal x3640=(cj6)*(cj6);
IkReal x3641=(sj6)*(sj6);
IkReal x3642=((sj5)*(sj6));
IkReal x3643=((IkReal(1.00000000000000))*(cj0));
IkReal x3644=((cj6)*(sj5));
IkReal x3645=((r20)*(sj0));
IkReal x3646=((cj0)*(r20));
IkReal x3647=((r00)*(r21));
IkReal x3648=((r22)*(sj0));
IkReal x3649=((IkReal(1.00000000000000))*(r21)*(sj0));
IkReal x3650=((cj5)*(x3641));
IkReal x3651=((cj5)*(x3640));
gconst14=IKsign(((((cj0)*(r01)*(r22)*(x3642)))+(((r11)*(x3645)*(x3651)))+(((r01)*(x3646)*(x3651)))+(((IkReal(-1.00000000000000))*(x3643)*(x3647)*(x3650)))+(((r02)*(x3644)*(x3646)))+(((r12)*(x3644)*(x3645)))+(((r01)*(x3646)*(x3650)))+(((IkReal(-1.00000000000000))*(r10)*(x3649)*(x3651)))+(((r11)*(x3645)*(x3650)))+(((IkReal(-1.00000000000000))*(r12)*(x3642)*(x3649)))+(((IkReal(-1.00000000000000))*(r00)*(r22)*(x3643)*(x3644)))+(((IkReal(-1.00000000000000))*(r10)*(x3649)*(x3650)))+(((IkReal(-1.00000000000000))*(x3643)*(x3647)*(x3651)))+(((IkReal(-1.00000000000000))*(r10)*(x3644)*(x3648)))+(((r11)*(x3642)*(x3648)))+(((IkReal(-1.00000000000000))*(r02)*(r21)*(x3642)*(x3643)))));
IkReal x3652=(cj6)*(cj6);
IkReal x3653=(sj6)*(sj6);
IkReal x3654=((sj5)*(sj6));
IkReal x3655=((IkReal(1.00000000000000))*(cj0));
IkReal x3656=((cj6)*(sj5));
IkReal x3657=((r20)*(sj0));
IkReal x3658=((cj0)*(r20));
IkReal x3659=((r00)*(r21));
IkReal x3660=((r22)*(sj0));
IkReal x3661=((IkReal(1.00000000000000))*(r21)*(sj0));
IkReal x3662=((cj5)*(x3653));
IkReal x3663=((cj5)*(x3652));
dummyeval[0]=((((cj0)*(r01)*(r22)*(x3654)))+(((IkReal(-1.00000000000000))*(r00)*(r22)*(x3655)*(x3656)))+(((r11)*(x3657)*(x3663)))+(((r11)*(x3657)*(x3662)))+(((IkReal(-1.00000000000000))*(x3655)*(x3659)*(x3663)))+(((r12)*(x3656)*(x3657)))+(((IkReal(-1.00000000000000))*(r10)*(x3656)*(x3660)))+(((IkReal(-1.00000000000000))*(r12)*(x3654)*(x3661)))+(((IkReal(-1.00000000000000))*(r02)*(r21)*(x3654)*(x3655)))+(((r01)*(x3658)*(x3662)))+(((r11)*(x3654)*(x3660)))+(((IkReal(-1.00000000000000))*(r10)*(x3661)*(x3663)))+(((r01)*(x3658)*(x3663)))+(((IkReal(-1.00000000000000))*(x3655)*(x3659)*(x3662)))+(((IkReal(-1.00000000000000))*(r10)*(x3661)*(x3662)))+(((r02)*(x3656)*(x3658))));
if( IKabs(dummyeval[0]) < 0.0000010000000000  )
{
{
IkReal dummyeval[1];
dummyeval[0]=sj1;
if( IKabs(dummyeval[0]) < 0.0000010000000000  )
{
{
IkReal evalcond[5];
IkReal x3664=((cj5)*(r22));
IkReal x3665=((IkReal(0.374290000000000))*(sj5));
IkReal x3666=((cj0)*(sj6));
IkReal x3667=((cj6)*(r21));
IkReal x3668=((IkReal(0.0100000000000000))*(sj5));
IkReal x3669=((cj0)*(r02));
IkReal x3670=((IkReal(0.0100000000000000))*(cj5));
IkReal x3671=((IkReal(1.00000000000000))*(py));
IkReal x3672=((r01)*(sj0));
IkReal x3673=((r20)*(sj6));
IkReal x3674=((r11)*(sj0));
IkReal x3675=((IkReal(0.374290000000000))*(cj5));
IkReal x3676=((cj0)*(r12));
IkReal x3677=((sj0)*(x3675));
IkReal x3678=((cj6)*(x3670));
IkReal x3679=((r10)*(sj0)*(sj6));
IkReal x3680=((r00)*(sj0)*(sj6));
IkReal x3681=((cj0)*(cj6)*(x3665));
evalcond[0]=((IkReal(-3.14159265358979))+(IKfmod(((IkReal(3.14159265358979))+(j1)), IkReal(6.28318530717959))));
evalcond[1]=((((sj5)*(x3667)))+(((IkReal(-1.00000000000000))*(x3664)))+(((sj5)*(x3673))));
evalcond[2]=((((IkReal(-1.00000000000000))*(x3670)*(x3673)))+(((IkReal(-1.00000000000000))*(r22)*(x3668)))+(pz)+(((x3665)*(x3673)))+(((IkReal(-0.374290000000000))*(x3664)))+(((IkReal(-1.00000000000000))*(x3667)*(x3670)))+(((x3665)*(x3667))));
evalcond[3]=((IkReal(0.0690000000000000))+(((IkReal(-1.00000000000000))*(cj0)*(x3671)))+(((x3668)*(x3676)))+(((IkReal(-1.00000000000000))*(r10)*(x3665)*(x3666)))+(((x3665)*(x3680)))+(((IkReal(-1.00000000000000))*(x3670)*(x3680)))+(((IkReal(-1.00000000000000))*(r02)*(x3677)))+(((cj0)*(r11)*(x3678)))+(((r10)*(x3666)*(x3670)))+(((x3675)*(x3676)))+(((IkReal(-1.00000000000000))*(r02)*(sj0)*(x3668)))+(((IkReal(-1.00000000000000))*(x3672)*(x3678)))+(((px)*(sj0)))+(((IkReal(-1.00000000000000))*(r11)*(x3681)))+(((cj6)*(x3665)*(x3672))));
evalcond[4]=((IkReal(0.433420000000000))+(((IkReal(-1.00000000000000))*(cj0)*(px)))+(((IkReal(-1.00000000000000))*(cj6)*(x3665)*(x3674)))+(((r12)*(x3677)))+(((x3674)*(x3678)))+(((x3668)*(x3669)))+(((IkReal(-1.00000000000000))*(sj0)*(x3671)))+(((x3670)*(x3679)))+(((IkReal(-1.00000000000000))*(r00)*(x3665)*(x3666)))+(((r00)*(x3666)*(x3670)))+(((IkReal(-1.00000000000000))*(r01)*(x3681)))+(((IkReal(-1.00000000000000))*(x3665)*(x3679)))+(((r12)*(sj0)*(x3668)))+(((x3669)*(x3675)))+(((cj0)*(r01)*(x3678))));
if( IKabs(evalcond[0]) < 0.0000010000000000  && IKabs(evalcond[1]) < 0.0000010000000000  && IKabs(evalcond[2]) < 0.0000010000000000  && IKabs(evalcond[3]) < 0.0000010000000000  && IKabs(evalcond[4]) < 0.0000010000000000  )
{
{
IkReal j3array[1], cj3array[1], sj3array[1];
bool j3valid[1]={false};
_nj3 = 1;
IkReal x3682=((cj0)*(cj5));
IkReal x3683=((IkReal(1.00000000000000))*(cj0));
IkReal x3684=((cj6)*(r11));
IkReal x3685=((r10)*(sj6));
IkReal x3686=((cj5)*(sj0));
IkReal x3687=((r00)*(sj5)*(sj6));
IkReal x3688=((cj6)*(r01)*(sj5));
IkReal x3689=((IkReal(1.00000000000000))*(sj0)*(sj5));
if( IKabs(((((IkReal(-1.00000000000000))*(r02)*(x3686)))+(((sj0)*(x3687)))+(((IkReal(-1.00000000000000))*(sj5)*(x3683)*(x3684)))+(((IkReal(-1.00000000000000))*(sj5)*(x3683)*(x3685)))+(((r12)*(x3682)))+(((sj0)*(x3688))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(((((r02)*(x3682)))+(((IkReal(-1.00000000000000))*(x3685)*(x3689)))+(((IkReal(-1.00000000000000))*(x3683)*(x3687)))+(((r12)*(x3686)))+(((IkReal(-1.00000000000000))*(x3684)*(x3689)))+(((IkReal(-1.00000000000000))*(x3683)*(x3688))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(IKsqr(((((IkReal(-1.00000000000000))*(r02)*(x3686)))+(((sj0)*(x3687)))+(((IkReal(-1.00000000000000))*(sj5)*(x3683)*(x3684)))+(((IkReal(-1.00000000000000))*(sj5)*(x3683)*(x3685)))+(((r12)*(x3682)))+(((sj0)*(x3688)))))+IKsqr(((((r02)*(x3682)))+(((IkReal(-1.00000000000000))*(x3685)*(x3689)))+(((IkReal(-1.00000000000000))*(x3683)*(x3687)))+(((r12)*(x3686)))+(((IkReal(-1.00000000000000))*(x3684)*(x3689)))+(((IkReal(-1.00000000000000))*(x3683)*(x3688)))))-1) <= IKFAST_SINCOS_THRESH )
    continue;
j3array[0]=IKatan2(((((IkReal(-1.00000000000000))*(r02)*(x3686)))+(((sj0)*(x3687)))+(((IkReal(-1.00000000000000))*(sj5)*(x3683)*(x3684)))+(((IkReal(-1.00000000000000))*(sj5)*(x3683)*(x3685)))+(((r12)*(x3682)))+(((sj0)*(x3688)))), ((((r02)*(x3682)))+(((IkReal(-1.00000000000000))*(x3685)*(x3689)))+(((IkReal(-1.00000000000000))*(x3683)*(x3687)))+(((r12)*(x3686)))+(((IkReal(-1.00000000000000))*(x3684)*(x3689)))+(((IkReal(-1.00000000000000))*(x3683)*(x3688)))));
sj3array[0]=IKsin(j3array[0]);
cj3array[0]=IKcos(j3array[0]);
if( j3array[0] > IKPI )
{
    j3array[0]-=IK2PI;
}
else if( j3array[0] < -IKPI )
{    j3array[0]+=IK2PI;
}
j3valid[0] = true;
for(int ij3 = 0; ij3 < 1; ++ij3)
{
if( !j3valid[ij3] )
{
    continue;
}
_ij3[0] = ij3; _ij3[1] = -1;
for(int iij3 = ij3+1; iij3 < 1; ++iij3)
{
if( j3valid[iij3] && IKabs(cj3array[ij3]-cj3array[iij3]) < IKFAST_SOLUTION_THRESH && IKabs(sj3array[ij3]-sj3array[iij3]) < IKFAST_SOLUTION_THRESH )
{
    j3valid[iij3]=false; _ij3[1] = iij3; break; 
}
}
j3 = j3array[ij3]; cj3 = cj3array[ij3]; sj3 = sj3array[ij3];
{
IkReal evalcond[2];
IkReal x3690=((cj0)*(cj5));
IkReal x3691=((IkReal(1.00000000000000))*(cj0));
IkReal x3692=((cj6)*(r11));
IkReal x3693=((r10)*(sj6));
IkReal x3694=((cj5)*(sj0));
IkReal x3695=((r00)*(sj5)*(sj6));
IkReal x3696=((cj6)*(r01)*(sj5));
IkReal x3697=((IkReal(1.00000000000000))*(sj0)*(sj5));
evalcond[0]=((((IkReal(-1.00000000000000))*(sj5)*(x3691)*(x3692)))+(((sj0)*(x3696)))+(((IkReal(-1.00000000000000))*(sj5)*(x3691)*(x3693)))+(((IkReal(-1.00000000000000))*(r02)*(x3694)))+(((sj0)*(x3695)))+(((IkReal(-1.00000000000000))*(IKsin(j3))))+(((r12)*(x3690))));
evalcond[1]=((((IkReal(-1.00000000000000))*(x3692)*(x3697)))+(((IkReal(-1.00000000000000))*(x3691)*(x3696)))+(((IkReal(-1.00000000000000))*(x3691)*(x3695)))+(((IkReal(-1.00000000000000))*(IKcos(j3))))+(((IkReal(-1.00000000000000))*(x3693)*(x3697)))+(((r02)*(x3690)))+(((r12)*(x3694))));
if( IKabs(evalcond[0]) > 0.000001  || IKabs(evalcond[1]) > 0.000001  )
{
continue;
}
}

{
IkReal dummyeval[1];
IkReal gconst20;
IkReal x3698=(cj5)*(cj5);
IkReal x3699=(r20)*(r20);
IkReal x3700=(sj6)*(sj6);
IkReal x3701=(cj6)*(cj6);
IkReal x3702=(r21)*(r21);
IkReal x3703=((cj6)*(r21));
IkReal x3704=((IkReal(2.00000000000000))*(r20)*(sj6));
IkReal x3705=((cj5)*(r22)*(sj5));
gconst20=IKsign(((((x3698)*(x3699)*(x3700)))+(((x3700)*(x3702)))+(((x3704)*(x3705)))+((((r22)*(r22))*((sj5)*(sj5))))+(((x3698)*(x3703)*(x3704)))+(((x3698)*(x3701)*(x3702)))+(((x3699)*(x3701)))+(((IkReal(-1.00000000000000))*(x3703)*(x3704)))+(((IkReal(2.00000000000000))*(x3703)*(x3705)))));
IkReal x3706=(cj5)*(cj5);
IkReal x3707=(r20)*(r20);
IkReal x3708=(sj6)*(sj6);
IkReal x3709=(cj6)*(cj6);
IkReal x3710=(r21)*(r21);
IkReal x3711=((cj6)*(r21));
IkReal x3712=((IkReal(2.00000000000000))*(r20)*(sj6));
IkReal x3713=((cj5)*(r22)*(sj5));
dummyeval[0]=((((x3706)*(x3707)*(x3708)))+(((IkReal(2.00000000000000))*(x3711)*(x3713)))+(((x3707)*(x3709)))+((((r22)*(r22))*((sj5)*(sj5))))+(((x3706)*(x3709)*(x3710)))+(((IkReal(-1.00000000000000))*(x3711)*(x3712)))+(((x3712)*(x3713)))+(((x3708)*(x3710)))+(((x3706)*(x3711)*(x3712))));
if( IKabs(dummyeval[0]) < 0.0000010000000000  )
{
{
IkReal dummyeval[1];
IkReal gconst21;
IkReal x3714=(cj6)*(cj6);
IkReal x3715=(sj6)*(sj6);
IkReal x3716=((IkReal(1.00000000000000))*(r21));
IkReal x3717=((cj6)*(r20));
IkReal x3718=((r22)*(sj5));
IkReal x3719=((r01)*(sj0));
IkReal x3720=((r00)*(sj0));
IkReal x3721=((cj0)*(r10));
IkReal x3722=((r02)*(sj0)*(sj5));
IkReal x3723=((cj5)*(x3714));
IkReal x3724=((cj0)*(r12)*(sj5));
IkReal x3725=((IkReal(1.00000000000000))*(cj0)*(r11));
IkReal x3726=((cj5)*(x3715));
IkReal x3727=((r20)*(x3726));
gconst21=IKsign(((((IkReal(-1.00000000000000))*(r20)*(x3723)*(x3725)))+(((cj6)*(x3718)*(x3721)))+(((IkReal(-1.00000000000000))*(x3717)*(x3724)))+(((IkReal(-1.00000000000000))*(cj6)*(x3718)*(x3720)))+(((IkReal(-1.00000000000000))*(sj6)*(x3718)*(x3725)))+(((IkReal(-1.00000000000000))*(sj6)*(x3716)*(x3722)))+(((r21)*(sj6)*(x3724)))+(((x3717)*(x3722)))+(((r20)*(x3719)*(x3723)))+(((r21)*(x3721)*(x3726)))+(((x3719)*(x3727)))+(((IkReal(-1.00000000000000))*(x3725)*(x3727)))+(((r21)*(x3721)*(x3723)))+(((IkReal(-1.00000000000000))*(x3716)*(x3720)*(x3726)))+(((IkReal(-1.00000000000000))*(x3716)*(x3720)*(x3723)))+(((sj6)*(x3718)*(x3719)))));
IkReal x3728=(cj6)*(cj6);
IkReal x3729=(sj6)*(sj6);
IkReal x3730=((IkReal(1.00000000000000))*(r21));
IkReal x3731=((cj6)*(r20));
IkReal x3732=((r22)*(sj5));
IkReal x3733=((r01)*(sj0));
IkReal x3734=((r00)*(sj0));
IkReal x3735=((cj0)*(r10));
IkReal x3736=((r02)*(sj0)*(sj5));
IkReal x3737=((cj5)*(x3728));
IkReal x3738=((cj0)*(r12)*(sj5));
IkReal x3739=((IkReal(1.00000000000000))*(cj0)*(r11));
IkReal x3740=((cj5)*(x3729));
IkReal x3741=((r20)*(x3740));
dummyeval[0]=((((IkReal(-1.00000000000000))*(x3730)*(x3734)*(x3737)))+(((sj6)*(x3732)*(x3733)))+(((x3731)*(x3736)))+(((r21)*(sj6)*(x3738)))+(((cj6)*(x3732)*(x3735)))+(((r21)*(x3735)*(x3740)))+(((r20)*(x3733)*(x3737)))+(((IkReal(-1.00000000000000))*(x3731)*(x3738)))+(((IkReal(-1.00000000000000))*(x3739)*(x3741)))+(((r21)*(x3735)*(x3737)))+(((x3733)*(x3741)))+(((IkReal(-1.00000000000000))*(sj6)*(x3730)*(x3736)))+(((IkReal(-1.00000000000000))*(r20)*(x3737)*(x3739)))+(((IkReal(-1.00000000000000))*(x3730)*(x3734)*(x3740)))+(((IkReal(-1.00000000000000))*(cj6)*(x3732)*(x3734)))+(((IkReal(-1.00000000000000))*(sj6)*(x3732)*(x3739))));
if( IKabs(dummyeval[0]) < 0.0000010000000000  )
{
continue;

} else
{
{
IkReal j4array[1], cj4array[1], sj4array[1];
bool j4valid[1]={false};
_nj4 = 1;
IkReal x3742=((sj0)*(sj6));
IkReal x3743=((cj0)*(cj6));
IkReal x3744=((IkReal(1.00000000000000))*(cj5));
IkReal x3745=((cj6)*(sj0));
IkReal x3746=((cj0)*(sj6));
if( IKabs(((gconst21)*(((((IkReal(-1.00000000000000))*(r00)*(x3745)))+(((IkReal(-1.00000000000000))*(r11)*(x3746)))+(((r10)*(x3743)))+(((r01)*(x3742))))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(((gconst21)*(((((cj5)*(r11)*(x3743)))+(((IkReal(-1.00000000000000))*(r00)*(x3742)*(x3744)))+(((IkReal(-1.00000000000000))*(r01)*(x3744)*(x3745)))+(((cj0)*(r12)*(sj5)))+(((IkReal(-1.00000000000000))*(r02)*(sj0)*(sj5)))+(((cj5)*(r10)*(x3746))))))) < IKFAST_ATAN2_MAGTHRESH )
    continue;
j4array[0]=IKatan2(((gconst21)*(((((IkReal(-1.00000000000000))*(r00)*(x3745)))+(((IkReal(-1.00000000000000))*(r11)*(x3746)))+(((r10)*(x3743)))+(((r01)*(x3742)))))), ((gconst21)*(((((cj5)*(r11)*(x3743)))+(((IkReal(-1.00000000000000))*(r00)*(x3742)*(x3744)))+(((IkReal(-1.00000000000000))*(r01)*(x3744)*(x3745)))+(((cj0)*(r12)*(sj5)))+(((IkReal(-1.00000000000000))*(r02)*(sj0)*(sj5)))+(((cj5)*(r10)*(x3746)))))));
sj4array[0]=IKsin(j4array[0]);
cj4array[0]=IKcos(j4array[0]);
if( j4array[0] > IKPI )
{
    j4array[0]-=IK2PI;
}
else if( j4array[0] < -IKPI )
{    j4array[0]+=IK2PI;
}
j4valid[0] = true;
for(int ij4 = 0; ij4 < 1; ++ij4)
{
if( !j4valid[ij4] )
{
    continue;
}
_ij4[0] = ij4; _ij4[1] = -1;
for(int iij4 = ij4+1; iij4 < 1; ++iij4)
{
if( j4valid[iij4] && IKabs(cj4array[ij4]-cj4array[iij4]) < IKFAST_SOLUTION_THRESH && IKabs(sj4array[ij4]-sj4array[iij4]) < IKFAST_SOLUTION_THRESH )
{
    j4valid[iij4]=false; _ij4[1] = iij4; break; 
}
}
j4 = j4array[ij4]; cj4 = cj4array[ij4]; sj4 = sj4array[ij4];
{
IkReal evalcond[6];
IkReal x3747=IKsin(j4);
IkReal x3748=IKcos(j4);
IkReal x3749=((r22)*(sj5));
IkReal x3750=((IkReal(1.00000000000000))*(cj6));
IkReal x3751=((IkReal(1.00000000000000))*(cj0));
IkReal x3752=((cj5)*(r11));
IkReal x3753=((cj5)*(cj6));
IkReal x3754=((r11)*(sj6));
IkReal x3755=((IkReal(1.00000000000000))*(sj6));
IkReal x3756=((cj6)*(r00));
IkReal x3757=((r12)*(sj5));
IkReal x3758=((r02)*(sj5));
IkReal x3759=((cj6)*(r10));
IkReal x3760=((cj5)*(sj6));
IkReal x3761=((cj5)*(r01));
IkReal x3762=((sj0)*(x3747));
IkReal x3763=((r00)*(x3760));
IkReal x3764=((cj0)*(x3747));
IkReal x3765=((sj0)*(x3748));
IkReal x3766=((r20)*(x3748));
IkReal x3767=((cj0)*(x3748));
IkReal x3768=((r21)*(x3747));
IkReal x3769=((r21)*(x3748));
IkReal x3770=((r20)*(x3747));
IkReal x3771=((x3748)*(x3757));
IkReal x3772=((r01)*(sj6)*(x3748));
IkReal x3773=((cj5)*(r10)*(x3755));
evalcond[0]=((IkReal(-1.00000000000000))+(((x3753)*(x3768)))+(((x3747)*(x3749)))+(((x3760)*(x3770)))+(((sj6)*(x3769)))+(((IkReal(-1.00000000000000))*(x3750)*(x3766))));
evalcond[1]=((((cj6)*(x3770)))+(((x3753)*(x3769)))+(((x3760)*(x3766)))+(((x3748)*(x3749)))+(((IkReal(-1.00000000000000))*(x3755)*(x3768))));
evalcond[2]=((((x3759)*(x3767)))+(((x3762)*(x3763)))+(((r01)*(sj6)*(x3765)))+(((IkReal(-1.00000000000000))*(x3748)*(x3751)*(x3754)))+(((r01)*(x3753)*(x3762)))+(((IkReal(-1.00000000000000))*(r00)*(x3750)*(x3765)))+(((IkReal(-1.00000000000000))*(x3750)*(x3752)*(x3764)))+(((x3758)*(x3762)))+(((IkReal(-1.00000000000000))*(x3747)*(x3751)*(x3757)))+(((IkReal(-1.00000000000000))*(r10)*(x3747)*(x3751)*(x3760))));
evalcond[3]=((((IkReal(-1.00000000000000))*(r10)*(x3750)*(x3764)))+(((IkReal(-1.00000000000000))*(x3750)*(x3752)*(x3767)))+(((IkReal(-1.00000000000000))*(r01)*(x3755)*(x3762)))+(((x3754)*(x3764)))+(((IkReal(-1.00000000000000))*(x3751)*(x3771)))+(((x3756)*(x3762)))+(cj3)+(((IkReal(-1.00000000000000))*(r10)*(x3748)*(x3751)*(x3760)))+(((r01)*(x3753)*(x3765)))+(((x3758)*(x3765)))+(((x3763)*(x3765))));
evalcond[4]=((((IkReal(-1.00000000000000))*(x3750)*(x3752)*(x3762)))+(((IkReal(-1.00000000000000))*(x3747)*(x3751)*(x3758)))+(((IkReal(-1.00000000000000))*(x3762)*(x3773)))+(((IkReal(-1.00000000000000))*(x3757)*(x3762)))+(((IkReal(-1.00000000000000))*(x3754)*(x3765)))+(((IkReal(-1.00000000000000))*(x3750)*(x3761)*(x3764)))+(((IkReal(-1.00000000000000))*(x3751)*(x3772)))+(((x3759)*(x3765)))+(((IkReal(-1.00000000000000))*(x3747)*(x3751)*(x3763)))+(((x3756)*(x3767))));
evalcond[5]=((((IkReal(-1.00000000000000))*(r10)*(x3750)*(x3762)))+(((IkReal(-1.00000000000000))*(x3757)*(x3765)))+(((IkReal(-1.00000000000000))*(x3750)*(x3752)*(x3765)))+(((IkReal(-1.00000000000000))*(x3748)*(x3751)*(x3758)))+(((IkReal(-1.00000000000000))*(r00)*(x3750)*(x3764)))+(((IkReal(-1.00000000000000))*(x3750)*(x3761)*(x3767)))+(((IkReal(-1.00000000000000))*(x3765)*(x3773)))+(((x3754)*(x3762)))+(((IkReal(-1.00000000000000))*(sj3)))+(((IkReal(-1.00000000000000))*(x3748)*(x3751)*(x3763)))+(((r01)*(sj6)*(x3764))));
if( IKabs(evalcond[0]) > 0.000001  || IKabs(evalcond[1]) > 0.000001  || IKabs(evalcond[2]) > 0.000001  || IKabs(evalcond[3]) > 0.000001  || IKabs(evalcond[4]) > 0.000001  || IKabs(evalcond[5]) > 0.000001  )
{
continue;
}
}

{
std::vector<IkSingleDOFSolutionBase<IkReal> > vinfos(7);
vinfos[0].jointtype = 1;
vinfos[0].foffset = j0;
vinfos[0].indices[0] = _ij0[0];
vinfos[0].indices[1] = _ij0[1];
vinfos[0].maxsolutions = _nj0;
vinfos[1].jointtype = 1;
vinfos[1].foffset = j1;
vinfos[1].indices[0] = _ij1[0];
vinfos[1].indices[1] = _ij1[1];
vinfos[1].maxsolutions = _nj1;
vinfos[2].jointtype = 1;
vinfos[2].foffset = j2;
vinfos[2].indices[0] = _ij2[0];
vinfos[2].indices[1] = _ij2[1];
vinfos[2].maxsolutions = _nj2;
vinfos[3].jointtype = 1;
vinfos[3].foffset = j3;
vinfos[3].indices[0] = _ij3[0];
vinfos[3].indices[1] = _ij3[1];
vinfos[3].maxsolutions = _nj3;
vinfos[4].jointtype = 1;
vinfos[4].foffset = j4;
vinfos[4].indices[0] = _ij4[0];
vinfos[4].indices[1] = _ij4[1];
vinfos[4].maxsolutions = _nj4;
vinfos[5].jointtype = 1;
vinfos[5].foffset = j5;
vinfos[5].indices[0] = _ij5[0];
vinfos[5].indices[1] = _ij5[1];
vinfos[5].maxsolutions = _nj5;
vinfos[6].jointtype = 1;
vinfos[6].foffset = j6;
vinfos[6].indices[0] = _ij6[0];
vinfos[6].indices[1] = _ij6[1];
vinfos[6].maxsolutions = _nj6;
std::vector<int> vfree(0);
solutions.AddSolution(vinfos,vfree);
}
}
}

}

}

} else
{
{
IkReal j4array[1], cj4array[1], sj4array[1];
bool j4valid[1]={false};
_nj4 = 1;
if( IKabs(((gconst20)*(((((cj5)*(r20)*(sj6)))+(((r22)*(sj5)))+(((cj5)*(cj6)*(r21))))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(((gconst20)*(((((r21)*(sj6)))+(((IkReal(-1.00000000000000))*(cj6)*(r20))))))) < IKFAST_ATAN2_MAGTHRESH )
    continue;
j4array[0]=IKatan2(((gconst20)*(((((cj5)*(r20)*(sj6)))+(((r22)*(sj5)))+(((cj5)*(cj6)*(r21)))))), ((gconst20)*(((((r21)*(sj6)))+(((IkReal(-1.00000000000000))*(cj6)*(r20)))))));
sj4array[0]=IKsin(j4array[0]);
cj4array[0]=IKcos(j4array[0]);
if( j4array[0] > IKPI )
{
    j4array[0]-=IK2PI;
}
else if( j4array[0] < -IKPI )
{    j4array[0]+=IK2PI;
}
j4valid[0] = true;
for(int ij4 = 0; ij4 < 1; ++ij4)
{
if( !j4valid[ij4] )
{
    continue;
}
_ij4[0] = ij4; _ij4[1] = -1;
for(int iij4 = ij4+1; iij4 < 1; ++iij4)
{
if( j4valid[iij4] && IKabs(cj4array[ij4]-cj4array[iij4]) < IKFAST_SOLUTION_THRESH && IKabs(sj4array[ij4]-sj4array[iij4]) < IKFAST_SOLUTION_THRESH )
{
    j4valid[iij4]=false; _ij4[1] = iij4; break; 
}
}
j4 = j4array[ij4]; cj4 = cj4array[ij4]; sj4 = sj4array[ij4];
{
IkReal evalcond[6];
IkReal x3774=IKsin(j4);
IkReal x3775=IKcos(j4);
IkReal x3776=((r22)*(sj5));
IkReal x3777=((IkReal(1.00000000000000))*(cj6));
IkReal x3778=((IkReal(1.00000000000000))*(cj0));
IkReal x3779=((cj5)*(r11));
IkReal x3780=((cj5)*(cj6));
IkReal x3781=((r11)*(sj6));
IkReal x3782=((IkReal(1.00000000000000))*(sj6));
IkReal x3783=((cj6)*(r00));
IkReal x3784=((r12)*(sj5));
IkReal x3785=((r02)*(sj5));
IkReal x3786=((cj6)*(r10));
IkReal x3787=((cj5)*(sj6));
IkReal x3788=((cj5)*(r01));
IkReal x3789=((sj0)*(x3774));
IkReal x3790=((r00)*(x3787));
IkReal x3791=((cj0)*(x3774));
IkReal x3792=((sj0)*(x3775));
IkReal x3793=((r20)*(x3775));
IkReal x3794=((cj0)*(x3775));
IkReal x3795=((r21)*(x3774));
IkReal x3796=((r21)*(x3775));
IkReal x3797=((r20)*(x3774));
IkReal x3798=((x3775)*(x3784));
IkReal x3799=((r01)*(sj6)*(x3775));
IkReal x3800=((cj5)*(r10)*(x3782));
evalcond[0]=((IkReal(-1.00000000000000))+(((IkReal(-1.00000000000000))*(x3777)*(x3793)))+(((x3787)*(x3797)))+(((x3780)*(x3795)))+(((x3774)*(x3776)))+(((sj6)*(x3796))));
evalcond[1]=((((x3787)*(x3793)))+(((IkReal(-1.00000000000000))*(x3782)*(x3795)))+(((x3775)*(x3776)))+(((x3780)*(x3796)))+(((cj6)*(x3797))));
evalcond[2]=((((x3789)*(x3790)))+(((IkReal(-1.00000000000000))*(x3775)*(x3778)*(x3781)))+(((x3785)*(x3789)))+(((IkReal(-1.00000000000000))*(x3774)*(x3778)*(x3784)))+(((r01)*(sj6)*(x3792)))+(((r01)*(x3780)*(x3789)))+(((x3786)*(x3794)))+(((IkReal(-1.00000000000000))*(r00)*(x3777)*(x3792)))+(((IkReal(-1.00000000000000))*(x3777)*(x3779)*(x3791)))+(((IkReal(-1.00000000000000))*(r10)*(x3774)*(x3778)*(x3787))));
evalcond[3]=((((x3785)*(x3792)))+(((IkReal(-1.00000000000000))*(r10)*(x3775)*(x3778)*(x3787)))+(((IkReal(-1.00000000000000))*(x3778)*(x3798)))+(((x3783)*(x3789)))+(cj3)+(((IkReal(-1.00000000000000))*(x3777)*(x3779)*(x3794)))+(((IkReal(-1.00000000000000))*(r10)*(x3777)*(x3791)))+(((r01)*(x3780)*(x3792)))+(((x3781)*(x3791)))+(((x3790)*(x3792)))+(((IkReal(-1.00000000000000))*(r01)*(x3782)*(x3789))));
evalcond[4]=((((IkReal(-1.00000000000000))*(x3774)*(x3778)*(x3785)))+(((x3786)*(x3792)))+(((IkReal(-1.00000000000000))*(x3784)*(x3789)))+(((IkReal(-1.00000000000000))*(x3777)*(x3788)*(x3791)))+(((IkReal(-1.00000000000000))*(x3778)*(x3799)))+(((IkReal(-1.00000000000000))*(x3774)*(x3778)*(x3790)))+(((IkReal(-1.00000000000000))*(x3789)*(x3800)))+(((IkReal(-1.00000000000000))*(x3777)*(x3779)*(x3789)))+(((IkReal(-1.00000000000000))*(x3781)*(x3792)))+(((x3783)*(x3794))));
evalcond[5]=((((IkReal(-1.00000000000000))*(r10)*(x3777)*(x3789)))+(((IkReal(-1.00000000000000))*(x3784)*(x3792)))+(((r01)*(sj6)*(x3791)))+(((IkReal(-1.00000000000000))*(x3792)*(x3800)))+(((x3781)*(x3789)))+(((IkReal(-1.00000000000000))*(x3775)*(x3778)*(x3790)))+(((IkReal(-1.00000000000000))*(x3777)*(x3779)*(x3792)))+(((IkReal(-1.00000000000000))*(x3777)*(x3788)*(x3794)))+(((IkReal(-1.00000000000000))*(x3775)*(x3778)*(x3785)))+(((IkReal(-1.00000000000000))*(sj3)))+(((IkReal(-1.00000000000000))*(r00)*(x3777)*(x3791))));
if( IKabs(evalcond[0]) > 0.000001  || IKabs(evalcond[1]) > 0.000001  || IKabs(evalcond[2]) > 0.000001  || IKabs(evalcond[3]) > 0.000001  || IKabs(evalcond[4]) > 0.000001  || IKabs(evalcond[5]) > 0.000001  )
{
continue;
}
}

{
std::vector<IkSingleDOFSolutionBase<IkReal> > vinfos(7);
vinfos[0].jointtype = 1;
vinfos[0].foffset = j0;
vinfos[0].indices[0] = _ij0[0];
vinfos[0].indices[1] = _ij0[1];
vinfos[0].maxsolutions = _nj0;
vinfos[1].jointtype = 1;
vinfos[1].foffset = j1;
vinfos[1].indices[0] = _ij1[0];
vinfos[1].indices[1] = _ij1[1];
vinfos[1].maxsolutions = _nj1;
vinfos[2].jointtype = 1;
vinfos[2].foffset = j2;
vinfos[2].indices[0] = _ij2[0];
vinfos[2].indices[1] = _ij2[1];
vinfos[2].maxsolutions = _nj2;
vinfos[3].jointtype = 1;
vinfos[3].foffset = j3;
vinfos[3].indices[0] = _ij3[0];
vinfos[3].indices[1] = _ij3[1];
vinfos[3].maxsolutions = _nj3;
vinfos[4].jointtype = 1;
vinfos[4].foffset = j4;
vinfos[4].indices[0] = _ij4[0];
vinfos[4].indices[1] = _ij4[1];
vinfos[4].maxsolutions = _nj4;
vinfos[5].jointtype = 1;
vinfos[5].foffset = j5;
vinfos[5].indices[0] = _ij5[0];
vinfos[5].indices[1] = _ij5[1];
vinfos[5].maxsolutions = _nj5;
vinfos[6].jointtype = 1;
vinfos[6].foffset = j6;
vinfos[6].indices[0] = _ij6[0];
vinfos[6].indices[1] = _ij6[1];
vinfos[6].maxsolutions = _nj6;
std::vector<int> vfree(0);
solutions.AddSolution(vinfos,vfree);
}
}
}

}

}
}
}

} else
{
IkReal x3801=((cj5)*(r22));
IkReal x3802=((IkReal(0.374290000000000))*(sj5));
IkReal x3803=((cj0)*(sj6));
IkReal x3804=((cj6)*(r21));
IkReal x3805=((IkReal(0.0100000000000000))*(sj5));
IkReal x3806=((cj0)*(r02));
IkReal x3807=((IkReal(0.0100000000000000))*(cj5));
IkReal x3808=((IkReal(1.00000000000000))*(py));
IkReal x3809=((r01)*(sj0));
IkReal x3810=((r20)*(sj6));
IkReal x3811=((r11)*(sj0));
IkReal x3812=((IkReal(0.374290000000000))*(cj5));
IkReal x3813=((cj0)*(r12));
IkReal x3814=((sj0)*(x3812));
IkReal x3815=((cj6)*(x3807));
IkReal x3816=((r10)*(sj0)*(sj6));
IkReal x3817=((r00)*(sj0)*(sj6));
IkReal x3818=((cj0)*(cj6)*(x3802));
evalcond[0]=((IkReal(-3.14159265358979))+(IKfmod(j1, IkReal(6.28318530717959))));
evalcond[1]=((((sj5)*(x3804)))+(((sj5)*(x3810)))+(((IkReal(-1.00000000000000))*(x3801))));
evalcond[2]=((((IkReal(-1.00000000000000))*(x3807)*(x3810)))+(((IkReal(-0.374290000000000))*(x3801)))+(((x3802)*(x3810)))+(((IkReal(-1.00000000000000))*(x3804)*(x3807)))+(pz)+(((IkReal(-1.00000000000000))*(r22)*(x3805)))+(((x3802)*(x3804))));
evalcond[3]=((IkReal(0.0690000000000000))+(((IkReal(-1.00000000000000))*(r02)*(x3814)))+(((x3805)*(x3813)))+(((IkReal(-1.00000000000000))*(r11)*(x3818)))+(((x3802)*(x3817)))+(((x3812)*(x3813)))+(((IkReal(-1.00000000000000))*(cj0)*(x3808)))+(((IkReal(-1.00000000000000))*(r10)*(x3802)*(x3803)))+(((cj0)*(r11)*(x3815)))+(((IkReal(-1.00000000000000))*(x3809)*(x3815)))+(((IkReal(-1.00000000000000))*(r02)*(sj0)*(x3805)))+(((IkReal(-1.00000000000000))*(x3807)*(x3817)))+(((cj6)*(x3802)*(x3809)))+(((px)*(sj0)))+(((r10)*(x3803)*(x3807))));
evalcond[4]=((IkReal(-0.295420000000000))+(((r12)*(x3814)))+(((IkReal(-1.00000000000000))*(cj0)*(px)))+(((x3805)*(x3806)))+(((IkReal(-1.00000000000000))*(cj6)*(x3802)*(x3811)))+(((x3811)*(x3815)))+(((IkReal(-1.00000000000000))*(x3802)*(x3816)))+(((x3807)*(x3816)))+(((r12)*(sj0)*(x3805)))+(((r00)*(x3803)*(x3807)))+(((IkReal(-1.00000000000000))*(r00)*(x3802)*(x3803)))+(((IkReal(-1.00000000000000))*(r01)*(x3818)))+(((cj0)*(r01)*(x3815)))+(((IkReal(-1.00000000000000))*(sj0)*(x3808)))+(((x3806)*(x3812))));
if( IKabs(evalcond[0]) < 0.0000010000000000  && IKabs(evalcond[1]) < 0.0000010000000000  && IKabs(evalcond[2]) < 0.0000010000000000  && IKabs(evalcond[3]) < 0.0000010000000000  && IKabs(evalcond[4]) < 0.0000010000000000  )
{
{
IkReal j3array[1], cj3array[1], sj3array[1];
bool j3valid[1]={false};
_nj3 = 1;
IkReal x3819=((sj0)*(sj5));
IkReal x3820=((r00)*(sj6));
IkReal x3821=((IkReal(1.00000000000000))*(cj5));
IkReal x3822=((cj6)*(r11));
IkReal x3823=((cj6)*(r01));
IkReal x3824=((r10)*(sj6));
IkReal x3825=((cj0)*(sj5));
if( IKabs(((((x3819)*(x3820)))+(((IkReal(-1.00000000000000))*(x3822)*(x3825)))+(((IkReal(-1.00000000000000))*(x3824)*(x3825)))+(((IkReal(-1.00000000000000))*(r02)*(sj0)*(x3821)))+(((cj0)*(cj5)*(r12)))+(((x3819)*(x3823))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(((((x3823)*(x3825)))+(((x3820)*(x3825)))+(((IkReal(-1.00000000000000))*(cj0)*(r02)*(x3821)))+(((IkReal(-1.00000000000000))*(r12)*(sj0)*(x3821)))+(((x3819)*(x3822)))+(((x3819)*(x3824))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(IKsqr(((((x3819)*(x3820)))+(((IkReal(-1.00000000000000))*(x3822)*(x3825)))+(((IkReal(-1.00000000000000))*(x3824)*(x3825)))+(((IkReal(-1.00000000000000))*(r02)*(sj0)*(x3821)))+(((cj0)*(cj5)*(r12)))+(((x3819)*(x3823)))))+IKsqr(((((x3823)*(x3825)))+(((x3820)*(x3825)))+(((IkReal(-1.00000000000000))*(cj0)*(r02)*(x3821)))+(((IkReal(-1.00000000000000))*(r12)*(sj0)*(x3821)))+(((x3819)*(x3822)))+(((x3819)*(x3824)))))-1) <= IKFAST_SINCOS_THRESH )
    continue;
j3array[0]=IKatan2(((((x3819)*(x3820)))+(((IkReal(-1.00000000000000))*(x3822)*(x3825)))+(((IkReal(-1.00000000000000))*(x3824)*(x3825)))+(((IkReal(-1.00000000000000))*(r02)*(sj0)*(x3821)))+(((cj0)*(cj5)*(r12)))+(((x3819)*(x3823)))), ((((x3823)*(x3825)))+(((x3820)*(x3825)))+(((IkReal(-1.00000000000000))*(cj0)*(r02)*(x3821)))+(((IkReal(-1.00000000000000))*(r12)*(sj0)*(x3821)))+(((x3819)*(x3822)))+(((x3819)*(x3824)))));
sj3array[0]=IKsin(j3array[0]);
cj3array[0]=IKcos(j3array[0]);
if( j3array[0] > IKPI )
{
    j3array[0]-=IK2PI;
}
else if( j3array[0] < -IKPI )
{    j3array[0]+=IK2PI;
}
j3valid[0] = true;
for(int ij3 = 0; ij3 < 1; ++ij3)
{
if( !j3valid[ij3] )
{
    continue;
}
_ij3[0] = ij3; _ij3[1] = -1;
for(int iij3 = ij3+1; iij3 < 1; ++iij3)
{
if( j3valid[iij3] && IKabs(cj3array[ij3]-cj3array[iij3]) < IKFAST_SOLUTION_THRESH && IKabs(sj3array[ij3]-sj3array[iij3]) < IKFAST_SOLUTION_THRESH )
{
    j3valid[iij3]=false; _ij3[1] = iij3; break; 
}
}
j3 = j3array[ij3]; cj3 = cj3array[ij3]; sj3 = sj3array[ij3];
{
IkReal evalcond[2];
IkReal x3826=((cj0)*(cj5));
IkReal x3827=((IkReal(1.00000000000000))*(cj0));
IkReal x3828=((cj6)*(r11));
IkReal x3829=((r10)*(sj6));
IkReal x3830=((cj5)*(sj0));
IkReal x3831=((r00)*(sj5)*(sj6));
IkReal x3832=((cj6)*(r01)*(sj5));
IkReal x3833=((IkReal(1.00000000000000))*(sj0)*(sj5));
evalcond[0]=((((IkReal(-1.00000000000000))*(sj5)*(x3827)*(x3828)))+(((IkReal(-1.00000000000000))*(r02)*(x3830)))+(((IkReal(-1.00000000000000))*(sj5)*(x3827)*(x3829)))+(((IkReal(-1.00000000000000))*(IKsin(j3))))+(((sj0)*(x3832)))+(((sj0)*(x3831)))+(((r12)*(x3826))));
evalcond[1]=((((r12)*(x3830)))+(((IkReal(-1.00000000000000))*(x3827)*(x3831)))+(((IkReal(-1.00000000000000))*(x3828)*(x3833)))+(((r02)*(x3826)))+(((IkReal(-1.00000000000000))*(x3829)*(x3833)))+(IKcos(j3))+(((IkReal(-1.00000000000000))*(x3827)*(x3832))));
if( IKabs(evalcond[0]) > 0.000001  || IKabs(evalcond[1]) > 0.000001  )
{
continue;
}
}

{
IkReal dummyeval[1];
IkReal gconst24;
IkReal x3834=(r21)*(r21);
IkReal x3835=(cj5)*(cj5);
IkReal x3836=(sj6)*(sj6);
IkReal x3837=(cj6)*(cj6);
IkReal x3838=(r20)*(r20);
IkReal x3839=((cj6)*(r21));
IkReal x3840=((IkReal(2.00000000000000))*(r20)*(sj6));
IkReal x3841=((cj5)*(r22)*(sj5));
IkReal x3842=((IkReal(1.00000000000000))*(x3836));
IkReal x3843=((IkReal(1.00000000000000))*(x3837));
gconst24=IKsign(((((IkReal(-1.00000000000000))*(x3834)*(x3835)*(x3843)))+(((x3839)*(x3840)))+(((IkReal(-1.00000000000000))*(x3835)*(x3839)*(x3840)))+(((IkReal(-1.00000000000000))*(x3835)*(x3838)*(x3842)))+(((IkReal(-1.00000000000000))*((r22)*(r22))*((sj5)*(sj5))))+(((IkReal(-1.00000000000000))*(x3834)*(x3842)))+(((IkReal(-2.00000000000000))*(x3839)*(x3841)))+(((IkReal(-1.00000000000000))*(x3838)*(x3843)))+(((IkReal(-1.00000000000000))*(x3840)*(x3841)))));
IkReal x3844=(r21)*(r21);
IkReal x3845=(cj5)*(cj5);
IkReal x3846=(sj6)*(sj6);
IkReal x3847=(cj6)*(cj6);
IkReal x3848=(r20)*(r20);
IkReal x3849=((cj6)*(r21));
IkReal x3850=((IkReal(2.00000000000000))*(r20)*(sj6));
IkReal x3851=((cj5)*(r22)*(sj5));
IkReal x3852=((IkReal(1.00000000000000))*(x3846));
IkReal x3853=((IkReal(1.00000000000000))*(x3847));
dummyeval[0]=((((IkReal(-1.00000000000000))*(x3848)*(x3853)))+(((IkReal(-2.00000000000000))*(x3849)*(x3851)))+(((x3849)*(x3850)))+(((IkReal(-1.00000000000000))*(x3844)*(x3845)*(x3853)))+(((IkReal(-1.00000000000000))*((r22)*(r22))*((sj5)*(sj5))))+(((IkReal(-1.00000000000000))*(x3845)*(x3848)*(x3852)))+(((IkReal(-1.00000000000000))*(x3844)*(x3852)))+(((IkReal(-1.00000000000000))*(x3850)*(x3851)))+(((IkReal(-1.00000000000000))*(x3845)*(x3849)*(x3850))));
if( IKabs(dummyeval[0]) < 0.0000010000000000  )
{
{
IkReal dummyeval[1];
IkReal gconst25;
IkReal x3854=(cj6)*(cj6);
IkReal x3855=(sj6)*(sj6);
IkReal x3856=((IkReal(1.00000000000000))*(r01));
IkReal x3857=((sj0)*(sj5));
IkReal x3858=((cj6)*(r22));
IkReal x3859=((r21)*(sj6));
IkReal x3860=((r00)*(r21));
IkReal x3861=((cj0)*(sj5));
IkReal x3862=((cj6)*(r20));
IkReal x3863=((r22)*(sj6));
IkReal x3864=((cj0)*(cj5));
IkReal x3865=((IkReal(1.00000000000000))*(r10));
IkReal x3866=((cj5)*(sj0));
IkReal x3867=((r20)*(x3855));
IkReal x3868=((x3854)*(x3866));
gconst25=IKsign(((((IkReal(-1.00000000000000))*(r02)*(x3857)*(x3862)))+(((r11)*(x3864)*(x3867)))+(((r00)*(x3857)*(x3858)))+(((IkReal(-1.00000000000000))*(x3856)*(x3857)*(x3863)))+(((x3855)*(x3860)*(x3866)))+(((r11)*(r20)*(x3854)*(x3864)))+(((IkReal(-1.00000000000000))*(x3856)*(x3866)*(x3867)))+(((r11)*(x3861)*(x3863)))+(((IkReal(-1.00000000000000))*(x3858)*(x3861)*(x3865)))+(((r02)*(x3857)*(x3859)))+(((IkReal(-1.00000000000000))*(r12)*(x3859)*(x3861)))+(((r12)*(x3861)*(x3862)))+(((IkReal(-1.00000000000000))*(r20)*(x3856)*(x3868)))+(((IkReal(-1.00000000000000))*(r21)*(x3855)*(x3864)*(x3865)))+(((x3860)*(x3868)))+(((IkReal(-1.00000000000000))*(r21)*(x3854)*(x3864)*(x3865)))));
IkReal x3869=(cj6)*(cj6);
IkReal x3870=(sj6)*(sj6);
IkReal x3871=((IkReal(1.00000000000000))*(r01));
IkReal x3872=((sj0)*(sj5));
IkReal x3873=((cj6)*(r22));
IkReal x3874=((r21)*(sj6));
IkReal x3875=((r00)*(r21));
IkReal x3876=((cj0)*(sj5));
IkReal x3877=((cj6)*(r20));
IkReal x3878=((r22)*(sj6));
IkReal x3879=((cj0)*(cj5));
IkReal x3880=((IkReal(1.00000000000000))*(r10));
IkReal x3881=((cj5)*(sj0));
IkReal x3882=((r20)*(x3870));
IkReal x3883=((x3869)*(x3881));
dummyeval[0]=((((x3870)*(x3875)*(x3881)))+(((r11)*(x3879)*(x3882)))+(((IkReal(-1.00000000000000))*(x3873)*(x3876)*(x3880)))+(((IkReal(-1.00000000000000))*(r21)*(x3869)*(x3879)*(x3880)))+(((r00)*(x3872)*(x3873)))+(((IkReal(-1.00000000000000))*(x3871)*(x3872)*(x3878)))+(((r11)*(x3876)*(x3878)))+(((IkReal(-1.00000000000000))*(r02)*(x3872)*(x3877)))+(((IkReal(-1.00000000000000))*(r20)*(x3871)*(x3883)))+(((r12)*(x3876)*(x3877)))+(((IkReal(-1.00000000000000))*(r21)*(x3870)*(x3879)*(x3880)))+(((x3875)*(x3883)))+(((IkReal(-1.00000000000000))*(x3871)*(x3881)*(x3882)))+(((r11)*(r20)*(x3869)*(x3879)))+(((IkReal(-1.00000000000000))*(r12)*(x3874)*(x3876)))+(((r02)*(x3872)*(x3874))));
if( IKabs(dummyeval[0]) < 0.0000010000000000  )
{
continue;

} else
{
{
IkReal j4array[1], cj4array[1], sj4array[1];
bool j4valid[1]={false};
_nj4 = 1;
IkReal x3884=((r01)*(sj0));
IkReal x3885=((IkReal(1.00000000000000))*(cj5));
IkReal x3886=((cj0)*(r10));
IkReal x3887=((r00)*(sj0));
IkReal x3888=((cj0)*(r11));
if( IKabs(((gconst25)*(((((sj6)*(x3884)))+(((IkReal(-1.00000000000000))*(cj6)*(x3887)))+(((IkReal(-1.00000000000000))*(sj6)*(x3888)))+(((cj6)*(x3886))))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(((gconst25)*(((((cj5)*(cj6)*(x3888)))+(((IkReal(-1.00000000000000))*(cj6)*(x3884)*(x3885)))+(((IkReal(-1.00000000000000))*(sj6)*(x3885)*(x3887)))+(((cj0)*(r12)*(sj5)))+(((IkReal(-1.00000000000000))*(r02)*(sj0)*(sj5)))+(((cj5)*(sj6)*(x3886))))))) < IKFAST_ATAN2_MAGTHRESH )
    continue;
j4array[0]=IKatan2(((gconst25)*(((((sj6)*(x3884)))+(((IkReal(-1.00000000000000))*(cj6)*(x3887)))+(((IkReal(-1.00000000000000))*(sj6)*(x3888)))+(((cj6)*(x3886)))))), ((gconst25)*(((((cj5)*(cj6)*(x3888)))+(((IkReal(-1.00000000000000))*(cj6)*(x3884)*(x3885)))+(((IkReal(-1.00000000000000))*(sj6)*(x3885)*(x3887)))+(((cj0)*(r12)*(sj5)))+(((IkReal(-1.00000000000000))*(r02)*(sj0)*(sj5)))+(((cj5)*(sj6)*(x3886)))))));
sj4array[0]=IKsin(j4array[0]);
cj4array[0]=IKcos(j4array[0]);
if( j4array[0] > IKPI )
{
    j4array[0]-=IK2PI;
}
else if( j4array[0] < -IKPI )
{    j4array[0]+=IK2PI;
}
j4valid[0] = true;
for(int ij4 = 0; ij4 < 1; ++ij4)
{
if( !j4valid[ij4] )
{
    continue;
}
_ij4[0] = ij4; _ij4[1] = -1;
for(int iij4 = ij4+1; iij4 < 1; ++iij4)
{
if( j4valid[iij4] && IKabs(cj4array[ij4]-cj4array[iij4]) < IKFAST_SOLUTION_THRESH && IKabs(sj4array[ij4]-sj4array[iij4]) < IKFAST_SOLUTION_THRESH )
{
    j4valid[iij4]=false; _ij4[1] = iij4; break; 
}
}
j4 = j4array[ij4]; cj4 = cj4array[ij4]; sj4 = sj4array[ij4];
{
IkReal evalcond[6];
IkReal x3889=IKsin(j4);
IkReal x3890=IKcos(j4);
IkReal x3891=((r22)*(sj5));
IkReal x3892=((IkReal(1.00000000000000))*(cj6));
IkReal x3893=((IkReal(1.00000000000000))*(cj0));
IkReal x3894=((cj5)*(r11));
IkReal x3895=((cj5)*(cj6));
IkReal x3896=((r11)*(sj6));
IkReal x3897=((IkReal(1.00000000000000))*(sj6));
IkReal x3898=((cj6)*(r00));
IkReal x3899=((r12)*(sj5));
IkReal x3900=((r02)*(sj5));
IkReal x3901=((cj6)*(r10));
IkReal x3902=((cj5)*(sj6));
IkReal x3903=((cj5)*(r01));
IkReal x3904=((sj0)*(x3889));
IkReal x3905=((r00)*(x3902));
IkReal x3906=((cj0)*(x3889));
IkReal x3907=((sj0)*(x3890));
IkReal x3908=((r20)*(x3890));
IkReal x3909=((cj0)*(x3890));
IkReal x3910=((r21)*(x3889));
IkReal x3911=((r21)*(x3890));
IkReal x3912=((r20)*(x3889));
IkReal x3913=((x3890)*(x3899));
IkReal x3914=((r01)*(sj6)*(x3890));
IkReal x3915=((cj5)*(r10)*(x3897));
evalcond[0]=((IkReal(1.00000000000000))+(((x3902)*(x3912)))+(((IkReal(-1.00000000000000))*(x3892)*(x3908)))+(((x3889)*(x3891)))+(((x3895)*(x3910)))+(((sj6)*(x3911))));
evalcond[1]=((((x3890)*(x3891)))+(((x3902)*(x3908)))+(((x3895)*(x3911)))+(((cj6)*(x3912)))+(((IkReal(-1.00000000000000))*(x3897)*(x3910))));
evalcond[2]=((((IkReal(-1.00000000000000))*(x3890)*(x3893)*(x3896)))+(((x3904)*(x3905)))+(((x3900)*(x3904)))+(((IkReal(-1.00000000000000))*(r00)*(x3892)*(x3907)))+(((x3901)*(x3909)))+(((r01)*(sj6)*(x3907)))+(((IkReal(-1.00000000000000))*(x3889)*(x3893)*(x3899)))+(((r01)*(x3895)*(x3904)))+(((IkReal(-1.00000000000000))*(r10)*(x3889)*(x3893)*(x3902)))+(((IkReal(-1.00000000000000))*(x3892)*(x3894)*(x3906))));
evalcond[3]=((((IkReal(-1.00000000000000))*(r01)*(x3897)*(x3904)))+(((x3896)*(x3906)))+(((IkReal(-1.00000000000000))*(x3892)*(x3894)*(x3909)))+(((x3905)*(x3907)))+(((r01)*(x3895)*(x3907)))+(((IkReal(-1.00000000000000))*(r10)*(x3890)*(x3893)*(x3902)))+(cj3)+(((x3898)*(x3904)))+(((x3900)*(x3907)))+(((IkReal(-1.00000000000000))*(r10)*(x3892)*(x3906)))+(((IkReal(-1.00000000000000))*(x3893)*(x3913))));
evalcond[4]=((((IkReal(-1.00000000000000))*(x3889)*(x3893)*(x3905)))+(((IkReal(-1.00000000000000))*(x3892)*(x3903)*(x3906)))+(((IkReal(-1.00000000000000))*(x3896)*(x3907)))+(((IkReal(-1.00000000000000))*(x3904)*(x3915)))+(((IkReal(-1.00000000000000))*(x3893)*(x3914)))+(((x3901)*(x3907)))+(((IkReal(-1.00000000000000))*(x3889)*(x3893)*(x3900)))+(((IkReal(-1.00000000000000))*(x3899)*(x3904)))+(((x3898)*(x3909)))+(((IkReal(-1.00000000000000))*(x3892)*(x3894)*(x3904))));
evalcond[5]=((((IkReal(-1.00000000000000))*(r00)*(x3892)*(x3906)))+(((r01)*(sj6)*(x3906)))+(sj3)+(((IkReal(-1.00000000000000))*(x3892)*(x3903)*(x3909)))+(((IkReal(-1.00000000000000))*(x3890)*(x3893)*(x3900)))+(((IkReal(-1.00000000000000))*(x3892)*(x3894)*(x3907)))+(((IkReal(-1.00000000000000))*(x3899)*(x3907)))+(((x3896)*(x3904)))+(((IkReal(-1.00000000000000))*(r10)*(x3892)*(x3904)))+(((IkReal(-1.00000000000000))*(x3890)*(x3893)*(x3905)))+(((IkReal(-1.00000000000000))*(x3907)*(x3915))));
if( IKabs(evalcond[0]) > 0.000001  || IKabs(evalcond[1]) > 0.000001  || IKabs(evalcond[2]) > 0.000001  || IKabs(evalcond[3]) > 0.000001  || IKabs(evalcond[4]) > 0.000001  || IKabs(evalcond[5]) > 0.000001  )
{
continue;
}
}

{
std::vector<IkSingleDOFSolutionBase<IkReal> > vinfos(7);
vinfos[0].jointtype = 1;
vinfos[0].foffset = j0;
vinfos[0].indices[0] = _ij0[0];
vinfos[0].indices[1] = _ij0[1];
vinfos[0].maxsolutions = _nj0;
vinfos[1].jointtype = 1;
vinfos[1].foffset = j1;
vinfos[1].indices[0] = _ij1[0];
vinfos[1].indices[1] = _ij1[1];
vinfos[1].maxsolutions = _nj1;
vinfos[2].jointtype = 1;
vinfos[2].foffset = j2;
vinfos[2].indices[0] = _ij2[0];
vinfos[2].indices[1] = _ij2[1];
vinfos[2].maxsolutions = _nj2;
vinfos[3].jointtype = 1;
vinfos[3].foffset = j3;
vinfos[3].indices[0] = _ij3[0];
vinfos[3].indices[1] = _ij3[1];
vinfos[3].maxsolutions = _nj3;
vinfos[4].jointtype = 1;
vinfos[4].foffset = j4;
vinfos[4].indices[0] = _ij4[0];
vinfos[4].indices[1] = _ij4[1];
vinfos[4].maxsolutions = _nj4;
vinfos[5].jointtype = 1;
vinfos[5].foffset = j5;
vinfos[5].indices[0] = _ij5[0];
vinfos[5].indices[1] = _ij5[1];
vinfos[5].maxsolutions = _nj5;
vinfos[6].jointtype = 1;
vinfos[6].foffset = j6;
vinfos[6].indices[0] = _ij6[0];
vinfos[6].indices[1] = _ij6[1];
vinfos[6].maxsolutions = _nj6;
std::vector<int> vfree(0);
solutions.AddSolution(vinfos,vfree);
}
}
}

}

}

} else
{
{
IkReal j4array[1], cj4array[1], sj4array[1];
bool j4valid[1]={false};
_nj4 = 1;
if( IKabs(((gconst24)*(((((cj5)*(r20)*(sj6)))+(((r22)*(sj5)))+(((cj5)*(cj6)*(r21))))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(((gconst24)*(((((r21)*(sj6)))+(((IkReal(-1.00000000000000))*(cj6)*(r20))))))) < IKFAST_ATAN2_MAGTHRESH )
    continue;
j4array[0]=IKatan2(((gconst24)*(((((cj5)*(r20)*(sj6)))+(((r22)*(sj5)))+(((cj5)*(cj6)*(r21)))))), ((gconst24)*(((((r21)*(sj6)))+(((IkReal(-1.00000000000000))*(cj6)*(r20)))))));
sj4array[0]=IKsin(j4array[0]);
cj4array[0]=IKcos(j4array[0]);
if( j4array[0] > IKPI )
{
    j4array[0]-=IK2PI;
}
else if( j4array[0] < -IKPI )
{    j4array[0]+=IK2PI;
}
j4valid[0] = true;
for(int ij4 = 0; ij4 < 1; ++ij4)
{
if( !j4valid[ij4] )
{
    continue;
}
_ij4[0] = ij4; _ij4[1] = -1;
for(int iij4 = ij4+1; iij4 < 1; ++iij4)
{
if( j4valid[iij4] && IKabs(cj4array[ij4]-cj4array[iij4]) < IKFAST_SOLUTION_THRESH && IKabs(sj4array[ij4]-sj4array[iij4]) < IKFAST_SOLUTION_THRESH )
{
    j4valid[iij4]=false; _ij4[1] = iij4; break; 
}
}
j4 = j4array[ij4]; cj4 = cj4array[ij4]; sj4 = sj4array[ij4];
{
IkReal evalcond[6];
IkReal x3916=IKsin(j4);
IkReal x3917=IKcos(j4);
IkReal x3918=((r22)*(sj5));
IkReal x3919=((IkReal(1.00000000000000))*(cj6));
IkReal x3920=((IkReal(1.00000000000000))*(cj0));
IkReal x3921=((cj5)*(r11));
IkReal x3922=((cj5)*(cj6));
IkReal x3923=((r11)*(sj6));
IkReal x3924=((IkReal(1.00000000000000))*(sj6));
IkReal x3925=((cj6)*(r00));
IkReal x3926=((r12)*(sj5));
IkReal x3927=((r02)*(sj5));
IkReal x3928=((cj6)*(r10));
IkReal x3929=((cj5)*(sj6));
IkReal x3930=((cj5)*(r01));
IkReal x3931=((sj0)*(x3916));
IkReal x3932=((r00)*(x3929));
IkReal x3933=((cj0)*(x3916));
IkReal x3934=((sj0)*(x3917));
IkReal x3935=((r20)*(x3917));
IkReal x3936=((cj0)*(x3917));
IkReal x3937=((r21)*(x3916));
IkReal x3938=((r21)*(x3917));
IkReal x3939=((r20)*(x3916));
IkReal x3940=((x3917)*(x3926));
IkReal x3941=((r01)*(sj6)*(x3917));
IkReal x3942=((cj5)*(r10)*(x3924));
evalcond[0]=((IkReal(1.00000000000000))+(((x3929)*(x3939)))+(((x3922)*(x3937)))+(((sj6)*(x3938)))+(((x3916)*(x3918)))+(((IkReal(-1.00000000000000))*(x3919)*(x3935))));
evalcond[1]=((((x3917)*(x3918)))+(((x3922)*(x3938)))+(((x3929)*(x3935)))+(((cj6)*(x3939)))+(((IkReal(-1.00000000000000))*(x3924)*(x3937))));
evalcond[2]=((((IkReal(-1.00000000000000))*(x3916)*(x3920)*(x3926)))+(((IkReal(-1.00000000000000))*(r10)*(x3916)*(x3920)*(x3929)))+(((r01)*(x3922)*(x3931)))+(((r01)*(sj6)*(x3934)))+(((IkReal(-1.00000000000000))*(r00)*(x3919)*(x3934)))+(((IkReal(-1.00000000000000))*(x3917)*(x3920)*(x3923)))+(((x3931)*(x3932)))+(((IkReal(-1.00000000000000))*(x3919)*(x3921)*(x3933)))+(((x3928)*(x3936)))+(((x3927)*(x3931))));
evalcond[3]=((((x3925)*(x3931)))+(((x3923)*(x3933)))+(((x3932)*(x3934)))+(((IkReal(-1.00000000000000))*(r01)*(x3924)*(x3931)))+(((r01)*(x3922)*(x3934)))+(((IkReal(-1.00000000000000))*(r10)*(x3919)*(x3933)))+(cj3)+(((IkReal(-1.00000000000000))*(x3919)*(x3921)*(x3936)))+(((x3927)*(x3934)))+(((IkReal(-1.00000000000000))*(r10)*(x3917)*(x3920)*(x3929)))+(((IkReal(-1.00000000000000))*(x3920)*(x3940))));
evalcond[4]=((((IkReal(-1.00000000000000))*(x3920)*(x3941)))+(((IkReal(-1.00000000000000))*(x3923)*(x3934)))+(((IkReal(-1.00000000000000))*(x3916)*(x3920)*(x3932)))+(((IkReal(-1.00000000000000))*(x3919)*(x3930)*(x3933)))+(((x3925)*(x3936)))+(((IkReal(-1.00000000000000))*(x3919)*(x3921)*(x3931)))+(((IkReal(-1.00000000000000))*(x3926)*(x3931)))+(((IkReal(-1.00000000000000))*(x3916)*(x3920)*(x3927)))+(((x3928)*(x3934)))+(((IkReal(-1.00000000000000))*(x3931)*(x3942))));
evalcond[5]=((((IkReal(-1.00000000000000))*(x3917)*(x3920)*(x3927)))+(((IkReal(-1.00000000000000))*(x3917)*(x3920)*(x3932)))+(sj3)+(((IkReal(-1.00000000000000))*(x3934)*(x3942)))+(((r01)*(sj6)*(x3933)))+(((IkReal(-1.00000000000000))*(x3919)*(x3921)*(x3934)))+(((IkReal(-1.00000000000000))*(r10)*(x3919)*(x3931)))+(((IkReal(-1.00000000000000))*(x3926)*(x3934)))+(((x3923)*(x3931)))+(((IkReal(-1.00000000000000))*(r00)*(x3919)*(x3933)))+(((IkReal(-1.00000000000000))*(x3919)*(x3930)*(x3936))));
if( IKabs(evalcond[0]) > 0.000001  || IKabs(evalcond[1]) > 0.000001  || IKabs(evalcond[2]) > 0.000001  || IKabs(evalcond[3]) > 0.000001  || IKabs(evalcond[4]) > 0.000001  || IKabs(evalcond[5]) > 0.000001  )
{
continue;
}
}

{
std::vector<IkSingleDOFSolutionBase<IkReal> > vinfos(7);
vinfos[0].jointtype = 1;
vinfos[0].foffset = j0;
vinfos[0].indices[0] = _ij0[0];
vinfos[0].indices[1] = _ij0[1];
vinfos[0].maxsolutions = _nj0;
vinfos[1].jointtype = 1;
vinfos[1].foffset = j1;
vinfos[1].indices[0] = _ij1[0];
vinfos[1].indices[1] = _ij1[1];
vinfos[1].maxsolutions = _nj1;
vinfos[2].jointtype = 1;
vinfos[2].foffset = j2;
vinfos[2].indices[0] = _ij2[0];
vinfos[2].indices[1] = _ij2[1];
vinfos[2].maxsolutions = _nj2;
vinfos[3].jointtype = 1;
vinfos[3].foffset = j3;
vinfos[3].indices[0] = _ij3[0];
vinfos[3].indices[1] = _ij3[1];
vinfos[3].maxsolutions = _nj3;
vinfos[4].jointtype = 1;
vinfos[4].foffset = j4;
vinfos[4].indices[0] = _ij4[0];
vinfos[4].indices[1] = _ij4[1];
vinfos[4].maxsolutions = _nj4;
vinfos[5].jointtype = 1;
vinfos[5].foffset = j5;
vinfos[5].indices[0] = _ij5[0];
vinfos[5].indices[1] = _ij5[1];
vinfos[5].maxsolutions = _nj5;
vinfos[6].jointtype = 1;
vinfos[6].foffset = j6;
vinfos[6].indices[0] = _ij6[0];
vinfos[6].indices[1] = _ij6[1];
vinfos[6].maxsolutions = _nj6;
std::vector<int> vfree(0);
solutions.AddSolution(vinfos,vfree);
}
}
}

}

}
}
}

} else
{
if( 1 )
{
continue;

} else
{
}
}
}
}

} else
{
{
IkReal j3array[1], cj3array[1], sj3array[1];
bool j3valid[1]={false};
_nj3 = 1;
IkReal x3943=((sj5)*(sj6));
IkReal x3944=((cj6)*(sj5));
IkReal x3945=((IkReal(1.00000000000000))*(cj0));
IkReal x3946=((IkReal(1.00000000000000))*(cj5));
if( IKabs(((((r00)*(sj0)*(x3943)))+(((IkReal(-1.00000000000000))*(r10)*(x3943)*(x3945)))+(((r01)*(sj0)*(x3944)))+(((cj0)*(cj5)*(r12)))+(((IkReal(-1.00000000000000))*(r11)*(x3944)*(x3945)))+(((IkReal(-1.00000000000000))*(r02)*(sj0)*(x3946))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(((((IKabs(sj1) != 0)?((IkReal)1/(sj1)):(IkReal)1.0e30))*(((((r20)*(x3943)))+(((IkReal(-1.00000000000000))*(r22)*(x3946)))+(((r21)*(x3944))))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(IKsqr(((((r00)*(sj0)*(x3943)))+(((IkReal(-1.00000000000000))*(r10)*(x3943)*(x3945)))+(((r01)*(sj0)*(x3944)))+(((cj0)*(cj5)*(r12)))+(((IkReal(-1.00000000000000))*(r11)*(x3944)*(x3945)))+(((IkReal(-1.00000000000000))*(r02)*(sj0)*(x3946)))))+IKsqr(((((IKabs(sj1) != 0)?((IkReal)1/(sj1)):(IkReal)1.0e30))*(((((r20)*(x3943)))+(((IkReal(-1.00000000000000))*(r22)*(x3946)))+(((r21)*(x3944)))))))-1) <= IKFAST_SINCOS_THRESH )
    continue;
j3array[0]=IKatan2(((((r00)*(sj0)*(x3943)))+(((IkReal(-1.00000000000000))*(r10)*(x3943)*(x3945)))+(((r01)*(sj0)*(x3944)))+(((cj0)*(cj5)*(r12)))+(((IkReal(-1.00000000000000))*(r11)*(x3944)*(x3945)))+(((IkReal(-1.00000000000000))*(r02)*(sj0)*(x3946)))), ((((IKabs(sj1) != 0)?((IkReal)1/(sj1)):(IkReal)1.0e30))*(((((r20)*(x3943)))+(((IkReal(-1.00000000000000))*(r22)*(x3946)))+(((r21)*(x3944)))))));
sj3array[0]=IKsin(j3array[0]);
cj3array[0]=IKcos(j3array[0]);
if( j3array[0] > IKPI )
{
    j3array[0]-=IK2PI;
}
else if( j3array[0] < -IKPI )
{    j3array[0]+=IK2PI;
}
j3valid[0] = true;
for(int ij3 = 0; ij3 < 1; ++ij3)
{
if( !j3valid[ij3] )
{
    continue;
}
_ij3[0] = ij3; _ij3[1] = -1;
for(int iij3 = ij3+1; iij3 < 1; ++iij3)
{
if( j3valid[iij3] && IKabs(cj3array[ij3]-cj3array[iij3]) < IKFAST_SOLUTION_THRESH && IKabs(sj3array[ij3]-sj3array[iij3]) < IKFAST_SOLUTION_THRESH )
{
    j3valid[iij3]=false; _ij3[1] = iij3; break; 
}
}
j3 = j3array[ij3]; cj3 = cj3array[ij3]; sj3 = sj3array[ij3];
{
IkReal evalcond[3];
IkReal x3947=IKcos(j3);
IkReal x3948=((sj5)*(sj6));
IkReal x3949=((cj0)*(cj5));
IkReal x3950=((IkReal(1.00000000000000))*(cj0));
IkReal x3951=((IkReal(1.00000000000000))*(sj0));
IkReal x3952=((IkReal(1.00000000000000))*(x3947));
IkReal x3953=((cj6)*(r01)*(sj5));
IkReal x3954=((cj6)*(r11)*(sj5));
evalcond[0]=((((cj6)*(r21)*(sj5)))+(((r20)*(x3948)))+(((IkReal(-1.00000000000000))*(cj5)*(r22)))+(((IkReal(-1.00000000000000))*(sj1)*(x3952))));
evalcond[1]=((((IkReal(-1.00000000000000))*(cj5)*(r02)*(x3951)))+(((r12)*(x3949)))+(((IkReal(-1.00000000000000))*(r10)*(x3948)*(x3950)))+(((sj0)*(x3953)))+(((r00)*(sj0)*(x3948)))+(((IkReal(-1.00000000000000))*(IKsin(j3))))+(((IkReal(-1.00000000000000))*(x3950)*(x3954))));
evalcond[2]=((((IkReal(-1.00000000000000))*(x3951)*(x3954)))+(((cj5)*(r12)*(sj0)))+(((IkReal(-1.00000000000000))*(r10)*(x3948)*(x3951)))+(((IkReal(-1.00000000000000))*(x3950)*(x3953)))+(((r02)*(x3949)))+(((IkReal(-1.00000000000000))*(r00)*(x3948)*(x3950)))+(((IkReal(-1.00000000000000))*(cj1)*(x3952))));
if( IKabs(evalcond[0]) > 0.000001  || IKabs(evalcond[1]) > 0.000001  || IKabs(evalcond[2]) > 0.000001  )
{
continue;
}
}

{
IkReal dummyeval[1];
IkReal gconst15;
IkReal x3955=(r21)*(r21);
IkReal x3956=(cj5)*(cj5);
IkReal x3957=(sj6)*(sj6);
IkReal x3958=(cj6)*(cj6);
IkReal x3959=(r20)*(r20);
IkReal x3960=((cj6)*(r21));
IkReal x3961=((IkReal(2.00000000000000))*(r20)*(sj6));
IkReal x3962=((cj5)*(r22)*(sj5));
IkReal x3963=((IkReal(1.00000000000000))*(x3957));
IkReal x3964=((IkReal(1.00000000000000))*(x3958));
gconst15=IKsign(((((IkReal(-1.00000000000000))*(x3959)*(x3964)))+(((IkReal(-2.00000000000000))*(x3960)*(x3962)))+(((IkReal(-1.00000000000000))*(x3955)*(x3963)))+(((IkReal(-1.00000000000000))*(x3961)*(x3962)))+(((IkReal(-1.00000000000000))*(x3956)*(x3959)*(x3963)))+(((IkReal(-1.00000000000000))*((r22)*(r22))*((sj5)*(sj5))))+(((x3960)*(x3961)))+(((IkReal(-1.00000000000000))*(x3956)*(x3960)*(x3961)))+(((IkReal(-1.00000000000000))*(x3955)*(x3956)*(x3964)))));
IkReal x3965=(r21)*(r21);
IkReal x3966=(cj5)*(cj5);
IkReal x3967=(sj6)*(sj6);
IkReal x3968=(cj6)*(cj6);
IkReal x3969=(r20)*(r20);
IkReal x3970=((cj6)*(r21));
IkReal x3971=((IkReal(2.00000000000000))*(r20)*(sj6));
IkReal x3972=((cj5)*(r22)*(sj5));
IkReal x3973=((IkReal(1.00000000000000))*(x3967));
IkReal x3974=((IkReal(1.00000000000000))*(x3968));
dummyeval[0]=((((IkReal(-1.00000000000000))*((r22)*(r22))*((sj5)*(sj5))))+(((x3970)*(x3971)))+(((IkReal(-1.00000000000000))*(x3966)*(x3970)*(x3971)))+(((IkReal(-1.00000000000000))*(x3966)*(x3969)*(x3973)))+(((IkReal(-1.00000000000000))*(x3971)*(x3972)))+(((IkReal(-2.00000000000000))*(x3970)*(x3972)))+(((IkReal(-1.00000000000000))*(x3965)*(x3973)))+(((IkReal(-1.00000000000000))*(x3965)*(x3966)*(x3974)))+(((IkReal(-1.00000000000000))*(x3969)*(x3974))));
if( IKabs(dummyeval[0]) < 0.0000010000000000  )
{
{
IkReal dummyeval[1];
IkReal gconst16;
IkReal x3975=(cj6)*(cj6);
IkReal x3976=(sj6)*(sj6);
IkReal x3977=((IkReal(1.00000000000000))*(r21));
IkReal x3978=((cj6)*(r20));
IkReal x3979=((r22)*(sj5));
IkReal x3980=((r01)*(sj0));
IkReal x3981=((r00)*(sj0));
IkReal x3982=((cj0)*(r10));
IkReal x3983=((r02)*(sj0)*(sj5));
IkReal x3984=((cj5)*(x3975));
IkReal x3985=((cj0)*(r12)*(sj5));
IkReal x3986=((IkReal(1.00000000000000))*(cj0)*(r11));
IkReal x3987=((cj5)*(x3976));
IkReal x3988=((r20)*(x3987));
gconst16=IKsign(((((x3978)*(x3983)))+(((IkReal(-1.00000000000000))*(x3977)*(x3981)*(x3987)))+(((IkReal(-1.00000000000000))*(sj6)*(x3977)*(x3983)))+(((r21)*(sj6)*(x3985)))+(((r21)*(x3982)*(x3984)))+(((r21)*(x3982)*(x3987)))+(((IkReal(-1.00000000000000))*(x3986)*(x3988)))+(((IkReal(-1.00000000000000))*(x3977)*(x3981)*(x3984)))+(((IkReal(-1.00000000000000))*(x3978)*(x3985)))+(((IkReal(-1.00000000000000))*(sj6)*(x3979)*(x3986)))+(((cj6)*(x3979)*(x3982)))+(((sj6)*(x3979)*(x3980)))+(((x3980)*(x3988)))+(((IkReal(-1.00000000000000))*(cj6)*(x3979)*(x3981)))+(((r20)*(x3980)*(x3984)))+(((IkReal(-1.00000000000000))*(r20)*(x3984)*(x3986)))));
IkReal x3989=(cj6)*(cj6);
IkReal x3990=(sj6)*(sj6);
IkReal x3991=((IkReal(1.00000000000000))*(r21));
IkReal x3992=((cj6)*(r20));
IkReal x3993=((r22)*(sj5));
IkReal x3994=((r01)*(sj0));
IkReal x3995=((r00)*(sj0));
IkReal x3996=((cj0)*(r10));
IkReal x3997=((r02)*(sj0)*(sj5));
IkReal x3998=((cj5)*(x3989));
IkReal x3999=((cj0)*(r12)*(sj5));
IkReal x4000=((IkReal(1.00000000000000))*(cj0)*(r11));
IkReal x4001=((cj5)*(x3990));
IkReal x4002=((r20)*(x4001));
dummyeval[0]=((((IkReal(-1.00000000000000))*(cj6)*(x3993)*(x3995)))+(((IkReal(-1.00000000000000))*(x3992)*(x3999)))+(((sj6)*(x3993)*(x3994)))+(((r21)*(x3996)*(x3998)))+(((IkReal(-1.00000000000000))*(x4000)*(x4002)))+(((r21)*(x3996)*(x4001)))+(((r20)*(x3994)*(x3998)))+(((IkReal(-1.00000000000000))*(sj6)*(x3991)*(x3997)))+(((cj6)*(x3993)*(x3996)))+(((IkReal(-1.00000000000000))*(r20)*(x3998)*(x4000)))+(((IkReal(-1.00000000000000))*(sj6)*(x3993)*(x4000)))+(((IkReal(-1.00000000000000))*(x3991)*(x3995)*(x4001)))+(((x3994)*(x4002)))+(((r21)*(sj6)*(x3999)))+(((x3992)*(x3997)))+(((IkReal(-1.00000000000000))*(x3991)*(x3995)*(x3998))));
if( IKabs(dummyeval[0]) < 0.0000010000000000  )
{
continue;

} else
{
{
IkReal j4array[1], cj4array[1], sj4array[1];
bool j4valid[1]={false};
_nj4 = 1;
IkReal x4003=((cj1)*(sj6));
IkReal x4004=((r01)*(sj0));
IkReal x4005=((cj0)*(r11));
IkReal x4006=((cj1)*(cj6));
IkReal x4007=((cj0)*(r10));
IkReal x4008=((IkReal(1.00000000000000))*(sj0));
IkReal x4009=((cj1)*(sj5));
if( IKabs(((gconst16)*(((((IkReal(-1.00000000000000))*(r00)*(x4006)*(x4008)))+(((x4006)*(x4007)))+(((IkReal(-1.00000000000000))*(x4003)*(x4005)))+(((x4003)*(x4004))))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(((gconst16)*(((((IkReal(-1.00000000000000))*(cj5)*(x4004)*(x4006)))+(((cj0)*(r12)*(x4009)))+(((IkReal(-1.00000000000000))*(r02)*(x4008)*(x4009)))+(((IkReal(-1.00000000000000))*(cj5)*(r00)*(x4003)*(x4008)))+(((cj5)*(x4003)*(x4007)))+(((cj5)*(x4005)*(x4006))))))) < IKFAST_ATAN2_MAGTHRESH )
    continue;
j4array[0]=IKatan2(((gconst16)*(((((IkReal(-1.00000000000000))*(r00)*(x4006)*(x4008)))+(((x4006)*(x4007)))+(((IkReal(-1.00000000000000))*(x4003)*(x4005)))+(((x4003)*(x4004)))))), ((gconst16)*(((((IkReal(-1.00000000000000))*(cj5)*(x4004)*(x4006)))+(((cj0)*(r12)*(x4009)))+(((IkReal(-1.00000000000000))*(r02)*(x4008)*(x4009)))+(((IkReal(-1.00000000000000))*(cj5)*(r00)*(x4003)*(x4008)))+(((cj5)*(x4003)*(x4007)))+(((cj5)*(x4005)*(x4006)))))));
sj4array[0]=IKsin(j4array[0]);
cj4array[0]=IKcos(j4array[0]);
if( j4array[0] > IKPI )
{
    j4array[0]-=IK2PI;
}
else if( j4array[0] < -IKPI )
{    j4array[0]+=IK2PI;
}
j4valid[0] = true;
for(int ij4 = 0; ij4 < 1; ++ij4)
{
if( !j4valid[ij4] )
{
    continue;
}
_ij4[0] = ij4; _ij4[1] = -1;
for(int iij4 = ij4+1; iij4 < 1; ++iij4)
{
if( j4valid[iij4] && IKabs(cj4array[ij4]-cj4array[iij4]) < IKFAST_SOLUTION_THRESH && IKabs(sj4array[ij4]-sj4array[iij4]) < IKFAST_SOLUTION_THRESH )
{
    j4valid[iij4]=false; _ij4[1] = iij4; break; 
}
}
j4 = j4array[ij4]; cj4 = cj4array[ij4]; sj4 = sj4array[ij4];
{
IkReal evalcond[6];
IkReal x4010=IKsin(j4);
IkReal x4011=IKcos(j4);
IkReal x4012=((r22)*(sj5));
IkReal x4013=((IkReal(1.00000000000000))*(cj6));
IkReal x4014=((IkReal(1.00000000000000))*(cj0));
IkReal x4015=((cj5)*(r11));
IkReal x4016=((cj5)*(cj6));
IkReal x4017=((IkReal(1.00000000000000))*(sj3));
IkReal x4018=((r11)*(sj6));
IkReal x4019=((IkReal(1.00000000000000))*(sj6));
IkReal x4020=((cj6)*(r00));
IkReal x4021=((r12)*(sj5));
IkReal x4022=((r02)*(sj5));
IkReal x4023=((cj6)*(r10));
IkReal x4024=((cj5)*(sj6));
IkReal x4025=((cj5)*(r01));
IkReal x4026=((sj0)*(x4010));
IkReal x4027=((r00)*(x4024));
IkReal x4028=((cj0)*(x4010));
IkReal x4029=((sj0)*(x4011));
IkReal x4030=((r20)*(x4011));
IkReal x4031=((cj0)*(x4011));
IkReal x4032=((r21)*(x4010));
IkReal x4033=((r21)*(x4011));
IkReal x4034=((r20)*(x4010));
IkReal x4035=((x4011)*(x4021));
IkReal x4036=((r01)*(sj6)*(x4011));
IkReal x4037=((cj5)*(r10)*(x4019));
evalcond[0]=((((IkReal(-1.00000000000000))*(x4013)*(x4030)))+(((IkReal(-1.00000000000000))*(cj1)))+(((x4024)*(x4034)))+(((sj6)*(x4033)))+(((x4010)*(x4012)))+(((x4016)*(x4032))));
evalcond[1]=((((IkReal(-1.00000000000000))*(sj1)*(x4017)))+(((x4024)*(x4030)))+(((x4016)*(x4033)))+(((cj6)*(x4034)))+(((IkReal(-1.00000000000000))*(x4019)*(x4032)))+(((x4011)*(x4012))));
evalcond[2]=((((IkReal(-1.00000000000000))*(r00)*(x4013)*(x4029)))+(((r01)*(sj6)*(x4029)))+(((x4023)*(x4031)))+(((IkReal(-1.00000000000000))*(x4011)*(x4014)*(x4018)))+(((x4026)*(x4027)))+(((r01)*(x4016)*(x4026)))+(((IkReal(-1.00000000000000))*(x4010)*(x4014)*(x4021)))+(((IkReal(-1.00000000000000))*(x4013)*(x4015)*(x4028)))+(((IkReal(-1.00000000000000))*(r10)*(x4010)*(x4014)*(x4024)))+(((x4022)*(x4026))));
evalcond[3]=((((x4020)*(x4026)))+(((x4018)*(x4028)))+(((x4027)*(x4029)))+(((IkReal(-1.00000000000000))*(x4014)*(x4035)))+(((IkReal(-1.00000000000000))*(x4013)*(x4015)*(x4031)))+(cj3)+(((IkReal(-1.00000000000000))*(r10)*(x4013)*(x4028)))+(((x4022)*(x4029)))+(((r01)*(x4016)*(x4029)))+(((IkReal(-1.00000000000000))*(r10)*(x4011)*(x4014)*(x4024)))+(((IkReal(-1.00000000000000))*(r01)*(x4019)*(x4026))));
evalcond[4]=((((IkReal(-1.00000000000000))*(x4010)*(x4014)*(x4022)))+(((IkReal(-1.00000000000000))*(x4014)*(x4036)))+(((IkReal(-1.00000000000000))*(x4021)*(x4026)))+(((IkReal(-1.00000000000000))*(x4010)*(x4014)*(x4027)))+(sj1)+(((IkReal(-1.00000000000000))*(x4013)*(x4015)*(x4026)))+(((x4023)*(x4029)))+(((IkReal(-1.00000000000000))*(x4026)*(x4037)))+(((x4020)*(x4031)))+(((IkReal(-1.00000000000000))*(x4018)*(x4029)))+(((IkReal(-1.00000000000000))*(x4013)*(x4025)*(x4028))));
evalcond[5]=((((IkReal(-1.00000000000000))*(r10)*(x4013)*(x4026)))+(((IkReal(-1.00000000000000))*(r00)*(x4013)*(x4028)))+(((IkReal(-1.00000000000000))*(x4013)*(x4025)*(x4031)))+(((IkReal(-1.00000000000000))*(x4011)*(x4014)*(x4022)))+(((IkReal(-1.00000000000000))*(x4011)*(x4014)*(x4027)))+(((IkReal(-1.00000000000000))*(cj1)*(x4017)))+(((IkReal(-1.00000000000000))*(x4029)*(x4037)))+(((x4018)*(x4026)))+(((r01)*(sj6)*(x4028)))+(((IkReal(-1.00000000000000))*(x4021)*(x4029)))+(((IkReal(-1.00000000000000))*(x4013)*(x4015)*(x4029))));
if( IKabs(evalcond[0]) > 0.000001  || IKabs(evalcond[1]) > 0.000001  || IKabs(evalcond[2]) > 0.000001  || IKabs(evalcond[3]) > 0.000001  || IKabs(evalcond[4]) > 0.000001  || IKabs(evalcond[5]) > 0.000001  )
{
continue;
}
}

{
std::vector<IkSingleDOFSolutionBase<IkReal> > vinfos(7);
vinfos[0].jointtype = 1;
vinfos[0].foffset = j0;
vinfos[0].indices[0] = _ij0[0];
vinfos[0].indices[1] = _ij0[1];
vinfos[0].maxsolutions = _nj0;
vinfos[1].jointtype = 1;
vinfos[1].foffset = j1;
vinfos[1].indices[0] = _ij1[0];
vinfos[1].indices[1] = _ij1[1];
vinfos[1].maxsolutions = _nj1;
vinfos[2].jointtype = 1;
vinfos[2].foffset = j2;
vinfos[2].indices[0] = _ij2[0];
vinfos[2].indices[1] = _ij2[1];
vinfos[2].maxsolutions = _nj2;
vinfos[3].jointtype = 1;
vinfos[3].foffset = j3;
vinfos[3].indices[0] = _ij3[0];
vinfos[3].indices[1] = _ij3[1];
vinfos[3].maxsolutions = _nj3;
vinfos[4].jointtype = 1;
vinfos[4].foffset = j4;
vinfos[4].indices[0] = _ij4[0];
vinfos[4].indices[1] = _ij4[1];
vinfos[4].maxsolutions = _nj4;
vinfos[5].jointtype = 1;
vinfos[5].foffset = j5;
vinfos[5].indices[0] = _ij5[0];
vinfos[5].indices[1] = _ij5[1];
vinfos[5].maxsolutions = _nj5;
vinfos[6].jointtype = 1;
vinfos[6].foffset = j6;
vinfos[6].indices[0] = _ij6[0];
vinfos[6].indices[1] = _ij6[1];
vinfos[6].maxsolutions = _nj6;
std::vector<int> vfree(0);
solutions.AddSolution(vinfos,vfree);
}
}
}

}

}

} else
{
{
IkReal j4array[1], cj4array[1], sj4array[1];
bool j4valid[1]={false};
_nj4 = 1;
IkReal x4038=((IkReal(1.00000000000000))*(cj1));
IkReal x4039=((sj1)*(sj3));
IkReal x4040=((r21)*(sj6));
IkReal x4041=((r22)*(sj5));
IkReal x4042=((cj6)*(r20));
IkReal x4043=((cj5)*(r20)*(sj6));
IkReal x4044=((cj5)*(cj6)*(r21));
if( IKabs(((gconst15)*(((((IkReal(-1.00000000000000))*(x4038)*(x4041)))+(((IkReal(-1.00000000000000))*(x4038)*(x4043)))+(((x4039)*(x4040)))+(((IkReal(-1.00000000000000))*(x4038)*(x4044)))+(((IkReal(-1.00000000000000))*(x4039)*(x4042))))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(((gconst15)*(((((cj1)*(x4042)))+(((IkReal(-1.00000000000000))*(x4038)*(x4040)))+(((IkReal(-1.00000000000000))*(x4039)*(x4041)))+(((IkReal(-1.00000000000000))*(x4039)*(x4044)))+(((IkReal(-1.00000000000000))*(x4039)*(x4043))))))) < IKFAST_ATAN2_MAGTHRESH )
    continue;
j4array[0]=IKatan2(((gconst15)*(((((IkReal(-1.00000000000000))*(x4038)*(x4041)))+(((IkReal(-1.00000000000000))*(x4038)*(x4043)))+(((x4039)*(x4040)))+(((IkReal(-1.00000000000000))*(x4038)*(x4044)))+(((IkReal(-1.00000000000000))*(x4039)*(x4042)))))), ((gconst15)*(((((cj1)*(x4042)))+(((IkReal(-1.00000000000000))*(x4038)*(x4040)))+(((IkReal(-1.00000000000000))*(x4039)*(x4041)))+(((IkReal(-1.00000000000000))*(x4039)*(x4044)))+(((IkReal(-1.00000000000000))*(x4039)*(x4043)))))));
sj4array[0]=IKsin(j4array[0]);
cj4array[0]=IKcos(j4array[0]);
if( j4array[0] > IKPI )
{
    j4array[0]-=IK2PI;
}
else if( j4array[0] < -IKPI )
{    j4array[0]+=IK2PI;
}
j4valid[0] = true;
for(int ij4 = 0; ij4 < 1; ++ij4)
{
if( !j4valid[ij4] )
{
    continue;
}
_ij4[0] = ij4; _ij4[1] = -1;
for(int iij4 = ij4+1; iij4 < 1; ++iij4)
{
if( j4valid[iij4] && IKabs(cj4array[ij4]-cj4array[iij4]) < IKFAST_SOLUTION_THRESH && IKabs(sj4array[ij4]-sj4array[iij4]) < IKFAST_SOLUTION_THRESH )
{
    j4valid[iij4]=false; _ij4[1] = iij4; break; 
}
}
j4 = j4array[ij4]; cj4 = cj4array[ij4]; sj4 = sj4array[ij4];
{
IkReal evalcond[6];
IkReal x4045=IKsin(j4);
IkReal x4046=IKcos(j4);
IkReal x4047=((r22)*(sj5));
IkReal x4048=((IkReal(1.00000000000000))*(cj6));
IkReal x4049=((IkReal(1.00000000000000))*(cj0));
IkReal x4050=((cj5)*(r11));
IkReal x4051=((cj5)*(cj6));
IkReal x4052=((IkReal(1.00000000000000))*(sj3));
IkReal x4053=((r11)*(sj6));
IkReal x4054=((IkReal(1.00000000000000))*(sj6));
IkReal x4055=((cj6)*(r00));
IkReal x4056=((r12)*(sj5));
IkReal x4057=((r02)*(sj5));
IkReal x4058=((cj6)*(r10));
IkReal x4059=((cj5)*(sj6));
IkReal x4060=((cj5)*(r01));
IkReal x4061=((sj0)*(x4045));
IkReal x4062=((r00)*(x4059));
IkReal x4063=((cj0)*(x4045));
IkReal x4064=((sj0)*(x4046));
IkReal x4065=((r20)*(x4046));
IkReal x4066=((cj0)*(x4046));
IkReal x4067=((r21)*(x4045));
IkReal x4068=((r21)*(x4046));
IkReal x4069=((r20)*(x4045));
IkReal x4070=((x4046)*(x4056));
IkReal x4071=((r01)*(sj6)*(x4046));
IkReal x4072=((cj5)*(r10)*(x4054));
evalcond[0]=((((x4051)*(x4067)))+(((sj6)*(x4068)))+(((x4045)*(x4047)))+(((IkReal(-1.00000000000000))*(cj1)))+(((x4059)*(x4069)))+(((IkReal(-1.00000000000000))*(x4048)*(x4065))));
evalcond[1]=((((x4059)*(x4065)))+(((IkReal(-1.00000000000000))*(x4054)*(x4067)))+(((IkReal(-1.00000000000000))*(sj1)*(x4052)))+(((cj6)*(x4069)))+(((x4051)*(x4068)))+(((x4046)*(x4047))));
evalcond[2]=((((x4057)*(x4061)))+(((x4061)*(x4062)))+(((IkReal(-1.00000000000000))*(x4046)*(x4049)*(x4053)))+(((r01)*(x4051)*(x4061)))+(((r01)*(sj6)*(x4064)))+(((IkReal(-1.00000000000000))*(r00)*(x4048)*(x4064)))+(((IkReal(-1.00000000000000))*(x4048)*(x4050)*(x4063)))+(((IkReal(-1.00000000000000))*(r10)*(x4045)*(x4049)*(x4059)))+(((IkReal(-1.00000000000000))*(x4045)*(x4049)*(x4056)))+(((x4058)*(x4066))));
evalcond[3]=((((IkReal(-1.00000000000000))*(r10)*(x4048)*(x4063)))+(((x4053)*(x4063)))+(((x4055)*(x4061)))+(((x4057)*(x4064)))+(((IkReal(-1.00000000000000))*(x4048)*(x4050)*(x4066)))+(cj3)+(((r01)*(x4051)*(x4064)))+(((x4062)*(x4064)))+(((IkReal(-1.00000000000000))*(r01)*(x4054)*(x4061)))+(((IkReal(-1.00000000000000))*(r10)*(x4046)*(x4049)*(x4059)))+(((IkReal(-1.00000000000000))*(x4049)*(x4070))));
evalcond[4]=((sj1)+(((IkReal(-1.00000000000000))*(x4048)*(x4050)*(x4061)))+(((IkReal(-1.00000000000000))*(x4056)*(x4061)))+(((IkReal(-1.00000000000000))*(x4061)*(x4072)))+(((IkReal(-1.00000000000000))*(x4045)*(x4049)*(x4062)))+(((x4055)*(x4066)))+(((IkReal(-1.00000000000000))*(x4048)*(x4060)*(x4063)))+(((x4058)*(x4064)))+(((IkReal(-1.00000000000000))*(x4045)*(x4049)*(x4057)))+(((IkReal(-1.00000000000000))*(x4049)*(x4071)))+(((IkReal(-1.00000000000000))*(x4053)*(x4064))));
evalcond[5]=((((IkReal(-1.00000000000000))*(cj1)*(x4052)))+(((IkReal(-1.00000000000000))*(x4048)*(x4050)*(x4064)))+(((IkReal(-1.00000000000000))*(x4048)*(x4060)*(x4066)))+(((IkReal(-1.00000000000000))*(x4046)*(x4049)*(x4057)))+(((IkReal(-1.00000000000000))*(r10)*(x4048)*(x4061)))+(((IkReal(-1.00000000000000))*(x4064)*(x4072)))+(((x4053)*(x4061)))+(((IkReal(-1.00000000000000))*(x4056)*(x4064)))+(((IkReal(-1.00000000000000))*(x4046)*(x4049)*(x4062)))+(((IkReal(-1.00000000000000))*(r00)*(x4048)*(x4063)))+(((r01)*(sj6)*(x4063))));
if( IKabs(evalcond[0]) > 0.000001  || IKabs(evalcond[1]) > 0.000001  || IKabs(evalcond[2]) > 0.000001  || IKabs(evalcond[3]) > 0.000001  || IKabs(evalcond[4]) > 0.000001  || IKabs(evalcond[5]) > 0.000001  )
{
continue;
}
}

{
std::vector<IkSingleDOFSolutionBase<IkReal> > vinfos(7);
vinfos[0].jointtype = 1;
vinfos[0].foffset = j0;
vinfos[0].indices[0] = _ij0[0];
vinfos[0].indices[1] = _ij0[1];
vinfos[0].maxsolutions = _nj0;
vinfos[1].jointtype = 1;
vinfos[1].foffset = j1;
vinfos[1].indices[0] = _ij1[0];
vinfos[1].indices[1] = _ij1[1];
vinfos[1].maxsolutions = _nj1;
vinfos[2].jointtype = 1;
vinfos[2].foffset = j2;
vinfos[2].indices[0] = _ij2[0];
vinfos[2].indices[1] = _ij2[1];
vinfos[2].maxsolutions = _nj2;
vinfos[3].jointtype = 1;
vinfos[3].foffset = j3;
vinfos[3].indices[0] = _ij3[0];
vinfos[3].indices[1] = _ij3[1];
vinfos[3].maxsolutions = _nj3;
vinfos[4].jointtype = 1;
vinfos[4].foffset = j4;
vinfos[4].indices[0] = _ij4[0];
vinfos[4].indices[1] = _ij4[1];
vinfos[4].maxsolutions = _nj4;
vinfos[5].jointtype = 1;
vinfos[5].foffset = j5;
vinfos[5].indices[0] = _ij5[0];
vinfos[5].indices[1] = _ij5[1];
vinfos[5].maxsolutions = _nj5;
vinfos[6].jointtype = 1;
vinfos[6].foffset = j6;
vinfos[6].indices[0] = _ij6[0];
vinfos[6].indices[1] = _ij6[1];
vinfos[6].maxsolutions = _nj6;
std::vector<int> vfree(0);
solutions.AddSolution(vinfos,vfree);
}
}
}

}

}
}
}

}

}

} else
{
{
IkReal j4array[1], cj4array[1], sj4array[1];
bool j4valid[1]={false};
_nj4 = 1;
IkReal x4073=((sj0)*(sj6));
IkReal x4074=((cj0)*(cj6));
IkReal x4075=((cj0)*(sj6));
IkReal x4076=((IkReal(1.00000000000000))*(cj1));
IkReal x4077=((r20)*(sj1));
IkReal x4078=((cj6)*(sj0));
IkReal x4079=((r21)*(sj1));
IkReal x4080=((cj5)*(x4076));
if( IKabs(((gconst14)*(((((IkReal(-1.00000000000000))*(sj6)*(x4079)))+(((cj6)*(x4077)))+(((cj1)*(r11)*(x4073)))+(((cj1)*(r01)*(x4075)))+(((IkReal(-1.00000000000000))*(r10)*(x4076)*(x4078)))+(((IkReal(-1.00000000000000))*(r00)*(x4074)*(x4076))))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(((gconst14)*(((((IkReal(-1.00000000000000))*(r11)*(x4078)*(x4080)))+(((IkReal(-1.00000000000000))*(r00)*(x4075)*(x4080)))+(((IkReal(-1.00000000000000))*(r12)*(sj0)*(sj5)*(x4076)))+(((cj5)*(sj6)*(x4077)))+(((IkReal(-1.00000000000000))*(r01)*(x4074)*(x4080)))+(((IkReal(-1.00000000000000))*(cj0)*(r02)*(sj5)*(x4076)))+(((IkReal(-1.00000000000000))*(r10)*(x4073)*(x4080)))+(((cj5)*(cj6)*(x4079)))+(((r22)*(sj1)*(sj5))))))) < IKFAST_ATAN2_MAGTHRESH )
    continue;
j4array[0]=IKatan2(((gconst14)*(((((IkReal(-1.00000000000000))*(sj6)*(x4079)))+(((cj6)*(x4077)))+(((cj1)*(r11)*(x4073)))+(((cj1)*(r01)*(x4075)))+(((IkReal(-1.00000000000000))*(r10)*(x4076)*(x4078)))+(((IkReal(-1.00000000000000))*(r00)*(x4074)*(x4076)))))), ((gconst14)*(((((IkReal(-1.00000000000000))*(r11)*(x4078)*(x4080)))+(((IkReal(-1.00000000000000))*(r00)*(x4075)*(x4080)))+(((IkReal(-1.00000000000000))*(r12)*(sj0)*(sj5)*(x4076)))+(((cj5)*(sj6)*(x4077)))+(((IkReal(-1.00000000000000))*(r01)*(x4074)*(x4080)))+(((IkReal(-1.00000000000000))*(cj0)*(r02)*(sj5)*(x4076)))+(((IkReal(-1.00000000000000))*(r10)*(x4073)*(x4080)))+(((cj5)*(cj6)*(x4079)))+(((r22)*(sj1)*(sj5)))))));
sj4array[0]=IKsin(j4array[0]);
cj4array[0]=IKcos(j4array[0]);
if( j4array[0] > IKPI )
{
    j4array[0]-=IK2PI;
}
else if( j4array[0] < -IKPI )
{    j4array[0]+=IK2PI;
}
j4valid[0] = true;
for(int ij4 = 0; ij4 < 1; ++ij4)
{
if( !j4valid[ij4] )
{
    continue;
}
_ij4[0] = ij4; _ij4[1] = -1;
for(int iij4 = ij4+1; iij4 < 1; ++iij4)
{
if( j4valid[iij4] && IKabs(cj4array[ij4]-cj4array[iij4]) < IKFAST_SOLUTION_THRESH && IKabs(sj4array[ij4]-sj4array[iij4]) < IKFAST_SOLUTION_THRESH )
{
    j4valid[iij4]=false; _ij4[1] = iij4; break; 
}
}
j4 = j4array[ij4]; cj4 = cj4array[ij4]; sj4 = sj4array[ij4];
{
IkReal evalcond[3];
IkReal x4081=IKsin(j4);
IkReal x4082=IKcos(j4);
IkReal x4083=((r00)*(sj6));
IkReal x4084=((cj6)*(r01));
IkReal x4085=((IkReal(1.00000000000000))*(cj0));
IkReal x4086=((IkReal(1.00000000000000))*(sj0));
IkReal x4087=((r10)*(sj6));
IkReal x4088=((sj5)*(x4081));
IkReal x4089=((IkReal(1.00000000000000))*(cj6)*(r11));
IkReal x4090=((cj5)*(x4081));
IkReal x4091=((cj6)*(x4082));
IkReal x4092=((sj0)*(x4090));
IkReal x4093=((r01)*(sj6)*(x4082));
IkReal x4094=((r11)*(sj6)*(x4082));
evalcond[0]=((((r20)*(sj6)*(x4090)))+(((r21)*(sj6)*(x4082)))+(((IkReal(-1.00000000000000))*(cj1)))+(((r22)*(x4088)))+(((cj6)*(r21)*(x4090)))+(((IkReal(-1.00000000000000))*(r20)*(x4091))));
evalcond[1]=((((IkReal(-1.00000000000000))*(x4085)*(x4094)))+(((r02)*(sj0)*(x4088)))+(((x4084)*(x4092)))+(((IkReal(-1.00000000000000))*(r00)*(x4086)*(x4091)))+(((IkReal(-1.00000000000000))*(x4085)*(x4087)*(x4090)))+(((cj0)*(r10)*(x4091)))+(((x4083)*(x4092)))+(((IkReal(-1.00000000000000))*(r12)*(x4085)*(x4088)))+(((IkReal(-1.00000000000000))*(cj6)*(r11)*(x4085)*(x4090)))+(((sj0)*(x4093))));
evalcond[2]=((((IkReal(-1.00000000000000))*(x4086)*(x4094)))+(((IkReal(-1.00000000000000))*(x4083)*(x4085)*(x4090)))+(((IkReal(-1.00000000000000))*(r02)*(x4085)*(x4088)))+(((IkReal(-1.00000000000000))*(x4086)*(x4087)*(x4090)))+(((cj0)*(r00)*(x4091)))+(sj1)+(((IkReal(-1.00000000000000))*(cj6)*(r11)*(x4086)*(x4090)))+(((r10)*(sj0)*(x4091)))+(((IkReal(-1.00000000000000))*(r12)*(x4086)*(x4088)))+(((IkReal(-1.00000000000000))*(x4085)*(x4093)))+(((IkReal(-1.00000000000000))*(x4084)*(x4085)*(x4090))));
if( IKabs(evalcond[0]) > 0.000001  || IKabs(evalcond[1]) > 0.000001  || IKabs(evalcond[2]) > 0.000001  )
{
continue;
}
}

{
IkReal dummyeval[1];
IkReal gconst17;
gconst17=IKsign(sj1);
dummyeval[0]=sj1;
if( IKabs(dummyeval[0]) < 0.0000010000000000  )
{
{
IkReal dummyeval[1];
dummyeval[0]=sj1;
if( IKabs(dummyeval[0]) < 0.0000010000000000  )
{
{
IkReal dummyeval[1];
dummyeval[0]=cj1;
if( IKabs(dummyeval[0]) < 0.0000010000000000  )
{
{
IkReal evalcond[9];
IkReal x4095=((IkReal(1.00000000000000))*(cj0));
IkReal x4096=((cj4)*(sj6));
IkReal x4097=((sj0)*(sj6));
IkReal x4098=((cj5)*(sj4));
IkReal x4099=((IkReal(0.374290000000000))*(sj5));
IkReal x4100=((sj4)*(sj5));
IkReal x4101=((cj0)*(cj6));
IkReal x4102=((IkReal(0.0100000000000000))*(cj5));
IkReal x4103=((cj4)*(sj5));
IkReal x4104=((cj5)*(sj0));
IkReal x4105=((IkReal(0.374290000000000))*(r02));
IkReal x4106=((r20)*(sj6));
IkReal x4107=((cj6)*(r21));
IkReal x4108=((IkReal(1.00000000000000))*(sj0));
IkReal x4109=((cj0)*(sj6));
IkReal x4110=((cj4)*(cj6));
IkReal x4111=((IkReal(0.374290000000000))*(r12));
IkReal x4112=((cj0)*(cj5));
IkReal x4113=((cj6)*(sj5));
IkReal x4114=((cj6)*(r01));
IkReal x4115=((r00)*(sj6));
IkReal x4116=((IkReal(0.0100000000000000))*(sj5));
IkReal x4117=((cj6)*(r11));
IkReal x4118=((IkReal(1.00000000000000))*(r10));
IkReal x4119=((r02)*(sj0));
IkReal x4120=((cj6)*(sj4));
IkReal x4121=((r12)*(x4108));
evalcond[0]=((IkReal(-3.14159265358979))+(IKfmod(((IkReal(1.57079632679490))+(j1)), IkReal(6.28318530717959))));
evalcond[1]=((((r22)*(x4100)))+(((r21)*(x4096)))+(((x4098)*(x4107)))+(((IkReal(-1.00000000000000))*(r20)*(x4110)))+(((x4098)*(x4106))));
evalcond[2]=((IkReal(0.364420000000000))+(((x4099)*(x4107)))+(((x4099)*(x4106)))+(((IkReal(-0.374290000000000))*(cj5)*(r22)))+(((IkReal(-1.00000000000000))*(r22)*(x4116)))+(pz)+(((IkReal(-1.00000000000000))*(x4102)*(x4107)))+(((IkReal(-1.00000000000000))*(x4102)*(x4106))));
evalcond[3]=((((IkReal(-1.00000000000000))*(sj5)*(x4095)*(x4115)))+(((r12)*(x4104)))+(((IkReal(-1.00000000000000))*(r11)*(x4108)*(x4113)))+(((IkReal(-1.00000000000000))*(sj5)*(x4097)*(x4118)))+(((IkReal(-1.00000000000000))*(r01)*(x4095)*(x4113)))+(((r02)*(x4112))));
evalcond[4]=((((sj0)*(x4098)*(x4114)))+(((IkReal(-1.00000000000000))*(r10)*(sj6)*(x4095)*(x4098)))+(((IkReal(-1.00000000000000))*(r12)*(x4095)*(x4100)))+(((IkReal(-1.00000000000000))*(r00)*(x4108)*(x4110)))+(((IkReal(-1.00000000000000))*(r11)*(x4095)*(x4096)))+(((r00)*(x4097)*(x4098)))+(((IkReal(-1.00000000000000))*(x4095)*(x4098)*(x4117)))+(((r01)*(sj0)*(x4096)))+(((x4100)*(x4119)))+(((cj4)*(r10)*(x4101))));
evalcond[5]=((IkReal(1.00000000000000))+(((IkReal(-1.00000000000000))*(x4095)*(x4098)*(x4114)))+(((IkReal(-1.00000000000000))*(x4098)*(x4108)*(x4117)))+(((IkReal(-1.00000000000000))*(x4100)*(x4121)))+(((cj4)*(r00)*(x4101)))+(((IkReal(-1.00000000000000))*(x4097)*(x4098)*(x4118)))+(((IkReal(-1.00000000000000))*(r11)*(x4096)*(x4108)))+(((IkReal(-1.00000000000000))*(x4095)*(x4098)*(x4115)))+(((IkReal(-1.00000000000000))*(r02)*(x4095)*(x4100)))+(((IkReal(-1.00000000000000))*(r01)*(x4095)*(x4096)))+(((r10)*(sj0)*(x4110))));
evalcond[6]=((IkReal(0.0690000000000000))+(((sj0)*(x4099)*(x4114)))+(((IkReal(-1.00000000000000))*(sj0)*(x4102)*(x4114)))+(((r11)*(x4101)*(x4102)))+(((r00)*(x4097)*(x4099)))+(((IkReal(-1.00000000000000))*(r11)*(x4099)*(x4101)))+(((IkReal(-1.00000000000000))*(r00)*(x4097)*(x4102)))+(((IkReal(-1.00000000000000))*(r10)*(x4099)*(x4109)))+(((IkReal(-1.00000000000000))*(x4116)*(x4119)))+(((IkReal(-1.00000000000000))*(py)*(x4095)))+(((IkReal(-1.00000000000000))*(x4104)*(x4105)))+(((r10)*(x4102)*(x4109)))+(((cj0)*(r12)*(x4116)))+(((px)*(sj0)))+(((x4111)*(x4112))));
evalcond[7]=((((IkReal(-1.00000000000000))*(r02)*(x4095)*(x4103)))+(((r01)*(sj4)*(x4109)))+(((IkReal(-1.00000000000000))*(x4103)*(x4121)))+(((IkReal(-1.00000000000000))*(r00)*(x4095)*(x4120)))+(((r11)*(sj4)*(x4097)))+(((IkReal(-1.00000000000000))*(r10)*(x4108)*(x4120)))+(((IkReal(-1.00000000000000))*(x4096)*(x4104)*(x4118)))+(((IkReal(-1.00000000000000))*(cj5)*(r01)*(x4095)*(x4110)))+(((IkReal(-1.00000000000000))*(r11)*(x4104)*(x4110)))+(((IkReal(-1.00000000000000))*(cj5)*(r00)*(x4095)*(x4096))));
evalcond[8]=((IkReal(0.0690000000000000))+(((r00)*(x4102)*(x4109)))+(((IkReal(-1.00000000000000))*(sj0)*(x4099)*(x4117)))+(((IkReal(-1.00000000000000))*(px)*(x4095)))+(((IkReal(-1.00000000000000))*(r01)*(x4099)*(x4101)))+(((r10)*(x4097)*(x4102)))+(((IkReal(-1.00000000000000))*(r10)*(x4097)*(x4099)))+(((cj0)*(r02)*(x4116)))+(((x4105)*(x4112)))+(((r01)*(x4101)*(x4102)))+(((IkReal(-1.00000000000000))*(r00)*(x4099)*(x4109)))+(((IkReal(-1.00000000000000))*(py)*(x4108)))+(((r12)*(sj0)*(x4116)))+(((x4104)*(x4111)))+(((sj0)*(x4102)*(x4117))));
if( IKabs(evalcond[0]) < 0.0000010000000000  && IKabs(evalcond[1]) < 0.0000010000000000  && IKabs(evalcond[2]) < 0.0000010000000000  && IKabs(evalcond[3]) < 0.0000010000000000  && IKabs(evalcond[4]) < 0.0000010000000000  && IKabs(evalcond[5]) < 0.0000010000000000  && IKabs(evalcond[6]) < 0.0000010000000000  && IKabs(evalcond[7]) < 0.0000010000000000  && IKabs(evalcond[8]) < 0.0000010000000000  )
{
{
IkReal j3array[1], cj3array[1], sj3array[1];
bool j3valid[1]={false};
_nj3 = 1;
IkReal x4122=((r20)*(sj6));
IkReal x4123=((cj4)*(cj5));
IkReal x4124=((cj6)*(r21));
if( IKabs(((((IkReal(-1.00000000000000))*(r21)*(sj4)*(sj6)))+(((cj6)*(r20)*(sj4)))+(((x4123)*(x4124)))+(((cj4)*(r22)*(sj5)))+(((x4122)*(x4123))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(((((sj5)*(x4124)))+(((IkReal(-1.00000000000000))*(cj5)*(r22)))+(((sj5)*(x4122))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(IKsqr(((((IkReal(-1.00000000000000))*(r21)*(sj4)*(sj6)))+(((cj6)*(r20)*(sj4)))+(((x4123)*(x4124)))+(((cj4)*(r22)*(sj5)))+(((x4122)*(x4123)))))+IKsqr(((((sj5)*(x4124)))+(((IkReal(-1.00000000000000))*(cj5)*(r22)))+(((sj5)*(x4122)))))-1) <= IKFAST_SINCOS_THRESH )
    continue;
j3array[0]=IKatan2(((((IkReal(-1.00000000000000))*(r21)*(sj4)*(sj6)))+(((cj6)*(r20)*(sj4)))+(((x4123)*(x4124)))+(((cj4)*(r22)*(sj5)))+(((x4122)*(x4123)))), ((((sj5)*(x4124)))+(((IkReal(-1.00000000000000))*(cj5)*(r22)))+(((sj5)*(x4122)))));
sj3array[0]=IKsin(j3array[0]);
cj3array[0]=IKcos(j3array[0]);
if( j3array[0] > IKPI )
{
    j3array[0]-=IK2PI;
}
else if( j3array[0] < -IKPI )
{    j3array[0]+=IK2PI;
}
j3valid[0] = true;
for(int ij3 = 0; ij3 < 1; ++ij3)
{
if( !j3valid[ij3] )
{
    continue;
}
_ij3[0] = ij3; _ij3[1] = -1;
for(int iij3 = ij3+1; iij3 < 1; ++iij3)
{
if( j3valid[iij3] && IKabs(cj3array[ij3]-cj3array[iij3]) < IKFAST_SOLUTION_THRESH && IKabs(sj3array[ij3]-sj3array[iij3]) < IKFAST_SOLUTION_THRESH )
{
    j3valid[iij3]=false; _ij3[1] = iij3; break; 
}
}
j3 = j3array[ij3]; cj3 = cj3array[ij3]; sj3 = sj3array[ij3];
{
IkReal evalcond[4];
IkReal x4125=IKcos(j3);
IkReal x4126=((sj0)*(sj5));
IkReal x4127=((r00)*(sj6));
IkReal x4128=((cj6)*(r01));
IkReal x4129=((cj5)*(sj0));
IkReal x4130=((cj0)*(cj5));
IkReal x4131=((cj6)*(sj4));
IkReal x4132=((sj4)*(sj6));
IkReal x4133=((cj0)*(r11));
IkReal x4134=((cj4)*(cj6));
IkReal x4135=((cj4)*(sj6));
IkReal x4136=((IkReal(1.00000000000000))*(cj0));
IkReal x4137=((cj4)*(sj5));
IkReal x4138=((sj5)*(sj6));
IkReal x4139=((cj6)*(sj5));
IkReal x4140=((IkReal(1.00000000000000))*(IKsin(j3)));
evalcond[0]=((((r21)*(x4139)))+(((IkReal(-1.00000000000000))*(cj5)*(r22)))+(((IkReal(-1.00000000000000))*(x4125)))+(((r20)*(x4138))));
evalcond[1]=((((IkReal(-1.00000000000000))*(x4140)))+(((r20)*(x4131)))+(((IkReal(-1.00000000000000))*(r21)*(x4132)))+(((cj5)*(r21)*(x4134)))+(((r22)*(x4137)))+(((cj5)*(r20)*(x4135))));
evalcond[2]=((((IkReal(-1.00000000000000))*(x4140)))+(((x4126)*(x4128)))+(((IkReal(-1.00000000000000))*(r02)*(x4129)))+(((IkReal(-1.00000000000000))*(x4133)*(x4139)))+(((r12)*(x4130)))+(((IkReal(-1.00000000000000))*(r10)*(x4136)*(x4138)))+(((x4126)*(x4127))));
evalcond[3]=((((cj4)*(x4127)*(x4129)))+(((IkReal(-1.00000000000000))*(r10)*(x4130)*(x4135)))+(((x4132)*(x4133)))+(((cj4)*(r02)*(x4126)))+(((IkReal(-1.00000000000000))*(r12)*(x4136)*(x4137)))+(((IkReal(-1.00000000000000))*(r10)*(x4131)*(x4136)))+(((IkReal(-1.00000000000000))*(r01)*(sj0)*(x4132)))+(((IkReal(-1.00000000000000))*(r11)*(x4130)*(x4134)))+(((r00)*(sj0)*(x4131)))+(((cj4)*(x4128)*(x4129)))+(x4125));
if( IKabs(evalcond[0]) > 0.000001  || IKabs(evalcond[1]) > 0.000001  || IKabs(evalcond[2]) > 0.000001  || IKabs(evalcond[3]) > 0.000001  )
{
continue;
}
}

{
std::vector<IkSingleDOFSolutionBase<IkReal> > vinfos(7);
vinfos[0].jointtype = 1;
vinfos[0].foffset = j0;
vinfos[0].indices[0] = _ij0[0];
vinfos[0].indices[1] = _ij0[1];
vinfos[0].maxsolutions = _nj0;
vinfos[1].jointtype = 1;
vinfos[1].foffset = j1;
vinfos[1].indices[0] = _ij1[0];
vinfos[1].indices[1] = _ij1[1];
vinfos[1].maxsolutions = _nj1;
vinfos[2].jointtype = 1;
vinfos[2].foffset = j2;
vinfos[2].indices[0] = _ij2[0];
vinfos[2].indices[1] = _ij2[1];
vinfos[2].maxsolutions = _nj2;
vinfos[3].jointtype = 1;
vinfos[3].foffset = j3;
vinfos[3].indices[0] = _ij3[0];
vinfos[3].indices[1] = _ij3[1];
vinfos[3].maxsolutions = _nj3;
vinfos[4].jointtype = 1;
vinfos[4].foffset = j4;
vinfos[4].indices[0] = _ij4[0];
vinfos[4].indices[1] = _ij4[1];
vinfos[4].maxsolutions = _nj4;
vinfos[5].jointtype = 1;
vinfos[5].foffset = j5;
vinfos[5].indices[0] = _ij5[0];
vinfos[5].indices[1] = _ij5[1];
vinfos[5].maxsolutions = _nj5;
vinfos[6].jointtype = 1;
vinfos[6].foffset = j6;
vinfos[6].indices[0] = _ij6[0];
vinfos[6].indices[1] = _ij6[1];
vinfos[6].maxsolutions = _nj6;
std::vector<int> vfree(0);
solutions.AddSolution(vinfos,vfree);
}
}
}

} else
{
IkReal x4141=((IkReal(1.00000000000000))*(cj0));
IkReal x4142=((cj4)*(sj6));
IkReal x4143=((sj0)*(sj6));
IkReal x4144=((cj5)*(sj4));
IkReal x4145=((IkReal(0.374290000000000))*(sj5));
IkReal x4146=((sj4)*(sj5));
IkReal x4147=((cj0)*(cj6));
IkReal x4148=((IkReal(0.0100000000000000))*(cj5));
IkReal x4149=((cj4)*(sj5));
IkReal x4150=((cj5)*(sj0));
IkReal x4151=((IkReal(0.374290000000000))*(r02));
IkReal x4152=((r20)*(sj6));
IkReal x4153=((cj6)*(r21));
IkReal x4154=((IkReal(1.00000000000000))*(sj0));
IkReal x4155=((cj0)*(sj6));
IkReal x4156=((cj4)*(cj6));
IkReal x4157=((IkReal(0.374290000000000))*(r12));
IkReal x4158=((cj0)*(cj5));
IkReal x4159=((cj6)*(sj5));
IkReal x4160=((cj6)*(r01));
IkReal x4161=((r00)*(sj6));
IkReal x4162=((IkReal(0.0100000000000000))*(sj5));
IkReal x4163=((cj6)*(r11));
IkReal x4164=((IkReal(1.00000000000000))*(r10));
IkReal x4165=((r02)*(sj0));
IkReal x4166=((cj6)*(sj4));
IkReal x4167=((r12)*(x4154));
evalcond[0]=((IkReal(-3.14159265358979))+(IKfmod(((IkReal(4.71238898038469))+(j1)), IkReal(6.28318530717959))));
evalcond[1]=((((x4144)*(x4153)))+(((x4144)*(x4152)))+(((r22)*(x4146)))+(((r21)*(x4142)))+(((IkReal(-1.00000000000000))*(r20)*(x4156))));
evalcond[2]=((IkReal(-0.364420000000000))+(((IkReal(-1.00000000000000))*(x4148)*(x4152)))+(((IkReal(-1.00000000000000))*(r22)*(x4162)))+(((IkReal(-0.374290000000000))*(cj5)*(r22)))+(pz)+(((x4145)*(x4152)))+(((IkReal(-1.00000000000000))*(x4148)*(x4153)))+(((x4145)*(x4153))));
evalcond[3]=((((IkReal(-1.00000000000000))*(sj5)*(x4141)*(x4161)))+(((IkReal(-1.00000000000000))*(r11)*(x4154)*(x4159)))+(((IkReal(-1.00000000000000))*(r01)*(x4141)*(x4159)))+(((r12)*(x4150)))+(((r02)*(x4158)))+(((IkReal(-1.00000000000000))*(sj5)*(x4143)*(x4164))));
evalcond[4]=((((IkReal(-1.00000000000000))*(r12)*(x4141)*(x4146)))+(((sj0)*(x4144)*(x4160)))+(((IkReal(-1.00000000000000))*(r11)*(x4141)*(x4142)))+(((r01)*(sj0)*(x4142)))+(((IkReal(-1.00000000000000))*(x4141)*(x4144)*(x4163)))+(((IkReal(-1.00000000000000))*(r00)*(x4154)*(x4156)))+(((cj4)*(r10)*(x4147)))+(((x4146)*(x4165)))+(((r00)*(x4143)*(x4144)))+(((IkReal(-1.00000000000000))*(r10)*(sj6)*(x4141)*(x4144))));
evalcond[5]=((IkReal(-1.00000000000000))+(((r10)*(sj0)*(x4156)))+(((IkReal(-1.00000000000000))*(x4146)*(x4167)))+(((cj4)*(r00)*(x4147)))+(((IkReal(-1.00000000000000))*(x4141)*(x4144)*(x4161)))+(((IkReal(-1.00000000000000))*(r11)*(x4142)*(x4154)))+(((IkReal(-1.00000000000000))*(x4144)*(x4154)*(x4163)))+(((IkReal(-1.00000000000000))*(x4141)*(x4144)*(x4160)))+(((IkReal(-1.00000000000000))*(x4143)*(x4144)*(x4164)))+(((IkReal(-1.00000000000000))*(r01)*(x4141)*(x4142)))+(((IkReal(-1.00000000000000))*(r02)*(x4141)*(x4146))));
evalcond[6]=((IkReal(0.0690000000000000))+(((r11)*(x4147)*(x4148)))+(((cj0)*(r12)*(x4162)))+(((IkReal(-1.00000000000000))*(x4162)*(x4165)))+(((r00)*(x4143)*(x4145)))+(((IkReal(-1.00000000000000))*(py)*(x4141)))+(((IkReal(-1.00000000000000))*(sj0)*(x4148)*(x4160)))+(((x4157)*(x4158)))+(((IkReal(-1.00000000000000))*(r00)*(x4143)*(x4148)))+(((r10)*(x4148)*(x4155)))+(((IkReal(-1.00000000000000))*(r10)*(x4145)*(x4155)))+(((IkReal(-1.00000000000000))*(x4150)*(x4151)))+(((sj0)*(x4145)*(x4160)))+(((px)*(sj0)))+(((IkReal(-1.00000000000000))*(r11)*(x4145)*(x4147))));
evalcond[7]=((((r01)*(sj4)*(x4155)))+(((IkReal(-1.00000000000000))*(cj5)*(r00)*(x4141)*(x4142)))+(((IkReal(-1.00000000000000))*(r11)*(x4150)*(x4156)))+(((IkReal(-1.00000000000000))*(cj5)*(r01)*(x4141)*(x4156)))+(((IkReal(-1.00000000000000))*(r10)*(x4154)*(x4166)))+(((IkReal(-1.00000000000000))*(x4142)*(x4150)*(x4164)))+(((r11)*(sj4)*(x4143)))+(((IkReal(-1.00000000000000))*(r02)*(x4141)*(x4149)))+(((IkReal(-1.00000000000000))*(r00)*(x4141)*(x4166)))+(((IkReal(-1.00000000000000))*(x4149)*(x4167))));
evalcond[8]=((IkReal(0.0690000000000000))+(((IkReal(-1.00000000000000))*(r10)*(x4143)*(x4145)))+(((r10)*(x4143)*(x4148)))+(((IkReal(-1.00000000000000))*(r00)*(x4145)*(x4155)))+(((r00)*(x4148)*(x4155)))+(((x4150)*(x4157)))+(((r12)*(sj0)*(x4162)))+(((IkReal(-1.00000000000000))*(sj0)*(x4145)*(x4163)))+(((sj0)*(x4148)*(x4163)))+(((IkReal(-1.00000000000000))*(r01)*(x4145)*(x4147)))+(((cj0)*(r02)*(x4162)))+(((r01)*(x4147)*(x4148)))+(((IkReal(-1.00000000000000))*(py)*(x4154)))+(((x4151)*(x4158)))+(((IkReal(-1.00000000000000))*(px)*(x4141))));
if( IKabs(evalcond[0]) < 0.0000010000000000  && IKabs(evalcond[1]) < 0.0000010000000000  && IKabs(evalcond[2]) < 0.0000010000000000  && IKabs(evalcond[3]) < 0.0000010000000000  && IKabs(evalcond[4]) < 0.0000010000000000  && IKabs(evalcond[5]) < 0.0000010000000000  && IKabs(evalcond[6]) < 0.0000010000000000  && IKabs(evalcond[7]) < 0.0000010000000000  && IKabs(evalcond[8]) < 0.0000010000000000  )
{
{
IkReal j3array[1], cj3array[1], sj3array[1];
bool j3valid[1]={false};
_nj3 = 1;
IkReal x4168=((IkReal(1.00000000000000))*(sj5));
IkReal x4169=((cj6)*(r21));
IkReal x4170=((r20)*(sj6));
IkReal x4171=((IkReal(1.00000000000000))*(cj4)*(cj5));
if( IKabs(((((IkReal(-1.00000000000000))*(x4170)*(x4171)))+(((IkReal(-1.00000000000000))*(x4169)*(x4171)))+(((r21)*(sj4)*(sj6)))+(((IkReal(-1.00000000000000))*(cj4)*(r22)*(x4168)))+(((IkReal(-1.00000000000000))*(cj6)*(r20)*(sj4))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(((((IkReal(-1.00000000000000))*(x4168)*(x4170)))+(((cj5)*(r22)))+(((IkReal(-1.00000000000000))*(x4168)*(x4169))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(IKsqr(((((IkReal(-1.00000000000000))*(x4170)*(x4171)))+(((IkReal(-1.00000000000000))*(x4169)*(x4171)))+(((r21)*(sj4)*(sj6)))+(((IkReal(-1.00000000000000))*(cj4)*(r22)*(x4168)))+(((IkReal(-1.00000000000000))*(cj6)*(r20)*(sj4)))))+IKsqr(((((IkReal(-1.00000000000000))*(x4168)*(x4170)))+(((cj5)*(r22)))+(((IkReal(-1.00000000000000))*(x4168)*(x4169)))))-1) <= IKFAST_SINCOS_THRESH )
    continue;
j3array[0]=IKatan2(((((IkReal(-1.00000000000000))*(x4170)*(x4171)))+(((IkReal(-1.00000000000000))*(x4169)*(x4171)))+(((r21)*(sj4)*(sj6)))+(((IkReal(-1.00000000000000))*(cj4)*(r22)*(x4168)))+(((IkReal(-1.00000000000000))*(cj6)*(r20)*(sj4)))), ((((IkReal(-1.00000000000000))*(x4168)*(x4170)))+(((cj5)*(r22)))+(((IkReal(-1.00000000000000))*(x4168)*(x4169)))));
sj3array[0]=IKsin(j3array[0]);
cj3array[0]=IKcos(j3array[0]);
if( j3array[0] > IKPI )
{
    j3array[0]-=IK2PI;
}
else if( j3array[0] < -IKPI )
{    j3array[0]+=IK2PI;
}
j3valid[0] = true;
for(int ij3 = 0; ij3 < 1; ++ij3)
{
if( !j3valid[ij3] )
{
    continue;
}
_ij3[0] = ij3; _ij3[1] = -1;
for(int iij3 = ij3+1; iij3 < 1; ++iij3)
{
if( j3valid[iij3] && IKabs(cj3array[ij3]-cj3array[iij3]) < IKFAST_SOLUTION_THRESH && IKabs(sj3array[ij3]-sj3array[iij3]) < IKFAST_SOLUTION_THRESH )
{
    j3valid[iij3]=false; _ij3[1] = iij3; break; 
}
}
j3 = j3array[ij3]; cj3 = cj3array[ij3]; sj3 = sj3array[ij3];
{
IkReal evalcond[4];
IkReal x4172=IKsin(j3);
IkReal x4173=IKcos(j3);
IkReal x4174=((sj0)*(sj5));
IkReal x4175=((r00)*(sj6));
IkReal x4176=((cj6)*(r01));
IkReal x4177=((cj5)*(sj0));
IkReal x4178=((cj0)*(cj5));
IkReal x4179=((cj6)*(sj4));
IkReal x4180=((sj4)*(sj6));
IkReal x4181=((cj0)*(r11));
IkReal x4182=((cj4)*(cj6));
IkReal x4183=((cj4)*(sj6));
IkReal x4184=((IkReal(1.00000000000000))*(cj0));
IkReal x4185=((cj4)*(sj5));
IkReal x4186=((sj5)*(sj6));
IkReal x4187=((cj6)*(sj5));
evalcond[0]=((((r21)*(x4187)))+(x4173)+(((IkReal(-1.00000000000000))*(cj5)*(r22)))+(((r20)*(x4186))));
evalcond[1]=((x4172)+(((r22)*(x4185)))+(((cj5)*(r21)*(x4182)))+(((IkReal(-1.00000000000000))*(r21)*(x4180)))+(((r20)*(x4179)))+(((cj5)*(r20)*(x4183))));
evalcond[2]=((((IkReal(-1.00000000000000))*(x4181)*(x4187)))+(((IkReal(-1.00000000000000))*(r02)*(x4177)))+(((r12)*(x4178)))+(((x4174)*(x4175)))+(((x4174)*(x4176)))+(((IkReal(-1.00000000000000))*(r10)*(x4184)*(x4186)))+(((IkReal(-1.00000000000000))*(x4172))));
evalcond[3]=((((r00)*(sj0)*(x4179)))+(((x4180)*(x4181)))+(((cj4)*(r02)*(x4174)))+(x4173)+(((IkReal(-1.00000000000000))*(r01)*(sj0)*(x4180)))+(((cj4)*(x4176)*(x4177)))+(((cj4)*(x4175)*(x4177)))+(((IkReal(-1.00000000000000))*(r10)*(x4179)*(x4184)))+(((IkReal(-1.00000000000000))*(r10)*(x4178)*(x4183)))+(((IkReal(-1.00000000000000))*(r12)*(x4184)*(x4185)))+(((IkReal(-1.00000000000000))*(r11)*(x4178)*(x4182))));
if( IKabs(evalcond[0]) > 0.000001  || IKabs(evalcond[1]) > 0.000001  || IKabs(evalcond[2]) > 0.000001  || IKabs(evalcond[3]) > 0.000001  )
{
continue;
}
}

{
std::vector<IkSingleDOFSolutionBase<IkReal> > vinfos(7);
vinfos[0].jointtype = 1;
vinfos[0].foffset = j0;
vinfos[0].indices[0] = _ij0[0];
vinfos[0].indices[1] = _ij0[1];
vinfos[0].maxsolutions = _nj0;
vinfos[1].jointtype = 1;
vinfos[1].foffset = j1;
vinfos[1].indices[0] = _ij1[0];
vinfos[1].indices[1] = _ij1[1];
vinfos[1].maxsolutions = _nj1;
vinfos[2].jointtype = 1;
vinfos[2].foffset = j2;
vinfos[2].indices[0] = _ij2[0];
vinfos[2].indices[1] = _ij2[1];
vinfos[2].maxsolutions = _nj2;
vinfos[3].jointtype = 1;
vinfos[3].foffset = j3;
vinfos[3].indices[0] = _ij3[0];
vinfos[3].indices[1] = _ij3[1];
vinfos[3].maxsolutions = _nj3;
vinfos[4].jointtype = 1;
vinfos[4].foffset = j4;
vinfos[4].indices[0] = _ij4[0];
vinfos[4].indices[1] = _ij4[1];
vinfos[4].maxsolutions = _nj4;
vinfos[5].jointtype = 1;
vinfos[5].foffset = j5;
vinfos[5].indices[0] = _ij5[0];
vinfos[5].indices[1] = _ij5[1];
vinfos[5].maxsolutions = _nj5;
vinfos[6].jointtype = 1;
vinfos[6].foffset = j6;
vinfos[6].indices[0] = _ij6[0];
vinfos[6].indices[1] = _ij6[1];
vinfos[6].maxsolutions = _nj6;
std::vector<int> vfree(0);
solutions.AddSolution(vinfos,vfree);
}
}
}

} else
{
IkReal x4188=((IkReal(1.00000000000000))*(cj0));
IkReal x4189=((cj4)*(sj6));
IkReal x4190=((sj0)*(sj4));
IkReal x4191=((cj5)*(sj6));
IkReal x4192=((sj4)*(sj5));
IkReal x4193=((r12)*(sj5));
IkReal x4194=((IkReal(0.374290000000000))*(cj5));
IkReal x4195=((r02)*(sj0));
IkReal x4196=((r20)*(sj4));
IkReal x4197=((IkReal(1.00000000000000))*(sj0));
IkReal x4198=((IkReal(1.00000000000000))*(cj5));
IkReal x4199=((cj0)*(r10));
IkReal x4200=((cj4)*(cj6));
IkReal x4201=((r00)*(sj0));
IkReal x4202=((cj6)*(r21));
IkReal x4203=((IkReal(0.374290000000000))*(sj5));
IkReal x4204=((cj0)*(r00));
IkReal x4205=((IkReal(0.0100000000000000))*(sj5));
IkReal x4206=((cj0)*(r02));
IkReal x4207=((cj5)*(sj4));
IkReal x4208=((cj6)*(r01));
IkReal x4209=((cj6)*(r11));
IkReal x4210=((r01)*(sj0));
IkReal x4211=((r10)*(sj0));
IkReal x4212=((IkReal(0.0100000000000000))*(cj5)*(cj6));
IkReal x4213=((sj6)*(x4203));
IkReal x4214=((cj0)*(cj6)*(x4203));
evalcond[0]=((IkReal(-3.14159265358979))+(IKfmod(((IkReal(3.14159265358979))+(j1)), IkReal(6.28318530717959))));
evalcond[1]=((((sj5)*(x4202)))+(((IkReal(-1.00000000000000))*(r22)*(x4198)))+(((r20)*(sj5)*(sj6))));
evalcond[2]=((IkReal(-1.00000000000000))+(((x4202)*(x4207)))+(((x4191)*(x4196)))+(((r21)*(x4189)))+(((r22)*(x4192)))+(((IkReal(-1.00000000000000))*(r20)*(x4200))));
evalcond[3]=((((IkReal(-0.0100000000000000))*(r20)*(x4191)))+(((IkReal(-0.0100000000000000))*(cj5)*(x4202)))+(((x4202)*(x4203)))+(pz)+(((IkReal(-1.00000000000000))*(r22)*(x4194)))+(((IkReal(-1.00000000000000))*(r22)*(x4205)))+(((r20)*(x4213))));
evalcond[4]=((((IkReal(-1.00000000000000))*(r21)*(sj4)*(sj6)))+(((cj5)*(r21)*(x4200)))+(((cj4)*(r22)*(sj5)))+(((cj5)*(r20)*(x4189)))+(((cj6)*(x4196))));
evalcond[5]=((((IkReal(-1.00000000000000))*(r10)*(sj4)*(x4188)*(x4191)))+(((r00)*(x4190)*(x4191)))+(((IkReal(-1.00000000000000))*(r00)*(x4197)*(x4200)))+(((IkReal(-1.00000000000000))*(r11)*(x4188)*(x4189)))+(((x4199)*(x4200)))+(((cj5)*(x4190)*(x4208)))+(((r02)*(sj5)*(x4190)))+(((IkReal(-1.00000000000000))*(r12)*(x4188)*(x4192)))+(((IkReal(-1.00000000000000))*(x4188)*(x4207)*(x4209)))+(((x4189)*(x4210))));
evalcond[6]=((((x4200)*(x4204)))+(((IkReal(-1.00000000000000))*(r00)*(sj4)*(x4188)*(x4191)))+(((x4200)*(x4211)))+(((IkReal(-1.00000000000000))*(r01)*(x4188)*(x4189)))+(((IkReal(-1.00000000000000))*(x4188)*(x4207)*(x4208)))+(((IkReal(-1.00000000000000))*(r02)*(x4188)*(x4192)))+(((IkReal(-1.00000000000000))*(x4190)*(x4198)*(x4209)))+(((IkReal(-1.00000000000000))*(x4190)*(x4193)))+(((IkReal(-1.00000000000000))*(r11)*(x4189)*(x4197)))+(((IkReal(-1.00000000000000))*(r10)*(x4190)*(x4191))));
evalcond[7]=((IkReal(0.0690000000000000))+(((IkReal(-1.00000000000000))*(cj0)*(x4203)*(x4209)))+(((IkReal(-1.00000000000000))*(x4195)*(x4205)))+(((sj0)*(x4203)*(x4208)))+(((IkReal(-1.00000000000000))*(py)*(x4188)))+(((cj0)*(r12)*(x4194)))+(((x4201)*(x4213)))+(((IkReal(-1.00000000000000))*(x4194)*(x4195)))+(((IkReal(-1.00000000000000))*(x4199)*(x4213)))+(((IkReal(0.0100000000000000))*(x4191)*(x4199)))+(((IkReal(0.0100000000000000))*(cj0)*(x4193)))+(((px)*(sj0)))+(((IkReal(0.0100000000000000))*(cj0)*(cj5)*(x4209)))+(((IkReal(-0.0100000000000000))*(x4191)*(x4201)))+(((IkReal(-0.0100000000000000))*(cj5)*(sj0)*(x4208))));
evalcond[8]=((IkReal(0.433420000000000))+(((r12)*(sj0)*(x4194)))+(((IkReal(0.0100000000000000))*(x4191)*(x4211)))+(((x4194)*(x4206)))+(((x4205)*(x4206)))+(((IkReal(-1.00000000000000))*(px)*(x4188)))+(((IkReal(-1.00000000000000))*(cj0)*(x4203)*(x4208)))+(((IkReal(0.0100000000000000))*(sj0)*(x4193)))+(((IkReal(-1.00000000000000))*(py)*(x4197)))+(((IkReal(-1.00000000000000))*(sj0)*(x4203)*(x4209)))+(((IkReal(0.0100000000000000))*(x4191)*(x4204)))+(((IkReal(0.0100000000000000))*(cj0)*(cj5)*(x4208)))+(((IkReal(-1.00000000000000))*(x4211)*(x4213)))+(((IkReal(0.0100000000000000))*(cj5)*(sj0)*(x4209)))+(((IkReal(-1.00000000000000))*(x4204)*(x4213))));
if( IKabs(evalcond[0]) < 0.0000010000000000  && IKabs(evalcond[1]) < 0.0000010000000000  && IKabs(evalcond[2]) < 0.0000010000000000  && IKabs(evalcond[3]) < 0.0000010000000000  && IKabs(evalcond[4]) < 0.0000010000000000  && IKabs(evalcond[5]) < 0.0000010000000000  && IKabs(evalcond[6]) < 0.0000010000000000  && IKabs(evalcond[7]) < 0.0000010000000000  && IKabs(evalcond[8]) < 0.0000010000000000  )
{
{
IkReal j3array[1], cj3array[1], sj3array[1];
bool j3valid[1]={false};
_nj3 = 1;
IkReal x4215=((cj0)*(cj5));
IkReal x4216=((IkReal(1.00000000000000))*(cj0));
IkReal x4217=((cj6)*(r11));
IkReal x4218=((r10)*(sj6));
IkReal x4219=((cj5)*(sj0));
IkReal x4220=((r00)*(sj5)*(sj6));
IkReal x4221=((cj6)*(r01)*(sj5));
IkReal x4222=((IkReal(1.00000000000000))*(sj0)*(sj5));
if( IKabs(((((sj0)*(x4221)))+(((IkReal(-1.00000000000000))*(r02)*(x4219)))+(((IkReal(-1.00000000000000))*(sj5)*(x4216)*(x4217)))+(((sj0)*(x4220)))+(((r12)*(x4215)))+(((IkReal(-1.00000000000000))*(sj5)*(x4216)*(x4218))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(((((IkReal(-1.00000000000000))*(x4218)*(x4222)))+(((IkReal(-1.00000000000000))*(x4216)*(x4221)))+(((IkReal(-1.00000000000000))*(x4217)*(x4222)))+(((r02)*(x4215)))+(((r12)*(x4219)))+(((IkReal(-1.00000000000000))*(x4216)*(x4220))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(IKsqr(((((sj0)*(x4221)))+(((IkReal(-1.00000000000000))*(r02)*(x4219)))+(((IkReal(-1.00000000000000))*(sj5)*(x4216)*(x4217)))+(((sj0)*(x4220)))+(((r12)*(x4215)))+(((IkReal(-1.00000000000000))*(sj5)*(x4216)*(x4218)))))+IKsqr(((((IkReal(-1.00000000000000))*(x4218)*(x4222)))+(((IkReal(-1.00000000000000))*(x4216)*(x4221)))+(((IkReal(-1.00000000000000))*(x4217)*(x4222)))+(((r02)*(x4215)))+(((r12)*(x4219)))+(((IkReal(-1.00000000000000))*(x4216)*(x4220)))))-1) <= IKFAST_SINCOS_THRESH )
    continue;
j3array[0]=IKatan2(((((sj0)*(x4221)))+(((IkReal(-1.00000000000000))*(r02)*(x4219)))+(((IkReal(-1.00000000000000))*(sj5)*(x4216)*(x4217)))+(((sj0)*(x4220)))+(((r12)*(x4215)))+(((IkReal(-1.00000000000000))*(sj5)*(x4216)*(x4218)))), ((((IkReal(-1.00000000000000))*(x4218)*(x4222)))+(((IkReal(-1.00000000000000))*(x4216)*(x4221)))+(((IkReal(-1.00000000000000))*(x4217)*(x4222)))+(((r02)*(x4215)))+(((r12)*(x4219)))+(((IkReal(-1.00000000000000))*(x4216)*(x4220)))));
sj3array[0]=IKsin(j3array[0]);
cj3array[0]=IKcos(j3array[0]);
if( j3array[0] > IKPI )
{
    j3array[0]-=IK2PI;
}
else if( j3array[0] < -IKPI )
{    j3array[0]+=IK2PI;
}
j3valid[0] = true;
for(int ij3 = 0; ij3 < 1; ++ij3)
{
if( !j3valid[ij3] )
{
    continue;
}
_ij3[0] = ij3; _ij3[1] = -1;
for(int iij3 = ij3+1; iij3 < 1; ++iij3)
{
if( j3valid[iij3] && IKabs(cj3array[ij3]-cj3array[iij3]) < IKFAST_SOLUTION_THRESH && IKabs(sj3array[ij3]-sj3array[iij3]) < IKFAST_SOLUTION_THRESH )
{
    j3valid[iij3]=false; _ij3[1] = iij3; break; 
}
}
j3 = j3array[ij3]; cj3 = cj3array[ij3]; sj3 = sj3array[ij3];
{
IkReal evalcond[4];
IkReal x4223=IKcos(j3);
IkReal x4224=((sj0)*(sj5));
IkReal x4225=((r00)*(sj6));
IkReal x4226=((cj6)*(sj0));
IkReal x4227=((IkReal(1.00000000000000))*(cj4));
IkReal x4228=((r00)*(sj4));
IkReal x4229=((cj0)*(cj5));
IkReal x4230=((cj5)*(sj0));
IkReal x4231=((cj6)*(r11));
IkReal x4232=((r10)*(sj6));
IkReal x4233=((cj0)*(sj5));
IkReal x4234=((r10)*(sj4));
IkReal x4235=((IkReal(1.00000000000000))*(IKsin(j3)));
IkReal x4236=((cj4)*(cj5)*(r01));
IkReal x4237=((IkReal(1.00000000000000))*(cj0)*(cj6));
IkReal x4238=((cj0)*(sj4)*(sj6));
IkReal x4239=((sj0)*(sj4)*(sj6));
evalcond[0]=((((cj6)*(r01)*(x4224)))+(((IkReal(-1.00000000000000))*(x4231)*(x4233)))+(((x4224)*(x4225)))+(((IkReal(-1.00000000000000))*(x4232)*(x4233)))+(((IkReal(-1.00000000000000))*(x4235)))+(((r12)*(x4229)))+(((IkReal(-1.00000000000000))*(r02)*(x4230))));
evalcond[1]=((((r02)*(x4229)))+(((r12)*(x4230)))+(((IkReal(-1.00000000000000))*(x4225)*(x4233)))+(((IkReal(-1.00000000000000))*(cj6)*(r01)*(x4233)))+(((IkReal(-1.00000000000000))*(x4223)))+(((IkReal(-1.00000000000000))*(x4224)*(x4232)))+(((IkReal(-1.00000000000000))*(x4224)*(x4231))));
evalcond[2]=((((IkReal(-1.00000000000000))*(x4234)*(x4237)))+(((x4226)*(x4236)))+(((cj4)*(x4225)*(x4230)))+(((IkReal(-1.00000000000000))*(r12)*(x4227)*(x4233)))+(((cj4)*(r02)*(x4224)))+(x4223)+(((IkReal(-1.00000000000000))*(r01)*(x4239)))+(((x4226)*(x4228)))+(((IkReal(-1.00000000000000))*(x4227)*(x4229)*(x4232)))+(((IkReal(-1.00000000000000))*(x4227)*(x4229)*(x4231)))+(((r11)*(x4238))));
evalcond[3]=((((IkReal(-1.00000000000000))*(cj6)*(r01)*(x4227)*(x4229)))+(((IkReal(-1.00000000000000))*(x4227)*(x4230)*(x4232)))+(((IkReal(-1.00000000000000))*(r12)*(x4224)*(x4227)))+(((IkReal(-1.00000000000000))*(x4228)*(x4237)))+(((IkReal(-1.00000000000000))*(cj5)*(r11)*(x4226)*(x4227)))+(((r01)*(x4238)))+(((IkReal(-1.00000000000000))*(x4226)*(x4234)))+(((IkReal(-1.00000000000000))*(r02)*(x4227)*(x4233)))+(((r11)*(x4239)))+(((IkReal(-1.00000000000000))*(x4235)))+(((IkReal(-1.00000000000000))*(x4225)*(x4227)*(x4229))));
if( IKabs(evalcond[0]) > 0.000001  || IKabs(evalcond[1]) > 0.000001  || IKabs(evalcond[2]) > 0.000001  || IKabs(evalcond[3]) > 0.000001  )
{
continue;
}
}

{
std::vector<IkSingleDOFSolutionBase<IkReal> > vinfos(7);
vinfos[0].jointtype = 1;
vinfos[0].foffset = j0;
vinfos[0].indices[0] = _ij0[0];
vinfos[0].indices[1] = _ij0[1];
vinfos[0].maxsolutions = _nj0;
vinfos[1].jointtype = 1;
vinfos[1].foffset = j1;
vinfos[1].indices[0] = _ij1[0];
vinfos[1].indices[1] = _ij1[1];
vinfos[1].maxsolutions = _nj1;
vinfos[2].jointtype = 1;
vinfos[2].foffset = j2;
vinfos[2].indices[0] = _ij2[0];
vinfos[2].indices[1] = _ij2[1];
vinfos[2].maxsolutions = _nj2;
vinfos[3].jointtype = 1;
vinfos[3].foffset = j3;
vinfos[3].indices[0] = _ij3[0];
vinfos[3].indices[1] = _ij3[1];
vinfos[3].maxsolutions = _nj3;
vinfos[4].jointtype = 1;
vinfos[4].foffset = j4;
vinfos[4].indices[0] = _ij4[0];
vinfos[4].indices[1] = _ij4[1];
vinfos[4].maxsolutions = _nj4;
vinfos[5].jointtype = 1;
vinfos[5].foffset = j5;
vinfos[5].indices[0] = _ij5[0];
vinfos[5].indices[1] = _ij5[1];
vinfos[5].maxsolutions = _nj5;
vinfos[6].jointtype = 1;
vinfos[6].foffset = j6;
vinfos[6].indices[0] = _ij6[0];
vinfos[6].indices[1] = _ij6[1];
vinfos[6].maxsolutions = _nj6;
std::vector<int> vfree(0);
solutions.AddSolution(vinfos,vfree);
}
}
}

} else
{
IkReal x4240=((IkReal(1.00000000000000))*(cj0));
IkReal x4241=((cj4)*(sj6));
IkReal x4242=((sj0)*(sj4));
IkReal x4243=((cj5)*(sj6));
IkReal x4244=((sj4)*(sj5));
IkReal x4245=((r12)*(sj5));
IkReal x4246=((IkReal(0.374290000000000))*(cj5));
IkReal x4247=((r02)*(sj0));
IkReal x4248=((r20)*(sj4));
IkReal x4249=((IkReal(1.00000000000000))*(sj0));
IkReal x4250=((IkReal(1.00000000000000))*(cj5));
IkReal x4251=((cj0)*(r10));
IkReal x4252=((cj4)*(cj6));
IkReal x4253=((r00)*(sj0));
IkReal x4254=((cj6)*(r21));
IkReal x4255=((IkReal(0.374290000000000))*(sj5));
IkReal x4256=((cj0)*(r00));
IkReal x4257=((IkReal(0.0100000000000000))*(sj5));
IkReal x4258=((cj0)*(r02));
IkReal x4259=((cj5)*(sj4));
IkReal x4260=((cj6)*(r01));
IkReal x4261=((cj6)*(r11));
IkReal x4262=((r01)*(sj0));
IkReal x4263=((r10)*(sj0));
IkReal x4264=((IkReal(0.0100000000000000))*(cj5)*(cj6));
IkReal x4265=((sj6)*(x4255));
IkReal x4266=((cj0)*(cj6)*(x4255));
evalcond[0]=((IkReal(-3.14159265358979))+(IKfmod(j1, IkReal(6.28318530717959))));
evalcond[1]=((((IkReal(-1.00000000000000))*(r22)*(x4250)))+(((sj5)*(x4254)))+(((r20)*(sj5)*(sj6))));
evalcond[2]=((IkReal(1.00000000000000))+(((x4243)*(x4248)))+(((r21)*(x4241)))+(((IkReal(-1.00000000000000))*(r20)*(x4252)))+(((x4254)*(x4259)))+(((r22)*(x4244))));
evalcond[3]=((((IkReal(-1.00000000000000))*(r22)*(x4246)))+(((x4254)*(x4255)))+(((IkReal(-0.0100000000000000))*(cj5)*(x4254)))+(pz)+(((IkReal(-0.0100000000000000))*(r20)*(x4243)))+(((IkReal(-1.00000000000000))*(r22)*(x4257)))+(((r20)*(x4265))));
evalcond[4]=((((cj5)*(r21)*(x4252)))+(((IkReal(-1.00000000000000))*(r21)*(sj4)*(sj6)))+(((cj6)*(x4248)))+(((cj4)*(r22)*(sj5)))+(((cj5)*(r20)*(x4241))));
evalcond[5]=((((IkReal(-1.00000000000000))*(r10)*(sj4)*(x4240)*(x4243)))+(((r00)*(x4242)*(x4243)))+(((IkReal(-1.00000000000000))*(r12)*(x4240)*(x4244)))+(((IkReal(-1.00000000000000))*(r11)*(x4240)*(x4241)))+(((x4251)*(x4252)))+(((x4241)*(x4262)))+(((r02)*(sj5)*(x4242)))+(((IkReal(-1.00000000000000))*(x4240)*(x4259)*(x4261)))+(((IkReal(-1.00000000000000))*(r00)*(x4249)*(x4252)))+(((cj5)*(x4242)*(x4260))));
evalcond[6]=((((IkReal(-1.00000000000000))*(r00)*(sj4)*(x4240)*(x4243)))+(((IkReal(-1.00000000000000))*(x4242)*(x4250)*(x4261)))+(((IkReal(-1.00000000000000))*(r01)*(x4240)*(x4241)))+(((x4252)*(x4256)))+(((IkReal(-1.00000000000000))*(r11)*(x4241)*(x4249)))+(((IkReal(-1.00000000000000))*(r10)*(x4242)*(x4243)))+(((IkReal(-1.00000000000000))*(x4242)*(x4245)))+(((IkReal(-1.00000000000000))*(x4240)*(x4259)*(x4260)))+(((x4252)*(x4263)))+(((IkReal(-1.00000000000000))*(r02)*(x4240)*(x4244))));
evalcond[7]=((IkReal(0.0690000000000000))+(((IkReal(0.0100000000000000))*(x4243)*(x4251)))+(((IkReal(-1.00000000000000))*(cj0)*(x4255)*(x4261)))+(((x4253)*(x4265)))+(((IkReal(-0.0100000000000000))*(x4243)*(x4253)))+(((IkReal(0.0100000000000000))*(cj0)*(x4245)))+(((IkReal(-1.00000000000000))*(x4246)*(x4247)))+(((cj0)*(r12)*(x4246)))+(((IkReal(-1.00000000000000))*(x4251)*(x4265)))+(((IkReal(0.0100000000000000))*(cj0)*(cj5)*(x4261)))+(((sj0)*(x4255)*(x4260)))+(((IkReal(-0.0100000000000000))*(cj5)*(sj0)*(x4260)))+(((px)*(sj0)))+(((IkReal(-1.00000000000000))*(x4247)*(x4257)))+(((IkReal(-1.00000000000000))*(py)*(x4240))));
evalcond[8]=((IkReal(-0.295420000000000))+(((IkReal(-1.00000000000000))*(x4256)*(x4265)))+(((IkReal(-1.00000000000000))*(py)*(x4249)))+(((IkReal(0.0100000000000000))*(cj5)*(sj0)*(x4261)))+(((IkReal(-1.00000000000000))*(cj0)*(x4255)*(x4260)))+(((r12)*(sj0)*(x4246)))+(((IkReal(-1.00000000000000))*(sj0)*(x4255)*(x4261)))+(((IkReal(0.0100000000000000))*(x4243)*(x4256)))+(((IkReal(0.0100000000000000))*(x4243)*(x4263)))+(((IkReal(-1.00000000000000))*(px)*(x4240)))+(((IkReal(-1.00000000000000))*(x4263)*(x4265)))+(((x4257)*(x4258)))+(((x4246)*(x4258)))+(((IkReal(0.0100000000000000))*(cj0)*(cj5)*(x4260)))+(((IkReal(0.0100000000000000))*(sj0)*(x4245))));
if( IKabs(evalcond[0]) < 0.0000010000000000  && IKabs(evalcond[1]) < 0.0000010000000000  && IKabs(evalcond[2]) < 0.0000010000000000  && IKabs(evalcond[3]) < 0.0000010000000000  && IKabs(evalcond[4]) < 0.0000010000000000  && IKabs(evalcond[5]) < 0.0000010000000000  && IKabs(evalcond[6]) < 0.0000010000000000  && IKabs(evalcond[7]) < 0.0000010000000000  && IKabs(evalcond[8]) < 0.0000010000000000  )
{
{
IkReal j3array[1], cj3array[1], sj3array[1];
bool j3valid[1]={false};
_nj3 = 1;
IkReal x4267=((sj0)*(sj5));
IkReal x4268=((r00)*(sj6));
IkReal x4269=((IkReal(1.00000000000000))*(cj5));
IkReal x4270=((cj6)*(r11));
IkReal x4271=((cj6)*(r01));
IkReal x4272=((r10)*(sj6));
IkReal x4273=((cj0)*(sj5));
if( IKabs(((((IkReal(-1.00000000000000))*(x4272)*(x4273)))+(((cj0)*(cj5)*(r12)))+(((x4267)*(x4268)))+(((IkReal(-1.00000000000000))*(r02)*(sj0)*(x4269)))+(((x4267)*(x4271)))+(((IkReal(-1.00000000000000))*(x4270)*(x4273))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(((((x4271)*(x4273)))+(((IkReal(-1.00000000000000))*(cj0)*(r02)*(x4269)))+(((x4267)*(x4270)))+(((IkReal(-1.00000000000000))*(r12)*(sj0)*(x4269)))+(((x4268)*(x4273)))+(((x4267)*(x4272))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(IKsqr(((((IkReal(-1.00000000000000))*(x4272)*(x4273)))+(((cj0)*(cj5)*(r12)))+(((x4267)*(x4268)))+(((IkReal(-1.00000000000000))*(r02)*(sj0)*(x4269)))+(((x4267)*(x4271)))+(((IkReal(-1.00000000000000))*(x4270)*(x4273)))))+IKsqr(((((x4271)*(x4273)))+(((IkReal(-1.00000000000000))*(cj0)*(r02)*(x4269)))+(((x4267)*(x4270)))+(((IkReal(-1.00000000000000))*(r12)*(sj0)*(x4269)))+(((x4268)*(x4273)))+(((x4267)*(x4272)))))-1) <= IKFAST_SINCOS_THRESH )
    continue;
j3array[0]=IKatan2(((((IkReal(-1.00000000000000))*(x4272)*(x4273)))+(((cj0)*(cj5)*(r12)))+(((x4267)*(x4268)))+(((IkReal(-1.00000000000000))*(r02)*(sj0)*(x4269)))+(((x4267)*(x4271)))+(((IkReal(-1.00000000000000))*(x4270)*(x4273)))), ((((x4271)*(x4273)))+(((IkReal(-1.00000000000000))*(cj0)*(r02)*(x4269)))+(((x4267)*(x4270)))+(((IkReal(-1.00000000000000))*(r12)*(sj0)*(x4269)))+(((x4268)*(x4273)))+(((x4267)*(x4272)))));
sj3array[0]=IKsin(j3array[0]);
cj3array[0]=IKcos(j3array[0]);
if( j3array[0] > IKPI )
{
    j3array[0]-=IK2PI;
}
else if( j3array[0] < -IKPI )
{    j3array[0]+=IK2PI;
}
j3valid[0] = true;
for(int ij3 = 0; ij3 < 1; ++ij3)
{
if( !j3valid[ij3] )
{
    continue;
}
_ij3[0] = ij3; _ij3[1] = -1;
for(int iij3 = ij3+1; iij3 < 1; ++iij3)
{
if( j3valid[iij3] && IKabs(cj3array[ij3]-cj3array[iij3]) < IKFAST_SOLUTION_THRESH && IKabs(sj3array[ij3]-sj3array[iij3]) < IKFAST_SOLUTION_THRESH )
{
    j3valid[iij3]=false; _ij3[1] = iij3; break; 
}
}
j3 = j3array[ij3]; cj3 = cj3array[ij3]; sj3 = sj3array[ij3];
{
IkReal evalcond[4];
IkReal x4274=IKcos(j3);
IkReal x4275=IKsin(j3);
IkReal x4276=((sj0)*(sj5));
IkReal x4277=((r00)*(sj6));
IkReal x4278=((cj6)*(sj0));
IkReal x4279=((IkReal(1.00000000000000))*(cj4));
IkReal x4280=((r00)*(sj4));
IkReal x4281=((cj0)*(cj5));
IkReal x4282=((cj5)*(sj0));
IkReal x4283=((cj6)*(r11));
IkReal x4284=((r10)*(sj6));
IkReal x4285=((cj0)*(sj5));
IkReal x4286=((r10)*(sj4));
IkReal x4287=((cj4)*(cj5)*(r01));
IkReal x4288=((IkReal(1.00000000000000))*(cj0)*(cj6));
IkReal x4289=((cj0)*(sj4)*(sj6));
IkReal x4290=((sj0)*(sj4)*(sj6));
evalcond[0]=((((cj6)*(r01)*(x4276)))+(((IkReal(-1.00000000000000))*(x4284)*(x4285)))+(((IkReal(-1.00000000000000))*(x4283)*(x4285)))+(((IkReal(-1.00000000000000))*(x4275)))+(((x4276)*(x4277)))+(((IkReal(-1.00000000000000))*(r02)*(x4282)))+(((r12)*(x4281))));
evalcond[1]=((((r02)*(x4281)))+(((IkReal(-1.00000000000000))*(x4277)*(x4285)))+(((IkReal(-1.00000000000000))*(x4276)*(x4284)))+(x4274)+(((IkReal(-1.00000000000000))*(cj6)*(r01)*(x4285)))+(((r12)*(x4282)))+(((IkReal(-1.00000000000000))*(x4276)*(x4283))));
evalcond[2]=((((IkReal(-1.00000000000000))*(x4279)*(x4281)*(x4284)))+(((x4278)*(x4287)))+(((r11)*(x4289)))+(((x4278)*(x4280)))+(((IkReal(-1.00000000000000))*(r01)*(x4290)))+(x4274)+(((IkReal(-1.00000000000000))*(x4286)*(x4288)))+(((IkReal(-1.00000000000000))*(r12)*(x4279)*(x4285)))+(((cj4)*(r02)*(x4276)))+(((IkReal(-1.00000000000000))*(x4279)*(x4281)*(x4283)))+(((cj4)*(x4277)*(x4282))));
evalcond[3]=((((IkReal(-1.00000000000000))*(r02)*(x4279)*(x4285)))+(((IkReal(-1.00000000000000))*(x4280)*(x4288)))+(x4275)+(((r01)*(x4289)))+(((r11)*(x4290)))+(((IkReal(-1.00000000000000))*(x4279)*(x4282)*(x4284)))+(((IkReal(-1.00000000000000))*(x4278)*(x4286)))+(((IkReal(-1.00000000000000))*(x4277)*(x4279)*(x4281)))+(((IkReal(-1.00000000000000))*(r12)*(x4276)*(x4279)))+(((IkReal(-1.00000000000000))*(cj6)*(r01)*(x4279)*(x4281)))+(((IkReal(-1.00000000000000))*(cj5)*(r11)*(x4278)*(x4279))));
if( IKabs(evalcond[0]) > 0.000001  || IKabs(evalcond[1]) > 0.000001  || IKabs(evalcond[2]) > 0.000001  || IKabs(evalcond[3]) > 0.000001  )
{
continue;
}
}

{
std::vector<IkSingleDOFSolutionBase<IkReal> > vinfos(7);
vinfos[0].jointtype = 1;
vinfos[0].foffset = j0;
vinfos[0].indices[0] = _ij0[0];
vinfos[0].indices[1] = _ij0[1];
vinfos[0].maxsolutions = _nj0;
vinfos[1].jointtype = 1;
vinfos[1].foffset = j1;
vinfos[1].indices[0] = _ij1[0];
vinfos[1].indices[1] = _ij1[1];
vinfos[1].maxsolutions = _nj1;
vinfos[2].jointtype = 1;
vinfos[2].foffset = j2;
vinfos[2].indices[0] = _ij2[0];
vinfos[2].indices[1] = _ij2[1];
vinfos[2].maxsolutions = _nj2;
vinfos[3].jointtype = 1;
vinfos[3].foffset = j3;
vinfos[3].indices[0] = _ij3[0];
vinfos[3].indices[1] = _ij3[1];
vinfos[3].maxsolutions = _nj3;
vinfos[4].jointtype = 1;
vinfos[4].foffset = j4;
vinfos[4].indices[0] = _ij4[0];
vinfos[4].indices[1] = _ij4[1];
vinfos[4].maxsolutions = _nj4;
vinfos[5].jointtype = 1;
vinfos[5].foffset = j5;
vinfos[5].indices[0] = _ij5[0];
vinfos[5].indices[1] = _ij5[1];
vinfos[5].maxsolutions = _nj5;
vinfos[6].jointtype = 1;
vinfos[6].foffset = j6;
vinfos[6].indices[0] = _ij6[0];
vinfos[6].indices[1] = _ij6[1];
vinfos[6].maxsolutions = _nj6;
std::vector<int> vfree(0);
solutions.AddSolution(vinfos,vfree);
}
}
}

} else
{
if( 1 )
{
continue;

} else
{
}
}
}
}
}
}

} else
{
{
IkReal j3array[1], cj3array[1], sj3array[1];
bool j3valid[1]={false};
_nj3 = 1;
IkReal x4291=((cj0)*(cj5));
IkReal x4292=((IkReal(1.00000000000000))*(cj0));
IkReal x4293=((cj6)*(r11));
IkReal x4294=((r10)*(sj6));
IkReal x4295=((cj5)*(sj0));
IkReal x4296=((r00)*(sj5)*(sj6));
IkReal x4297=((cj6)*(r01)*(sj5));
IkReal x4298=((IkReal(1.00000000000000))*(sj0)*(sj5));
if( IKabs(((((IkReal(-1.00000000000000))*(sj5)*(x4292)*(x4294)))+(((sj0)*(x4296)))+(((sj0)*(x4297)))+(((IkReal(-1.00000000000000))*(r02)*(x4295)))+(((IkReal(-1.00000000000000))*(sj5)*(x4292)*(x4293)))+(((r12)*(x4291))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(((((IKabs(cj1) != 0)?((IkReal)1/(cj1)):(IkReal)1.0e30))*(((((r12)*(x4295)))+(((IkReal(-1.00000000000000))*(x4293)*(x4298)))+(((r02)*(x4291)))+(((IkReal(-1.00000000000000))*(x4294)*(x4298)))+(((IkReal(-1.00000000000000))*(x4292)*(x4297)))+(((IkReal(-1.00000000000000))*(x4292)*(x4296))))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(IKsqr(((((IkReal(-1.00000000000000))*(sj5)*(x4292)*(x4294)))+(((sj0)*(x4296)))+(((sj0)*(x4297)))+(((IkReal(-1.00000000000000))*(r02)*(x4295)))+(((IkReal(-1.00000000000000))*(sj5)*(x4292)*(x4293)))+(((r12)*(x4291)))))+IKsqr(((((IKabs(cj1) != 0)?((IkReal)1/(cj1)):(IkReal)1.0e30))*(((((r12)*(x4295)))+(((IkReal(-1.00000000000000))*(x4293)*(x4298)))+(((r02)*(x4291)))+(((IkReal(-1.00000000000000))*(x4294)*(x4298)))+(((IkReal(-1.00000000000000))*(x4292)*(x4297)))+(((IkReal(-1.00000000000000))*(x4292)*(x4296)))))))-1) <= IKFAST_SINCOS_THRESH )
    continue;
j3array[0]=IKatan2(((((IkReal(-1.00000000000000))*(sj5)*(x4292)*(x4294)))+(((sj0)*(x4296)))+(((sj0)*(x4297)))+(((IkReal(-1.00000000000000))*(r02)*(x4295)))+(((IkReal(-1.00000000000000))*(sj5)*(x4292)*(x4293)))+(((r12)*(x4291)))), ((((IKabs(cj1) != 0)?((IkReal)1/(cj1)):(IkReal)1.0e30))*(((((r12)*(x4295)))+(((IkReal(-1.00000000000000))*(x4293)*(x4298)))+(((r02)*(x4291)))+(((IkReal(-1.00000000000000))*(x4294)*(x4298)))+(((IkReal(-1.00000000000000))*(x4292)*(x4297)))+(((IkReal(-1.00000000000000))*(x4292)*(x4296)))))));
sj3array[0]=IKsin(j3array[0]);
cj3array[0]=IKcos(j3array[0]);
if( j3array[0] > IKPI )
{
    j3array[0]-=IK2PI;
}
else if( j3array[0] < -IKPI )
{    j3array[0]+=IK2PI;
}
j3valid[0] = true;
for(int ij3 = 0; ij3 < 1; ++ij3)
{
if( !j3valid[ij3] )
{
    continue;
}
_ij3[0] = ij3; _ij3[1] = -1;
for(int iij3 = ij3+1; iij3 < 1; ++iij3)
{
if( j3valid[iij3] && IKabs(cj3array[ij3]-cj3array[iij3]) < IKFAST_SOLUTION_THRESH && IKabs(sj3array[ij3]-sj3array[iij3]) < IKFAST_SOLUTION_THRESH )
{
    j3valid[iij3]=false; _ij3[1] = iij3; break; 
}
}
j3 = j3array[ij3]; cj3 = cj3array[ij3]; sj3 = sj3array[ij3];
{
IkReal evalcond[6];
IkReal x4299=IKsin(j3);
IkReal x4300=IKcos(j3);
IkReal x4301=((sj0)*(sj5));
IkReal x4302=((r00)*(sj6));
IkReal x4303=((cj6)*(r01));
IkReal x4304=((cj4)*(cj5));
IkReal x4305=((IkReal(1.00000000000000))*(cj0));
IkReal x4306=((cj5)*(r12));
IkReal x4307=((IkReal(1.00000000000000))*(sj0));
IkReal x4308=((cj6)*(r11));
IkReal x4309=((cj5)*(r02));
IkReal x4310=((IkReal(1.00000000000000))*(cj1));
IkReal x4311=((cj6)*(sj4));
IkReal x4312=((cj6)*(r21));
IkReal x4313=((r20)*(sj6));
IkReal x4314=((r10)*(sj6));
IkReal x4315=((sj4)*(sj6));
IkReal x4316=((cj4)*(r02));
IkReal x4317=((IkReal(1.00000000000000))*(cj4)*(r12));
IkReal x4318=((IkReal(1.00000000000000))*(x4299));
IkReal x4319=((cj0)*(x4315));
evalcond[0]=((((sj5)*(x4313)))+(((IkReal(-1.00000000000000))*(sj1)*(x4300)))+(((IkReal(-1.00000000000000))*(cj5)*(r22)))+(((sj5)*(x4312))));
evalcond[1]=((((IkReal(-1.00000000000000))*(sj1)*(x4318)))+(((x4304)*(x4313)))+(((IkReal(-1.00000000000000))*(r21)*(x4315)))+(((cj4)*(r22)*(sj5)))+(((r20)*(x4311)))+(((x4304)*(x4312))));
evalcond[2]=((((cj0)*(x4306)))+(((IkReal(-1.00000000000000))*(sj5)*(x4305)*(x4314)))+(((x4301)*(x4303)))+(((IkReal(-1.00000000000000))*(x4318)))+(((IkReal(-1.00000000000000))*(x4307)*(x4309)))+(((x4301)*(x4302)))+(((IkReal(-1.00000000000000))*(sj5)*(x4305)*(x4308))));
evalcond[3]=((((sj0)*(x4306)))+(((IkReal(-1.00000000000000))*(x4301)*(x4308)))+(((IkReal(-1.00000000000000))*(sj5)*(x4302)*(x4305)))+(((IkReal(-1.00000000000000))*(x4301)*(x4314)))+(((IkReal(-1.00000000000000))*(x4300)*(x4310)))+(((IkReal(-1.00000000000000))*(sj5)*(x4303)*(x4305)))+(((cj0)*(x4309))));
evalcond[4]=((((r11)*(x4319)))+(((x4301)*(x4316)))+(((IkReal(-1.00000000000000))*(x4304)*(x4305)*(x4308)))+(((IkReal(-1.00000000000000))*(x4304)*(x4305)*(x4314)))+(((IkReal(-1.00000000000000))*(r10)*(x4305)*(x4311)))+(((sj0)*(x4303)*(x4304)))+(((IkReal(-1.00000000000000))*(r01)*(x4307)*(x4315)))+(((IkReal(-1.00000000000000))*(cj4)*(r12)*(sj5)*(x4305)))+(((sj0)*(x4302)*(x4304)))+(x4300)+(((r00)*(sj0)*(x4311))));
evalcond[5]=((((r11)*(sj0)*(x4315)))+(((IkReal(-1.00000000000000))*(r00)*(x4305)*(x4311)))+(((IkReal(-1.00000000000000))*(r10)*(x4307)*(x4311)))+(((IkReal(-1.00000000000000))*(x4299)*(x4310)))+(((IkReal(-1.00000000000000))*(x4304)*(x4307)*(x4308)))+(((IkReal(-1.00000000000000))*(x4301)*(x4317)))+(((IkReal(-1.00000000000000))*(sj5)*(x4305)*(x4316)))+(((IkReal(-1.00000000000000))*(x4303)*(x4304)*(x4305)))+(((IkReal(-1.00000000000000))*(x4304)*(x4307)*(x4314)))+(((IkReal(-1.00000000000000))*(x4302)*(x4304)*(x4305)))+(((r01)*(x4319))));
if( IKabs(evalcond[0]) > 0.000001  || IKabs(evalcond[1]) > 0.000001  || IKabs(evalcond[2]) > 0.000001  || IKabs(evalcond[3]) > 0.000001  || IKabs(evalcond[4]) > 0.000001  || IKabs(evalcond[5]) > 0.000001  )
{
continue;
}
}

{
std::vector<IkSingleDOFSolutionBase<IkReal> > vinfos(7);
vinfos[0].jointtype = 1;
vinfos[0].foffset = j0;
vinfos[0].indices[0] = _ij0[0];
vinfos[0].indices[1] = _ij0[1];
vinfos[0].maxsolutions = _nj0;
vinfos[1].jointtype = 1;
vinfos[1].foffset = j1;
vinfos[1].indices[0] = _ij1[0];
vinfos[1].indices[1] = _ij1[1];
vinfos[1].maxsolutions = _nj1;
vinfos[2].jointtype = 1;
vinfos[2].foffset = j2;
vinfos[2].indices[0] = _ij2[0];
vinfos[2].indices[1] = _ij2[1];
vinfos[2].maxsolutions = _nj2;
vinfos[3].jointtype = 1;
vinfos[3].foffset = j3;
vinfos[3].indices[0] = _ij3[0];
vinfos[3].indices[1] = _ij3[1];
vinfos[3].maxsolutions = _nj3;
vinfos[4].jointtype = 1;
vinfos[4].foffset = j4;
vinfos[4].indices[0] = _ij4[0];
vinfos[4].indices[1] = _ij4[1];
vinfos[4].maxsolutions = _nj4;
vinfos[5].jointtype = 1;
vinfos[5].foffset = j5;
vinfos[5].indices[0] = _ij5[0];
vinfos[5].indices[1] = _ij5[1];
vinfos[5].maxsolutions = _nj5;
vinfos[6].jointtype = 1;
vinfos[6].foffset = j6;
vinfos[6].indices[0] = _ij6[0];
vinfos[6].indices[1] = _ij6[1];
vinfos[6].maxsolutions = _nj6;
std::vector<int> vfree(0);
solutions.AddSolution(vinfos,vfree);
}
}
}

}

}

} else
{
{
IkReal j3array[1], cj3array[1], sj3array[1];
bool j3valid[1]={false};
_nj3 = 1;
IkReal x4320=((sj5)*(sj6));
IkReal x4321=((cj6)*(sj5));
IkReal x4322=((IkReal(1.00000000000000))*(cj0));
IkReal x4323=((IkReal(1.00000000000000))*(cj5));
if( IKabs(((((IkReal(-1.00000000000000))*(r10)*(x4320)*(x4322)))+(((r01)*(sj0)*(x4321)))+(((IkReal(-1.00000000000000))*(r02)*(sj0)*(x4323)))+(((cj0)*(cj5)*(r12)))+(((r00)*(sj0)*(x4320)))+(((IkReal(-1.00000000000000))*(r11)*(x4321)*(x4322))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(((((IKabs(sj1) != 0)?((IkReal)1/(sj1)):(IkReal)1.0e30))*(((((r21)*(x4321)))+(((IkReal(-1.00000000000000))*(r22)*(x4323)))+(((r20)*(x4320))))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(IKsqr(((((IkReal(-1.00000000000000))*(r10)*(x4320)*(x4322)))+(((r01)*(sj0)*(x4321)))+(((IkReal(-1.00000000000000))*(r02)*(sj0)*(x4323)))+(((cj0)*(cj5)*(r12)))+(((r00)*(sj0)*(x4320)))+(((IkReal(-1.00000000000000))*(r11)*(x4321)*(x4322)))))+IKsqr(((((IKabs(sj1) != 0)?((IkReal)1/(sj1)):(IkReal)1.0e30))*(((((r21)*(x4321)))+(((IkReal(-1.00000000000000))*(r22)*(x4323)))+(((r20)*(x4320)))))))-1) <= IKFAST_SINCOS_THRESH )
    continue;
j3array[0]=IKatan2(((((IkReal(-1.00000000000000))*(r10)*(x4320)*(x4322)))+(((r01)*(sj0)*(x4321)))+(((IkReal(-1.00000000000000))*(r02)*(sj0)*(x4323)))+(((cj0)*(cj5)*(r12)))+(((r00)*(sj0)*(x4320)))+(((IkReal(-1.00000000000000))*(r11)*(x4321)*(x4322)))), ((((IKabs(sj1) != 0)?((IkReal)1/(sj1)):(IkReal)1.0e30))*(((((r21)*(x4321)))+(((IkReal(-1.00000000000000))*(r22)*(x4323)))+(((r20)*(x4320)))))));
sj3array[0]=IKsin(j3array[0]);
cj3array[0]=IKcos(j3array[0]);
if( j3array[0] > IKPI )
{
    j3array[0]-=IK2PI;
}
else if( j3array[0] < -IKPI )
{    j3array[0]+=IK2PI;
}
j3valid[0] = true;
for(int ij3 = 0; ij3 < 1; ++ij3)
{
if( !j3valid[ij3] )
{
    continue;
}
_ij3[0] = ij3; _ij3[1] = -1;
for(int iij3 = ij3+1; iij3 < 1; ++iij3)
{
if( j3valid[iij3] && IKabs(cj3array[ij3]-cj3array[iij3]) < IKFAST_SOLUTION_THRESH && IKabs(sj3array[ij3]-sj3array[iij3]) < IKFAST_SOLUTION_THRESH )
{
    j3valid[iij3]=false; _ij3[1] = iij3; break; 
}
}
j3 = j3array[ij3]; cj3 = cj3array[ij3]; sj3 = sj3array[ij3];
{
IkReal evalcond[6];
IkReal x4324=IKsin(j3);
IkReal x4325=IKcos(j3);
IkReal x4326=((sj0)*(sj5));
IkReal x4327=((r00)*(sj6));
IkReal x4328=((cj6)*(r01));
IkReal x4329=((cj4)*(cj5));
IkReal x4330=((IkReal(1.00000000000000))*(cj0));
IkReal x4331=((cj5)*(r12));
IkReal x4332=((IkReal(1.00000000000000))*(sj0));
IkReal x4333=((cj6)*(r11));
IkReal x4334=((cj5)*(r02));
IkReal x4335=((IkReal(1.00000000000000))*(cj1));
IkReal x4336=((cj6)*(sj4));
IkReal x4337=((cj6)*(r21));
IkReal x4338=((r20)*(sj6));
IkReal x4339=((r10)*(sj6));
IkReal x4340=((sj4)*(sj6));
IkReal x4341=((cj4)*(r02));
IkReal x4342=((IkReal(1.00000000000000))*(cj4)*(r12));
IkReal x4343=((IkReal(1.00000000000000))*(x4324));
IkReal x4344=((cj0)*(x4340));
evalcond[0]=((((IkReal(-1.00000000000000))*(sj1)*(x4325)))+(((IkReal(-1.00000000000000))*(cj5)*(r22)))+(((sj5)*(x4337)))+(((sj5)*(x4338))));
evalcond[1]=((((IkReal(-1.00000000000000))*(r21)*(x4340)))+(((r20)*(x4336)))+(((x4329)*(x4337)))+(((cj4)*(r22)*(sj5)))+(((IkReal(-1.00000000000000))*(sj1)*(x4343)))+(((x4329)*(x4338))));
evalcond[2]=((((IkReal(-1.00000000000000))*(x4343)))+(((cj0)*(x4331)))+(((x4326)*(x4328)))+(((x4326)*(x4327)))+(((IkReal(-1.00000000000000))*(x4332)*(x4334)))+(((IkReal(-1.00000000000000))*(sj5)*(x4330)*(x4339)))+(((IkReal(-1.00000000000000))*(sj5)*(x4330)*(x4333))));
evalcond[3]=((((IkReal(-1.00000000000000))*(sj5)*(x4327)*(x4330)))+(((IkReal(-1.00000000000000))*(x4325)*(x4335)))+(((cj0)*(x4334)))+(((IkReal(-1.00000000000000))*(x4326)*(x4339)))+(((sj0)*(x4331)))+(((IkReal(-1.00000000000000))*(sj5)*(x4328)*(x4330)))+(((IkReal(-1.00000000000000))*(x4326)*(x4333))));
evalcond[4]=((((IkReal(-1.00000000000000))*(cj4)*(r12)*(sj5)*(x4330)))+(((IkReal(-1.00000000000000))*(x4329)*(x4330)*(x4333)))+(((IkReal(-1.00000000000000))*(x4329)*(x4330)*(x4339)))+(((r00)*(sj0)*(x4336)))+(((r11)*(x4344)))+(((sj0)*(x4327)*(x4329)))+(((IkReal(-1.00000000000000))*(r01)*(x4332)*(x4340)))+(((IkReal(-1.00000000000000))*(r10)*(x4330)*(x4336)))+(((x4326)*(x4341)))+(((sj0)*(x4328)*(x4329)))+(x4325));
evalcond[5]=((((r01)*(x4344)))+(((IkReal(-1.00000000000000))*(r00)*(x4330)*(x4336)))+(((IkReal(-1.00000000000000))*(x4326)*(x4342)))+(((IkReal(-1.00000000000000))*(x4328)*(x4329)*(x4330)))+(((IkReal(-1.00000000000000))*(r10)*(x4332)*(x4336)))+(((IkReal(-1.00000000000000))*(x4327)*(x4329)*(x4330)))+(((IkReal(-1.00000000000000))*(x4329)*(x4332)*(x4339)))+(((IkReal(-1.00000000000000))*(x4324)*(x4335)))+(((IkReal(-1.00000000000000))*(x4329)*(x4332)*(x4333)))+(((IkReal(-1.00000000000000))*(sj5)*(x4330)*(x4341)))+(((r11)*(sj0)*(x4340))));
if( IKabs(evalcond[0]) > 0.000001  || IKabs(evalcond[1]) > 0.000001  || IKabs(evalcond[2]) > 0.000001  || IKabs(evalcond[3]) > 0.000001  || IKabs(evalcond[4]) > 0.000001  || IKabs(evalcond[5]) > 0.000001  )
{
continue;
}
}

{
std::vector<IkSingleDOFSolutionBase<IkReal> > vinfos(7);
vinfos[0].jointtype = 1;
vinfos[0].foffset = j0;
vinfos[0].indices[0] = _ij0[0];
vinfos[0].indices[1] = _ij0[1];
vinfos[0].maxsolutions = _nj0;
vinfos[1].jointtype = 1;
vinfos[1].foffset = j1;
vinfos[1].indices[0] = _ij1[0];
vinfos[1].indices[1] = _ij1[1];
vinfos[1].maxsolutions = _nj1;
vinfos[2].jointtype = 1;
vinfos[2].foffset = j2;
vinfos[2].indices[0] = _ij2[0];
vinfos[2].indices[1] = _ij2[1];
vinfos[2].maxsolutions = _nj2;
vinfos[3].jointtype = 1;
vinfos[3].foffset = j3;
vinfos[3].indices[0] = _ij3[0];
vinfos[3].indices[1] = _ij3[1];
vinfos[3].maxsolutions = _nj3;
vinfos[4].jointtype = 1;
vinfos[4].foffset = j4;
vinfos[4].indices[0] = _ij4[0];
vinfos[4].indices[1] = _ij4[1];
vinfos[4].maxsolutions = _nj4;
vinfos[5].jointtype = 1;
vinfos[5].foffset = j5;
vinfos[5].indices[0] = _ij5[0];
vinfos[5].indices[1] = _ij5[1];
vinfos[5].maxsolutions = _nj5;
vinfos[6].jointtype = 1;
vinfos[6].foffset = j6;
vinfos[6].indices[0] = _ij6[0];
vinfos[6].indices[1] = _ij6[1];
vinfos[6].maxsolutions = _nj6;
std::vector<int> vfree(0);
solutions.AddSolution(vinfos,vfree);
}
}
}

}

}

} else
{
{
IkReal j3array[1], cj3array[1], sj3array[1];
bool j3valid[1]={false};
_nj3 = 1;
IkReal x4345=((r20)*(sj6));
IkReal x4346=((cj4)*(cj5));
IkReal x4347=((cj6)*(r21));
if( IKabs(((gconst17)*(((((x4345)*(x4346)))+(((x4346)*(x4347)))+(((IkReal(-1.00000000000000))*(r21)*(sj4)*(sj6)))+(((cj6)*(r20)*(sj4)))+(((cj4)*(r22)*(sj5))))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(((gconst17)*(((((sj5)*(x4345)))+(((IkReal(-1.00000000000000))*(cj5)*(r22)))+(((sj5)*(x4347))))))) < IKFAST_ATAN2_MAGTHRESH )
    continue;
j3array[0]=IKatan2(((gconst17)*(((((x4345)*(x4346)))+(((x4346)*(x4347)))+(((IkReal(-1.00000000000000))*(r21)*(sj4)*(sj6)))+(((cj6)*(r20)*(sj4)))+(((cj4)*(r22)*(sj5)))))), ((gconst17)*(((((sj5)*(x4345)))+(((IkReal(-1.00000000000000))*(cj5)*(r22)))+(((sj5)*(x4347)))))));
sj3array[0]=IKsin(j3array[0]);
cj3array[0]=IKcos(j3array[0]);
if( j3array[0] > IKPI )
{
    j3array[0]-=IK2PI;
}
else if( j3array[0] < -IKPI )
{    j3array[0]+=IK2PI;
}
j3valid[0] = true;
for(int ij3 = 0; ij3 < 1; ++ij3)
{
if( !j3valid[ij3] )
{
    continue;
}
_ij3[0] = ij3; _ij3[1] = -1;
for(int iij3 = ij3+1; iij3 < 1; ++iij3)
{
if( j3valid[iij3] && IKabs(cj3array[ij3]-cj3array[iij3]) < IKFAST_SOLUTION_THRESH && IKabs(sj3array[ij3]-sj3array[iij3]) < IKFAST_SOLUTION_THRESH )
{
    j3valid[iij3]=false; _ij3[1] = iij3; break; 
}
}
j3 = j3array[ij3]; cj3 = cj3array[ij3]; sj3 = sj3array[ij3];
{
IkReal evalcond[6];
IkReal x4348=IKsin(j3);
IkReal x4349=IKcos(j3);
IkReal x4350=((sj0)*(sj5));
IkReal x4351=((r00)*(sj6));
IkReal x4352=((cj6)*(r01));
IkReal x4353=((cj4)*(cj5));
IkReal x4354=((IkReal(1.00000000000000))*(cj0));
IkReal x4355=((cj5)*(r12));
IkReal x4356=((IkReal(1.00000000000000))*(sj0));
IkReal x4357=((cj6)*(r11));
IkReal x4358=((cj5)*(r02));
IkReal x4359=((IkReal(1.00000000000000))*(cj1));
IkReal x4360=((cj6)*(sj4));
IkReal x4361=((cj6)*(r21));
IkReal x4362=((r20)*(sj6));
IkReal x4363=((r10)*(sj6));
IkReal x4364=((sj4)*(sj6));
IkReal x4365=((cj4)*(r02));
IkReal x4366=((IkReal(1.00000000000000))*(cj4)*(r12));
IkReal x4367=((IkReal(1.00000000000000))*(x4348));
IkReal x4368=((cj0)*(x4364));
evalcond[0]=((((sj5)*(x4361)))+(((sj5)*(x4362)))+(((IkReal(-1.00000000000000))*(sj1)*(x4349)))+(((IkReal(-1.00000000000000))*(cj5)*(r22))));
evalcond[1]=((((x4353)*(x4362)))+(((x4353)*(x4361)))+(((IkReal(-1.00000000000000))*(r21)*(x4364)))+(((cj4)*(r22)*(sj5)))+(((r20)*(x4360)))+(((IkReal(-1.00000000000000))*(sj1)*(x4367))));
evalcond[2]=((((cj0)*(x4355)))+(((IkReal(-1.00000000000000))*(x4356)*(x4358)))+(((x4350)*(x4352)))+(((IkReal(-1.00000000000000))*(sj5)*(x4354)*(x4363)))+(((IkReal(-1.00000000000000))*(sj5)*(x4354)*(x4357)))+(((IkReal(-1.00000000000000))*(x4367)))+(((x4350)*(x4351))));
evalcond[3]=((((cj0)*(x4358)))+(((IkReal(-1.00000000000000))*(x4349)*(x4359)))+(((IkReal(-1.00000000000000))*(sj5)*(x4352)*(x4354)))+(((IkReal(-1.00000000000000))*(sj5)*(x4351)*(x4354)))+(((IkReal(-1.00000000000000))*(x4350)*(x4357)))+(((sj0)*(x4355)))+(((IkReal(-1.00000000000000))*(x4350)*(x4363))));
evalcond[4]=((((r00)*(sj0)*(x4360)))+(((IkReal(-1.00000000000000))*(r01)*(x4356)*(x4364)))+(((sj0)*(x4352)*(x4353)))+(((sj0)*(x4351)*(x4353)))+(((IkReal(-1.00000000000000))*(x4353)*(x4354)*(x4363)))+(((IkReal(-1.00000000000000))*(x4353)*(x4354)*(x4357)))+(x4349)+(((IkReal(-1.00000000000000))*(r10)*(x4354)*(x4360)))+(((x4350)*(x4365)))+(((r11)*(x4368)))+(((IkReal(-1.00000000000000))*(cj4)*(r12)*(sj5)*(x4354))));
evalcond[5]=((((r01)*(x4368)))+(((IkReal(-1.00000000000000))*(sj5)*(x4354)*(x4365)))+(((IkReal(-1.00000000000000))*(x4353)*(x4356)*(x4357)))+(((r11)*(sj0)*(x4364)))+(((IkReal(-1.00000000000000))*(x4350)*(x4366)))+(((IkReal(-1.00000000000000))*(x4353)*(x4356)*(x4363)))+(((IkReal(-1.00000000000000))*(x4351)*(x4353)*(x4354)))+(((IkReal(-1.00000000000000))*(x4348)*(x4359)))+(((IkReal(-1.00000000000000))*(r10)*(x4356)*(x4360)))+(((IkReal(-1.00000000000000))*(r00)*(x4354)*(x4360)))+(((IkReal(-1.00000000000000))*(x4352)*(x4353)*(x4354))));
if( IKabs(evalcond[0]) > 0.000001  || IKabs(evalcond[1]) > 0.000001  || IKabs(evalcond[2]) > 0.000001  || IKabs(evalcond[3]) > 0.000001  || IKabs(evalcond[4]) > 0.000001  || IKabs(evalcond[5]) > 0.000001  )
{
continue;
}
}

{
std::vector<IkSingleDOFSolutionBase<IkReal> > vinfos(7);
vinfos[0].jointtype = 1;
vinfos[0].foffset = j0;
vinfos[0].indices[0] = _ij0[0];
vinfos[0].indices[1] = _ij0[1];
vinfos[0].maxsolutions = _nj0;
vinfos[1].jointtype = 1;
vinfos[1].foffset = j1;
vinfos[1].indices[0] = _ij1[0];
vinfos[1].indices[1] = _ij1[1];
vinfos[1].maxsolutions = _nj1;
vinfos[2].jointtype = 1;
vinfos[2].foffset = j2;
vinfos[2].indices[0] = _ij2[0];
vinfos[2].indices[1] = _ij2[1];
vinfos[2].maxsolutions = _nj2;
vinfos[3].jointtype = 1;
vinfos[3].foffset = j3;
vinfos[3].indices[0] = _ij3[0];
vinfos[3].indices[1] = _ij3[1];
vinfos[3].maxsolutions = _nj3;
vinfos[4].jointtype = 1;
vinfos[4].foffset = j4;
vinfos[4].indices[0] = _ij4[0];
vinfos[4].indices[1] = _ij4[1];
vinfos[4].maxsolutions = _nj4;
vinfos[5].jointtype = 1;
vinfos[5].foffset = j5;
vinfos[5].indices[0] = _ij5[0];
vinfos[5].indices[1] = _ij5[1];
vinfos[5].maxsolutions = _nj5;
vinfos[6].jointtype = 1;
vinfos[6].foffset = j6;
vinfos[6].indices[0] = _ij6[0];
vinfos[6].indices[1] = _ij6[1];
vinfos[6].maxsolutions = _nj6;
std::vector<int> vfree(0);
solutions.AddSolution(vinfos,vfree);
}
}
}

}

}
}
}

}

}

} else
{
{
IkReal j4array[1], cj4array[1], sj4array[1];
bool j4valid[1]={false};
_nj4 = 1;
IkReal x4369=((cj1)*(sj6));
IkReal x4370=((r01)*(sj0));
IkReal x4371=((cj0)*(r11));
IkReal x4372=((cj1)*(cj6));
IkReal x4373=((cj0)*(r10));
IkReal x4374=((IkReal(1.00000000000000))*(sj0));
IkReal x4375=((cj1)*(sj5));
if( IKabs(((gconst13)*(((((IkReal(-1.00000000000000))*(r00)*(x4372)*(x4374)))+(((x4372)*(x4373)))+(((x4369)*(x4370)))+(((IkReal(-1.00000000000000))*(x4369)*(x4371))))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(((gconst13)*(((((IkReal(-1.00000000000000))*(cj5)*(r00)*(x4369)*(x4374)))+(((IkReal(-1.00000000000000))*(r02)*(x4374)*(x4375)))+(((cj0)*(r12)*(x4375)))+(((cj5)*(x4369)*(x4373)))+(((IkReal(-1.00000000000000))*(cj5)*(x4370)*(x4372)))+(((cj5)*(x4371)*(x4372))))))) < IKFAST_ATAN2_MAGTHRESH )
    continue;
j4array[0]=IKatan2(((gconst13)*(((((IkReal(-1.00000000000000))*(r00)*(x4372)*(x4374)))+(((x4372)*(x4373)))+(((x4369)*(x4370)))+(((IkReal(-1.00000000000000))*(x4369)*(x4371)))))), ((gconst13)*(((((IkReal(-1.00000000000000))*(cj5)*(r00)*(x4369)*(x4374)))+(((IkReal(-1.00000000000000))*(r02)*(x4374)*(x4375)))+(((cj0)*(r12)*(x4375)))+(((cj5)*(x4369)*(x4373)))+(((IkReal(-1.00000000000000))*(cj5)*(x4370)*(x4372)))+(((cj5)*(x4371)*(x4372)))))));
sj4array[0]=IKsin(j4array[0]);
cj4array[0]=IKcos(j4array[0]);
if( j4array[0] > IKPI )
{
    j4array[0]-=IK2PI;
}
else if( j4array[0] < -IKPI )
{    j4array[0]+=IK2PI;
}
j4valid[0] = true;
for(int ij4 = 0; ij4 < 1; ++ij4)
{
if( !j4valid[ij4] )
{
    continue;
}
_ij4[0] = ij4; _ij4[1] = -1;
for(int iij4 = ij4+1; iij4 < 1; ++iij4)
{
if( j4valid[iij4] && IKabs(cj4array[ij4]-cj4array[iij4]) < IKFAST_SOLUTION_THRESH && IKabs(sj4array[ij4]-sj4array[iij4]) < IKFAST_SOLUTION_THRESH )
{
    j4valid[iij4]=false; _ij4[1] = iij4; break; 
}
}
j4 = j4array[ij4]; cj4 = cj4array[ij4]; sj4 = sj4array[ij4];
{
IkReal evalcond[3];
IkReal x4376=IKsin(j4);
IkReal x4377=IKcos(j4);
IkReal x4378=((r00)*(sj6));
IkReal x4379=((cj6)*(r01));
IkReal x4380=((IkReal(1.00000000000000))*(cj0));
IkReal x4381=((IkReal(1.00000000000000))*(sj0));
IkReal x4382=((r10)*(sj6));
IkReal x4383=((sj5)*(x4376));
IkReal x4384=((IkReal(1.00000000000000))*(cj6)*(r11));
IkReal x4385=((cj5)*(x4376));
IkReal x4386=((cj6)*(x4377));
IkReal x4387=((sj0)*(x4385));
IkReal x4388=((r01)*(sj6)*(x4377));
IkReal x4389=((r11)*(sj6)*(x4377));
evalcond[0]=((((r22)*(x4383)))+(((r20)*(sj6)*(x4385)))+(((r21)*(sj6)*(x4377)))+(((IkReal(-1.00000000000000))*(cj1)))+(((IkReal(-1.00000000000000))*(r20)*(x4386)))+(((cj6)*(r21)*(x4385))));
evalcond[1]=((((x4378)*(x4387)))+(((IkReal(-1.00000000000000))*(r12)*(x4380)*(x4383)))+(((cj0)*(r10)*(x4386)))+(((IkReal(-1.00000000000000))*(r00)*(x4381)*(x4386)))+(((r02)*(sj0)*(x4383)))+(((IkReal(-1.00000000000000))*(x4380)*(x4382)*(x4385)))+(((IkReal(-1.00000000000000))*(cj6)*(r11)*(x4380)*(x4385)))+(((IkReal(-1.00000000000000))*(x4380)*(x4389)))+(((x4379)*(x4387)))+(((sj0)*(x4388))));
evalcond[2]=((((IkReal(-1.00000000000000))*(x4379)*(x4380)*(x4385)))+(((cj0)*(r00)*(x4386)))+(((IkReal(-1.00000000000000))*(r12)*(x4381)*(x4383)))+(sj1)+(((IkReal(-1.00000000000000))*(x4380)*(x4388)))+(((r10)*(sj0)*(x4386)))+(((IkReal(-1.00000000000000))*(x4381)*(x4389)))+(((IkReal(-1.00000000000000))*(r02)*(x4380)*(x4383)))+(((IkReal(-1.00000000000000))*(x4381)*(x4382)*(x4385)))+(((IkReal(-1.00000000000000))*(cj6)*(r11)*(x4381)*(x4385)))+(((IkReal(-1.00000000000000))*(x4378)*(x4380)*(x4385))));
if( IKabs(evalcond[0]) > 0.000001  || IKabs(evalcond[1]) > 0.000001  || IKabs(evalcond[2]) > 0.000001  )
{
continue;
}
}

{
IkReal dummyeval[1];
IkReal gconst17;
gconst17=IKsign(sj1);
dummyeval[0]=sj1;
if( IKabs(dummyeval[0]) < 0.0000010000000000  )
{
{
IkReal dummyeval[1];
dummyeval[0]=sj1;
if( IKabs(dummyeval[0]) < 0.0000010000000000  )
{
{
IkReal dummyeval[1];
dummyeval[0]=cj1;
if( IKabs(dummyeval[0]) < 0.0000010000000000  )
{
{
IkReal evalcond[9];
IkReal x4390=((IkReal(1.00000000000000))*(cj0));
IkReal x4391=((cj4)*(sj6));
IkReal x4392=((sj0)*(sj6));
IkReal x4393=((cj5)*(sj4));
IkReal x4394=((IkReal(0.374290000000000))*(sj5));
IkReal x4395=((sj4)*(sj5));
IkReal x4396=((cj0)*(cj6));
IkReal x4397=((IkReal(0.0100000000000000))*(cj5));
IkReal x4398=((cj4)*(sj5));
IkReal x4399=((cj5)*(sj0));
IkReal x4400=((IkReal(0.374290000000000))*(r02));
IkReal x4401=((r20)*(sj6));
IkReal x4402=((cj6)*(r21));
IkReal x4403=((IkReal(1.00000000000000))*(sj0));
IkReal x4404=((cj0)*(sj6));
IkReal x4405=((cj4)*(cj6));
IkReal x4406=((IkReal(0.374290000000000))*(r12));
IkReal x4407=((cj0)*(cj5));
IkReal x4408=((cj6)*(sj5));
IkReal x4409=((cj6)*(r01));
IkReal x4410=((r00)*(sj6));
IkReal x4411=((IkReal(0.0100000000000000))*(sj5));
IkReal x4412=((cj6)*(r11));
IkReal x4413=((IkReal(1.00000000000000))*(r10));
IkReal x4414=((r02)*(sj0));
IkReal x4415=((cj6)*(sj4));
IkReal x4416=((r12)*(x4403));
evalcond[0]=((IkReal(-3.14159265358979))+(IKfmod(((IkReal(1.57079632679490))+(j1)), IkReal(6.28318530717959))));
evalcond[1]=((((IkReal(-1.00000000000000))*(r20)*(x4405)))+(((x4393)*(x4402)))+(((x4393)*(x4401)))+(((r21)*(x4391)))+(((r22)*(x4395))));
evalcond[2]=((IkReal(0.364420000000000))+(((IkReal(-1.00000000000000))*(r22)*(x4411)))+(((IkReal(-0.374290000000000))*(cj5)*(r22)))+(((IkReal(-1.00000000000000))*(x4397)*(x4402)))+(((IkReal(-1.00000000000000))*(x4397)*(x4401)))+(((x4394)*(x4401)))+(pz)+(((x4394)*(x4402))));
evalcond[3]=((((IkReal(-1.00000000000000))*(r11)*(x4403)*(x4408)))+(((r12)*(x4399)))+(((IkReal(-1.00000000000000))*(r01)*(x4390)*(x4408)))+(((IkReal(-1.00000000000000))*(sj5)*(x4392)*(x4413)))+(((IkReal(-1.00000000000000))*(sj5)*(x4390)*(x4410)))+(((r02)*(x4407))));
evalcond[4]=((((IkReal(-1.00000000000000))*(r11)*(x4390)*(x4391)))+(((r01)*(sj0)*(x4391)))+(((IkReal(-1.00000000000000))*(r00)*(x4403)*(x4405)))+(((IkReal(-1.00000000000000))*(r10)*(sj6)*(x4390)*(x4393)))+(((IkReal(-1.00000000000000))*(r12)*(x4390)*(x4395)))+(((x4395)*(x4414)))+(((IkReal(-1.00000000000000))*(x4390)*(x4393)*(x4412)))+(((r00)*(x4392)*(x4393)))+(((sj0)*(x4393)*(x4409)))+(((cj4)*(r10)*(x4396))));
evalcond[5]=((IkReal(1.00000000000000))+(((r10)*(sj0)*(x4405)))+(((IkReal(-1.00000000000000))*(x4390)*(x4393)*(x4410)))+(((IkReal(-1.00000000000000))*(x4393)*(x4403)*(x4412)))+(((IkReal(-1.00000000000000))*(r11)*(x4391)*(x4403)))+(((cj4)*(r00)*(x4396)))+(((IkReal(-1.00000000000000))*(x4390)*(x4393)*(x4409)))+(((IkReal(-1.00000000000000))*(r01)*(x4390)*(x4391)))+(((IkReal(-1.00000000000000))*(x4395)*(x4416)))+(((IkReal(-1.00000000000000))*(r02)*(x4390)*(x4395)))+(((IkReal(-1.00000000000000))*(x4392)*(x4393)*(x4413))));
evalcond[6]=((IkReal(0.0690000000000000))+(((IkReal(-1.00000000000000))*(x4411)*(x4414)))+(((IkReal(-1.00000000000000))*(r00)*(x4392)*(x4397)))+(((IkReal(-1.00000000000000))*(x4399)*(x4400)))+(((r11)*(x4396)*(x4397)))+(((IkReal(-1.00000000000000))*(sj0)*(x4397)*(x4409)))+(((IkReal(-1.00000000000000))*(py)*(x4390)))+(((r10)*(x4397)*(x4404)))+(((x4406)*(x4407)))+(((cj0)*(r12)*(x4411)))+(((IkReal(-1.00000000000000))*(r11)*(x4394)*(x4396)))+(((IkReal(-1.00000000000000))*(r10)*(x4394)*(x4404)))+(((px)*(sj0)))+(((r00)*(x4392)*(x4394)))+(((sj0)*(x4394)*(x4409))));
evalcond[7]=((((IkReal(-1.00000000000000))*(cj5)*(r00)*(x4390)*(x4391)))+(((IkReal(-1.00000000000000))*(x4398)*(x4416)))+(((r01)*(sj4)*(x4404)))+(((IkReal(-1.00000000000000))*(r02)*(x4390)*(x4398)))+(((IkReal(-1.00000000000000))*(cj5)*(r01)*(x4390)*(x4405)))+(((IkReal(-1.00000000000000))*(r00)*(x4390)*(x4415)))+(((IkReal(-1.00000000000000))*(r10)*(x4403)*(x4415)))+(((IkReal(-1.00000000000000))*(r11)*(x4399)*(x4405)))+(((r11)*(sj4)*(x4392)))+(((IkReal(-1.00000000000000))*(x4391)*(x4399)*(x4413))));
evalcond[8]=((IkReal(0.0690000000000000))+(((IkReal(-1.00000000000000))*(px)*(x4390)))+(((r01)*(x4396)*(x4397)))+(((r12)*(sj0)*(x4411)))+(((x4399)*(x4406)))+(((IkReal(-1.00000000000000))*(r01)*(x4394)*(x4396)))+(((IkReal(-1.00000000000000))*(r00)*(x4394)*(x4404)))+(((IkReal(-1.00000000000000))*(sj0)*(x4394)*(x4412)))+(((IkReal(-1.00000000000000))*(r10)*(x4392)*(x4394)))+(((cj0)*(r02)*(x4411)))+(((r10)*(x4392)*(x4397)))+(((IkReal(-1.00000000000000))*(py)*(x4403)))+(((r00)*(x4397)*(x4404)))+(((sj0)*(x4397)*(x4412)))+(((x4400)*(x4407))));
if( IKabs(evalcond[0]) < 0.0000010000000000  && IKabs(evalcond[1]) < 0.0000010000000000  && IKabs(evalcond[2]) < 0.0000010000000000  && IKabs(evalcond[3]) < 0.0000010000000000  && IKabs(evalcond[4]) < 0.0000010000000000  && IKabs(evalcond[5]) < 0.0000010000000000  && IKabs(evalcond[6]) < 0.0000010000000000  && IKabs(evalcond[7]) < 0.0000010000000000  && IKabs(evalcond[8]) < 0.0000010000000000  )
{
{
IkReal j3array[1], cj3array[1], sj3array[1];
bool j3valid[1]={false};
_nj3 = 1;
IkReal x4417=((r20)*(sj6));
IkReal x4418=((cj4)*(cj5));
IkReal x4419=((cj6)*(r21));
if( IKabs(((((IkReal(-1.00000000000000))*(r21)*(sj4)*(sj6)))+(((cj6)*(r20)*(sj4)))+(((cj4)*(r22)*(sj5)))+(((x4417)*(x4418)))+(((x4418)*(x4419))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(((((sj5)*(x4419)))+(((IkReal(-1.00000000000000))*(cj5)*(r22)))+(((sj5)*(x4417))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(IKsqr(((((IkReal(-1.00000000000000))*(r21)*(sj4)*(sj6)))+(((cj6)*(r20)*(sj4)))+(((cj4)*(r22)*(sj5)))+(((x4417)*(x4418)))+(((x4418)*(x4419)))))+IKsqr(((((sj5)*(x4419)))+(((IkReal(-1.00000000000000))*(cj5)*(r22)))+(((sj5)*(x4417)))))-1) <= IKFAST_SINCOS_THRESH )
    continue;
j3array[0]=IKatan2(((((IkReal(-1.00000000000000))*(r21)*(sj4)*(sj6)))+(((cj6)*(r20)*(sj4)))+(((cj4)*(r22)*(sj5)))+(((x4417)*(x4418)))+(((x4418)*(x4419)))), ((((sj5)*(x4419)))+(((IkReal(-1.00000000000000))*(cj5)*(r22)))+(((sj5)*(x4417)))));
sj3array[0]=IKsin(j3array[0]);
cj3array[0]=IKcos(j3array[0]);
if( j3array[0] > IKPI )
{
    j3array[0]-=IK2PI;
}
else if( j3array[0] < -IKPI )
{    j3array[0]+=IK2PI;
}
j3valid[0] = true;
for(int ij3 = 0; ij3 < 1; ++ij3)
{
if( !j3valid[ij3] )
{
    continue;
}
_ij3[0] = ij3; _ij3[1] = -1;
for(int iij3 = ij3+1; iij3 < 1; ++iij3)
{
if( j3valid[iij3] && IKabs(cj3array[ij3]-cj3array[iij3]) < IKFAST_SOLUTION_THRESH && IKabs(sj3array[ij3]-sj3array[iij3]) < IKFAST_SOLUTION_THRESH )
{
    j3valid[iij3]=false; _ij3[1] = iij3; break; 
}
}
j3 = j3array[ij3]; cj3 = cj3array[ij3]; sj3 = sj3array[ij3];
{
IkReal evalcond[4];
IkReal x4420=IKcos(j3);
IkReal x4421=((sj0)*(sj5));
IkReal x4422=((r00)*(sj6));
IkReal x4423=((cj6)*(r01));
IkReal x4424=((cj5)*(sj0));
IkReal x4425=((cj0)*(cj5));
IkReal x4426=((cj6)*(sj4));
IkReal x4427=((sj4)*(sj6));
IkReal x4428=((cj0)*(r11));
IkReal x4429=((cj4)*(cj6));
IkReal x4430=((cj4)*(sj6));
IkReal x4431=((IkReal(1.00000000000000))*(cj0));
IkReal x4432=((cj4)*(sj5));
IkReal x4433=((sj5)*(sj6));
IkReal x4434=((cj6)*(sj5));
IkReal x4435=((IkReal(1.00000000000000))*(IKsin(j3)));
evalcond[0]=((((r21)*(x4434)))+(((r20)*(x4433)))+(((IkReal(-1.00000000000000))*(x4420)))+(((IkReal(-1.00000000000000))*(cj5)*(r22))));
evalcond[1]=((((IkReal(-1.00000000000000))*(r21)*(x4427)))+(((r20)*(x4426)))+(((r22)*(x4432)))+(((cj5)*(r20)*(x4430)))+(((IkReal(-1.00000000000000))*(x4435)))+(((cj5)*(r21)*(x4429))));
evalcond[2]=((((IkReal(-1.00000000000000))*(r02)*(x4424)))+(((r12)*(x4425)))+(((IkReal(-1.00000000000000))*(x4428)*(x4434)))+(((x4421)*(x4422)))+(((x4421)*(x4423)))+(((IkReal(-1.00000000000000))*(r10)*(x4431)*(x4433)))+(((IkReal(-1.00000000000000))*(x4435))));
evalcond[3]=((((cj4)*(r02)*(x4421)))+(((cj4)*(x4423)*(x4424)))+(((IkReal(-1.00000000000000))*(r11)*(x4425)*(x4429)))+(((IkReal(-1.00000000000000))*(r12)*(x4431)*(x4432)))+(x4420)+(((x4427)*(x4428)))+(((cj4)*(x4422)*(x4424)))+(((IkReal(-1.00000000000000))*(r01)*(sj0)*(x4427)))+(((IkReal(-1.00000000000000))*(r10)*(x4425)*(x4430)))+(((r00)*(sj0)*(x4426)))+(((IkReal(-1.00000000000000))*(r10)*(x4426)*(x4431))));
if( IKabs(evalcond[0]) > 0.000001  || IKabs(evalcond[1]) > 0.000001  || IKabs(evalcond[2]) > 0.000001  || IKabs(evalcond[3]) > 0.000001  )
{
continue;
}
}

{
std::vector<IkSingleDOFSolutionBase<IkReal> > vinfos(7);
vinfos[0].jointtype = 1;
vinfos[0].foffset = j0;
vinfos[0].indices[0] = _ij0[0];
vinfos[0].indices[1] = _ij0[1];
vinfos[0].maxsolutions = _nj0;
vinfos[1].jointtype = 1;
vinfos[1].foffset = j1;
vinfos[1].indices[0] = _ij1[0];
vinfos[1].indices[1] = _ij1[1];
vinfos[1].maxsolutions = _nj1;
vinfos[2].jointtype = 1;
vinfos[2].foffset = j2;
vinfos[2].indices[0] = _ij2[0];
vinfos[2].indices[1] = _ij2[1];
vinfos[2].maxsolutions = _nj2;
vinfos[3].jointtype = 1;
vinfos[3].foffset = j3;
vinfos[3].indices[0] = _ij3[0];
vinfos[3].indices[1] = _ij3[1];
vinfos[3].maxsolutions = _nj3;
vinfos[4].jointtype = 1;
vinfos[4].foffset = j4;
vinfos[4].indices[0] = _ij4[0];
vinfos[4].indices[1] = _ij4[1];
vinfos[4].maxsolutions = _nj4;
vinfos[5].jointtype = 1;
vinfos[5].foffset = j5;
vinfos[5].indices[0] = _ij5[0];
vinfos[5].indices[1] = _ij5[1];
vinfos[5].maxsolutions = _nj5;
vinfos[6].jointtype = 1;
vinfos[6].foffset = j6;
vinfos[6].indices[0] = _ij6[0];
vinfos[6].indices[1] = _ij6[1];
vinfos[6].maxsolutions = _nj6;
std::vector<int> vfree(0);
solutions.AddSolution(vinfos,vfree);
}
}
}

} else
{
IkReal x4436=((IkReal(1.00000000000000))*(cj0));
IkReal x4437=((cj4)*(sj6));
IkReal x4438=((sj0)*(sj6));
IkReal x4439=((cj5)*(sj4));
IkReal x4440=((IkReal(0.374290000000000))*(sj5));
IkReal x4441=((sj4)*(sj5));
IkReal x4442=((cj0)*(cj6));
IkReal x4443=((IkReal(0.0100000000000000))*(cj5));
IkReal x4444=((cj4)*(sj5));
IkReal x4445=((cj5)*(sj0));
IkReal x4446=((IkReal(0.374290000000000))*(r02));
IkReal x4447=((r20)*(sj6));
IkReal x4448=((cj6)*(r21));
IkReal x4449=((IkReal(1.00000000000000))*(sj0));
IkReal x4450=((cj0)*(sj6));
IkReal x4451=((cj4)*(cj6));
IkReal x4452=((IkReal(0.374290000000000))*(r12));
IkReal x4453=((cj0)*(cj5));
IkReal x4454=((cj6)*(sj5));
IkReal x4455=((cj6)*(r01));
IkReal x4456=((r00)*(sj6));
IkReal x4457=((IkReal(0.0100000000000000))*(sj5));
IkReal x4458=((cj6)*(r11));
IkReal x4459=((IkReal(1.00000000000000))*(r10));
IkReal x4460=((r02)*(sj0));
IkReal x4461=((cj6)*(sj4));
IkReal x4462=((r12)*(x4449));
evalcond[0]=((IkReal(-3.14159265358979))+(IKfmod(((IkReal(4.71238898038469))+(j1)), IkReal(6.28318530717959))));
evalcond[1]=((((r21)*(x4437)))+(((x4439)*(x4448)))+(((x4439)*(x4447)))+(((r22)*(x4441)))+(((IkReal(-1.00000000000000))*(r20)*(x4451))));
evalcond[2]=((IkReal(-0.364420000000000))+(((IkReal(-1.00000000000000))*(x4443)*(x4447)))+(((x4440)*(x4447)))+(((IkReal(-0.374290000000000))*(cj5)*(r22)))+(((IkReal(-1.00000000000000))*(x4443)*(x4448)))+(((IkReal(-1.00000000000000))*(r22)*(x4457)))+(pz)+(((x4440)*(x4448))));
evalcond[3]=((((IkReal(-1.00000000000000))*(sj5)*(x4436)*(x4456)))+(((IkReal(-1.00000000000000))*(r11)*(x4449)*(x4454)))+(((r12)*(x4445)))+(((IkReal(-1.00000000000000))*(r01)*(x4436)*(x4454)))+(((r02)*(x4453)))+(((IkReal(-1.00000000000000))*(sj5)*(x4438)*(x4459))));
evalcond[4]=((((IkReal(-1.00000000000000))*(r10)*(sj6)*(x4436)*(x4439)))+(((IkReal(-1.00000000000000))*(r11)*(x4436)*(x4437)))+(((IkReal(-1.00000000000000))*(r00)*(x4449)*(x4451)))+(((IkReal(-1.00000000000000))*(x4436)*(x4439)*(x4458)))+(((sj0)*(x4439)*(x4455)))+(((IkReal(-1.00000000000000))*(r12)*(x4436)*(x4441)))+(((r01)*(sj0)*(x4437)))+(((x4441)*(x4460)))+(((cj4)*(r10)*(x4442)))+(((r00)*(x4438)*(x4439))));
evalcond[5]=((IkReal(-1.00000000000000))+(((r10)*(sj0)*(x4451)))+(((cj4)*(r00)*(x4442)))+(((IkReal(-1.00000000000000))*(x4439)*(x4449)*(x4458)))+(((IkReal(-1.00000000000000))*(r02)*(x4436)*(x4441)))+(((IkReal(-1.00000000000000))*(x4441)*(x4462)))+(((IkReal(-1.00000000000000))*(x4436)*(x4439)*(x4455)))+(((IkReal(-1.00000000000000))*(x4436)*(x4439)*(x4456)))+(((IkReal(-1.00000000000000))*(r11)*(x4437)*(x4449)))+(((IkReal(-1.00000000000000))*(x4438)*(x4439)*(x4459)))+(((IkReal(-1.00000000000000))*(r01)*(x4436)*(x4437))));
evalcond[6]=((IkReal(0.0690000000000000))+(((r10)*(x4443)*(x4450)))+(((IkReal(-1.00000000000000))*(r11)*(x4440)*(x4442)))+(((x4452)*(x4453)))+(((cj0)*(r12)*(x4457)))+(((r00)*(x4438)*(x4440)))+(((IkReal(-1.00000000000000))*(x4445)*(x4446)))+(((r11)*(x4442)*(x4443)))+(((IkReal(-1.00000000000000))*(sj0)*(x4443)*(x4455)))+(((px)*(sj0)))+(((IkReal(-1.00000000000000))*(py)*(x4436)))+(((IkReal(-1.00000000000000))*(r00)*(x4438)*(x4443)))+(((IkReal(-1.00000000000000))*(x4457)*(x4460)))+(((IkReal(-1.00000000000000))*(r10)*(x4440)*(x4450)))+(((sj0)*(x4440)*(x4455))));
evalcond[7]=((((IkReal(-1.00000000000000))*(x4437)*(x4445)*(x4459)))+(((r11)*(sj4)*(x4438)))+(((IkReal(-1.00000000000000))*(r11)*(x4445)*(x4451)))+(((IkReal(-1.00000000000000))*(cj5)*(r00)*(x4436)*(x4437)))+(((IkReal(-1.00000000000000))*(x4444)*(x4462)))+(((r01)*(sj4)*(x4450)))+(((IkReal(-1.00000000000000))*(r00)*(x4436)*(x4461)))+(((IkReal(-1.00000000000000))*(cj5)*(r01)*(x4436)*(x4451)))+(((IkReal(-1.00000000000000))*(r02)*(x4436)*(x4444)))+(((IkReal(-1.00000000000000))*(r10)*(x4449)*(x4461))));
evalcond[8]=((IkReal(0.0690000000000000))+(((IkReal(-1.00000000000000))*(r00)*(x4440)*(x4450)))+(((r01)*(x4442)*(x4443)))+(((r10)*(x4438)*(x4443)))+(((x4445)*(x4452)))+(((r12)*(sj0)*(x4457)))+(((IkReal(-1.00000000000000))*(px)*(x4436)))+(((IkReal(-1.00000000000000))*(py)*(x4449)))+(((cj0)*(r02)*(x4457)))+(((IkReal(-1.00000000000000))*(r01)*(x4440)*(x4442)))+(((IkReal(-1.00000000000000))*(r10)*(x4438)*(x4440)))+(((r00)*(x4443)*(x4450)))+(((sj0)*(x4443)*(x4458)))+(((x4446)*(x4453)))+(((IkReal(-1.00000000000000))*(sj0)*(x4440)*(x4458))));
if( IKabs(evalcond[0]) < 0.0000010000000000  && IKabs(evalcond[1]) < 0.0000010000000000  && IKabs(evalcond[2]) < 0.0000010000000000  && IKabs(evalcond[3]) < 0.0000010000000000  && IKabs(evalcond[4]) < 0.0000010000000000  && IKabs(evalcond[5]) < 0.0000010000000000  && IKabs(evalcond[6]) < 0.0000010000000000  && IKabs(evalcond[7]) < 0.0000010000000000  && IKabs(evalcond[8]) < 0.0000010000000000  )
{
{
IkReal j3array[1], cj3array[1], sj3array[1];
bool j3valid[1]={false};
_nj3 = 1;
IkReal x4463=((IkReal(1.00000000000000))*(sj5));
IkReal x4464=((cj6)*(r21));
IkReal x4465=((r20)*(sj6));
IkReal x4466=((IkReal(1.00000000000000))*(cj4)*(cj5));
if( IKabs(((((IkReal(-1.00000000000000))*(x4464)*(x4466)))+(((IkReal(-1.00000000000000))*(x4465)*(x4466)))+(((IkReal(-1.00000000000000))*(cj4)*(r22)*(x4463)))+(((r21)*(sj4)*(sj6)))+(((IkReal(-1.00000000000000))*(cj6)*(r20)*(sj4))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(((((IkReal(-1.00000000000000))*(x4463)*(x4465)))+(((IkReal(-1.00000000000000))*(x4463)*(x4464)))+(((cj5)*(r22))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(IKsqr(((((IkReal(-1.00000000000000))*(x4464)*(x4466)))+(((IkReal(-1.00000000000000))*(x4465)*(x4466)))+(((IkReal(-1.00000000000000))*(cj4)*(r22)*(x4463)))+(((r21)*(sj4)*(sj6)))+(((IkReal(-1.00000000000000))*(cj6)*(r20)*(sj4)))))+IKsqr(((((IkReal(-1.00000000000000))*(x4463)*(x4465)))+(((IkReal(-1.00000000000000))*(x4463)*(x4464)))+(((cj5)*(r22)))))-1) <= IKFAST_SINCOS_THRESH )
    continue;
j3array[0]=IKatan2(((((IkReal(-1.00000000000000))*(x4464)*(x4466)))+(((IkReal(-1.00000000000000))*(x4465)*(x4466)))+(((IkReal(-1.00000000000000))*(cj4)*(r22)*(x4463)))+(((r21)*(sj4)*(sj6)))+(((IkReal(-1.00000000000000))*(cj6)*(r20)*(sj4)))), ((((IkReal(-1.00000000000000))*(x4463)*(x4465)))+(((IkReal(-1.00000000000000))*(x4463)*(x4464)))+(((cj5)*(r22)))));
sj3array[0]=IKsin(j3array[0]);
cj3array[0]=IKcos(j3array[0]);
if( j3array[0] > IKPI )
{
    j3array[0]-=IK2PI;
}
else if( j3array[0] < -IKPI )
{    j3array[0]+=IK2PI;
}
j3valid[0] = true;
for(int ij3 = 0; ij3 < 1; ++ij3)
{
if( !j3valid[ij3] )
{
    continue;
}
_ij3[0] = ij3; _ij3[1] = -1;
for(int iij3 = ij3+1; iij3 < 1; ++iij3)
{
if( j3valid[iij3] && IKabs(cj3array[ij3]-cj3array[iij3]) < IKFAST_SOLUTION_THRESH && IKabs(sj3array[ij3]-sj3array[iij3]) < IKFAST_SOLUTION_THRESH )
{
    j3valid[iij3]=false; _ij3[1] = iij3; break; 
}
}
j3 = j3array[ij3]; cj3 = cj3array[ij3]; sj3 = sj3array[ij3];
{
IkReal evalcond[4];
IkReal x4467=IKsin(j3);
IkReal x4468=IKcos(j3);
IkReal x4469=((sj0)*(sj5));
IkReal x4470=((r00)*(sj6));
IkReal x4471=((cj6)*(r01));
IkReal x4472=((cj5)*(sj0));
IkReal x4473=((cj0)*(cj5));
IkReal x4474=((cj6)*(sj4));
IkReal x4475=((sj4)*(sj6));
IkReal x4476=((cj0)*(r11));
IkReal x4477=((cj4)*(cj6));
IkReal x4478=((cj4)*(sj6));
IkReal x4479=((IkReal(1.00000000000000))*(cj0));
IkReal x4480=((cj4)*(sj5));
IkReal x4481=((sj5)*(sj6));
IkReal x4482=((cj6)*(sj5));
evalcond[0]=((x4468)+(((r21)*(x4482)))+(((IkReal(-1.00000000000000))*(cj5)*(r22)))+(((r20)*(x4481))));
evalcond[1]=((x4467)+(((r22)*(x4480)))+(((cj5)*(r20)*(x4478)))+(((cj5)*(r21)*(x4477)))+(((IkReal(-1.00000000000000))*(r21)*(x4475)))+(((r20)*(x4474))));
evalcond[2]=((((IkReal(-1.00000000000000))*(r10)*(x4479)*(x4481)))+(((r12)*(x4473)))+(((x4469)*(x4471)))+(((IkReal(-1.00000000000000))*(x4476)*(x4482)))+(((x4469)*(x4470)))+(((IkReal(-1.00000000000000))*(r02)*(x4472)))+(((IkReal(-1.00000000000000))*(x4467))));
evalcond[3]=((x4468)+(((r00)*(sj0)*(x4474)))+(((IkReal(-1.00000000000000))*(r10)*(x4474)*(x4479)))+(((cj4)*(x4471)*(x4472)))+(((cj4)*(r02)*(x4469)))+(((x4475)*(x4476)))+(((IkReal(-1.00000000000000))*(r01)*(sj0)*(x4475)))+(((IkReal(-1.00000000000000))*(r11)*(x4473)*(x4477)))+(((IkReal(-1.00000000000000))*(r10)*(x4473)*(x4478)))+(((IkReal(-1.00000000000000))*(r12)*(x4479)*(x4480)))+(((cj4)*(x4470)*(x4472))));
if( IKabs(evalcond[0]) > 0.000001  || IKabs(evalcond[1]) > 0.000001  || IKabs(evalcond[2]) > 0.000001  || IKabs(evalcond[3]) > 0.000001  )
{
continue;
}
}

{
std::vector<IkSingleDOFSolutionBase<IkReal> > vinfos(7);
vinfos[0].jointtype = 1;
vinfos[0].foffset = j0;
vinfos[0].indices[0] = _ij0[0];
vinfos[0].indices[1] = _ij0[1];
vinfos[0].maxsolutions = _nj0;
vinfos[1].jointtype = 1;
vinfos[1].foffset = j1;
vinfos[1].indices[0] = _ij1[0];
vinfos[1].indices[1] = _ij1[1];
vinfos[1].maxsolutions = _nj1;
vinfos[2].jointtype = 1;
vinfos[2].foffset = j2;
vinfos[2].indices[0] = _ij2[0];
vinfos[2].indices[1] = _ij2[1];
vinfos[2].maxsolutions = _nj2;
vinfos[3].jointtype = 1;
vinfos[3].foffset = j3;
vinfos[3].indices[0] = _ij3[0];
vinfos[3].indices[1] = _ij3[1];
vinfos[3].maxsolutions = _nj3;
vinfos[4].jointtype = 1;
vinfos[4].foffset = j4;
vinfos[4].indices[0] = _ij4[0];
vinfos[4].indices[1] = _ij4[1];
vinfos[4].maxsolutions = _nj4;
vinfos[5].jointtype = 1;
vinfos[5].foffset = j5;
vinfos[5].indices[0] = _ij5[0];
vinfos[5].indices[1] = _ij5[1];
vinfos[5].maxsolutions = _nj5;
vinfos[6].jointtype = 1;
vinfos[6].foffset = j6;
vinfos[6].indices[0] = _ij6[0];
vinfos[6].indices[1] = _ij6[1];
vinfos[6].maxsolutions = _nj6;
std::vector<int> vfree(0);
solutions.AddSolution(vinfos,vfree);
}
}
}

} else
{
IkReal x4483=((IkReal(1.00000000000000))*(cj0));
IkReal x4484=((cj4)*(sj6));
IkReal x4485=((sj0)*(sj4));
IkReal x4486=((cj5)*(sj6));
IkReal x4487=((sj4)*(sj5));
IkReal x4488=((r12)*(sj5));
IkReal x4489=((IkReal(0.374290000000000))*(cj5));
IkReal x4490=((r02)*(sj0));
IkReal x4491=((r20)*(sj4));
IkReal x4492=((IkReal(1.00000000000000))*(sj0));
IkReal x4493=((IkReal(1.00000000000000))*(cj5));
IkReal x4494=((cj0)*(r10));
IkReal x4495=((cj4)*(cj6));
IkReal x4496=((r00)*(sj0));
IkReal x4497=((cj6)*(r21));
IkReal x4498=((IkReal(0.374290000000000))*(sj5));
IkReal x4499=((cj0)*(r00));
IkReal x4500=((IkReal(0.0100000000000000))*(sj5));
IkReal x4501=((cj0)*(r02));
IkReal x4502=((cj5)*(sj4));
IkReal x4503=((cj6)*(r01));
IkReal x4504=((cj6)*(r11));
IkReal x4505=((r01)*(sj0));
IkReal x4506=((r10)*(sj0));
IkReal x4507=((IkReal(0.0100000000000000))*(cj5)*(cj6));
IkReal x4508=((sj6)*(x4498));
IkReal x4509=((cj0)*(cj6)*(x4498));
evalcond[0]=((IkReal(-3.14159265358979))+(IKfmod(((IkReal(3.14159265358979))+(j1)), IkReal(6.28318530717959))));
evalcond[1]=((((sj5)*(x4497)))+(((IkReal(-1.00000000000000))*(r22)*(x4493)))+(((r20)*(sj5)*(sj6))));
evalcond[2]=((IkReal(-1.00000000000000))+(((IkReal(-1.00000000000000))*(r20)*(x4495)))+(((x4486)*(x4491)))+(((r22)*(x4487)))+(((r21)*(x4484)))+(((x4497)*(x4502))));
evalcond[3]=((((IkReal(-1.00000000000000))*(r22)*(x4489)))+(((IkReal(-1.00000000000000))*(r22)*(x4500)))+(((IkReal(-0.0100000000000000))*(cj5)*(x4497)))+(((IkReal(-0.0100000000000000))*(r20)*(x4486)))+(pz)+(((r20)*(x4508)))+(((x4497)*(x4498))));
evalcond[4]=((((IkReal(-1.00000000000000))*(r21)*(sj4)*(sj6)))+(((cj4)*(r22)*(sj5)))+(((cj6)*(x4491)))+(((cj5)*(r20)*(x4484)))+(((cj5)*(r21)*(x4495))));
evalcond[5]=((((x4494)*(x4495)))+(((x4484)*(x4505)))+(((IkReal(-1.00000000000000))*(r10)*(sj4)*(x4483)*(x4486)))+(((r02)*(sj5)*(x4485)))+(((r00)*(x4485)*(x4486)))+(((IkReal(-1.00000000000000))*(r12)*(x4483)*(x4487)))+(((IkReal(-1.00000000000000))*(r00)*(x4492)*(x4495)))+(((IkReal(-1.00000000000000))*(r11)*(x4483)*(x4484)))+(((IkReal(-1.00000000000000))*(x4483)*(x4502)*(x4504)))+(((cj5)*(x4485)*(x4503))));
evalcond[6]=((((x4495)*(x4506)))+(((x4495)*(x4499)))+(((IkReal(-1.00000000000000))*(x4483)*(x4502)*(x4503)))+(((IkReal(-1.00000000000000))*(r11)*(x4484)*(x4492)))+(((IkReal(-1.00000000000000))*(r00)*(sj4)*(x4483)*(x4486)))+(((IkReal(-1.00000000000000))*(r02)*(x4483)*(x4487)))+(((IkReal(-1.00000000000000))*(x4485)*(x4493)*(x4504)))+(((IkReal(-1.00000000000000))*(r10)*(x4485)*(x4486)))+(((IkReal(-1.00000000000000))*(x4485)*(x4488)))+(((IkReal(-1.00000000000000))*(r01)*(x4483)*(x4484))));
evalcond[7]=((IkReal(0.0690000000000000))+(((IkReal(-0.0100000000000000))*(x4486)*(x4496)))+(((IkReal(-1.00000000000000))*(x4490)*(x4500)))+(((IkReal(-1.00000000000000))*(py)*(x4483)))+(((IkReal(-1.00000000000000))*(cj0)*(x4498)*(x4504)))+(((IkReal(-0.0100000000000000))*(cj5)*(sj0)*(x4503)))+(((IkReal(0.0100000000000000))*(cj0)*(cj5)*(x4504)))+(((sj0)*(x4498)*(x4503)))+(((x4496)*(x4508)))+(((IkReal(0.0100000000000000))*(cj0)*(x4488)))+(((IkReal(0.0100000000000000))*(x4486)*(x4494)))+(((cj0)*(r12)*(x4489)))+(((px)*(sj0)))+(((IkReal(-1.00000000000000))*(x4489)*(x4490)))+(((IkReal(-1.00000000000000))*(x4494)*(x4508))));
evalcond[8]=((IkReal(0.433420000000000))+(((IkReal(0.0100000000000000))*(cj0)*(cj5)*(x4503)))+(((x4500)*(x4501)))+(((x4489)*(x4501)))+(((r12)*(sj0)*(x4489)))+(((IkReal(0.0100000000000000))*(sj0)*(x4488)))+(((IkReal(-1.00000000000000))*(sj0)*(x4498)*(x4504)))+(((IkReal(-1.00000000000000))*(py)*(x4492)))+(((IkReal(-1.00000000000000))*(x4506)*(x4508)))+(((IkReal(0.0100000000000000))*(cj5)*(sj0)*(x4504)))+(((IkReal(0.0100000000000000))*(x4486)*(x4506)))+(((IkReal(-1.00000000000000))*(x4499)*(x4508)))+(((IkReal(0.0100000000000000))*(x4486)*(x4499)))+(((IkReal(-1.00000000000000))*(px)*(x4483)))+(((IkReal(-1.00000000000000))*(cj0)*(x4498)*(x4503))));
if( IKabs(evalcond[0]) < 0.0000010000000000  && IKabs(evalcond[1]) < 0.0000010000000000  && IKabs(evalcond[2]) < 0.0000010000000000  && IKabs(evalcond[3]) < 0.0000010000000000  && IKabs(evalcond[4]) < 0.0000010000000000  && IKabs(evalcond[5]) < 0.0000010000000000  && IKabs(evalcond[6]) < 0.0000010000000000  && IKabs(evalcond[7]) < 0.0000010000000000  && IKabs(evalcond[8]) < 0.0000010000000000  )
{
{
IkReal j3array[1], cj3array[1], sj3array[1];
bool j3valid[1]={false};
_nj3 = 1;
IkReal x4510=((cj0)*(cj5));
IkReal x4511=((IkReal(1.00000000000000))*(cj0));
IkReal x4512=((cj6)*(r11));
IkReal x4513=((r10)*(sj6));
IkReal x4514=((cj5)*(sj0));
IkReal x4515=((r00)*(sj5)*(sj6));
IkReal x4516=((cj6)*(r01)*(sj5));
IkReal x4517=((IkReal(1.00000000000000))*(sj0)*(sj5));
if( IKabs(((((IkReal(-1.00000000000000))*(sj5)*(x4511)*(x4512)))+(((IkReal(-1.00000000000000))*(sj5)*(x4511)*(x4513)))+(((r12)*(x4510)))+(((IkReal(-1.00000000000000))*(r02)*(x4514)))+(((sj0)*(x4515)))+(((sj0)*(x4516))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(((((r02)*(x4510)))+(((r12)*(x4514)))+(((IkReal(-1.00000000000000))*(x4513)*(x4517)))+(((IkReal(-1.00000000000000))*(x4511)*(x4516)))+(((IkReal(-1.00000000000000))*(x4512)*(x4517)))+(((IkReal(-1.00000000000000))*(x4511)*(x4515))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(IKsqr(((((IkReal(-1.00000000000000))*(sj5)*(x4511)*(x4512)))+(((IkReal(-1.00000000000000))*(sj5)*(x4511)*(x4513)))+(((r12)*(x4510)))+(((IkReal(-1.00000000000000))*(r02)*(x4514)))+(((sj0)*(x4515)))+(((sj0)*(x4516)))))+IKsqr(((((r02)*(x4510)))+(((r12)*(x4514)))+(((IkReal(-1.00000000000000))*(x4513)*(x4517)))+(((IkReal(-1.00000000000000))*(x4511)*(x4516)))+(((IkReal(-1.00000000000000))*(x4512)*(x4517)))+(((IkReal(-1.00000000000000))*(x4511)*(x4515)))))-1) <= IKFAST_SINCOS_THRESH )
    continue;
j3array[0]=IKatan2(((((IkReal(-1.00000000000000))*(sj5)*(x4511)*(x4512)))+(((IkReal(-1.00000000000000))*(sj5)*(x4511)*(x4513)))+(((r12)*(x4510)))+(((IkReal(-1.00000000000000))*(r02)*(x4514)))+(((sj0)*(x4515)))+(((sj0)*(x4516)))), ((((r02)*(x4510)))+(((r12)*(x4514)))+(((IkReal(-1.00000000000000))*(x4513)*(x4517)))+(((IkReal(-1.00000000000000))*(x4511)*(x4516)))+(((IkReal(-1.00000000000000))*(x4512)*(x4517)))+(((IkReal(-1.00000000000000))*(x4511)*(x4515)))));
sj3array[0]=IKsin(j3array[0]);
cj3array[0]=IKcos(j3array[0]);
if( j3array[0] > IKPI )
{
    j3array[0]-=IK2PI;
}
else if( j3array[0] < -IKPI )
{    j3array[0]+=IK2PI;
}
j3valid[0] = true;
for(int ij3 = 0; ij3 < 1; ++ij3)
{
if( !j3valid[ij3] )
{
    continue;
}
_ij3[0] = ij3; _ij3[1] = -1;
for(int iij3 = ij3+1; iij3 < 1; ++iij3)
{
if( j3valid[iij3] && IKabs(cj3array[ij3]-cj3array[iij3]) < IKFAST_SOLUTION_THRESH && IKabs(sj3array[ij3]-sj3array[iij3]) < IKFAST_SOLUTION_THRESH )
{
    j3valid[iij3]=false; _ij3[1] = iij3; break; 
}
}
j3 = j3array[ij3]; cj3 = cj3array[ij3]; sj3 = sj3array[ij3];
{
IkReal evalcond[4];
IkReal x4518=IKcos(j3);
IkReal x4519=((sj0)*(sj5));
IkReal x4520=((r00)*(sj6));
IkReal x4521=((cj6)*(sj0));
IkReal x4522=((IkReal(1.00000000000000))*(cj4));
IkReal x4523=((r00)*(sj4));
IkReal x4524=((cj0)*(cj5));
IkReal x4525=((cj5)*(sj0));
IkReal x4526=((cj6)*(r11));
IkReal x4527=((r10)*(sj6));
IkReal x4528=((cj0)*(sj5));
IkReal x4529=((r10)*(sj4));
IkReal x4530=((IkReal(1.00000000000000))*(IKsin(j3)));
IkReal x4531=((cj4)*(cj5)*(r01));
IkReal x4532=((IkReal(1.00000000000000))*(cj0)*(cj6));
IkReal x4533=((cj0)*(sj4)*(sj6));
IkReal x4534=((sj0)*(sj4)*(sj6));
evalcond[0]=((((x4519)*(x4520)))+(((IkReal(-1.00000000000000))*(x4526)*(x4528)))+(((r12)*(x4524)))+(((IkReal(-1.00000000000000))*(r02)*(x4525)))+(((cj6)*(r01)*(x4519)))+(((IkReal(-1.00000000000000))*(x4530)))+(((IkReal(-1.00000000000000))*(x4527)*(x4528))));
evalcond[1]=((((r02)*(x4524)))+(((IkReal(-1.00000000000000))*(x4518)))+(((IkReal(-1.00000000000000))*(cj6)*(r01)*(x4528)))+(((IkReal(-1.00000000000000))*(x4519)*(x4526)))+(((IkReal(-1.00000000000000))*(x4520)*(x4528)))+(((r12)*(x4525)))+(((IkReal(-1.00000000000000))*(x4519)*(x4527))));
evalcond[2]=((x4518)+(((x4521)*(x4523)))+(((IkReal(-1.00000000000000))*(x4522)*(x4524)*(x4527)))+(((IkReal(-1.00000000000000))*(r12)*(x4522)*(x4528)))+(((IkReal(-1.00000000000000))*(x4522)*(x4524)*(x4526)))+(((IkReal(-1.00000000000000))*(r01)*(x4534)))+(((IkReal(-1.00000000000000))*(x4529)*(x4532)))+(((cj4)*(r02)*(x4519)))+(((r11)*(x4533)))+(((x4521)*(x4531)))+(((cj4)*(x4520)*(x4525))));
evalcond[3]=((((IkReal(-1.00000000000000))*(cj6)*(r01)*(x4522)*(x4524)))+(((IkReal(-1.00000000000000))*(x4521)*(x4529)))+(((IkReal(-1.00000000000000))*(x4522)*(x4525)*(x4527)))+(((IkReal(-1.00000000000000))*(x4520)*(x4522)*(x4524)))+(((IkReal(-1.00000000000000))*(x4523)*(x4532)))+(((r11)*(x4534)))+(((r01)*(x4533)))+(((IkReal(-1.00000000000000))*(r12)*(x4519)*(x4522)))+(((IkReal(-1.00000000000000))*(cj5)*(r11)*(x4521)*(x4522)))+(((IkReal(-1.00000000000000))*(x4530)))+(((IkReal(-1.00000000000000))*(r02)*(x4522)*(x4528))));
if( IKabs(evalcond[0]) > 0.000001  || IKabs(evalcond[1]) > 0.000001  || IKabs(evalcond[2]) > 0.000001  || IKabs(evalcond[3]) > 0.000001  )
{
continue;
}
}

{
std::vector<IkSingleDOFSolutionBase<IkReal> > vinfos(7);
vinfos[0].jointtype = 1;
vinfos[0].foffset = j0;
vinfos[0].indices[0] = _ij0[0];
vinfos[0].indices[1] = _ij0[1];
vinfos[0].maxsolutions = _nj0;
vinfos[1].jointtype = 1;
vinfos[1].foffset = j1;
vinfos[1].indices[0] = _ij1[0];
vinfos[1].indices[1] = _ij1[1];
vinfos[1].maxsolutions = _nj1;
vinfos[2].jointtype = 1;
vinfos[2].foffset = j2;
vinfos[2].indices[0] = _ij2[0];
vinfos[2].indices[1] = _ij2[1];
vinfos[2].maxsolutions = _nj2;
vinfos[3].jointtype = 1;
vinfos[3].foffset = j3;
vinfos[3].indices[0] = _ij3[0];
vinfos[3].indices[1] = _ij3[1];
vinfos[3].maxsolutions = _nj3;
vinfos[4].jointtype = 1;
vinfos[4].foffset = j4;
vinfos[4].indices[0] = _ij4[0];
vinfos[4].indices[1] = _ij4[1];
vinfos[4].maxsolutions = _nj4;
vinfos[5].jointtype = 1;
vinfos[5].foffset = j5;
vinfos[5].indices[0] = _ij5[0];
vinfos[5].indices[1] = _ij5[1];
vinfos[5].maxsolutions = _nj5;
vinfos[6].jointtype = 1;
vinfos[6].foffset = j6;
vinfos[6].indices[0] = _ij6[0];
vinfos[6].indices[1] = _ij6[1];
vinfos[6].maxsolutions = _nj6;
std::vector<int> vfree(0);
solutions.AddSolution(vinfos,vfree);
}
}
}

} else
{
IkReal x4535=((IkReal(1.00000000000000))*(cj0));
IkReal x4536=((cj4)*(sj6));
IkReal x4537=((sj0)*(sj4));
IkReal x4538=((cj5)*(sj6));
IkReal x4539=((sj4)*(sj5));
IkReal x4540=((r12)*(sj5));
IkReal x4541=((IkReal(0.374290000000000))*(cj5));
IkReal x4542=((r02)*(sj0));
IkReal x4543=((r20)*(sj4));
IkReal x4544=((IkReal(1.00000000000000))*(sj0));
IkReal x4545=((IkReal(1.00000000000000))*(cj5));
IkReal x4546=((cj0)*(r10));
IkReal x4547=((cj4)*(cj6));
IkReal x4548=((r00)*(sj0));
IkReal x4549=((cj6)*(r21));
IkReal x4550=((IkReal(0.374290000000000))*(sj5));
IkReal x4551=((cj0)*(r00));
IkReal x4552=((IkReal(0.0100000000000000))*(sj5));
IkReal x4553=((cj0)*(r02));
IkReal x4554=((cj5)*(sj4));
IkReal x4555=((cj6)*(r01));
IkReal x4556=((cj6)*(r11));
IkReal x4557=((r01)*(sj0));
IkReal x4558=((r10)*(sj0));
IkReal x4559=((IkReal(0.0100000000000000))*(cj5)*(cj6));
IkReal x4560=((sj6)*(x4550));
IkReal x4561=((cj0)*(cj6)*(x4550));
evalcond[0]=((IkReal(-3.14159265358979))+(IKfmod(j1, IkReal(6.28318530717959))));
evalcond[1]=((((IkReal(-1.00000000000000))*(r22)*(x4545)))+(((sj5)*(x4549)))+(((r20)*(sj5)*(sj6))));
evalcond[2]=((IkReal(1.00000000000000))+(((IkReal(-1.00000000000000))*(r20)*(x4547)))+(((r21)*(x4536)))+(((x4538)*(x4543)))+(((r22)*(x4539)))+(((x4549)*(x4554))));
evalcond[3]=((((IkReal(-1.00000000000000))*(r22)*(x4541)))+(((IkReal(-0.0100000000000000))*(r20)*(x4538)))+(((x4549)*(x4550)))+(pz)+(((r20)*(x4560)))+(((IkReal(-1.00000000000000))*(r22)*(x4552)))+(((IkReal(-0.0100000000000000))*(cj5)*(x4549))));
evalcond[4]=((((cj5)*(r21)*(x4547)))+(((IkReal(-1.00000000000000))*(r21)*(sj4)*(sj6)))+(((cj5)*(r20)*(x4536)))+(((cj4)*(r22)*(sj5)))+(((cj6)*(x4543))));
evalcond[5]=((((IkReal(-1.00000000000000))*(r10)*(sj4)*(x4535)*(x4538)))+(((cj5)*(x4537)*(x4555)))+(((IkReal(-1.00000000000000))*(r12)*(x4535)*(x4539)))+(((IkReal(-1.00000000000000))*(x4535)*(x4554)*(x4556)))+(((r00)*(x4537)*(x4538)))+(((r02)*(sj5)*(x4537)))+(((IkReal(-1.00000000000000))*(r00)*(x4544)*(x4547)))+(((IkReal(-1.00000000000000))*(r11)*(x4535)*(x4536)))+(((x4536)*(x4557)))+(((x4546)*(x4547))));
evalcond[6]=((((IkReal(-1.00000000000000))*(r10)*(x4537)*(x4538)))+(((IkReal(-1.00000000000000))*(x4537)*(x4545)*(x4556)))+(((x4547)*(x4558)))+(((x4547)*(x4551)))+(((IkReal(-1.00000000000000))*(r00)*(sj4)*(x4535)*(x4538)))+(((IkReal(-1.00000000000000))*(x4537)*(x4540)))+(((IkReal(-1.00000000000000))*(r01)*(x4535)*(x4536)))+(((IkReal(-1.00000000000000))*(r02)*(x4535)*(x4539)))+(((IkReal(-1.00000000000000))*(r11)*(x4536)*(x4544)))+(((IkReal(-1.00000000000000))*(x4535)*(x4554)*(x4555))));
evalcond[7]=((IkReal(0.0690000000000000))+(((IkReal(-1.00000000000000))*(cj0)*(x4550)*(x4556)))+(((IkReal(0.0100000000000000))*(cj0)*(x4540)))+(((IkReal(-1.00000000000000))*(py)*(x4535)))+(((IkReal(-0.0100000000000000))*(cj5)*(sj0)*(x4555)))+(((IkReal(-1.00000000000000))*(x4546)*(x4560)))+(((IkReal(-0.0100000000000000))*(x4538)*(x4548)))+(((x4548)*(x4560)))+(((IkReal(-1.00000000000000))*(x4542)*(x4552)))+(((IkReal(0.0100000000000000))*(x4538)*(x4546)))+(((cj0)*(r12)*(x4541)))+(((px)*(sj0)))+(((sj0)*(x4550)*(x4555)))+(((IkReal(-1.00000000000000))*(x4541)*(x4542)))+(((IkReal(0.0100000000000000))*(cj0)*(cj5)*(x4556))));
evalcond[8]=((IkReal(-0.295420000000000))+(((x4552)*(x4553)))+(((IkReal(-1.00000000000000))*(x4558)*(x4560)))+(((IkReal(-1.00000000000000))*(py)*(x4544)))+(((x4541)*(x4553)))+(((IkReal(0.0100000000000000))*(cj0)*(cj5)*(x4555)))+(((IkReal(-1.00000000000000))*(px)*(x4535)))+(((IkReal(-1.00000000000000))*(sj0)*(x4550)*(x4556)))+(((IkReal(-1.00000000000000))*(cj0)*(x4550)*(x4555)))+(((r12)*(sj0)*(x4541)))+(((IkReal(0.0100000000000000))*(x4538)*(x4551)))+(((IkReal(-1.00000000000000))*(x4551)*(x4560)))+(((IkReal(0.0100000000000000))*(sj0)*(x4540)))+(((IkReal(0.0100000000000000))*(x4538)*(x4558)))+(((IkReal(0.0100000000000000))*(cj5)*(sj0)*(x4556))));
if( IKabs(evalcond[0]) < 0.0000010000000000  && IKabs(evalcond[1]) < 0.0000010000000000  && IKabs(evalcond[2]) < 0.0000010000000000  && IKabs(evalcond[3]) < 0.0000010000000000  && IKabs(evalcond[4]) < 0.0000010000000000  && IKabs(evalcond[5]) < 0.0000010000000000  && IKabs(evalcond[6]) < 0.0000010000000000  && IKabs(evalcond[7]) < 0.0000010000000000  && IKabs(evalcond[8]) < 0.0000010000000000  )
{
{
IkReal j3array[1], cj3array[1], sj3array[1];
bool j3valid[1]={false};
_nj3 = 1;
IkReal x4562=((sj0)*(sj5));
IkReal x4563=((r00)*(sj6));
IkReal x4564=((IkReal(1.00000000000000))*(cj5));
IkReal x4565=((cj6)*(r11));
IkReal x4566=((cj6)*(r01));
IkReal x4567=((r10)*(sj6));
IkReal x4568=((cj0)*(sj5));
if( IKabs(((((IkReal(-1.00000000000000))*(x4565)*(x4568)))+(((x4562)*(x4563)))+(((IkReal(-1.00000000000000))*(r02)*(sj0)*(x4564)))+(((IkReal(-1.00000000000000))*(x4567)*(x4568)))+(((cj0)*(cj5)*(r12)))+(((x4562)*(x4566))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(((((x4563)*(x4568)))+(((IkReal(-1.00000000000000))*(r12)*(sj0)*(x4564)))+(((x4562)*(x4567)))+(((IkReal(-1.00000000000000))*(cj0)*(r02)*(x4564)))+(((x4562)*(x4565)))+(((x4566)*(x4568))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(IKsqr(((((IkReal(-1.00000000000000))*(x4565)*(x4568)))+(((x4562)*(x4563)))+(((IkReal(-1.00000000000000))*(r02)*(sj0)*(x4564)))+(((IkReal(-1.00000000000000))*(x4567)*(x4568)))+(((cj0)*(cj5)*(r12)))+(((x4562)*(x4566)))))+IKsqr(((((x4563)*(x4568)))+(((IkReal(-1.00000000000000))*(r12)*(sj0)*(x4564)))+(((x4562)*(x4567)))+(((IkReal(-1.00000000000000))*(cj0)*(r02)*(x4564)))+(((x4562)*(x4565)))+(((x4566)*(x4568)))))-1) <= IKFAST_SINCOS_THRESH )
    continue;
j3array[0]=IKatan2(((((IkReal(-1.00000000000000))*(x4565)*(x4568)))+(((x4562)*(x4563)))+(((IkReal(-1.00000000000000))*(r02)*(sj0)*(x4564)))+(((IkReal(-1.00000000000000))*(x4567)*(x4568)))+(((cj0)*(cj5)*(r12)))+(((x4562)*(x4566)))), ((((x4563)*(x4568)))+(((IkReal(-1.00000000000000))*(r12)*(sj0)*(x4564)))+(((x4562)*(x4567)))+(((IkReal(-1.00000000000000))*(cj0)*(r02)*(x4564)))+(((x4562)*(x4565)))+(((x4566)*(x4568)))));
sj3array[0]=IKsin(j3array[0]);
cj3array[0]=IKcos(j3array[0]);
if( j3array[0] > IKPI )
{
    j3array[0]-=IK2PI;
}
else if( j3array[0] < -IKPI )
{    j3array[0]+=IK2PI;
}
j3valid[0] = true;
for(int ij3 = 0; ij3 < 1; ++ij3)
{
if( !j3valid[ij3] )
{
    continue;
}
_ij3[0] = ij3; _ij3[1] = -1;
for(int iij3 = ij3+1; iij3 < 1; ++iij3)
{
if( j3valid[iij3] && IKabs(cj3array[ij3]-cj3array[iij3]) < IKFAST_SOLUTION_THRESH && IKabs(sj3array[ij3]-sj3array[iij3]) < IKFAST_SOLUTION_THRESH )
{
    j3valid[iij3]=false; _ij3[1] = iij3; break; 
}
}
j3 = j3array[ij3]; cj3 = cj3array[ij3]; sj3 = sj3array[ij3];
{
IkReal evalcond[4];
IkReal x4569=IKcos(j3);
IkReal x4570=IKsin(j3);
IkReal x4571=((sj0)*(sj5));
IkReal x4572=((r00)*(sj6));
IkReal x4573=((cj6)*(sj0));
IkReal x4574=((IkReal(1.00000000000000))*(cj4));
IkReal x4575=((r00)*(sj4));
IkReal x4576=((cj0)*(cj5));
IkReal x4577=((cj5)*(sj0));
IkReal x4578=((cj6)*(r11));
IkReal x4579=((r10)*(sj6));
IkReal x4580=((cj0)*(sj5));
IkReal x4581=((r10)*(sj4));
IkReal x4582=((cj4)*(cj5)*(r01));
IkReal x4583=((IkReal(1.00000000000000))*(cj0)*(cj6));
IkReal x4584=((cj0)*(sj4)*(sj6));
IkReal x4585=((sj0)*(sj4)*(sj6));
evalcond[0]=((((r12)*(x4576)))+(((cj6)*(r01)*(x4571)))+(((IkReal(-1.00000000000000))*(x4579)*(x4580)))+(((x4571)*(x4572)))+(((IkReal(-1.00000000000000))*(x4578)*(x4580)))+(((IkReal(-1.00000000000000))*(x4570)))+(((IkReal(-1.00000000000000))*(r02)*(x4577))));
evalcond[1]=((((IkReal(-1.00000000000000))*(x4571)*(x4579)))+(((IkReal(-1.00000000000000))*(x4571)*(x4578)))+(((IkReal(-1.00000000000000))*(cj6)*(r01)*(x4580)))+(((r12)*(x4577)))+(((IkReal(-1.00000000000000))*(x4572)*(x4580)))+(x4569)+(((r02)*(x4576))));
evalcond[2]=((((IkReal(-1.00000000000000))*(r01)*(x4585)))+(((IkReal(-1.00000000000000))*(x4574)*(x4576)*(x4579)))+(((IkReal(-1.00000000000000))*(x4574)*(x4576)*(x4578)))+(((cj4)*(x4572)*(x4577)))+(((r11)*(x4584)))+(((IkReal(-1.00000000000000))*(x4581)*(x4583)))+(((cj4)*(r02)*(x4571)))+(x4569)+(((x4573)*(x4575)))+(((x4573)*(x4582)))+(((IkReal(-1.00000000000000))*(r12)*(x4574)*(x4580))));
evalcond[3]=((x4570)+(((IkReal(-1.00000000000000))*(x4574)*(x4577)*(x4579)))+(((IkReal(-1.00000000000000))*(r02)*(x4574)*(x4580)))+(((r11)*(x4585)))+(((IkReal(-1.00000000000000))*(cj6)*(r01)*(x4574)*(x4576)))+(((IkReal(-1.00000000000000))*(x4573)*(x4581)))+(((IkReal(-1.00000000000000))*(x4575)*(x4583)))+(((IkReal(-1.00000000000000))*(cj5)*(r11)*(x4573)*(x4574)))+(((r01)*(x4584)))+(((IkReal(-1.00000000000000))*(r12)*(x4571)*(x4574)))+(((IkReal(-1.00000000000000))*(x4572)*(x4574)*(x4576))));
if( IKabs(evalcond[0]) > 0.000001  || IKabs(evalcond[1]) > 0.000001  || IKabs(evalcond[2]) > 0.000001  || IKabs(evalcond[3]) > 0.000001  )
{
continue;
}
}

{
std::vector<IkSingleDOFSolutionBase<IkReal> > vinfos(7);
vinfos[0].jointtype = 1;
vinfos[0].foffset = j0;
vinfos[0].indices[0] = _ij0[0];
vinfos[0].indices[1] = _ij0[1];
vinfos[0].maxsolutions = _nj0;
vinfos[1].jointtype = 1;
vinfos[1].foffset = j1;
vinfos[1].indices[0] = _ij1[0];
vinfos[1].indices[1] = _ij1[1];
vinfos[1].maxsolutions = _nj1;
vinfos[2].jointtype = 1;
vinfos[2].foffset = j2;
vinfos[2].indices[0] = _ij2[0];
vinfos[2].indices[1] = _ij2[1];
vinfos[2].maxsolutions = _nj2;
vinfos[3].jointtype = 1;
vinfos[3].foffset = j3;
vinfos[3].indices[0] = _ij3[0];
vinfos[3].indices[1] = _ij3[1];
vinfos[3].maxsolutions = _nj3;
vinfos[4].jointtype = 1;
vinfos[4].foffset = j4;
vinfos[4].indices[0] = _ij4[0];
vinfos[4].indices[1] = _ij4[1];
vinfos[4].maxsolutions = _nj4;
vinfos[5].jointtype = 1;
vinfos[5].foffset = j5;
vinfos[5].indices[0] = _ij5[0];
vinfos[5].indices[1] = _ij5[1];
vinfos[5].maxsolutions = _nj5;
vinfos[6].jointtype = 1;
vinfos[6].foffset = j6;
vinfos[6].indices[0] = _ij6[0];
vinfos[6].indices[1] = _ij6[1];
vinfos[6].maxsolutions = _nj6;
std::vector<int> vfree(0);
solutions.AddSolution(vinfos,vfree);
}
}
}

} else
{
if( 1 )
{
continue;

} else
{
}
}
}
}
}
}

} else
{
{
IkReal j3array[1], cj3array[1], sj3array[1];
bool j3valid[1]={false};
_nj3 = 1;
IkReal x4586=((cj0)*(cj5));
IkReal x4587=((IkReal(1.00000000000000))*(cj0));
IkReal x4588=((cj6)*(r11));
IkReal x4589=((r10)*(sj6));
IkReal x4590=((cj5)*(sj0));
IkReal x4591=((r00)*(sj5)*(sj6));
IkReal x4592=((cj6)*(r01)*(sj5));
IkReal x4593=((IkReal(1.00000000000000))*(sj0)*(sj5));
if( IKabs(((((sj0)*(x4592)))+(((sj0)*(x4591)))+(((IkReal(-1.00000000000000))*(sj5)*(x4587)*(x4588)))+(((IkReal(-1.00000000000000))*(r02)*(x4590)))+(((r12)*(x4586)))+(((IkReal(-1.00000000000000))*(sj5)*(x4587)*(x4589))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(((((IKabs(cj1) != 0)?((IkReal)1/(cj1)):(IkReal)1.0e30))*(((((IkReal(-1.00000000000000))*(x4587)*(x4592)))+(((IkReal(-1.00000000000000))*(x4588)*(x4593)))+(((IkReal(-1.00000000000000))*(x4589)*(x4593)))+(((IkReal(-1.00000000000000))*(x4587)*(x4591)))+(((r12)*(x4590)))+(((r02)*(x4586))))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(IKsqr(((((sj0)*(x4592)))+(((sj0)*(x4591)))+(((IkReal(-1.00000000000000))*(sj5)*(x4587)*(x4588)))+(((IkReal(-1.00000000000000))*(r02)*(x4590)))+(((r12)*(x4586)))+(((IkReal(-1.00000000000000))*(sj5)*(x4587)*(x4589)))))+IKsqr(((((IKabs(cj1) != 0)?((IkReal)1/(cj1)):(IkReal)1.0e30))*(((((IkReal(-1.00000000000000))*(x4587)*(x4592)))+(((IkReal(-1.00000000000000))*(x4588)*(x4593)))+(((IkReal(-1.00000000000000))*(x4589)*(x4593)))+(((IkReal(-1.00000000000000))*(x4587)*(x4591)))+(((r12)*(x4590)))+(((r02)*(x4586)))))))-1) <= IKFAST_SINCOS_THRESH )
    continue;
j3array[0]=IKatan2(((((sj0)*(x4592)))+(((sj0)*(x4591)))+(((IkReal(-1.00000000000000))*(sj5)*(x4587)*(x4588)))+(((IkReal(-1.00000000000000))*(r02)*(x4590)))+(((r12)*(x4586)))+(((IkReal(-1.00000000000000))*(sj5)*(x4587)*(x4589)))), ((((IKabs(cj1) != 0)?((IkReal)1/(cj1)):(IkReal)1.0e30))*(((((IkReal(-1.00000000000000))*(x4587)*(x4592)))+(((IkReal(-1.00000000000000))*(x4588)*(x4593)))+(((IkReal(-1.00000000000000))*(x4589)*(x4593)))+(((IkReal(-1.00000000000000))*(x4587)*(x4591)))+(((r12)*(x4590)))+(((r02)*(x4586)))))));
sj3array[0]=IKsin(j3array[0]);
cj3array[0]=IKcos(j3array[0]);
if( j3array[0] > IKPI )
{
    j3array[0]-=IK2PI;
}
else if( j3array[0] < -IKPI )
{    j3array[0]+=IK2PI;
}
j3valid[0] = true;
for(int ij3 = 0; ij3 < 1; ++ij3)
{
if( !j3valid[ij3] )
{
    continue;
}
_ij3[0] = ij3; _ij3[1] = -1;
for(int iij3 = ij3+1; iij3 < 1; ++iij3)
{
if( j3valid[iij3] && IKabs(cj3array[ij3]-cj3array[iij3]) < IKFAST_SOLUTION_THRESH && IKabs(sj3array[ij3]-sj3array[iij3]) < IKFAST_SOLUTION_THRESH )
{
    j3valid[iij3]=false; _ij3[1] = iij3; break; 
}
}
j3 = j3array[ij3]; cj3 = cj3array[ij3]; sj3 = sj3array[ij3];
{
IkReal evalcond[6];
IkReal x4594=IKsin(j3);
IkReal x4595=IKcos(j3);
IkReal x4596=((sj0)*(sj5));
IkReal x4597=((r00)*(sj6));
IkReal x4598=((cj6)*(r01));
IkReal x4599=((cj4)*(cj5));
IkReal x4600=((IkReal(1.00000000000000))*(cj0));
IkReal x4601=((cj5)*(r12));
IkReal x4602=((IkReal(1.00000000000000))*(sj0));
IkReal x4603=((cj6)*(r11));
IkReal x4604=((cj5)*(r02));
IkReal x4605=((IkReal(1.00000000000000))*(cj1));
IkReal x4606=((cj6)*(sj4));
IkReal x4607=((cj6)*(r21));
IkReal x4608=((r20)*(sj6));
IkReal x4609=((r10)*(sj6));
IkReal x4610=((sj4)*(sj6));
IkReal x4611=((cj4)*(r02));
IkReal x4612=((IkReal(1.00000000000000))*(cj4)*(r12));
IkReal x4613=((IkReal(1.00000000000000))*(x4594));
IkReal x4614=((cj0)*(x4610));
evalcond[0]=((((sj5)*(x4608)))+(((IkReal(-1.00000000000000))*(cj5)*(r22)))+(((IkReal(-1.00000000000000))*(sj1)*(x4595)))+(((sj5)*(x4607))));
evalcond[1]=((((r20)*(x4606)))+(((cj4)*(r22)*(sj5)))+(((x4599)*(x4607)))+(((IkReal(-1.00000000000000))*(sj1)*(x4613)))+(((IkReal(-1.00000000000000))*(r21)*(x4610)))+(((x4599)*(x4608))));
evalcond[2]=((((cj0)*(x4601)))+(((IkReal(-1.00000000000000))*(sj5)*(x4600)*(x4609)))+(((IkReal(-1.00000000000000))*(x4613)))+(((IkReal(-1.00000000000000))*(sj5)*(x4600)*(x4603)))+(((x4596)*(x4597)))+(((x4596)*(x4598)))+(((IkReal(-1.00000000000000))*(x4602)*(x4604))));
evalcond[3]=((((IkReal(-1.00000000000000))*(sj5)*(x4598)*(x4600)))+(((IkReal(-1.00000000000000))*(x4595)*(x4605)))+(((sj0)*(x4601)))+(((IkReal(-1.00000000000000))*(x4596)*(x4603)))+(((cj0)*(x4604)))+(((IkReal(-1.00000000000000))*(sj5)*(x4597)*(x4600)))+(((IkReal(-1.00000000000000))*(x4596)*(x4609))));
evalcond[4]=((x4595)+(((r11)*(x4614)))+(((sj0)*(x4598)*(x4599)))+(((sj0)*(x4597)*(x4599)))+(((IkReal(-1.00000000000000))*(x4599)*(x4600)*(x4609)))+(((x4596)*(x4611)))+(((IkReal(-1.00000000000000))*(r01)*(x4602)*(x4610)))+(((IkReal(-1.00000000000000))*(x4599)*(x4600)*(x4603)))+(((IkReal(-1.00000000000000))*(cj4)*(r12)*(sj5)*(x4600)))+(((IkReal(-1.00000000000000))*(r10)*(x4600)*(x4606)))+(((r00)*(sj0)*(x4606))));
evalcond[5]=((((IkReal(-1.00000000000000))*(x4594)*(x4605)))+(((IkReal(-1.00000000000000))*(x4599)*(x4602)*(x4603)))+(((IkReal(-1.00000000000000))*(r00)*(x4600)*(x4606)))+(((r01)*(x4614)))+(((IkReal(-1.00000000000000))*(x4597)*(x4599)*(x4600)))+(((IkReal(-1.00000000000000))*(x4599)*(x4602)*(x4609)))+(((IkReal(-1.00000000000000))*(x4598)*(x4599)*(x4600)))+(((IkReal(-1.00000000000000))*(sj5)*(x4600)*(x4611)))+(((r11)*(sj0)*(x4610)))+(((IkReal(-1.00000000000000))*(r10)*(x4602)*(x4606)))+(((IkReal(-1.00000000000000))*(x4596)*(x4612))));
if( IKabs(evalcond[0]) > 0.000001  || IKabs(evalcond[1]) > 0.000001  || IKabs(evalcond[2]) > 0.000001  || IKabs(evalcond[3]) > 0.000001  || IKabs(evalcond[4]) > 0.000001  || IKabs(evalcond[5]) > 0.000001  )
{
continue;
}
}

{
std::vector<IkSingleDOFSolutionBase<IkReal> > vinfos(7);
vinfos[0].jointtype = 1;
vinfos[0].foffset = j0;
vinfos[0].indices[0] = _ij0[0];
vinfos[0].indices[1] = _ij0[1];
vinfos[0].maxsolutions = _nj0;
vinfos[1].jointtype = 1;
vinfos[1].foffset = j1;
vinfos[1].indices[0] = _ij1[0];
vinfos[1].indices[1] = _ij1[1];
vinfos[1].maxsolutions = _nj1;
vinfos[2].jointtype = 1;
vinfos[2].foffset = j2;
vinfos[2].indices[0] = _ij2[0];
vinfos[2].indices[1] = _ij2[1];
vinfos[2].maxsolutions = _nj2;
vinfos[3].jointtype = 1;
vinfos[3].foffset = j3;
vinfos[3].indices[0] = _ij3[0];
vinfos[3].indices[1] = _ij3[1];
vinfos[3].maxsolutions = _nj3;
vinfos[4].jointtype = 1;
vinfos[4].foffset = j4;
vinfos[4].indices[0] = _ij4[0];
vinfos[4].indices[1] = _ij4[1];
vinfos[4].maxsolutions = _nj4;
vinfos[5].jointtype = 1;
vinfos[5].foffset = j5;
vinfos[5].indices[0] = _ij5[0];
vinfos[5].indices[1] = _ij5[1];
vinfos[5].maxsolutions = _nj5;
vinfos[6].jointtype = 1;
vinfos[6].foffset = j6;
vinfos[6].indices[0] = _ij6[0];
vinfos[6].indices[1] = _ij6[1];
vinfos[6].maxsolutions = _nj6;
std::vector<int> vfree(0);
solutions.AddSolution(vinfos,vfree);
}
}
}

}

}

} else
{
{
IkReal j3array[1], cj3array[1], sj3array[1];
bool j3valid[1]={false};
_nj3 = 1;
IkReal x4615=((sj5)*(sj6));
IkReal x4616=((cj6)*(sj5));
IkReal x4617=((IkReal(1.00000000000000))*(cj0));
IkReal x4618=((IkReal(1.00000000000000))*(cj5));
if( IKabs(((((r01)*(sj0)*(x4616)))+(((r00)*(sj0)*(x4615)))+(((IkReal(-1.00000000000000))*(r10)*(x4615)*(x4617)))+(((cj0)*(cj5)*(r12)))+(((IkReal(-1.00000000000000))*(r02)*(sj0)*(x4618)))+(((IkReal(-1.00000000000000))*(r11)*(x4616)*(x4617))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(((((IKabs(sj1) != 0)?((IkReal)1/(sj1)):(IkReal)1.0e30))*(((((IkReal(-1.00000000000000))*(r22)*(x4618)))+(((r20)*(x4615)))+(((r21)*(x4616))))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(IKsqr(((((r01)*(sj0)*(x4616)))+(((r00)*(sj0)*(x4615)))+(((IkReal(-1.00000000000000))*(r10)*(x4615)*(x4617)))+(((cj0)*(cj5)*(r12)))+(((IkReal(-1.00000000000000))*(r02)*(sj0)*(x4618)))+(((IkReal(-1.00000000000000))*(r11)*(x4616)*(x4617)))))+IKsqr(((((IKabs(sj1) != 0)?((IkReal)1/(sj1)):(IkReal)1.0e30))*(((((IkReal(-1.00000000000000))*(r22)*(x4618)))+(((r20)*(x4615)))+(((r21)*(x4616)))))))-1) <= IKFAST_SINCOS_THRESH )
    continue;
j3array[0]=IKatan2(((((r01)*(sj0)*(x4616)))+(((r00)*(sj0)*(x4615)))+(((IkReal(-1.00000000000000))*(r10)*(x4615)*(x4617)))+(((cj0)*(cj5)*(r12)))+(((IkReal(-1.00000000000000))*(r02)*(sj0)*(x4618)))+(((IkReal(-1.00000000000000))*(r11)*(x4616)*(x4617)))), ((((IKabs(sj1) != 0)?((IkReal)1/(sj1)):(IkReal)1.0e30))*(((((IkReal(-1.00000000000000))*(r22)*(x4618)))+(((r20)*(x4615)))+(((r21)*(x4616)))))));
sj3array[0]=IKsin(j3array[0]);
cj3array[0]=IKcos(j3array[0]);
if( j3array[0] > IKPI )
{
    j3array[0]-=IK2PI;
}
else if( j3array[0] < -IKPI )
{    j3array[0]+=IK2PI;
}
j3valid[0] = true;
for(int ij3 = 0; ij3 < 1; ++ij3)
{
if( !j3valid[ij3] )
{
    continue;
}
_ij3[0] = ij3; _ij3[1] = -1;
for(int iij3 = ij3+1; iij3 < 1; ++iij3)
{
if( j3valid[iij3] && IKabs(cj3array[ij3]-cj3array[iij3]) < IKFAST_SOLUTION_THRESH && IKabs(sj3array[ij3]-sj3array[iij3]) < IKFAST_SOLUTION_THRESH )
{
    j3valid[iij3]=false; _ij3[1] = iij3; break; 
}
}
j3 = j3array[ij3]; cj3 = cj3array[ij3]; sj3 = sj3array[ij3];
{
IkReal evalcond[6];
IkReal x4619=IKsin(j3);
IkReal x4620=IKcos(j3);
IkReal x4621=((sj0)*(sj5));
IkReal x4622=((r00)*(sj6));
IkReal x4623=((cj6)*(r01));
IkReal x4624=((cj4)*(cj5));
IkReal x4625=((IkReal(1.00000000000000))*(cj0));
IkReal x4626=((cj5)*(r12));
IkReal x4627=((IkReal(1.00000000000000))*(sj0));
IkReal x4628=((cj6)*(r11));
IkReal x4629=((cj5)*(r02));
IkReal x4630=((IkReal(1.00000000000000))*(cj1));
IkReal x4631=((cj6)*(sj4));
IkReal x4632=((cj6)*(r21));
IkReal x4633=((r20)*(sj6));
IkReal x4634=((r10)*(sj6));
IkReal x4635=((sj4)*(sj6));
IkReal x4636=((cj4)*(r02));
IkReal x4637=((IkReal(1.00000000000000))*(cj4)*(r12));
IkReal x4638=((IkReal(1.00000000000000))*(x4619));
IkReal x4639=((cj0)*(x4635));
evalcond[0]=((((IkReal(-1.00000000000000))*(sj1)*(x4620)))+(((IkReal(-1.00000000000000))*(cj5)*(r22)))+(((sj5)*(x4632)))+(((sj5)*(x4633))));
evalcond[1]=((((IkReal(-1.00000000000000))*(sj1)*(x4638)))+(((cj4)*(r22)*(sj5)))+(((r20)*(x4631)))+(((x4624)*(x4633)))+(((x4624)*(x4632)))+(((IkReal(-1.00000000000000))*(r21)*(x4635))));
evalcond[2]=((((IkReal(-1.00000000000000))*(x4627)*(x4629)))+(((IkReal(-1.00000000000000))*(x4638)))+(((IkReal(-1.00000000000000))*(sj5)*(x4625)*(x4634)))+(((x4621)*(x4623)))+(((x4621)*(x4622)))+(((cj0)*(x4626)))+(((IkReal(-1.00000000000000))*(sj5)*(x4625)*(x4628))));
evalcond[3]=((((IkReal(-1.00000000000000))*(x4621)*(x4628)))+(((cj0)*(x4629)))+(((IkReal(-1.00000000000000))*(sj5)*(x4622)*(x4625)))+(((IkReal(-1.00000000000000))*(sj5)*(x4623)*(x4625)))+(((IkReal(-1.00000000000000))*(x4620)*(x4630)))+(((IkReal(-1.00000000000000))*(x4621)*(x4634)))+(((sj0)*(x4626))));
evalcond[4]=((((sj0)*(x4623)*(x4624)))+(((IkReal(-1.00000000000000))*(x4624)*(x4625)*(x4634)))+(((IkReal(-1.00000000000000))*(cj4)*(r12)*(sj5)*(x4625)))+(((x4621)*(x4636)))+(((r11)*(x4639)))+(((IkReal(-1.00000000000000))*(r10)*(x4625)*(x4631)))+(((IkReal(-1.00000000000000))*(r01)*(x4627)*(x4635)))+(((r00)*(sj0)*(x4631)))+(((sj0)*(x4622)*(x4624)))+(((IkReal(-1.00000000000000))*(x4624)*(x4625)*(x4628)))+(x4620));
evalcond[5]=((((IkReal(-1.00000000000000))*(x4624)*(x4627)*(x4628)))+(((IkReal(-1.00000000000000))*(x4624)*(x4627)*(x4634)))+(((IkReal(-1.00000000000000))*(r00)*(x4625)*(x4631)))+(((IkReal(-1.00000000000000))*(r10)*(x4627)*(x4631)))+(((IkReal(-1.00000000000000))*(x4622)*(x4624)*(x4625)))+(((IkReal(-1.00000000000000))*(x4619)*(x4630)))+(((r11)*(sj0)*(x4635)))+(((IkReal(-1.00000000000000))*(x4621)*(x4637)))+(((IkReal(-1.00000000000000))*(sj5)*(x4625)*(x4636)))+(((r01)*(x4639)))+(((IkReal(-1.00000000000000))*(x4623)*(x4624)*(x4625))));
if( IKabs(evalcond[0]) > 0.000001  || IKabs(evalcond[1]) > 0.000001  || IKabs(evalcond[2]) > 0.000001  || IKabs(evalcond[3]) > 0.000001  || IKabs(evalcond[4]) > 0.000001  || IKabs(evalcond[5]) > 0.000001  )
{
continue;
}
}

{
std::vector<IkSingleDOFSolutionBase<IkReal> > vinfos(7);
vinfos[0].jointtype = 1;
vinfos[0].foffset = j0;
vinfos[0].indices[0] = _ij0[0];
vinfos[0].indices[1] = _ij0[1];
vinfos[0].maxsolutions = _nj0;
vinfos[1].jointtype = 1;
vinfos[1].foffset = j1;
vinfos[1].indices[0] = _ij1[0];
vinfos[1].indices[1] = _ij1[1];
vinfos[1].maxsolutions = _nj1;
vinfos[2].jointtype = 1;
vinfos[2].foffset = j2;
vinfos[2].indices[0] = _ij2[0];
vinfos[2].indices[1] = _ij2[1];
vinfos[2].maxsolutions = _nj2;
vinfos[3].jointtype = 1;
vinfos[3].foffset = j3;
vinfos[3].indices[0] = _ij3[0];
vinfos[3].indices[1] = _ij3[1];
vinfos[3].maxsolutions = _nj3;
vinfos[4].jointtype = 1;
vinfos[4].foffset = j4;
vinfos[4].indices[0] = _ij4[0];
vinfos[4].indices[1] = _ij4[1];
vinfos[4].maxsolutions = _nj4;
vinfos[5].jointtype = 1;
vinfos[5].foffset = j5;
vinfos[5].indices[0] = _ij5[0];
vinfos[5].indices[1] = _ij5[1];
vinfos[5].maxsolutions = _nj5;
vinfos[6].jointtype = 1;
vinfos[6].foffset = j6;
vinfos[6].indices[0] = _ij6[0];
vinfos[6].indices[1] = _ij6[1];
vinfos[6].maxsolutions = _nj6;
std::vector<int> vfree(0);
solutions.AddSolution(vinfos,vfree);
}
}
}

}

}

} else
{
{
IkReal j3array[1], cj3array[1], sj3array[1];
bool j3valid[1]={false};
_nj3 = 1;
IkReal x4640=((r20)*(sj6));
IkReal x4641=((cj4)*(cj5));
IkReal x4642=((cj6)*(r21));
if( IKabs(((gconst17)*(((((IkReal(-1.00000000000000))*(r21)*(sj4)*(sj6)))+(((x4641)*(x4642)))+(((cj6)*(r20)*(sj4)))+(((cj4)*(r22)*(sj5)))+(((x4640)*(x4641))))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(((gconst17)*(((((IkReal(-1.00000000000000))*(cj5)*(r22)))+(((sj5)*(x4640)))+(((sj5)*(x4642))))))) < IKFAST_ATAN2_MAGTHRESH )
    continue;
j3array[0]=IKatan2(((gconst17)*(((((IkReal(-1.00000000000000))*(r21)*(sj4)*(sj6)))+(((x4641)*(x4642)))+(((cj6)*(r20)*(sj4)))+(((cj4)*(r22)*(sj5)))+(((x4640)*(x4641)))))), ((gconst17)*(((((IkReal(-1.00000000000000))*(cj5)*(r22)))+(((sj5)*(x4640)))+(((sj5)*(x4642)))))));
sj3array[0]=IKsin(j3array[0]);
cj3array[0]=IKcos(j3array[0]);
if( j3array[0] > IKPI )
{
    j3array[0]-=IK2PI;
}
else if( j3array[0] < -IKPI )
{    j3array[0]+=IK2PI;
}
j3valid[0] = true;
for(int ij3 = 0; ij3 < 1; ++ij3)
{
if( !j3valid[ij3] )
{
    continue;
}
_ij3[0] = ij3; _ij3[1] = -1;
for(int iij3 = ij3+1; iij3 < 1; ++iij3)
{
if( j3valid[iij3] && IKabs(cj3array[ij3]-cj3array[iij3]) < IKFAST_SOLUTION_THRESH && IKabs(sj3array[ij3]-sj3array[iij3]) < IKFAST_SOLUTION_THRESH )
{
    j3valid[iij3]=false; _ij3[1] = iij3; break; 
}
}
j3 = j3array[ij3]; cj3 = cj3array[ij3]; sj3 = sj3array[ij3];
{
IkReal evalcond[6];
IkReal x4643=IKsin(j3);
IkReal x4644=IKcos(j3);
IkReal x4645=((sj0)*(sj5));
IkReal x4646=((r00)*(sj6));
IkReal x4647=((cj6)*(r01));
IkReal x4648=((cj4)*(cj5));
IkReal x4649=((IkReal(1.00000000000000))*(cj0));
IkReal x4650=((cj5)*(r12));
IkReal x4651=((IkReal(1.00000000000000))*(sj0));
IkReal x4652=((cj6)*(r11));
IkReal x4653=((cj5)*(r02));
IkReal x4654=((IkReal(1.00000000000000))*(cj1));
IkReal x4655=((cj6)*(sj4));
IkReal x4656=((cj6)*(r21));
IkReal x4657=((r20)*(sj6));
IkReal x4658=((r10)*(sj6));
IkReal x4659=((sj4)*(sj6));
IkReal x4660=((cj4)*(r02));
IkReal x4661=((IkReal(1.00000000000000))*(cj4)*(r12));
IkReal x4662=((IkReal(1.00000000000000))*(x4643));
IkReal x4663=((cj0)*(x4659));
evalcond[0]=((((IkReal(-1.00000000000000))*(cj5)*(r22)))+(((sj5)*(x4656)))+(((sj5)*(x4657)))+(((IkReal(-1.00000000000000))*(sj1)*(x4644))));
evalcond[1]=((((IkReal(-1.00000000000000))*(sj1)*(x4662)))+(((r20)*(x4655)))+(((cj4)*(r22)*(sj5)))+(((IkReal(-1.00000000000000))*(r21)*(x4659)))+(((x4648)*(x4657)))+(((x4648)*(x4656))));
evalcond[2]=((((x4645)*(x4646)))+(((IkReal(-1.00000000000000))*(sj5)*(x4649)*(x4658)))+(((cj0)*(x4650)))+(((x4645)*(x4647)))+(((IkReal(-1.00000000000000))*(x4662)))+(((IkReal(-1.00000000000000))*(sj5)*(x4649)*(x4652)))+(((IkReal(-1.00000000000000))*(x4651)*(x4653))));
evalcond[3]=((((IkReal(-1.00000000000000))*(x4645)*(x4658)))+(((IkReal(-1.00000000000000))*(sj5)*(x4647)*(x4649)))+(((IkReal(-1.00000000000000))*(x4644)*(x4654)))+(((cj0)*(x4653)))+(((sj0)*(x4650)))+(((IkReal(-1.00000000000000))*(x4645)*(x4652)))+(((IkReal(-1.00000000000000))*(sj5)*(x4646)*(x4649))));
evalcond[4]=((((r11)*(x4663)))+(((IkReal(-1.00000000000000))*(cj4)*(r12)*(sj5)*(x4649)))+(((sj0)*(x4647)*(x4648)))+(((x4645)*(x4660)))+(((sj0)*(x4646)*(x4648)))+(((IkReal(-1.00000000000000))*(r01)*(x4651)*(x4659)))+(((IkReal(-1.00000000000000))*(x4648)*(x4649)*(x4658)))+(((r00)*(sj0)*(x4655)))+(((IkReal(-1.00000000000000))*(x4648)*(x4649)*(x4652)))+(x4644)+(((IkReal(-1.00000000000000))*(r10)*(x4649)*(x4655))));
evalcond[5]=((((IkReal(-1.00000000000000))*(sj5)*(x4649)*(x4660)))+(((r01)*(x4663)))+(((IkReal(-1.00000000000000))*(r10)*(x4651)*(x4655)))+(((IkReal(-1.00000000000000))*(x4648)*(x4651)*(x4658)))+(((IkReal(-1.00000000000000))*(x4643)*(x4654)))+(((IkReal(-1.00000000000000))*(x4648)*(x4651)*(x4652)))+(((IkReal(-1.00000000000000))*(r00)*(x4649)*(x4655)))+(((r11)*(sj0)*(x4659)))+(((IkReal(-1.00000000000000))*(x4647)*(x4648)*(x4649)))+(((IkReal(-1.00000000000000))*(x4645)*(x4661)))+(((IkReal(-1.00000000000000))*(x4646)*(x4648)*(x4649))));
if( IKabs(evalcond[0]) > 0.000001  || IKabs(evalcond[1]) > 0.000001  || IKabs(evalcond[2]) > 0.000001  || IKabs(evalcond[3]) > 0.000001  || IKabs(evalcond[4]) > 0.000001  || IKabs(evalcond[5]) > 0.000001  )
{
continue;
}
}

{
std::vector<IkSingleDOFSolutionBase<IkReal> > vinfos(7);
vinfos[0].jointtype = 1;
vinfos[0].foffset = j0;
vinfos[0].indices[0] = _ij0[0];
vinfos[0].indices[1] = _ij0[1];
vinfos[0].maxsolutions = _nj0;
vinfos[1].jointtype = 1;
vinfos[1].foffset = j1;
vinfos[1].indices[0] = _ij1[0];
vinfos[1].indices[1] = _ij1[1];
vinfos[1].maxsolutions = _nj1;
vinfos[2].jointtype = 1;
vinfos[2].foffset = j2;
vinfos[2].indices[0] = _ij2[0];
vinfos[2].indices[1] = _ij2[1];
vinfos[2].maxsolutions = _nj2;
vinfos[3].jointtype = 1;
vinfos[3].foffset = j3;
vinfos[3].indices[0] = _ij3[0];
vinfos[3].indices[1] = _ij3[1];
vinfos[3].maxsolutions = _nj3;
vinfos[4].jointtype = 1;
vinfos[4].foffset = j4;
vinfos[4].indices[0] = _ij4[0];
vinfos[4].indices[1] = _ij4[1];
vinfos[4].maxsolutions = _nj4;
vinfos[5].jointtype = 1;
vinfos[5].foffset = j5;
vinfos[5].indices[0] = _ij5[0];
vinfos[5].indices[1] = _ij5[1];
vinfos[5].maxsolutions = _nj5;
vinfos[6].jointtype = 1;
vinfos[6].foffset = j6;
vinfos[6].indices[0] = _ij6[0];
vinfos[6].indices[1] = _ij6[1];
vinfos[6].maxsolutions = _nj6;
std::vector<int> vfree(0);
solutions.AddSolution(vinfos,vfree);
}
}
}

}

}
}
}

}

}

} else
{
IkReal x4664=((IkReal(0.374290000000000))*(sj5));
IkReal x4665=((cj0)*(sj6));
IkReal x4666=((IkReal(0.0100000000000000))*(sj5));
IkReal x4667=((cj0)*(r02));
IkReal x4668=((IkReal(0.0100000000000000))*(cj5));
IkReal x4669=((IkReal(1.00000000000000))*(py));
IkReal x4670=((r01)*(sj0));
IkReal x4671=((r20)*(sj6));
IkReal x4672=((r11)*(sj0));
IkReal x4673=((IkReal(0.374290000000000))*(cj5));
IkReal x4674=((cj0)*(r12));
IkReal x4675=((sj0)*(x4673));
IkReal x4676=((cj6)*(x4668));
IkReal x4677=((r10)*(sj0)*(sj6));
IkReal x4678=((r00)*(sj0)*(sj6));
IkReal x4679=((cj0)*(cj6)*(x4664));
evalcond[0]=((IkReal(-3.14159265358979))+(IKfmod(((IkReal(4.71238898038469))+(j2)), IkReal(6.28318530717959))));
evalcond[1]=((((IkReal(0.364420000000000))*(sj1)))+(((x4664)*(x4671)))+(((IkReal(-1.00000000000000))*(r22)*(x4673)))+(((cj6)*(r21)*(x4664)))+(((IkReal(-1.00000000000000))*(r21)*(x4676)))+(pz)+(((IkReal(-1.00000000000000))*(x4668)*(x4671)))+(((IkReal(-1.00000000000000))*(r22)*(x4666))));
evalcond[2]=((IkReal(-0.0690000000000000))+(((IkReal(-1.00000000000000))*(r11)*(x4679)))+(((IkReal(-1.00000000000000))*(x4670)*(x4676)))+(((x4664)*(x4678)))+(((IkReal(-1.00000000000000))*(x4668)*(x4678)))+(((x4666)*(x4674)))+(((cj0)*(r11)*(x4676)))+(((IkReal(-1.00000000000000))*(r10)*(x4664)*(x4665)))+(((cj6)*(x4664)*(x4670)))+(((r10)*(x4665)*(x4668)))+(((IkReal(-1.00000000000000))*(r02)*(sj0)*(x4666)))+(((px)*(sj0)))+(((x4673)*(x4674)))+(((IkReal(-1.00000000000000))*(r02)*(x4675)))+(((IkReal(-1.00000000000000))*(cj0)*(x4669))));
evalcond[3]=((IkReal(0.0690000000000000))+(((x4667)*(x4673)))+(((IkReal(-1.00000000000000))*(cj0)*(px)))+(((IkReal(-1.00000000000000))*(cj6)*(x4664)*(x4672)))+(((r00)*(x4665)*(x4668)))+(((r12)*(sj0)*(x4666)))+(((cj0)*(r01)*(x4676)))+(((IkReal(-1.00000000000000))*(r00)*(x4664)*(x4665)))+(((x4666)*(x4667)))+(((IkReal(-1.00000000000000))*(sj0)*(x4669)))+(((IkReal(-1.00000000000000))*(r01)*(x4679)))+(((r12)*(x4675)))+(((x4668)*(x4677)))+(((IkReal(0.364420000000000))*(cj1)))+(((IkReal(-1.00000000000000))*(x4664)*(x4677)))+(((x4672)*(x4676))));
if( IKabs(evalcond[0]) < 0.0000010000000000  && IKabs(evalcond[1]) < 0.0000010000000000  && IKabs(evalcond[2]) < 0.0000010000000000  && IKabs(evalcond[3]) < 0.0000010000000000  )
{
{
IkReal dummyeval[1];
IkReal gconst26;
IkReal x4680=(cj6)*(cj6);
IkReal x4681=(sj6)*(sj6);
IkReal x4682=((IkReal(1.00000000000000))*(r01));
IkReal x4683=((sj0)*(sj5));
IkReal x4684=((cj6)*(r22));
IkReal x4685=((r21)*(sj6));
IkReal x4686=((r00)*(r21));
IkReal x4687=((cj0)*(sj5));
IkReal x4688=((cj6)*(r20));
IkReal x4689=((r22)*(sj6));
IkReal x4690=((cj0)*(cj5));
IkReal x4691=((IkReal(1.00000000000000))*(r10));
IkReal x4692=((cj5)*(sj0));
IkReal x4693=((r20)*(x4681));
IkReal x4694=((x4680)*(x4692));
gconst26=IKsign(((((r00)*(x4683)*(x4684)))+(((r11)*(x4690)*(x4693)))+(((x4686)*(x4694)))+(((IkReal(-1.00000000000000))*(x4682)*(x4683)*(x4689)))+(((IkReal(-1.00000000000000))*(r02)*(x4683)*(x4688)))+(((IkReal(-1.00000000000000))*(x4682)*(x4692)*(x4693)))+(((r11)*(x4687)*(x4689)))+(((IkReal(-1.00000000000000))*(r21)*(x4681)*(x4690)*(x4691)))+(((r11)*(r20)*(x4680)*(x4690)))+(((IkReal(-1.00000000000000))*(r12)*(x4685)*(x4687)))+(((IkReal(-1.00000000000000))*(x4684)*(x4687)*(x4691)))+(((r12)*(x4687)*(x4688)))+(((IkReal(-1.00000000000000))*(r21)*(x4680)*(x4690)*(x4691)))+(((x4681)*(x4686)*(x4692)))+(((r02)*(x4683)*(x4685)))+(((IkReal(-1.00000000000000))*(r20)*(x4682)*(x4694)))));
IkReal x4695=(cj6)*(cj6);
IkReal x4696=(sj6)*(sj6);
IkReal x4697=((IkReal(1.00000000000000))*(r01));
IkReal x4698=((sj0)*(sj5));
IkReal x4699=((cj6)*(r22));
IkReal x4700=((r21)*(sj6));
IkReal x4701=((r00)*(r21));
IkReal x4702=((cj0)*(sj5));
IkReal x4703=((cj6)*(r20));
IkReal x4704=((r22)*(sj6));
IkReal x4705=((cj0)*(cj5));
IkReal x4706=((IkReal(1.00000000000000))*(r10));
IkReal x4707=((cj5)*(sj0));
IkReal x4708=((r20)*(x4696));
IkReal x4709=((x4695)*(x4707));
dummyeval[0]=((((r11)*(x4705)*(x4708)))+(((IkReal(-1.00000000000000))*(x4697)*(x4698)*(x4704)))+(((IkReal(-1.00000000000000))*(r20)*(x4697)*(x4709)))+(((r11)*(x4702)*(x4704)))+(((IkReal(-1.00000000000000))*(r21)*(x4696)*(x4705)*(x4706)))+(((IkReal(-1.00000000000000))*(r21)*(x4695)*(x4705)*(x4706)))+(((r00)*(x4698)*(x4699)))+(((r11)*(r20)*(x4695)*(x4705)))+(((IkReal(-1.00000000000000))*(r12)*(x4700)*(x4702)))+(((r12)*(x4702)*(x4703)))+(((r02)*(x4698)*(x4700)))+(((IkReal(-1.00000000000000))*(x4699)*(x4702)*(x4706)))+(((x4701)*(x4709)))+(((x4696)*(x4701)*(x4707)))+(((IkReal(-1.00000000000000))*(x4697)*(x4707)*(x4708)))+(((IkReal(-1.00000000000000))*(r02)*(x4698)*(x4703))));
if( IKabs(dummyeval[0]) < 0.0000010000000000  )
{
{
IkReal dummyeval[1];
IkReal gconst27;
IkReal x4710=(cj6)*(cj6);
IkReal x4711=(sj6)*(sj6);
IkReal x4712=((sj5)*(sj6));
IkReal x4713=((IkReal(1.00000000000000))*(cj0));
IkReal x4714=((cj6)*(sj5));
IkReal x4715=((r20)*(sj0));
IkReal x4716=((cj0)*(r20));
IkReal x4717=((r00)*(r21));
IkReal x4718=((r22)*(sj0));
IkReal x4719=((IkReal(1.00000000000000))*(r21)*(sj0));
IkReal x4720=((cj5)*(x4711));
IkReal x4721=((cj5)*(x4710));
gconst27=IKsign(((((IkReal(-1.00000000000000))*(r10)*(x4719)*(x4721)))+(((r11)*(x4715)*(x4720)))+(((r01)*(x4716)*(x4720)))+(((r11)*(x4712)*(x4718)))+(((IkReal(-1.00000000000000))*(x4713)*(x4717)*(x4721)))+(((r01)*(x4716)*(x4721)))+(((IkReal(-1.00000000000000))*(r10)*(x4719)*(x4720)))+(((IkReal(-1.00000000000000))*(r00)*(r22)*(x4713)*(x4714)))+(((r12)*(x4714)*(x4715)))+(((IkReal(-1.00000000000000))*(r02)*(r21)*(x4712)*(x4713)))+(((cj0)*(r01)*(r22)*(x4712)))+(((r11)*(x4715)*(x4721)))+(((r02)*(x4714)*(x4716)))+(((IkReal(-1.00000000000000))*(x4713)*(x4717)*(x4720)))+(((IkReal(-1.00000000000000))*(r12)*(x4712)*(x4719)))+(((IkReal(-1.00000000000000))*(r10)*(x4714)*(x4718)))));
IkReal x4722=(cj6)*(cj6);
IkReal x4723=(sj6)*(sj6);
IkReal x4724=((sj5)*(sj6));
IkReal x4725=((IkReal(1.00000000000000))*(cj0));
IkReal x4726=((cj6)*(sj5));
IkReal x4727=((r20)*(sj0));
IkReal x4728=((cj0)*(r20));
IkReal x4729=((r00)*(r21));
IkReal x4730=((r22)*(sj0));
IkReal x4731=((IkReal(1.00000000000000))*(r21)*(sj0));
IkReal x4732=((cj5)*(x4723));
IkReal x4733=((cj5)*(x4722));
dummyeval[0]=((((cj0)*(r01)*(r22)*(x4724)))+(((IkReal(-1.00000000000000))*(r12)*(x4724)*(x4731)))+(((r02)*(x4726)*(x4728)))+(((IkReal(-1.00000000000000))*(r10)*(x4731)*(x4733)))+(((IkReal(-1.00000000000000))*(x4725)*(x4729)*(x4733)))+(((IkReal(-1.00000000000000))*(r02)*(r21)*(x4724)*(x4725)))+(((r01)*(x4728)*(x4733)))+(((IkReal(-1.00000000000000))*(r10)*(x4731)*(x4732)))+(((r11)*(x4727)*(x4732)))+(((r01)*(x4728)*(x4732)))+(((IkReal(-1.00000000000000))*(r10)*(x4726)*(x4730)))+(((IkReal(-1.00000000000000))*(r00)*(r22)*(x4725)*(x4726)))+(((r11)*(x4724)*(x4730)))+(((r12)*(x4726)*(x4727)))+(((r11)*(x4727)*(x4733)))+(((IkReal(-1.00000000000000))*(x4725)*(x4729)*(x4732))));
if( IKabs(dummyeval[0]) < 0.0000010000000000  )
{
{
IkReal dummyeval[1];
dummyeval[0]=sj1;
if( IKabs(dummyeval[0]) < 0.0000010000000000  )
{
{
IkReal evalcond[5];
IkReal x4734=((cj5)*(r22));
IkReal x4735=((IkReal(0.374290000000000))*(sj5));
IkReal x4736=((cj0)*(sj6));
IkReal x4737=((cj6)*(r21));
IkReal x4738=((IkReal(0.0100000000000000))*(sj5));
IkReal x4739=((cj0)*(r02));
IkReal x4740=((IkReal(0.0100000000000000))*(cj5));
IkReal x4741=((IkReal(1.00000000000000))*(py));
IkReal x4742=((r01)*(sj0));
IkReal x4743=((r20)*(sj6));
IkReal x4744=((r11)*(sj0));
IkReal x4745=((IkReal(0.374290000000000))*(cj5));
IkReal x4746=((cj0)*(r12));
IkReal x4747=((sj0)*(x4745));
IkReal x4748=((cj6)*(x4740));
IkReal x4749=((r10)*(sj0)*(sj6));
IkReal x4750=((r00)*(sj0)*(sj6));
IkReal x4751=((cj0)*(cj6)*(x4735));
evalcond[0]=((IkReal(-3.14159265358979))+(IKfmod(((IkReal(3.14159265358979))+(j1)), IkReal(6.28318530717959))));
evalcond[1]=((((IkReal(-1.00000000000000))*(x4734)))+(((sj5)*(x4737)))+(((sj5)*(x4743))));
evalcond[2]=((((IkReal(-1.00000000000000))*(r22)*(x4738)))+(((x4735)*(x4737)))+(pz)+(((IkReal(-1.00000000000000))*(x4740)*(x4743)))+(((IkReal(-0.374290000000000))*(x4734)))+(((IkReal(-1.00000000000000))*(x4737)*(x4740)))+(((x4735)*(x4743))));
evalcond[3]=((IkReal(-0.0690000000000000))+(((x4738)*(x4746)))+(((IkReal(-1.00000000000000))*(r02)*(sj0)*(x4738)))+(((x4735)*(x4750)))+(((IkReal(-1.00000000000000))*(x4742)*(x4748)))+(((r10)*(x4736)*(x4740)))+(((cj0)*(r11)*(x4748)))+(((IkReal(-1.00000000000000))*(r11)*(x4751)))+(((IkReal(-1.00000000000000))*(r10)*(x4735)*(x4736)))+(((x4745)*(x4746)))+(((IkReal(-1.00000000000000))*(x4740)*(x4750)))+(((IkReal(-1.00000000000000))*(r02)*(x4747)))+(((cj6)*(x4735)*(x4742)))+(((IkReal(-1.00000000000000))*(cj0)*(x4741)))+(((px)*(sj0))));
evalcond[4]=((IkReal(0.433420000000000))+(((IkReal(-1.00000000000000))*(cj0)*(px)))+(((IkReal(-1.00000000000000))*(r01)*(x4751)))+(((IkReal(-1.00000000000000))*(x4735)*(x4749)))+(((r12)*(x4747)))+(((cj0)*(r01)*(x4748)))+(((r00)*(x4736)*(x4740)))+(((IkReal(-1.00000000000000))*(sj0)*(x4741)))+(((IkReal(-1.00000000000000))*(r00)*(x4735)*(x4736)))+(((x4738)*(x4739)))+(((x4739)*(x4745)))+(((r12)*(sj0)*(x4738)))+(((IkReal(-1.00000000000000))*(cj6)*(x4735)*(x4744)))+(((x4744)*(x4748)))+(((x4740)*(x4749))));
if( IKabs(evalcond[0]) < 0.0000010000000000  && IKabs(evalcond[1]) < 0.0000010000000000  && IKabs(evalcond[2]) < 0.0000010000000000  && IKabs(evalcond[3]) < 0.0000010000000000  && IKabs(evalcond[4]) < 0.0000010000000000  )
{
{
IkReal j3array[1], cj3array[1], sj3array[1];
bool j3valid[1]={false};
_nj3 = 1;
IkReal x4752=((cj5)*(r02));
IkReal x4753=((cj0)*(sj5));
IkReal x4754=((r10)*(sj6));
IkReal x4755=((IkReal(1.00000000000000))*(cj6));
IkReal x4756=((sj0)*(sj5));
IkReal x4757=((cj5)*(r12));
IkReal x4758=((IkReal(1.00000000000000))*(r00)*(sj6));
if( IKabs(((((IkReal(-1.00000000000000))*(cj0)*(x4757)))+(((IkReal(-1.00000000000000))*(r01)*(x4755)*(x4756)))+(((x4753)*(x4754)))+(((IkReal(-1.00000000000000))*(x4756)*(x4758)))+(((cj6)*(r11)*(x4753)))+(((sj0)*(x4752))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(((((sj0)*(x4757)))+(((cj0)*(x4752)))+(((IkReal(-1.00000000000000))*(x4754)*(x4756)))+(((IkReal(-1.00000000000000))*(x4753)*(x4758)))+(((IkReal(-1.00000000000000))*(r11)*(x4755)*(x4756)))+(((IkReal(-1.00000000000000))*(r01)*(x4753)*(x4755))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(IKsqr(((((IkReal(-1.00000000000000))*(cj0)*(x4757)))+(((IkReal(-1.00000000000000))*(r01)*(x4755)*(x4756)))+(((x4753)*(x4754)))+(((IkReal(-1.00000000000000))*(x4756)*(x4758)))+(((cj6)*(r11)*(x4753)))+(((sj0)*(x4752)))))+IKsqr(((((sj0)*(x4757)))+(((cj0)*(x4752)))+(((IkReal(-1.00000000000000))*(x4754)*(x4756)))+(((IkReal(-1.00000000000000))*(x4753)*(x4758)))+(((IkReal(-1.00000000000000))*(r11)*(x4755)*(x4756)))+(((IkReal(-1.00000000000000))*(r01)*(x4753)*(x4755)))))-1) <= IKFAST_SINCOS_THRESH )
    continue;
j3array[0]=IKatan2(((((IkReal(-1.00000000000000))*(cj0)*(x4757)))+(((IkReal(-1.00000000000000))*(r01)*(x4755)*(x4756)))+(((x4753)*(x4754)))+(((IkReal(-1.00000000000000))*(x4756)*(x4758)))+(((cj6)*(r11)*(x4753)))+(((sj0)*(x4752)))), ((((sj0)*(x4757)))+(((cj0)*(x4752)))+(((IkReal(-1.00000000000000))*(x4754)*(x4756)))+(((IkReal(-1.00000000000000))*(x4753)*(x4758)))+(((IkReal(-1.00000000000000))*(r11)*(x4755)*(x4756)))+(((IkReal(-1.00000000000000))*(r01)*(x4753)*(x4755)))));
sj3array[0]=IKsin(j3array[0]);
cj3array[0]=IKcos(j3array[0]);
if( j3array[0] > IKPI )
{
    j3array[0]-=IK2PI;
}
else if( j3array[0] < -IKPI )
{    j3array[0]+=IK2PI;
}
j3valid[0] = true;
for(int ij3 = 0; ij3 < 1; ++ij3)
{
if( !j3valid[ij3] )
{
    continue;
}
_ij3[0] = ij3; _ij3[1] = -1;
for(int iij3 = ij3+1; iij3 < 1; ++iij3)
{
if( j3valid[iij3] && IKabs(cj3array[ij3]-cj3array[iij3]) < IKFAST_SOLUTION_THRESH && IKabs(sj3array[ij3]-sj3array[iij3]) < IKFAST_SOLUTION_THRESH )
{
    j3valid[iij3]=false; _ij3[1] = iij3; break; 
}
}
j3 = j3array[ij3]; cj3 = cj3array[ij3]; sj3 = sj3array[ij3];
{
IkReal evalcond[2];
IkReal x4759=((cj0)*(cj5));
IkReal x4760=((IkReal(1.00000000000000))*(cj0));
IkReal x4761=((cj6)*(r11));
IkReal x4762=((r10)*(sj6));
IkReal x4763=((cj5)*(sj0));
IkReal x4764=((r00)*(sj5)*(sj6));
IkReal x4765=((cj6)*(r01)*(sj5));
IkReal x4766=((IkReal(1.00000000000000))*(sj0)*(sj5));
evalcond[0]=((((IkReal(-1.00000000000000))*(r02)*(x4763)))+(((sj0)*(x4765)))+(((r12)*(x4759)))+(((sj0)*(x4764)))+(((IkReal(-1.00000000000000))*(sj5)*(x4760)*(x4761)))+(IKsin(j3))+(((IkReal(-1.00000000000000))*(sj5)*(x4760)*(x4762))));
evalcond[1]=((((IkReal(-1.00000000000000))*(x4760)*(x4765)))+(((IkReal(-1.00000000000000))*(x4761)*(x4766)))+(((IkReal(-1.00000000000000))*(IKcos(j3))))+(((r02)*(x4759)))+(((IkReal(-1.00000000000000))*(x4760)*(x4764)))+(((r12)*(x4763)))+(((IkReal(-1.00000000000000))*(x4762)*(x4766))));
if( IKabs(evalcond[0]) > 0.000001  || IKabs(evalcond[1]) > 0.000001  )
{
continue;
}
}

{
IkReal dummyeval[1];
IkReal gconst33;
IkReal x4767=(r21)*(r21);
IkReal x4768=(cj5)*(cj5);
IkReal x4769=(sj6)*(sj6);
IkReal x4770=(cj6)*(cj6);
IkReal x4771=(r20)*(r20);
IkReal x4772=((cj6)*(r21));
IkReal x4773=((IkReal(2.00000000000000))*(r20)*(sj6));
IkReal x4774=((cj5)*(r22)*(sj5));
IkReal x4775=((IkReal(1.00000000000000))*(x4769));
IkReal x4776=((IkReal(1.00000000000000))*(x4770));
gconst33=IKsign(((((IkReal(-1.00000000000000))*(x4771)*(x4776)))+(((IkReal(-1.00000000000000))*(x4767)*(x4775)))+(((IkReal(-1.00000000000000))*((r22)*(r22))*((sj5)*(sj5))))+(((IkReal(-1.00000000000000))*(x4767)*(x4768)*(x4776)))+(((IkReal(-1.00000000000000))*(x4768)*(x4771)*(x4775)))+(((IkReal(-1.00000000000000))*(x4768)*(x4772)*(x4773)))+(((x4772)*(x4773)))+(((IkReal(-1.00000000000000))*(x4773)*(x4774)))+(((IkReal(-2.00000000000000))*(x4772)*(x4774)))));
IkReal x4777=(r21)*(r21);
IkReal x4778=(cj5)*(cj5);
IkReal x4779=(sj6)*(sj6);
IkReal x4780=(cj6)*(cj6);
IkReal x4781=(r20)*(r20);
IkReal x4782=((cj6)*(r21));
IkReal x4783=((IkReal(2.00000000000000))*(r20)*(sj6));
IkReal x4784=((cj5)*(r22)*(sj5));
IkReal x4785=((IkReal(1.00000000000000))*(x4779));
IkReal x4786=((IkReal(1.00000000000000))*(x4780));
dummyeval[0]=((((IkReal(-1.00000000000000))*(x4777)*(x4785)))+(((IkReal(-1.00000000000000))*(x4783)*(x4784)))+(((IkReal(-1.00000000000000))*(x4778)*(x4782)*(x4783)))+(((IkReal(-1.00000000000000))*((r22)*(r22))*((sj5)*(sj5))))+(((IkReal(-1.00000000000000))*(x4777)*(x4778)*(x4786)))+(((x4782)*(x4783)))+(((IkReal(-1.00000000000000))*(x4781)*(x4786)))+(((IkReal(-1.00000000000000))*(x4778)*(x4781)*(x4785)))+(((IkReal(-2.00000000000000))*(x4782)*(x4784))));
if( IKabs(dummyeval[0]) < 0.0000010000000000  )
{
{
IkReal dummyeval[1];
IkReal gconst34;
IkReal x4787=(cj6)*(cj6);
IkReal x4788=(sj6)*(sj6);
IkReal x4789=((IkReal(1.00000000000000))*(r01));
IkReal x4790=((sj0)*(sj5));
IkReal x4791=((cj6)*(r22));
IkReal x4792=((r21)*(sj6));
IkReal x4793=((r00)*(r21));
IkReal x4794=((cj0)*(sj5));
IkReal x4795=((cj6)*(r20));
IkReal x4796=((r22)*(sj6));
IkReal x4797=((cj0)*(cj5));
IkReal x4798=((IkReal(1.00000000000000))*(r10));
IkReal x4799=((cj5)*(sj0));
IkReal x4800=((r20)*(x4788));
IkReal x4801=((x4787)*(x4799));
gconst34=IKsign(((((r02)*(x4790)*(x4792)))+(((IkReal(-1.00000000000000))*(r20)*(x4789)*(x4801)))+(((r12)*(x4794)*(x4795)))+(((r11)*(x4794)*(x4796)))+(((IkReal(-1.00000000000000))*(x4789)*(x4799)*(x4800)))+(((x4788)*(x4793)*(x4799)))+(((x4793)*(x4801)))+(((IkReal(-1.00000000000000))*(r21)*(x4787)*(x4797)*(x4798)))+(((r11)*(r20)*(x4787)*(x4797)))+(((IkReal(-1.00000000000000))*(r21)*(x4788)*(x4797)*(x4798)))+(((r00)*(x4790)*(x4791)))+(((IkReal(-1.00000000000000))*(r02)*(x4790)*(x4795)))+(((IkReal(-1.00000000000000))*(x4791)*(x4794)*(x4798)))+(((IkReal(-1.00000000000000))*(x4789)*(x4790)*(x4796)))+(((r11)*(x4797)*(x4800)))+(((IkReal(-1.00000000000000))*(r12)*(x4792)*(x4794)))));
IkReal x4802=(cj6)*(cj6);
IkReal x4803=(sj6)*(sj6);
IkReal x4804=((IkReal(1.00000000000000))*(r01));
IkReal x4805=((sj0)*(sj5));
IkReal x4806=((cj6)*(r22));
IkReal x4807=((r21)*(sj6));
IkReal x4808=((r00)*(r21));
IkReal x4809=((cj0)*(sj5));
IkReal x4810=((cj6)*(r20));
IkReal x4811=((r22)*(sj6));
IkReal x4812=((cj0)*(cj5));
IkReal x4813=((IkReal(1.00000000000000))*(r10));
IkReal x4814=((cj5)*(sj0));
IkReal x4815=((r20)*(x4803));
IkReal x4816=((x4802)*(x4814));
dummyeval[0]=((((r11)*(r20)*(x4802)*(x4812)))+(((IkReal(-1.00000000000000))*(r21)*(x4803)*(x4812)*(x4813)))+(((r12)*(x4809)*(x4810)))+(((IkReal(-1.00000000000000))*(x4804)*(x4805)*(x4811)))+(((IkReal(-1.00000000000000))*(r21)*(x4802)*(x4812)*(x4813)))+(((IkReal(-1.00000000000000))*(r20)*(x4804)*(x4816)))+(((x4803)*(x4808)*(x4814)))+(((IkReal(-1.00000000000000))*(x4806)*(x4809)*(x4813)))+(((IkReal(-1.00000000000000))*(r12)*(x4807)*(x4809)))+(((r00)*(x4805)*(x4806)))+(((r11)*(x4809)*(x4811)))+(((IkReal(-1.00000000000000))*(r02)*(x4805)*(x4810)))+(((x4808)*(x4816)))+(((r11)*(x4812)*(x4815)))+(((IkReal(-1.00000000000000))*(x4804)*(x4814)*(x4815)))+(((r02)*(x4805)*(x4807))));
if( IKabs(dummyeval[0]) < 0.0000010000000000  )
{
continue;

} else
{
{
IkReal j4array[1], cj4array[1], sj4array[1];
bool j4valid[1]={false};
_nj4 = 1;
IkReal x4817=((sj0)*(sj6));
IkReal x4818=((cj0)*(r10));
IkReal x4819=((IkReal(1.00000000000000))*(cj5));
IkReal x4820=((cj6)*(sj0));
IkReal x4821=((cj0)*(r11));
if( IKabs(((gconst34)*(((((r01)*(x4817)))+(((IkReal(-1.00000000000000))*(r00)*(x4820)))+(((cj6)*(x4818)))+(((IkReal(-1.00000000000000))*(sj6)*(x4821))))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(((gconst34)*(((((IkReal(-1.00000000000000))*(r00)*(x4817)*(x4819)))+(((cj0)*(r12)*(sj5)))+(((cj5)*(cj6)*(x4821)))+(((IkReal(-1.00000000000000))*(r02)*(sj0)*(sj5)))+(((IkReal(-1.00000000000000))*(r01)*(x4819)*(x4820)))+(((cj5)*(sj6)*(x4818))))))) < IKFAST_ATAN2_MAGTHRESH )
    continue;
j4array[0]=IKatan2(((gconst34)*(((((r01)*(x4817)))+(((IkReal(-1.00000000000000))*(r00)*(x4820)))+(((cj6)*(x4818)))+(((IkReal(-1.00000000000000))*(sj6)*(x4821)))))), ((gconst34)*(((((IkReal(-1.00000000000000))*(r00)*(x4817)*(x4819)))+(((cj0)*(r12)*(sj5)))+(((cj5)*(cj6)*(x4821)))+(((IkReal(-1.00000000000000))*(r02)*(sj0)*(sj5)))+(((IkReal(-1.00000000000000))*(r01)*(x4819)*(x4820)))+(((cj5)*(sj6)*(x4818)))))));
sj4array[0]=IKsin(j4array[0]);
cj4array[0]=IKcos(j4array[0]);
if( j4array[0] > IKPI )
{
    j4array[0]-=IK2PI;
}
else if( j4array[0] < -IKPI )
{    j4array[0]+=IK2PI;
}
j4valid[0] = true;
for(int ij4 = 0; ij4 < 1; ++ij4)
{
if( !j4valid[ij4] )
{
    continue;
}
_ij4[0] = ij4; _ij4[1] = -1;
for(int iij4 = ij4+1; iij4 < 1; ++iij4)
{
if( j4valid[iij4] && IKabs(cj4array[ij4]-cj4array[iij4]) < IKFAST_SOLUTION_THRESH && IKabs(sj4array[ij4]-sj4array[iij4]) < IKFAST_SOLUTION_THRESH )
{
    j4valid[iij4]=false; _ij4[1] = iij4; break; 
}
}
j4 = j4array[ij4]; cj4 = cj4array[ij4]; sj4 = sj4array[ij4];
{
IkReal evalcond[6];
IkReal x4822=IKsin(j4);
IkReal x4823=IKcos(j4);
IkReal x4824=((r22)*(sj5));
IkReal x4825=((IkReal(1.00000000000000))*(cj6));
IkReal x4826=((IkReal(1.00000000000000))*(cj0));
IkReal x4827=((cj5)*(r11));
IkReal x4828=((cj5)*(cj6));
IkReal x4829=((r11)*(sj6));
IkReal x4830=((IkReal(1.00000000000000))*(sj6));
IkReal x4831=((cj6)*(r00));
IkReal x4832=((r12)*(sj5));
IkReal x4833=((r02)*(sj5));
IkReal x4834=((cj6)*(r10));
IkReal x4835=((cj5)*(sj6));
IkReal x4836=((cj5)*(r01));
IkReal x4837=((sj0)*(x4822));
IkReal x4838=((r00)*(x4835));
IkReal x4839=((cj0)*(x4822));
IkReal x4840=((sj0)*(x4823));
IkReal x4841=((r20)*(x4823));
IkReal x4842=((cj0)*(x4823));
IkReal x4843=((r21)*(x4822));
IkReal x4844=((r21)*(x4823));
IkReal x4845=((r20)*(x4822));
IkReal x4846=((x4823)*(x4832));
IkReal x4847=((r01)*(sj6)*(x4823));
IkReal x4848=((cj5)*(r10)*(x4830));
evalcond[0]=((IkReal(1.00000000000000))+(((IkReal(-1.00000000000000))*(x4825)*(x4841)))+(((x4835)*(x4845)))+(((sj6)*(x4844)))+(((x4828)*(x4843)))+(((x4822)*(x4824))));
evalcond[1]=((((x4828)*(x4844)))+(((x4835)*(x4841)))+(((cj6)*(x4845)))+(((IkReal(-1.00000000000000))*(x4830)*(x4843)))+(((x4823)*(x4824))));
evalcond[2]=((((r01)*(x4828)*(x4837)))+(((IkReal(-1.00000000000000))*(r10)*(x4822)*(x4826)*(x4835)))+(((IkReal(-1.00000000000000))*(x4822)*(x4826)*(x4832)))+(((IkReal(-1.00000000000000))*(x4825)*(x4827)*(x4839)))+(((IkReal(-1.00000000000000))*(r00)*(x4825)*(x4840)))+(((x4833)*(x4837)))+(((x4837)*(x4838)))+(((IkReal(-1.00000000000000))*(x4823)*(x4826)*(x4829)))+(((r01)*(sj6)*(x4840)))+(((x4834)*(x4842))));
evalcond[3]=((((IkReal(-1.00000000000000))*(r10)*(x4825)*(x4839)))+(((IkReal(-1.00000000000000))*(r01)*(x4830)*(x4837)))+(((IkReal(-1.00000000000000))*(x4825)*(x4827)*(x4842)))+(((x4838)*(x4840)))+(((x4829)*(x4839)))+(((IkReal(-1.00000000000000))*(r10)*(x4823)*(x4826)*(x4835)))+(((IkReal(-1.00000000000000))*(cj3)))+(((x4831)*(x4837)))+(((r01)*(x4828)*(x4840)))+(((x4833)*(x4840)))+(((IkReal(-1.00000000000000))*(x4826)*(x4846))));
evalcond[4]=((((IkReal(-1.00000000000000))*(x4837)*(x4848)))+(((x4831)*(x4842)))+(((IkReal(-1.00000000000000))*(x4822)*(x4826)*(x4838)))+(((IkReal(-1.00000000000000))*(x4822)*(x4826)*(x4833)))+(((IkReal(-1.00000000000000))*(x4829)*(x4840)))+(((x4834)*(x4840)))+(((IkReal(-1.00000000000000))*(x4825)*(x4827)*(x4837)))+(((IkReal(-1.00000000000000))*(x4826)*(x4847)))+(((IkReal(-1.00000000000000))*(x4825)*(x4836)*(x4839)))+(((IkReal(-1.00000000000000))*(x4832)*(x4837))));
evalcond[5]=((((IkReal(-1.00000000000000))*(r10)*(x4825)*(x4837)))+(((r01)*(sj6)*(x4839)))+(((IkReal(-1.00000000000000))*(x4825)*(x4836)*(x4842)))+(((x4829)*(x4837)))+(((IkReal(-1.00000000000000))*(x4825)*(x4827)*(x4840)))+(((IkReal(-1.00000000000000))*(x4840)*(x4848)))+(((IkReal(-1.00000000000000))*(x4832)*(x4840)))+(((IkReal(-1.00000000000000))*(x4823)*(x4826)*(x4833)))+(((IkReal(-1.00000000000000))*(sj3)))+(((IkReal(-1.00000000000000))*(r00)*(x4825)*(x4839)))+(((IkReal(-1.00000000000000))*(x4823)*(x4826)*(x4838))));
if( IKabs(evalcond[0]) > 0.000001  || IKabs(evalcond[1]) > 0.000001  || IKabs(evalcond[2]) > 0.000001  || IKabs(evalcond[3]) > 0.000001  || IKabs(evalcond[4]) > 0.000001  || IKabs(evalcond[5]) > 0.000001  )
{
continue;
}
}

{
std::vector<IkSingleDOFSolutionBase<IkReal> > vinfos(7);
vinfos[0].jointtype = 1;
vinfos[0].foffset = j0;
vinfos[0].indices[0] = _ij0[0];
vinfos[0].indices[1] = _ij0[1];
vinfos[0].maxsolutions = _nj0;
vinfos[1].jointtype = 1;
vinfos[1].foffset = j1;
vinfos[1].indices[0] = _ij1[0];
vinfos[1].indices[1] = _ij1[1];
vinfos[1].maxsolutions = _nj1;
vinfos[2].jointtype = 1;
vinfos[2].foffset = j2;
vinfos[2].indices[0] = _ij2[0];
vinfos[2].indices[1] = _ij2[1];
vinfos[2].maxsolutions = _nj2;
vinfos[3].jointtype = 1;
vinfos[3].foffset = j3;
vinfos[3].indices[0] = _ij3[0];
vinfos[3].indices[1] = _ij3[1];
vinfos[3].maxsolutions = _nj3;
vinfos[4].jointtype = 1;
vinfos[4].foffset = j4;
vinfos[4].indices[0] = _ij4[0];
vinfos[4].indices[1] = _ij4[1];
vinfos[4].maxsolutions = _nj4;
vinfos[5].jointtype = 1;
vinfos[5].foffset = j5;
vinfos[5].indices[0] = _ij5[0];
vinfos[5].indices[1] = _ij5[1];
vinfos[5].maxsolutions = _nj5;
vinfos[6].jointtype = 1;
vinfos[6].foffset = j6;
vinfos[6].indices[0] = _ij6[0];
vinfos[6].indices[1] = _ij6[1];
vinfos[6].maxsolutions = _nj6;
std::vector<int> vfree(0);
solutions.AddSolution(vinfos,vfree);
}
}
}

}

}

} else
{
{
IkReal j4array[1], cj4array[1], sj4array[1];
bool j4valid[1]={false};
_nj4 = 1;
if( IKabs(((gconst33)*(((((cj5)*(r20)*(sj6)))+(((r22)*(sj5)))+(((cj5)*(cj6)*(r21))))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(((gconst33)*(((((r21)*(sj6)))+(((IkReal(-1.00000000000000))*(cj6)*(r20))))))) < IKFAST_ATAN2_MAGTHRESH )
    continue;
j4array[0]=IKatan2(((gconst33)*(((((cj5)*(r20)*(sj6)))+(((r22)*(sj5)))+(((cj5)*(cj6)*(r21)))))), ((gconst33)*(((((r21)*(sj6)))+(((IkReal(-1.00000000000000))*(cj6)*(r20)))))));
sj4array[0]=IKsin(j4array[0]);
cj4array[0]=IKcos(j4array[0]);
if( j4array[0] > IKPI )
{
    j4array[0]-=IK2PI;
}
else if( j4array[0] < -IKPI )
{    j4array[0]+=IK2PI;
}
j4valid[0] = true;
for(int ij4 = 0; ij4 < 1; ++ij4)
{
if( !j4valid[ij4] )
{
    continue;
}
_ij4[0] = ij4; _ij4[1] = -1;
for(int iij4 = ij4+1; iij4 < 1; ++iij4)
{
if( j4valid[iij4] && IKabs(cj4array[ij4]-cj4array[iij4]) < IKFAST_SOLUTION_THRESH && IKabs(sj4array[ij4]-sj4array[iij4]) < IKFAST_SOLUTION_THRESH )
{
    j4valid[iij4]=false; _ij4[1] = iij4; break; 
}
}
j4 = j4array[ij4]; cj4 = cj4array[ij4]; sj4 = sj4array[ij4];
{
IkReal evalcond[6];
IkReal x4849=IKsin(j4);
IkReal x4850=IKcos(j4);
IkReal x4851=((r22)*(sj5));
IkReal x4852=((IkReal(1.00000000000000))*(cj6));
IkReal x4853=((IkReal(1.00000000000000))*(cj0));
IkReal x4854=((cj5)*(r11));
IkReal x4855=((cj5)*(cj6));
IkReal x4856=((r11)*(sj6));
IkReal x4857=((IkReal(1.00000000000000))*(sj6));
IkReal x4858=((cj6)*(r00));
IkReal x4859=((r12)*(sj5));
IkReal x4860=((r02)*(sj5));
IkReal x4861=((cj6)*(r10));
IkReal x4862=((cj5)*(sj6));
IkReal x4863=((cj5)*(r01));
IkReal x4864=((sj0)*(x4849));
IkReal x4865=((r00)*(x4862));
IkReal x4866=((cj0)*(x4849));
IkReal x4867=((sj0)*(x4850));
IkReal x4868=((r20)*(x4850));
IkReal x4869=((cj0)*(x4850));
IkReal x4870=((r21)*(x4849));
IkReal x4871=((r21)*(x4850));
IkReal x4872=((r20)*(x4849));
IkReal x4873=((x4850)*(x4859));
IkReal x4874=((r01)*(sj6)*(x4850));
IkReal x4875=((cj5)*(r10)*(x4857));
evalcond[0]=((IkReal(1.00000000000000))+(((IkReal(-1.00000000000000))*(x4852)*(x4868)))+(((sj6)*(x4871)))+(((x4849)*(x4851)))+(((x4855)*(x4870)))+(((x4862)*(x4872))));
evalcond[1]=((((x4850)*(x4851)))+(((IkReal(-1.00000000000000))*(x4857)*(x4870)))+(((x4862)*(x4868)))+(((cj6)*(x4872)))+(((x4855)*(x4871))));
evalcond[2]=((((IkReal(-1.00000000000000))*(r00)*(x4852)*(x4867)))+(((IkReal(-1.00000000000000))*(x4852)*(x4854)*(x4866)))+(((x4861)*(x4869)))+(((x4864)*(x4865)))+(((IkReal(-1.00000000000000))*(r10)*(x4849)*(x4853)*(x4862)))+(((IkReal(-1.00000000000000))*(x4849)*(x4853)*(x4859)))+(((IkReal(-1.00000000000000))*(x4850)*(x4853)*(x4856)))+(((x4860)*(x4864)))+(((r01)*(x4855)*(x4864)))+(((r01)*(sj6)*(x4867))));
evalcond[3]=((((x4858)*(x4864)))+(((IkReal(-1.00000000000000))*(r10)*(x4852)*(x4866)))+(((x4856)*(x4866)))+(((IkReal(-1.00000000000000))*(r10)*(x4850)*(x4853)*(x4862)))+(((r01)*(x4855)*(x4867)))+(((IkReal(-1.00000000000000))*(r01)*(x4857)*(x4864)))+(((IkReal(-1.00000000000000))*(cj3)))+(((IkReal(-1.00000000000000))*(x4853)*(x4873)))+(((x4865)*(x4867)))+(((IkReal(-1.00000000000000))*(x4852)*(x4854)*(x4869)))+(((x4860)*(x4867))));
evalcond[4]=((((x4858)*(x4869)))+(((IkReal(-1.00000000000000))*(x4849)*(x4853)*(x4865)))+(((IkReal(-1.00000000000000))*(x4864)*(x4875)))+(((IkReal(-1.00000000000000))*(x4852)*(x4863)*(x4866)))+(((IkReal(-1.00000000000000))*(x4859)*(x4864)))+(((IkReal(-1.00000000000000))*(x4853)*(x4874)))+(((IkReal(-1.00000000000000))*(x4849)*(x4853)*(x4860)))+(((IkReal(-1.00000000000000))*(x4856)*(x4867)))+(((x4861)*(x4867)))+(((IkReal(-1.00000000000000))*(x4852)*(x4854)*(x4864))));
evalcond[5]=((((IkReal(-1.00000000000000))*(x4850)*(x4853)*(x4860)))+(((IkReal(-1.00000000000000))*(r00)*(x4852)*(x4866)))+(((x4856)*(x4864)))+(((IkReal(-1.00000000000000))*(x4852)*(x4854)*(x4867)))+(((r01)*(sj6)*(x4866)))+(((IkReal(-1.00000000000000))*(x4852)*(x4863)*(x4869)))+(((IkReal(-1.00000000000000))*(x4867)*(x4875)))+(((IkReal(-1.00000000000000))*(sj3)))+(((IkReal(-1.00000000000000))*(r10)*(x4852)*(x4864)))+(((IkReal(-1.00000000000000))*(x4859)*(x4867)))+(((IkReal(-1.00000000000000))*(x4850)*(x4853)*(x4865))));
if( IKabs(evalcond[0]) > 0.000001  || IKabs(evalcond[1]) > 0.000001  || IKabs(evalcond[2]) > 0.000001  || IKabs(evalcond[3]) > 0.000001  || IKabs(evalcond[4]) > 0.000001  || IKabs(evalcond[5]) > 0.000001  )
{
continue;
}
}

{
std::vector<IkSingleDOFSolutionBase<IkReal> > vinfos(7);
vinfos[0].jointtype = 1;
vinfos[0].foffset = j0;
vinfos[0].indices[0] = _ij0[0];
vinfos[0].indices[1] = _ij0[1];
vinfos[0].maxsolutions = _nj0;
vinfos[1].jointtype = 1;
vinfos[1].foffset = j1;
vinfos[1].indices[0] = _ij1[0];
vinfos[1].indices[1] = _ij1[1];
vinfos[1].maxsolutions = _nj1;
vinfos[2].jointtype = 1;
vinfos[2].foffset = j2;
vinfos[2].indices[0] = _ij2[0];
vinfos[2].indices[1] = _ij2[1];
vinfos[2].maxsolutions = _nj2;
vinfos[3].jointtype = 1;
vinfos[3].foffset = j3;
vinfos[3].indices[0] = _ij3[0];
vinfos[3].indices[1] = _ij3[1];
vinfos[3].maxsolutions = _nj3;
vinfos[4].jointtype = 1;
vinfos[4].foffset = j4;
vinfos[4].indices[0] = _ij4[0];
vinfos[4].indices[1] = _ij4[1];
vinfos[4].maxsolutions = _nj4;
vinfos[5].jointtype = 1;
vinfos[5].foffset = j5;
vinfos[5].indices[0] = _ij5[0];
vinfos[5].indices[1] = _ij5[1];
vinfos[5].maxsolutions = _nj5;
vinfos[6].jointtype = 1;
vinfos[6].foffset = j6;
vinfos[6].indices[0] = _ij6[0];
vinfos[6].indices[1] = _ij6[1];
vinfos[6].maxsolutions = _nj6;
std::vector<int> vfree(0);
solutions.AddSolution(vinfos,vfree);
}
}
}

}

}
}
}

} else
{
IkReal x4876=((cj5)*(r22));
IkReal x4877=((IkReal(0.374290000000000))*(sj5));
IkReal x4878=((cj0)*(sj6));
IkReal x4879=((cj6)*(r21));
IkReal x4880=((IkReal(0.0100000000000000))*(sj5));
IkReal x4881=((cj0)*(r02));
IkReal x4882=((IkReal(0.0100000000000000))*(cj5));
IkReal x4883=((IkReal(1.00000000000000))*(py));
IkReal x4884=((r01)*(sj0));
IkReal x4885=((r20)*(sj6));
IkReal x4886=((r11)*(sj0));
IkReal x4887=((IkReal(0.374290000000000))*(cj5));
IkReal x4888=((cj0)*(r12));
IkReal x4889=((sj0)*(x4887));
IkReal x4890=((cj6)*(x4882));
IkReal x4891=((r10)*(sj0)*(sj6));
IkReal x4892=((r00)*(sj0)*(sj6));
IkReal x4893=((cj0)*(cj6)*(x4877));
evalcond[0]=((IkReal(-3.14159265358979))+(IKfmod(j1, IkReal(6.28318530717959))));
evalcond[1]=((((IkReal(-1.00000000000000))*(x4876)))+(((sj5)*(x4879)))+(((sj5)*(x4885))));
evalcond[2]=((((IkReal(-1.00000000000000))*(x4879)*(x4882)))+(((IkReal(-0.374290000000000))*(x4876)))+(((x4877)*(x4879)))+(((IkReal(-1.00000000000000))*(r22)*(x4880)))+(((IkReal(-1.00000000000000))*(x4882)*(x4885)))+(pz)+(((x4877)*(x4885))));
evalcond[3]=((IkReal(-0.0690000000000000))+(((cj0)*(r11)*(x4890)))+(((x4880)*(x4888)))+(((IkReal(-1.00000000000000))*(x4884)*(x4890)))+(((x4877)*(x4892)))+(((r10)*(x4878)*(x4882)))+(((IkReal(-1.00000000000000))*(r10)*(x4877)*(x4878)))+(((IkReal(-1.00000000000000))*(r02)*(x4889)))+(((cj6)*(x4877)*(x4884)))+(((x4887)*(x4888)))+(((IkReal(-1.00000000000000))*(x4882)*(x4892)))+(((IkReal(-1.00000000000000))*(cj0)*(x4883)))+(((px)*(sj0)))+(((IkReal(-1.00000000000000))*(r02)*(sj0)*(x4880)))+(((IkReal(-1.00000000000000))*(r11)*(x4893))));
evalcond[4]=((IkReal(-0.295420000000000))+(((IkReal(-1.00000000000000))*(cj0)*(px)))+(((cj0)*(r01)*(x4890)))+(((IkReal(-1.00000000000000))*(r00)*(x4877)*(x4878)))+(((r12)*(x4889)))+(((IkReal(-1.00000000000000))*(cj6)*(x4877)*(x4886)))+(((x4882)*(x4891)))+(((r12)*(sj0)*(x4880)))+(((IkReal(-1.00000000000000))*(x4877)*(x4891)))+(((x4881)*(x4887)))+(((IkReal(-1.00000000000000))*(sj0)*(x4883)))+(((r00)*(x4878)*(x4882)))+(((x4880)*(x4881)))+(((IkReal(-1.00000000000000))*(r01)*(x4893)))+(((x4886)*(x4890))));
if( IKabs(evalcond[0]) < 0.0000010000000000  && IKabs(evalcond[1]) < 0.0000010000000000  && IKabs(evalcond[2]) < 0.0000010000000000  && IKabs(evalcond[3]) < 0.0000010000000000  && IKabs(evalcond[4]) < 0.0000010000000000  )
{
{
IkReal j3array[1], cj3array[1], sj3array[1];
bool j3valid[1]={false};
_nj3 = 1;
IkReal x4894=((IkReal(1.00000000000000))*(cj5));
IkReal x4895=((r10)*(sj5)*(sj6));
IkReal x4896=((cj6)*(sj0)*(sj5));
IkReal x4897=((r00)*(sj5)*(sj6));
IkReal x4898=((cj0)*(cj6)*(sj5));
if( IKabs(((((r11)*(x4898)))+(((cj0)*(x4895)))+(((IkReal(-1.00000000000000))*(sj0)*(x4897)))+(((IkReal(-1.00000000000000))*(r01)*(x4896)))+(((IkReal(-1.00000000000000))*(cj0)*(r12)*(x4894)))+(((cj5)*(r02)*(sj0))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(((((r01)*(x4898)))+(((cj0)*(x4897)))+(((IkReal(-1.00000000000000))*(cj0)*(r02)*(x4894)))+(((IkReal(-1.00000000000000))*(r12)*(sj0)*(x4894)))+(((r11)*(x4896)))+(((sj0)*(x4895))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(IKsqr(((((r11)*(x4898)))+(((cj0)*(x4895)))+(((IkReal(-1.00000000000000))*(sj0)*(x4897)))+(((IkReal(-1.00000000000000))*(r01)*(x4896)))+(((IkReal(-1.00000000000000))*(cj0)*(r12)*(x4894)))+(((cj5)*(r02)*(sj0)))))+IKsqr(((((r01)*(x4898)))+(((cj0)*(x4897)))+(((IkReal(-1.00000000000000))*(cj0)*(r02)*(x4894)))+(((IkReal(-1.00000000000000))*(r12)*(sj0)*(x4894)))+(((r11)*(x4896)))+(((sj0)*(x4895)))))-1) <= IKFAST_SINCOS_THRESH )
    continue;
j3array[0]=IKatan2(((((r11)*(x4898)))+(((cj0)*(x4895)))+(((IkReal(-1.00000000000000))*(sj0)*(x4897)))+(((IkReal(-1.00000000000000))*(r01)*(x4896)))+(((IkReal(-1.00000000000000))*(cj0)*(r12)*(x4894)))+(((cj5)*(r02)*(sj0)))), ((((r01)*(x4898)))+(((cj0)*(x4897)))+(((IkReal(-1.00000000000000))*(cj0)*(r02)*(x4894)))+(((IkReal(-1.00000000000000))*(r12)*(sj0)*(x4894)))+(((r11)*(x4896)))+(((sj0)*(x4895)))));
sj3array[0]=IKsin(j3array[0]);
cj3array[0]=IKcos(j3array[0]);
if( j3array[0] > IKPI )
{
    j3array[0]-=IK2PI;
}
else if( j3array[0] < -IKPI )
{    j3array[0]+=IK2PI;
}
j3valid[0] = true;
for(int ij3 = 0; ij3 < 1; ++ij3)
{
if( !j3valid[ij3] )
{
    continue;
}
_ij3[0] = ij3; _ij3[1] = -1;
for(int iij3 = ij3+1; iij3 < 1; ++iij3)
{
if( j3valid[iij3] && IKabs(cj3array[ij3]-cj3array[iij3]) < IKFAST_SOLUTION_THRESH && IKabs(sj3array[ij3]-sj3array[iij3]) < IKFAST_SOLUTION_THRESH )
{
    j3valid[iij3]=false; _ij3[1] = iij3; break; 
}
}
j3 = j3array[ij3]; cj3 = cj3array[ij3]; sj3 = sj3array[ij3];
{
IkReal evalcond[2];
IkReal x4899=((cj0)*(cj5));
IkReal x4900=((IkReal(1.00000000000000))*(cj0));
IkReal x4901=((cj6)*(r11));
IkReal x4902=((r10)*(sj6));
IkReal x4903=((cj5)*(sj0));
IkReal x4904=((r00)*(sj5)*(sj6));
IkReal x4905=((cj6)*(r01)*(sj5));
IkReal x4906=((IkReal(1.00000000000000))*(sj0)*(sj5));
evalcond[0]=((((sj0)*(x4904)))+(((r12)*(x4899)))+(IKsin(j3))+(((IkReal(-1.00000000000000))*(sj5)*(x4900)*(x4901)))+(((IkReal(-1.00000000000000))*(sj5)*(x4900)*(x4902)))+(((sj0)*(x4905)))+(((IkReal(-1.00000000000000))*(r02)*(x4903))));
evalcond[1]=((((r02)*(x4899)))+(((IkReal(-1.00000000000000))*(x4902)*(x4906)))+(((IkReal(-1.00000000000000))*(x4900)*(x4905)))+(((IkReal(-1.00000000000000))*(x4900)*(x4904)))+(IKcos(j3))+(((IkReal(-1.00000000000000))*(x4901)*(x4906)))+(((r12)*(x4903))));
if( IKabs(evalcond[0]) > 0.000001  || IKabs(evalcond[1]) > 0.000001  )
{
continue;
}
}

{
IkReal dummyeval[1];
IkReal gconst37;
IkReal x4907=(cj5)*(cj5);
IkReal x4908=(r20)*(r20);
IkReal x4909=(sj6)*(sj6);
IkReal x4910=(cj6)*(cj6);
IkReal x4911=(r21)*(r21);
IkReal x4912=((cj6)*(r21));
IkReal x4913=((IkReal(2.00000000000000))*(r20)*(sj6));
IkReal x4914=((cj5)*(r22)*(sj5));
gconst37=IKsign(((((x4907)*(x4910)*(x4911)))+(((x4907)*(x4908)*(x4909)))+(((x4913)*(x4914)))+((((r22)*(r22))*((sj5)*(sj5))))+(((x4907)*(x4912)*(x4913)))+(((IkReal(-1.00000000000000))*(x4912)*(x4913)))+(((IkReal(2.00000000000000))*(x4912)*(x4914)))+(((x4908)*(x4910)))+(((x4909)*(x4911)))));
IkReal x4915=(cj5)*(cj5);
IkReal x4916=(r20)*(r20);
IkReal x4917=(sj6)*(sj6);
IkReal x4918=(cj6)*(cj6);
IkReal x4919=(r21)*(r21);
IkReal x4920=((cj6)*(r21));
IkReal x4921=((IkReal(2.00000000000000))*(r20)*(sj6));
IkReal x4922=((cj5)*(r22)*(sj5));
dummyeval[0]=((((IkReal(2.00000000000000))*(x4920)*(x4922)))+(((x4915)*(x4916)*(x4917)))+((((r22)*(r22))*((sj5)*(sj5))))+(((x4917)*(x4919)))+(((IkReal(-1.00000000000000))*(x4920)*(x4921)))+(((x4915)*(x4920)*(x4921)))+(((x4921)*(x4922)))+(((x4915)*(x4918)*(x4919)))+(((x4916)*(x4918))));
if( IKabs(dummyeval[0]) < 0.0000010000000000  )
{
{
IkReal dummyeval[1];
IkReal gconst38;
IkReal x4923=(cj6)*(cj6);
IkReal x4924=(sj6)*(sj6);
IkReal x4925=((IkReal(1.00000000000000))*(r21));
IkReal x4926=((cj6)*(r20));
IkReal x4927=((r22)*(sj5));
IkReal x4928=((r01)*(sj0));
IkReal x4929=((r00)*(sj0));
IkReal x4930=((cj0)*(r10));
IkReal x4931=((r02)*(sj0)*(sj5));
IkReal x4932=((cj5)*(x4923));
IkReal x4933=((cj0)*(r12)*(sj5));
IkReal x4934=((IkReal(1.00000000000000))*(cj0)*(r11));
IkReal x4935=((cj5)*(x4924));
IkReal x4936=((r20)*(x4935));
gconst38=IKsign(((((x4928)*(x4936)))+(((IkReal(-1.00000000000000))*(cj6)*(x4927)*(x4929)))+(((IkReal(-1.00000000000000))*(sj6)*(x4927)*(x4934)))+(((IkReal(-1.00000000000000))*(sj6)*(x4925)*(x4931)))+(((r21)*(sj6)*(x4933)))+(((r21)*(x4930)*(x4935)))+(((IkReal(-1.00000000000000))*(x4925)*(x4929)*(x4935)))+(((x4926)*(x4931)))+(((IkReal(-1.00000000000000))*(r20)*(x4932)*(x4934)))+(((IkReal(-1.00000000000000))*(x4925)*(x4929)*(x4932)))+(((IkReal(-1.00000000000000))*(x4926)*(x4933)))+(((r21)*(x4930)*(x4932)))+(((IkReal(-1.00000000000000))*(x4934)*(x4936)))+(((r20)*(x4928)*(x4932)))+(((cj6)*(x4927)*(x4930)))+(((sj6)*(x4927)*(x4928)))));
IkReal x4937=(cj6)*(cj6);
IkReal x4938=(sj6)*(sj6);
IkReal x4939=((IkReal(1.00000000000000))*(r21));
IkReal x4940=((cj6)*(r20));
IkReal x4941=((r22)*(sj5));
IkReal x4942=((r01)*(sj0));
IkReal x4943=((r00)*(sj0));
IkReal x4944=((cj0)*(r10));
IkReal x4945=((r02)*(sj0)*(sj5));
IkReal x4946=((cj5)*(x4937));
IkReal x4947=((cj0)*(r12)*(sj5));
IkReal x4948=((IkReal(1.00000000000000))*(cj0)*(r11));
IkReal x4949=((cj5)*(x4938));
IkReal x4950=((r20)*(x4949));
dummyeval[0]=((((IkReal(-1.00000000000000))*(x4939)*(x4943)*(x4946)))+(((r21)*(x4944)*(x4949)))+(((r21)*(x4944)*(x4946)))+(((r20)*(x4942)*(x4946)))+(((IkReal(-1.00000000000000))*(cj6)*(x4941)*(x4943)))+(((sj6)*(x4941)*(x4942)))+(((IkReal(-1.00000000000000))*(sj6)*(x4939)*(x4945)))+(((x4940)*(x4945)))+(((IkReal(-1.00000000000000))*(x4940)*(x4947)))+(((IkReal(-1.00000000000000))*(x4948)*(x4950)))+(((IkReal(-1.00000000000000))*(x4939)*(x4943)*(x4949)))+(((IkReal(-1.00000000000000))*(sj6)*(x4941)*(x4948)))+(((x4942)*(x4950)))+(((cj6)*(x4941)*(x4944)))+(((r21)*(sj6)*(x4947)))+(((IkReal(-1.00000000000000))*(r20)*(x4946)*(x4948))));
if( IKabs(dummyeval[0]) < 0.0000010000000000  )
{
continue;

} else
{
{
IkReal j4array[1], cj4array[1], sj4array[1];
bool j4valid[1]={false};
_nj4 = 1;
IkReal x4951=((sj0)*(sj6));
IkReal x4952=((cj0)*(r10));
IkReal x4953=((IkReal(1.00000000000000))*(cj5));
IkReal x4954=((cj6)*(sj0));
IkReal x4955=((cj0)*(r11));
if( IKabs(((gconst38)*(((((cj6)*(x4952)))+(((r01)*(x4951)))+(((IkReal(-1.00000000000000))*(r00)*(x4954)))+(((IkReal(-1.00000000000000))*(sj6)*(x4955))))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(((gconst38)*(((((cj5)*(sj6)*(x4952)))+(((IkReal(-1.00000000000000))*(r01)*(x4953)*(x4954)))+(((cj0)*(r12)*(sj5)))+(((IkReal(-1.00000000000000))*(r02)*(sj0)*(sj5)))+(((IkReal(-1.00000000000000))*(r00)*(x4951)*(x4953)))+(((cj5)*(cj6)*(x4955))))))) < IKFAST_ATAN2_MAGTHRESH )
    continue;
j4array[0]=IKatan2(((gconst38)*(((((cj6)*(x4952)))+(((r01)*(x4951)))+(((IkReal(-1.00000000000000))*(r00)*(x4954)))+(((IkReal(-1.00000000000000))*(sj6)*(x4955)))))), ((gconst38)*(((((cj5)*(sj6)*(x4952)))+(((IkReal(-1.00000000000000))*(r01)*(x4953)*(x4954)))+(((cj0)*(r12)*(sj5)))+(((IkReal(-1.00000000000000))*(r02)*(sj0)*(sj5)))+(((IkReal(-1.00000000000000))*(r00)*(x4951)*(x4953)))+(((cj5)*(cj6)*(x4955)))))));
sj4array[0]=IKsin(j4array[0]);
cj4array[0]=IKcos(j4array[0]);
if( j4array[0] > IKPI )
{
    j4array[0]-=IK2PI;
}
else if( j4array[0] < -IKPI )
{    j4array[0]+=IK2PI;
}
j4valid[0] = true;
for(int ij4 = 0; ij4 < 1; ++ij4)
{
if( !j4valid[ij4] )
{
    continue;
}
_ij4[0] = ij4; _ij4[1] = -1;
for(int iij4 = ij4+1; iij4 < 1; ++iij4)
{
if( j4valid[iij4] && IKabs(cj4array[ij4]-cj4array[iij4]) < IKFAST_SOLUTION_THRESH && IKabs(sj4array[ij4]-sj4array[iij4]) < IKFAST_SOLUTION_THRESH )
{
    j4valid[iij4]=false; _ij4[1] = iij4; break; 
}
}
j4 = j4array[ij4]; cj4 = cj4array[ij4]; sj4 = sj4array[ij4];
{
IkReal evalcond[6];
IkReal x4956=IKsin(j4);
IkReal x4957=IKcos(j4);
IkReal x4958=((r22)*(sj5));
IkReal x4959=((IkReal(1.00000000000000))*(cj6));
IkReal x4960=((IkReal(1.00000000000000))*(cj0));
IkReal x4961=((cj5)*(r11));
IkReal x4962=((cj5)*(cj6));
IkReal x4963=((r11)*(sj6));
IkReal x4964=((IkReal(1.00000000000000))*(sj6));
IkReal x4965=((cj6)*(r00));
IkReal x4966=((r12)*(sj5));
IkReal x4967=((r02)*(sj5));
IkReal x4968=((cj6)*(r10));
IkReal x4969=((cj5)*(sj6));
IkReal x4970=((cj5)*(r01));
IkReal x4971=((sj0)*(x4956));
IkReal x4972=((r00)*(x4969));
IkReal x4973=((cj0)*(x4956));
IkReal x4974=((sj0)*(x4957));
IkReal x4975=((r20)*(x4957));
IkReal x4976=((cj0)*(x4957));
IkReal x4977=((r21)*(x4956));
IkReal x4978=((r21)*(x4957));
IkReal x4979=((r20)*(x4956));
IkReal x4980=((x4957)*(x4966));
IkReal x4981=((r01)*(sj6)*(x4957));
IkReal x4982=((cj5)*(r10)*(x4964));
evalcond[0]=((IkReal(-1.00000000000000))+(((IkReal(-1.00000000000000))*(x4959)*(x4975)))+(((x4969)*(x4979)))+(((sj6)*(x4978)))+(((x4956)*(x4958)))+(((x4962)*(x4977))));
evalcond[1]=((((x4969)*(x4975)))+(((IkReal(-1.00000000000000))*(x4964)*(x4977)))+(((x4962)*(x4978)))+(((x4957)*(x4958)))+(((cj6)*(x4979))));
evalcond[2]=((((IkReal(-1.00000000000000))*(r10)*(x4956)*(x4960)*(x4969)))+(((x4967)*(x4971)))+(((IkReal(-1.00000000000000))*(x4956)*(x4960)*(x4966)))+(((IkReal(-1.00000000000000))*(x4957)*(x4960)*(x4963)))+(((r01)*(x4962)*(x4971)))+(((r01)*(sj6)*(x4974)))+(((x4971)*(x4972)))+(((IkReal(-1.00000000000000))*(r00)*(x4959)*(x4974)))+(((x4968)*(x4976)))+(((IkReal(-1.00000000000000))*(x4959)*(x4961)*(x4973))));
evalcond[3]=((((r01)*(x4962)*(x4974)))+(((x4965)*(x4971)))+(((IkReal(-1.00000000000000))*(r10)*(x4959)*(x4973)))+(((x4963)*(x4973)))+(((IkReal(-1.00000000000000))*(r01)*(x4964)*(x4971)))+(((IkReal(-1.00000000000000))*(r10)*(x4957)*(x4960)*(x4969)))+(((IkReal(-1.00000000000000))*(x4959)*(x4961)*(x4976)))+(((IkReal(-1.00000000000000))*(cj3)))+(((x4972)*(x4974)))+(((x4967)*(x4974)))+(((IkReal(-1.00000000000000))*(x4960)*(x4980))));
evalcond[4]=((((x4968)*(x4974)))+(((IkReal(-1.00000000000000))*(x4956)*(x4960)*(x4967)))+(((IkReal(-1.00000000000000))*(x4959)*(x4970)*(x4973)))+(((IkReal(-1.00000000000000))*(x4956)*(x4960)*(x4972)))+(((IkReal(-1.00000000000000))*(x4960)*(x4981)))+(((IkReal(-1.00000000000000))*(x4963)*(x4974)))+(((IkReal(-1.00000000000000))*(x4959)*(x4961)*(x4971)))+(((IkReal(-1.00000000000000))*(x4966)*(x4971)))+(((x4965)*(x4976)))+(((IkReal(-1.00000000000000))*(x4971)*(x4982))));
evalcond[5]=((((IkReal(-1.00000000000000))*(x4959)*(x4970)*(x4976)))+(sj3)+(((IkReal(-1.00000000000000))*(r00)*(x4959)*(x4973)))+(((IkReal(-1.00000000000000))*(x4959)*(x4961)*(x4974)))+(((r01)*(sj6)*(x4973)))+(((IkReal(-1.00000000000000))*(x4966)*(x4974)))+(((x4963)*(x4971)))+(((IkReal(-1.00000000000000))*(x4957)*(x4960)*(x4972)))+(((IkReal(-1.00000000000000))*(r10)*(x4959)*(x4971)))+(((IkReal(-1.00000000000000))*(x4974)*(x4982)))+(((IkReal(-1.00000000000000))*(x4957)*(x4960)*(x4967))));
if( IKabs(evalcond[0]) > 0.000001  || IKabs(evalcond[1]) > 0.000001  || IKabs(evalcond[2]) > 0.000001  || IKabs(evalcond[3]) > 0.000001  || IKabs(evalcond[4]) > 0.000001  || IKabs(evalcond[5]) > 0.000001  )
{
continue;
}
}

{
std::vector<IkSingleDOFSolutionBase<IkReal> > vinfos(7);
vinfos[0].jointtype = 1;
vinfos[0].foffset = j0;
vinfos[0].indices[0] = _ij0[0];
vinfos[0].indices[1] = _ij0[1];
vinfos[0].maxsolutions = _nj0;
vinfos[1].jointtype = 1;
vinfos[1].foffset = j1;
vinfos[1].indices[0] = _ij1[0];
vinfos[1].indices[1] = _ij1[1];
vinfos[1].maxsolutions = _nj1;
vinfos[2].jointtype = 1;
vinfos[2].foffset = j2;
vinfos[2].indices[0] = _ij2[0];
vinfos[2].indices[1] = _ij2[1];
vinfos[2].maxsolutions = _nj2;
vinfos[3].jointtype = 1;
vinfos[3].foffset = j3;
vinfos[3].indices[0] = _ij3[0];
vinfos[3].indices[1] = _ij3[1];
vinfos[3].maxsolutions = _nj3;
vinfos[4].jointtype = 1;
vinfos[4].foffset = j4;
vinfos[4].indices[0] = _ij4[0];
vinfos[4].indices[1] = _ij4[1];
vinfos[4].maxsolutions = _nj4;
vinfos[5].jointtype = 1;
vinfos[5].foffset = j5;
vinfos[5].indices[0] = _ij5[0];
vinfos[5].indices[1] = _ij5[1];
vinfos[5].maxsolutions = _nj5;
vinfos[6].jointtype = 1;
vinfos[6].foffset = j6;
vinfos[6].indices[0] = _ij6[0];
vinfos[6].indices[1] = _ij6[1];
vinfos[6].maxsolutions = _nj6;
std::vector<int> vfree(0);
solutions.AddSolution(vinfos,vfree);
}
}
}

}

}

} else
{
{
IkReal j4array[1], cj4array[1], sj4array[1];
bool j4valid[1]={false};
_nj4 = 1;
if( IKabs(((gconst37)*(((((cj5)*(r20)*(sj6)))+(((r22)*(sj5)))+(((cj5)*(cj6)*(r21))))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(((gconst37)*(((((r21)*(sj6)))+(((IkReal(-1.00000000000000))*(cj6)*(r20))))))) < IKFAST_ATAN2_MAGTHRESH )
    continue;
j4array[0]=IKatan2(((gconst37)*(((((cj5)*(r20)*(sj6)))+(((r22)*(sj5)))+(((cj5)*(cj6)*(r21)))))), ((gconst37)*(((((r21)*(sj6)))+(((IkReal(-1.00000000000000))*(cj6)*(r20)))))));
sj4array[0]=IKsin(j4array[0]);
cj4array[0]=IKcos(j4array[0]);
if( j4array[0] > IKPI )
{
    j4array[0]-=IK2PI;
}
else if( j4array[0] < -IKPI )
{    j4array[0]+=IK2PI;
}
j4valid[0] = true;
for(int ij4 = 0; ij4 < 1; ++ij4)
{
if( !j4valid[ij4] )
{
    continue;
}
_ij4[0] = ij4; _ij4[1] = -1;
for(int iij4 = ij4+1; iij4 < 1; ++iij4)
{
if( j4valid[iij4] && IKabs(cj4array[ij4]-cj4array[iij4]) < IKFAST_SOLUTION_THRESH && IKabs(sj4array[ij4]-sj4array[iij4]) < IKFAST_SOLUTION_THRESH )
{
    j4valid[iij4]=false; _ij4[1] = iij4; break; 
}
}
j4 = j4array[ij4]; cj4 = cj4array[ij4]; sj4 = sj4array[ij4];
{
IkReal evalcond[6];
IkReal x4983=IKsin(j4);
IkReal x4984=IKcos(j4);
IkReal x4985=((r22)*(sj5));
IkReal x4986=((IkReal(1.00000000000000))*(cj6));
IkReal x4987=((IkReal(1.00000000000000))*(cj0));
IkReal x4988=((cj5)*(r11));
IkReal x4989=((cj5)*(cj6));
IkReal x4990=((r11)*(sj6));
IkReal x4991=((IkReal(1.00000000000000))*(sj6));
IkReal x4992=((cj6)*(r00));
IkReal x4993=((r12)*(sj5));
IkReal x4994=((r02)*(sj5));
IkReal x4995=((cj6)*(r10));
IkReal x4996=((cj5)*(sj6));
IkReal x4997=((cj5)*(r01));
IkReal x4998=((sj0)*(x4983));
IkReal x4999=((r00)*(x4996));
IkReal x5000=((cj0)*(x4983));
IkReal x5001=((sj0)*(x4984));
IkReal x5002=((r20)*(x4984));
IkReal x5003=((cj0)*(x4984));
IkReal x5004=((r21)*(x4983));
IkReal x5005=((r21)*(x4984));
IkReal x5006=((r20)*(x4983));
IkReal x5007=((x4984)*(x4993));
IkReal x5008=((r01)*(sj6)*(x4984));
IkReal x5009=((cj5)*(r10)*(x4991));
evalcond[0]=((IkReal(-1.00000000000000))+(((sj6)*(x5005)))+(((x4996)*(x5006)))+(((x4983)*(x4985)))+(((x4989)*(x5004)))+(((IkReal(-1.00000000000000))*(x4986)*(x5002))));
evalcond[1]=((((x4989)*(x5005)))+(((x4984)*(x4985)))+(((IkReal(-1.00000000000000))*(x4991)*(x5004)))+(((cj6)*(x5006)))+(((x4996)*(x5002))));
evalcond[2]=((((r01)*(x4989)*(x4998)))+(((IkReal(-1.00000000000000))*(x4986)*(x4988)*(x5000)))+(((x4994)*(x4998)))+(((x4998)*(x4999)))+(((IkReal(-1.00000000000000))*(r10)*(x4983)*(x4987)*(x4996)))+(((IkReal(-1.00000000000000))*(x4984)*(x4987)*(x4990)))+(((IkReal(-1.00000000000000))*(x4983)*(x4987)*(x4993)))+(((x4995)*(x5003)))+(((IkReal(-1.00000000000000))*(r00)*(x4986)*(x5001)))+(((r01)*(sj6)*(x5001))));
evalcond[3]=((((x4994)*(x5001)))+(((IkReal(-1.00000000000000))*(r10)*(x4986)*(x5000)))+(((IkReal(-1.00000000000000))*(r10)*(x4984)*(x4987)*(x4996)))+(((IkReal(-1.00000000000000))*(x4987)*(x5007)))+(((x4990)*(x5000)))+(((r01)*(x4989)*(x5001)))+(((IkReal(-1.00000000000000))*(r01)*(x4991)*(x4998)))+(((IkReal(-1.00000000000000))*(cj3)))+(((IkReal(-1.00000000000000))*(x4986)*(x4988)*(x5003)))+(((x4999)*(x5001)))+(((x4992)*(x4998))));
evalcond[4]=((((IkReal(-1.00000000000000))*(x4993)*(x4998)))+(((IkReal(-1.00000000000000))*(x4983)*(x4987)*(x4999)))+(((IkReal(-1.00000000000000))*(x4987)*(x5008)))+(((IkReal(-1.00000000000000))*(x4986)*(x4988)*(x4998)))+(((IkReal(-1.00000000000000))*(x4990)*(x5001)))+(((IkReal(-1.00000000000000))*(x4983)*(x4987)*(x4994)))+(((x4992)*(x5003)))+(((IkReal(-1.00000000000000))*(x4998)*(x5009)))+(((x4995)*(x5001)))+(((IkReal(-1.00000000000000))*(x4986)*(x4997)*(x5000))));
evalcond[5]=((((IkReal(-1.00000000000000))*(x4984)*(x4987)*(x4999)))+(sj3)+(((IkReal(-1.00000000000000))*(x5001)*(x5009)))+(((r01)*(sj6)*(x5000)))+(((IkReal(-1.00000000000000))*(x4993)*(x5001)))+(((IkReal(-1.00000000000000))*(x4986)*(x4997)*(x5003)))+(((IkReal(-1.00000000000000))*(x4984)*(x4987)*(x4994)))+(((IkReal(-1.00000000000000))*(x4986)*(x4988)*(x5001)))+(((IkReal(-1.00000000000000))*(r10)*(x4986)*(x4998)))+(((x4990)*(x4998)))+(((IkReal(-1.00000000000000))*(r00)*(x4986)*(x5000))));
if( IKabs(evalcond[0]) > 0.000001  || IKabs(evalcond[1]) > 0.000001  || IKabs(evalcond[2]) > 0.000001  || IKabs(evalcond[3]) > 0.000001  || IKabs(evalcond[4]) > 0.000001  || IKabs(evalcond[5]) > 0.000001  )
{
continue;
}
}

{
std::vector<IkSingleDOFSolutionBase<IkReal> > vinfos(7);
vinfos[0].jointtype = 1;
vinfos[0].foffset = j0;
vinfos[0].indices[0] = _ij0[0];
vinfos[0].indices[1] = _ij0[1];
vinfos[0].maxsolutions = _nj0;
vinfos[1].jointtype = 1;
vinfos[1].foffset = j1;
vinfos[1].indices[0] = _ij1[0];
vinfos[1].indices[1] = _ij1[1];
vinfos[1].maxsolutions = _nj1;
vinfos[2].jointtype = 1;
vinfos[2].foffset = j2;
vinfos[2].indices[0] = _ij2[0];
vinfos[2].indices[1] = _ij2[1];
vinfos[2].maxsolutions = _nj2;
vinfos[3].jointtype = 1;
vinfos[3].foffset = j3;
vinfos[3].indices[0] = _ij3[0];
vinfos[3].indices[1] = _ij3[1];
vinfos[3].maxsolutions = _nj3;
vinfos[4].jointtype = 1;
vinfos[4].foffset = j4;
vinfos[4].indices[0] = _ij4[0];
vinfos[4].indices[1] = _ij4[1];
vinfos[4].maxsolutions = _nj4;
vinfos[5].jointtype = 1;
vinfos[5].foffset = j5;
vinfos[5].indices[0] = _ij5[0];
vinfos[5].indices[1] = _ij5[1];
vinfos[5].maxsolutions = _nj5;
vinfos[6].jointtype = 1;
vinfos[6].foffset = j6;
vinfos[6].indices[0] = _ij6[0];
vinfos[6].indices[1] = _ij6[1];
vinfos[6].maxsolutions = _nj6;
std::vector<int> vfree(0);
solutions.AddSolution(vinfos,vfree);
}
}
}

}

}
}
}

} else
{
if( 1 )
{
continue;

} else
{
}
}
}
}

} else
{
{
IkReal j3array[1], cj3array[1], sj3array[1];
bool j3valid[1]={false};
_nj3 = 1;
IkReal x5010=((sj5)*(sj6));
IkReal x5011=((IkReal(1.00000000000000))*(sj0));
IkReal x5012=((cj6)*(sj5));
IkReal x5013=((IkReal(1.00000000000000))*(cj5));
if( IKabs(((((IkReal(-1.00000000000000))*(r01)*(x5011)*(x5012)))+(((IkReal(-1.00000000000000))*(r00)*(x5010)*(x5011)))+(((IkReal(-1.00000000000000))*(cj0)*(r12)*(x5013)))+(((cj0)*(r11)*(x5012)))+(((cj5)*(r02)*(sj0)))+(((cj0)*(r10)*(x5010))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(((((IKabs(sj1) != 0)?((IkReal)1/(sj1)):(IkReal)1.0e30))*(((((r21)*(x5012)))+(((IkReal(-1.00000000000000))*(r22)*(x5013)))+(((r20)*(x5010))))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(IKsqr(((((IkReal(-1.00000000000000))*(r01)*(x5011)*(x5012)))+(((IkReal(-1.00000000000000))*(r00)*(x5010)*(x5011)))+(((IkReal(-1.00000000000000))*(cj0)*(r12)*(x5013)))+(((cj0)*(r11)*(x5012)))+(((cj5)*(r02)*(sj0)))+(((cj0)*(r10)*(x5010)))))+IKsqr(((((IKabs(sj1) != 0)?((IkReal)1/(sj1)):(IkReal)1.0e30))*(((((r21)*(x5012)))+(((IkReal(-1.00000000000000))*(r22)*(x5013)))+(((r20)*(x5010)))))))-1) <= IKFAST_SINCOS_THRESH )
    continue;
j3array[0]=IKatan2(((((IkReal(-1.00000000000000))*(r01)*(x5011)*(x5012)))+(((IkReal(-1.00000000000000))*(r00)*(x5010)*(x5011)))+(((IkReal(-1.00000000000000))*(cj0)*(r12)*(x5013)))+(((cj0)*(r11)*(x5012)))+(((cj5)*(r02)*(sj0)))+(((cj0)*(r10)*(x5010)))), ((((IKabs(sj1) != 0)?((IkReal)1/(sj1)):(IkReal)1.0e30))*(((((r21)*(x5012)))+(((IkReal(-1.00000000000000))*(r22)*(x5013)))+(((r20)*(x5010)))))));
sj3array[0]=IKsin(j3array[0]);
cj3array[0]=IKcos(j3array[0]);
if( j3array[0] > IKPI )
{
    j3array[0]-=IK2PI;
}
else if( j3array[0] < -IKPI )
{    j3array[0]+=IK2PI;
}
j3valid[0] = true;
for(int ij3 = 0; ij3 < 1; ++ij3)
{
if( !j3valid[ij3] )
{
    continue;
}
_ij3[0] = ij3; _ij3[1] = -1;
for(int iij3 = ij3+1; iij3 < 1; ++iij3)
{
if( j3valid[iij3] && IKabs(cj3array[ij3]-cj3array[iij3]) < IKFAST_SOLUTION_THRESH && IKabs(sj3array[ij3]-sj3array[iij3]) < IKFAST_SOLUTION_THRESH )
{
    j3valid[iij3]=false; _ij3[1] = iij3; break; 
}
}
j3 = j3array[ij3]; cj3 = cj3array[ij3]; sj3 = sj3array[ij3];
{
IkReal evalcond[3];
IkReal x5014=IKcos(j3);
IkReal x5015=((sj5)*(sj6));
IkReal x5016=((cj0)*(cj5));
IkReal x5017=((IkReal(1.00000000000000))*(cj0));
IkReal x5018=((IkReal(1.00000000000000))*(sj0));
IkReal x5019=((IkReal(1.00000000000000))*(x5014));
IkReal x5020=((cj6)*(r01)*(sj5));
IkReal x5021=((cj6)*(r11)*(sj5));
evalcond[0]=((((cj6)*(r21)*(sj5)))+(((IkReal(-1.00000000000000))*(sj1)*(x5019)))+(((r20)*(x5015)))+(((IkReal(-1.00000000000000))*(cj5)*(r22))));
evalcond[1]=((((sj0)*(x5020)))+(((IkReal(-1.00000000000000))*(x5017)*(x5021)))+(((r12)*(x5016)))+(((r00)*(sj0)*(x5015)))+(((IkReal(-1.00000000000000))*(cj5)*(r02)*(x5018)))+(((IkReal(-1.00000000000000))*(r10)*(x5015)*(x5017)))+(IKsin(j3)));
evalcond[2]=((((IkReal(-1.00000000000000))*(r00)*(x5015)*(x5017)))+(((cj5)*(r12)*(sj0)))+(((r02)*(x5016)))+(((IkReal(-1.00000000000000))*(x5018)*(x5021)))+(((IkReal(-1.00000000000000))*(cj1)*(x5019)))+(((IkReal(-1.00000000000000))*(r10)*(x5015)*(x5018)))+(((IkReal(-1.00000000000000))*(x5017)*(x5020))));
if( IKabs(evalcond[0]) > 0.000001  || IKabs(evalcond[1]) > 0.000001  || IKabs(evalcond[2]) > 0.000001  )
{
continue;
}
}

{
IkReal dummyeval[1];
IkReal gconst28;
IkReal x5022=(r21)*(r21);
IkReal x5023=(cj5)*(cj5);
IkReal x5024=(sj6)*(sj6);
IkReal x5025=(cj6)*(cj6);
IkReal x5026=(r20)*(r20);
IkReal x5027=((cj6)*(r21));
IkReal x5028=((IkReal(2.00000000000000))*(r20)*(sj6));
IkReal x5029=((cj5)*(r22)*(sj5));
IkReal x5030=((IkReal(1.00000000000000))*(x5024));
IkReal x5031=((IkReal(1.00000000000000))*(x5025));
gconst28=IKsign(((((IkReal(-1.00000000000000))*(x5026)*(x5031)))+(((IkReal(-1.00000000000000))*((r22)*(r22))*((sj5)*(sj5))))+(((IkReal(-1.00000000000000))*(x5022)*(x5030)))+(((IkReal(-1.00000000000000))*(x5023)*(x5026)*(x5030)))+(((IkReal(-2.00000000000000))*(x5027)*(x5029)))+(((x5027)*(x5028)))+(((IkReal(-1.00000000000000))*(x5022)*(x5023)*(x5031)))+(((IkReal(-1.00000000000000))*(x5023)*(x5027)*(x5028)))+(((IkReal(-1.00000000000000))*(x5028)*(x5029)))));
IkReal x5032=(r21)*(r21);
IkReal x5033=(cj5)*(cj5);
IkReal x5034=(sj6)*(sj6);
IkReal x5035=(cj6)*(cj6);
IkReal x5036=(r20)*(r20);
IkReal x5037=((cj6)*(r21));
IkReal x5038=((IkReal(2.00000000000000))*(r20)*(sj6));
IkReal x5039=((cj5)*(r22)*(sj5));
IkReal x5040=((IkReal(1.00000000000000))*(x5034));
IkReal x5041=((IkReal(1.00000000000000))*(x5035));
dummyeval[0]=((((x5037)*(x5038)))+(((IkReal(-1.00000000000000))*(x5038)*(x5039)))+(((IkReal(-1.00000000000000))*(x5036)*(x5041)))+(((IkReal(-1.00000000000000))*((r22)*(r22))*((sj5)*(sj5))))+(((IkReal(-1.00000000000000))*(x5032)*(x5033)*(x5041)))+(((IkReal(-1.00000000000000))*(x5033)*(x5037)*(x5038)))+(((IkReal(-2.00000000000000))*(x5037)*(x5039)))+(((IkReal(-1.00000000000000))*(x5032)*(x5040)))+(((IkReal(-1.00000000000000))*(x5033)*(x5036)*(x5040))));
if( IKabs(dummyeval[0]) < 0.0000010000000000  )
{
{
IkReal dummyeval[1];
IkReal gconst29;
IkReal x5042=(cj6)*(cj6);
IkReal x5043=(sj6)*(sj6);
IkReal x5044=((IkReal(1.00000000000000))*(r01));
IkReal x5045=((sj0)*(sj5));
IkReal x5046=((cj6)*(r22));
IkReal x5047=((r21)*(sj6));
IkReal x5048=((r00)*(r21));
IkReal x5049=((cj0)*(sj5));
IkReal x5050=((cj6)*(r20));
IkReal x5051=((r22)*(sj6));
IkReal x5052=((cj0)*(cj5));
IkReal x5053=((IkReal(1.00000000000000))*(r10));
IkReal x5054=((cj5)*(sj0));
IkReal x5055=((r20)*(x5043));
IkReal x5056=((x5042)*(x5054));
gconst29=IKsign(((((r11)*(r20)*(x5042)*(x5052)))+(((r00)*(x5045)*(x5046)))+(((IkReal(-1.00000000000000))*(x5046)*(x5049)*(x5053)))+(((IkReal(-1.00000000000000))*(r12)*(x5047)*(x5049)))+(((r11)*(x5052)*(x5055)))+(((IkReal(-1.00000000000000))*(r20)*(x5044)*(x5056)))+(((r02)*(x5045)*(x5047)))+(((IkReal(-1.00000000000000))*(r21)*(x5042)*(x5052)*(x5053)))+(((IkReal(-1.00000000000000))*(x5044)*(x5045)*(x5051)))+(((IkReal(-1.00000000000000))*(r21)*(x5043)*(x5052)*(x5053)))+(((r12)*(x5049)*(x5050)))+(((IkReal(-1.00000000000000))*(r02)*(x5045)*(x5050)))+(((x5043)*(x5048)*(x5054)))+(((x5048)*(x5056)))+(((IkReal(-1.00000000000000))*(x5044)*(x5054)*(x5055)))+(((r11)*(x5049)*(x5051)))));
IkReal x5057=(cj6)*(cj6);
IkReal x5058=(sj6)*(sj6);
IkReal x5059=((IkReal(1.00000000000000))*(r01));
IkReal x5060=((sj0)*(sj5));
IkReal x5061=((cj6)*(r22));
IkReal x5062=((r21)*(sj6));
IkReal x5063=((r00)*(r21));
IkReal x5064=((cj0)*(sj5));
IkReal x5065=((cj6)*(r20));
IkReal x5066=((r22)*(sj6));
IkReal x5067=((cj0)*(cj5));
IkReal x5068=((IkReal(1.00000000000000))*(r10));
IkReal x5069=((cj5)*(sj0));
IkReal x5070=((r20)*(x5058));
IkReal x5071=((x5057)*(x5069));
dummyeval[0]=((((r02)*(x5060)*(x5062)))+(((x5058)*(x5063)*(x5069)))+(((IkReal(-1.00000000000000))*(x5061)*(x5064)*(x5068)))+(((r11)*(r20)*(x5057)*(x5067)))+(((IkReal(-1.00000000000000))*(r12)*(x5062)*(x5064)))+(((r11)*(x5064)*(x5066)))+(((r11)*(x5067)*(x5070)))+(((IkReal(-1.00000000000000))*(r02)*(x5060)*(x5065)))+(((x5063)*(x5071)))+(((r00)*(x5060)*(x5061)))+(((r12)*(x5064)*(x5065)))+(((IkReal(-1.00000000000000))*(r21)*(x5058)*(x5067)*(x5068)))+(((IkReal(-1.00000000000000))*(x5059)*(x5069)*(x5070)))+(((IkReal(-1.00000000000000))*(x5059)*(x5060)*(x5066)))+(((IkReal(-1.00000000000000))*(r21)*(x5057)*(x5067)*(x5068)))+(((IkReal(-1.00000000000000))*(r20)*(x5059)*(x5071))));
if( IKabs(dummyeval[0]) < 0.0000010000000000  )
{
continue;

} else
{
{
IkReal j4array[1], cj4array[1], sj4array[1];
bool j4valid[1]={false};
_nj4 = 1;
IkReal x5072=((cj1)*(cj6));
IkReal x5073=((IkReal(1.00000000000000))*(sj0));
IkReal x5074=((cj0)*(r10));
IkReal x5075=((cj1)*(sj5));
IkReal x5076=((cj1)*(sj6));
IkReal x5077=((cj0)*(r11));
if( IKabs(((gconst29)*(((((IkReal(-1.00000000000000))*(x5076)*(x5077)))+(((x5072)*(x5074)))+(((r01)*(sj0)*(x5076)))+(((IkReal(-1.00000000000000))*(r00)*(x5072)*(x5073))))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(((gconst29)*(((((cj5)*(x5074)*(x5076)))+(((IkReal(-1.00000000000000))*(cj5)*(r00)*(x5073)*(x5076)))+(((cj5)*(x5072)*(x5077)))+(((IkReal(-1.00000000000000))*(cj5)*(r01)*(x5072)*(x5073)))+(((IkReal(-1.00000000000000))*(r02)*(x5073)*(x5075)))+(((cj0)*(r12)*(x5075))))))) < IKFAST_ATAN2_MAGTHRESH )
    continue;
j4array[0]=IKatan2(((gconst29)*(((((IkReal(-1.00000000000000))*(x5076)*(x5077)))+(((x5072)*(x5074)))+(((r01)*(sj0)*(x5076)))+(((IkReal(-1.00000000000000))*(r00)*(x5072)*(x5073)))))), ((gconst29)*(((((cj5)*(x5074)*(x5076)))+(((IkReal(-1.00000000000000))*(cj5)*(r00)*(x5073)*(x5076)))+(((cj5)*(x5072)*(x5077)))+(((IkReal(-1.00000000000000))*(cj5)*(r01)*(x5072)*(x5073)))+(((IkReal(-1.00000000000000))*(r02)*(x5073)*(x5075)))+(((cj0)*(r12)*(x5075)))))));
sj4array[0]=IKsin(j4array[0]);
cj4array[0]=IKcos(j4array[0]);
if( j4array[0] > IKPI )
{
    j4array[0]-=IK2PI;
}
else if( j4array[0] < -IKPI )
{    j4array[0]+=IK2PI;
}
j4valid[0] = true;
for(int ij4 = 0; ij4 < 1; ++ij4)
{
if( !j4valid[ij4] )
{
    continue;
}
_ij4[0] = ij4; _ij4[1] = -1;
for(int iij4 = ij4+1; iij4 < 1; ++iij4)
{
if( j4valid[iij4] && IKabs(cj4array[ij4]-cj4array[iij4]) < IKFAST_SOLUTION_THRESH && IKabs(sj4array[ij4]-sj4array[iij4]) < IKFAST_SOLUTION_THRESH )
{
    j4valid[iij4]=false; _ij4[1] = iij4; break; 
}
}
j4 = j4array[ij4]; cj4 = cj4array[ij4]; sj4 = sj4array[ij4];
{
IkReal evalcond[6];
IkReal x5078=IKsin(j4);
IkReal x5079=IKcos(j4);
IkReal x5080=((r22)*(sj5));
IkReal x5081=((IkReal(1.00000000000000))*(cj6));
IkReal x5082=((IkReal(1.00000000000000))*(cj0));
IkReal x5083=((IkReal(1.00000000000000))*(sj1));
IkReal x5084=((cj5)*(r11));
IkReal x5085=((cj5)*(cj6));
IkReal x5086=((r11)*(sj6));
IkReal x5087=((IkReal(1.00000000000000))*(sj6));
IkReal x5088=((cj6)*(r00));
IkReal x5089=((r12)*(sj5));
IkReal x5090=((r02)*(sj5));
IkReal x5091=((cj6)*(r10));
IkReal x5092=((cj5)*(sj6));
IkReal x5093=((cj5)*(r01));
IkReal x5094=((sj0)*(x5078));
IkReal x5095=((r00)*(x5092));
IkReal x5096=((cj0)*(x5078));
IkReal x5097=((sj0)*(x5079));
IkReal x5098=((r20)*(x5079));
IkReal x5099=((cj0)*(x5079));
IkReal x5100=((r21)*(x5078));
IkReal x5101=((r21)*(x5079));
IkReal x5102=((r20)*(x5078));
IkReal x5103=((x5079)*(x5089));
IkReal x5104=((r01)*(sj6)*(x5079));
IkReal x5105=((cj5)*(r10)*(x5087));
evalcond[0]=((((IkReal(-1.00000000000000))*(x5081)*(x5098)))+(((x5085)*(x5100)))+(((x5092)*(x5102)))+(cj1)+(((sj6)*(x5101)))+(((x5078)*(x5080))));
evalcond[1]=((((x5085)*(x5101)))+(((x5079)*(x5080)))+(((x5092)*(x5098)))+(((IkReal(-1.00000000000000))*(sj3)*(x5083)))+(((IkReal(-1.00000000000000))*(x5087)*(x5100)))+(((cj6)*(x5102))));
evalcond[2]=((((x5090)*(x5094)))+(((x5091)*(x5099)))+(((r01)*(sj6)*(x5097)))+(((IkReal(-1.00000000000000))*(x5078)*(x5082)*(x5089)))+(((IkReal(-1.00000000000000))*(x5079)*(x5082)*(x5086)))+(((IkReal(-1.00000000000000))*(r00)*(x5081)*(x5097)))+(((r01)*(x5085)*(x5094)))+(((IkReal(-1.00000000000000))*(r10)*(x5078)*(x5082)*(x5092)))+(((IkReal(-1.00000000000000))*(x5081)*(x5084)*(x5096)))+(((x5094)*(x5095))));
evalcond[3]=((((IkReal(-1.00000000000000))*(x5082)*(x5103)))+(((IkReal(-1.00000000000000))*(r10)*(x5081)*(x5096)))+(((IkReal(-1.00000000000000))*(x5081)*(x5084)*(x5099)))+(((IkReal(-1.00000000000000))*(cj3)))+(((x5095)*(x5097)))+(((x5086)*(x5096)))+(((IkReal(-1.00000000000000))*(r01)*(x5087)*(x5094)))+(((r01)*(x5085)*(x5097)))+(((x5090)*(x5097)))+(((x5088)*(x5094)))+(((IkReal(-1.00000000000000))*(r10)*(x5079)*(x5082)*(x5092))));
evalcond[4]=((((IkReal(-1.00000000000000))*(x5094)*(x5105)))+(((IkReal(-1.00000000000000))*(x5082)*(x5104)))+(((IkReal(-1.00000000000000))*(x5086)*(x5097)))+(((IkReal(-1.00000000000000))*(x5081)*(x5093)*(x5096)))+(((IkReal(-1.00000000000000))*(x5089)*(x5094)))+(((IkReal(-1.00000000000000))*(x5081)*(x5084)*(x5094)))+(((x5091)*(x5097)))+(((x5088)*(x5099)))+(((IkReal(-1.00000000000000))*(x5078)*(x5082)*(x5090)))+(((IkReal(-1.00000000000000))*(x5078)*(x5082)*(x5095)))+(((IkReal(-1.00000000000000))*(x5083))));
evalcond[5]=((((x5086)*(x5094)))+(((IkReal(-1.00000000000000))*(r00)*(x5081)*(x5096)))+(((IkReal(-1.00000000000000))*(r10)*(x5081)*(x5094)))+(((r01)*(sj6)*(x5096)))+(((IkReal(-1.00000000000000))*(cj1)*(sj3)))+(((IkReal(-1.00000000000000))*(x5081)*(x5093)*(x5099)))+(((IkReal(-1.00000000000000))*(x5079)*(x5082)*(x5090)))+(((IkReal(-1.00000000000000))*(x5079)*(x5082)*(x5095)))+(((IkReal(-1.00000000000000))*(x5081)*(x5084)*(x5097)))+(((IkReal(-1.00000000000000))*(x5097)*(x5105)))+(((IkReal(-1.00000000000000))*(x5089)*(x5097))));
if( IKabs(evalcond[0]) > 0.000001  || IKabs(evalcond[1]) > 0.000001  || IKabs(evalcond[2]) > 0.000001  || IKabs(evalcond[3]) > 0.000001  || IKabs(evalcond[4]) > 0.000001  || IKabs(evalcond[5]) > 0.000001  )
{
continue;
}
}

{
std::vector<IkSingleDOFSolutionBase<IkReal> > vinfos(7);
vinfos[0].jointtype = 1;
vinfos[0].foffset = j0;
vinfos[0].indices[0] = _ij0[0];
vinfos[0].indices[1] = _ij0[1];
vinfos[0].maxsolutions = _nj0;
vinfos[1].jointtype = 1;
vinfos[1].foffset = j1;
vinfos[1].indices[0] = _ij1[0];
vinfos[1].indices[1] = _ij1[1];
vinfos[1].maxsolutions = _nj1;
vinfos[2].jointtype = 1;
vinfos[2].foffset = j2;
vinfos[2].indices[0] = _ij2[0];
vinfos[2].indices[1] = _ij2[1];
vinfos[2].maxsolutions = _nj2;
vinfos[3].jointtype = 1;
vinfos[3].foffset = j3;
vinfos[3].indices[0] = _ij3[0];
vinfos[3].indices[1] = _ij3[1];
vinfos[3].maxsolutions = _nj3;
vinfos[4].jointtype = 1;
vinfos[4].foffset = j4;
vinfos[4].indices[0] = _ij4[0];
vinfos[4].indices[1] = _ij4[1];
vinfos[4].maxsolutions = _nj4;
vinfos[5].jointtype = 1;
vinfos[5].foffset = j5;
vinfos[5].indices[0] = _ij5[0];
vinfos[5].indices[1] = _ij5[1];
vinfos[5].maxsolutions = _nj5;
vinfos[6].jointtype = 1;
vinfos[6].foffset = j6;
vinfos[6].indices[0] = _ij6[0];
vinfos[6].indices[1] = _ij6[1];
vinfos[6].maxsolutions = _nj6;
std::vector<int> vfree(0);
solutions.AddSolution(vinfos,vfree);
}
}
}

}

}

} else
{
{
IkReal j4array[1], cj4array[1], sj4array[1];
bool j4valid[1]={false};
_nj4 = 1;
IkReal x5106=((cj1)*(r20));
IkReal x5107=((cj5)*(sj6));
IkReal x5108=((sj1)*(sj3));
IkReal x5109=((r21)*(sj6));
IkReal x5110=((r22)*(sj5));
IkReal x5111=((IkReal(1.00000000000000))*(cj6));
IkReal x5112=((cj5)*(r21));
if( IKabs(((gconst28)*(((((cj1)*(x5110)))+(((x5106)*(x5107)))+(((IkReal(-1.00000000000000))*(r20)*(x5108)*(x5111)))+(((x5108)*(x5109)))+(((cj1)*(cj6)*(x5112))))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(((gconst28)*(((((IkReal(-1.00000000000000))*(r20)*(x5107)*(x5108)))+(((IkReal(-1.00000000000000))*(x5108)*(x5111)*(x5112)))+(((IkReal(-1.00000000000000))*(x5108)*(x5110)))+(((cj1)*(x5109)))+(((IkReal(-1.00000000000000))*(x5106)*(x5111))))))) < IKFAST_ATAN2_MAGTHRESH )
    continue;
j4array[0]=IKatan2(((gconst28)*(((((cj1)*(x5110)))+(((x5106)*(x5107)))+(((IkReal(-1.00000000000000))*(r20)*(x5108)*(x5111)))+(((x5108)*(x5109)))+(((cj1)*(cj6)*(x5112)))))), ((gconst28)*(((((IkReal(-1.00000000000000))*(r20)*(x5107)*(x5108)))+(((IkReal(-1.00000000000000))*(x5108)*(x5111)*(x5112)))+(((IkReal(-1.00000000000000))*(x5108)*(x5110)))+(((cj1)*(x5109)))+(((IkReal(-1.00000000000000))*(x5106)*(x5111)))))));
sj4array[0]=IKsin(j4array[0]);
cj4array[0]=IKcos(j4array[0]);
if( j4array[0] > IKPI )
{
    j4array[0]-=IK2PI;
}
else if( j4array[0] < -IKPI )
{    j4array[0]+=IK2PI;
}
j4valid[0] = true;
for(int ij4 = 0; ij4 < 1; ++ij4)
{
if( !j4valid[ij4] )
{
    continue;
}
_ij4[0] = ij4; _ij4[1] = -1;
for(int iij4 = ij4+1; iij4 < 1; ++iij4)
{
if( j4valid[iij4] && IKabs(cj4array[ij4]-cj4array[iij4]) < IKFAST_SOLUTION_THRESH && IKabs(sj4array[ij4]-sj4array[iij4]) < IKFAST_SOLUTION_THRESH )
{
    j4valid[iij4]=false; _ij4[1] = iij4; break; 
}
}
j4 = j4array[ij4]; cj4 = cj4array[ij4]; sj4 = sj4array[ij4];
{
IkReal evalcond[6];
IkReal x5113=IKsin(j4);
IkReal x5114=IKcos(j4);
IkReal x5115=((r22)*(sj5));
IkReal x5116=((IkReal(1.00000000000000))*(cj6));
IkReal x5117=((IkReal(1.00000000000000))*(cj0));
IkReal x5118=((IkReal(1.00000000000000))*(sj1));
IkReal x5119=((cj5)*(r11));
IkReal x5120=((cj5)*(cj6));
IkReal x5121=((r11)*(sj6));
IkReal x5122=((IkReal(1.00000000000000))*(sj6));
IkReal x5123=((cj6)*(r00));
IkReal x5124=((r12)*(sj5));
IkReal x5125=((r02)*(sj5));
IkReal x5126=((cj6)*(r10));
IkReal x5127=((cj5)*(sj6));
IkReal x5128=((cj5)*(r01));
IkReal x5129=((sj0)*(x5113));
IkReal x5130=((r00)*(x5127));
IkReal x5131=((cj0)*(x5113));
IkReal x5132=((sj0)*(x5114));
IkReal x5133=((r20)*(x5114));
IkReal x5134=((cj0)*(x5114));
IkReal x5135=((r21)*(x5113));
IkReal x5136=((r21)*(x5114));
IkReal x5137=((r20)*(x5113));
IkReal x5138=((x5114)*(x5124));
IkReal x5139=((r01)*(sj6)*(x5114));
IkReal x5140=((cj5)*(r10)*(x5122));
evalcond[0]=((((x5127)*(x5137)))+(((x5113)*(x5115)))+(((x5120)*(x5135)))+(cj1)+(((IkReal(-1.00000000000000))*(x5116)*(x5133)))+(((sj6)*(x5136))));
evalcond[1]=((((cj6)*(x5137)))+(((x5114)*(x5115)))+(((x5127)*(x5133)))+(((IkReal(-1.00000000000000))*(x5122)*(x5135)))+(((x5120)*(x5136)))+(((IkReal(-1.00000000000000))*(sj3)*(x5118))));
evalcond[2]=((((IkReal(-1.00000000000000))*(x5113)*(x5117)*(x5124)))+(((IkReal(-1.00000000000000))*(x5116)*(x5119)*(x5131)))+(((x5125)*(x5129)))+(((x5129)*(x5130)))+(((IkReal(-1.00000000000000))*(x5114)*(x5117)*(x5121)))+(((x5126)*(x5134)))+(((r01)*(sj6)*(x5132)))+(((IkReal(-1.00000000000000))*(r10)*(x5113)*(x5117)*(x5127)))+(((r01)*(x5120)*(x5129)))+(((IkReal(-1.00000000000000))*(r00)*(x5116)*(x5132))));
evalcond[3]=((((IkReal(-1.00000000000000))*(r10)*(x5116)*(x5131)))+(((IkReal(-1.00000000000000))*(r10)*(x5114)*(x5117)*(x5127)))+(((x5130)*(x5132)))+(((IkReal(-1.00000000000000))*(x5117)*(x5138)))+(((IkReal(-1.00000000000000))*(x5116)*(x5119)*(x5134)))+(((x5123)*(x5129)))+(((r01)*(x5120)*(x5132)))+(((x5121)*(x5131)))+(((IkReal(-1.00000000000000))*(cj3)))+(((IkReal(-1.00000000000000))*(r01)*(x5122)*(x5129)))+(((x5125)*(x5132))));
evalcond[4]=((((IkReal(-1.00000000000000))*(x5116)*(x5119)*(x5129)))+(((IkReal(-1.00000000000000))*(x5129)*(x5140)))+(((IkReal(-1.00000000000000))*(x5113)*(x5117)*(x5125)))+(((x5126)*(x5132)))+(((IkReal(-1.00000000000000))*(x5117)*(x5139)))+(((IkReal(-1.00000000000000))*(x5113)*(x5117)*(x5130)))+(((IkReal(-1.00000000000000))*(x5124)*(x5129)))+(((IkReal(-1.00000000000000))*(x5121)*(x5132)))+(((IkReal(-1.00000000000000))*(x5118)))+(((x5123)*(x5134)))+(((IkReal(-1.00000000000000))*(x5116)*(x5128)*(x5131))));
evalcond[5]=((((IkReal(-1.00000000000000))*(x5116)*(x5128)*(x5134)))+(((IkReal(-1.00000000000000))*(x5114)*(x5117)*(x5125)))+(((IkReal(-1.00000000000000))*(x5114)*(x5117)*(x5130)))+(((IkReal(-1.00000000000000))*(x5116)*(x5119)*(x5132)))+(((IkReal(-1.00000000000000))*(r00)*(x5116)*(x5131)))+(((x5121)*(x5129)))+(((IkReal(-1.00000000000000))*(r10)*(x5116)*(x5129)))+(((IkReal(-1.00000000000000))*(cj1)*(sj3)))+(((IkReal(-1.00000000000000))*(x5132)*(x5140)))+(((r01)*(sj6)*(x5131)))+(((IkReal(-1.00000000000000))*(x5124)*(x5132))));
if( IKabs(evalcond[0]) > 0.000001  || IKabs(evalcond[1]) > 0.000001  || IKabs(evalcond[2]) > 0.000001  || IKabs(evalcond[3]) > 0.000001  || IKabs(evalcond[4]) > 0.000001  || IKabs(evalcond[5]) > 0.000001  )
{
continue;
}
}

{
std::vector<IkSingleDOFSolutionBase<IkReal> > vinfos(7);
vinfos[0].jointtype = 1;
vinfos[0].foffset = j0;
vinfos[0].indices[0] = _ij0[0];
vinfos[0].indices[1] = _ij0[1];
vinfos[0].maxsolutions = _nj0;
vinfos[1].jointtype = 1;
vinfos[1].foffset = j1;
vinfos[1].indices[0] = _ij1[0];
vinfos[1].indices[1] = _ij1[1];
vinfos[1].maxsolutions = _nj1;
vinfos[2].jointtype = 1;
vinfos[2].foffset = j2;
vinfos[2].indices[0] = _ij2[0];
vinfos[2].indices[1] = _ij2[1];
vinfos[2].maxsolutions = _nj2;
vinfos[3].jointtype = 1;
vinfos[3].foffset = j3;
vinfos[3].indices[0] = _ij3[0];
vinfos[3].indices[1] = _ij3[1];
vinfos[3].maxsolutions = _nj3;
vinfos[4].jointtype = 1;
vinfos[4].foffset = j4;
vinfos[4].indices[0] = _ij4[0];
vinfos[4].indices[1] = _ij4[1];
vinfos[4].maxsolutions = _nj4;
vinfos[5].jointtype = 1;
vinfos[5].foffset = j5;
vinfos[5].indices[0] = _ij5[0];
vinfos[5].indices[1] = _ij5[1];
vinfos[5].maxsolutions = _nj5;
vinfos[6].jointtype = 1;
vinfos[6].foffset = j6;
vinfos[6].indices[0] = _ij6[0];
vinfos[6].indices[1] = _ij6[1];
vinfos[6].maxsolutions = _nj6;
std::vector<int> vfree(0);
solutions.AddSolution(vinfos,vfree);
}
}
}

}

}
}
}

}

}

} else
{
{
IkReal j4array[1], cj4array[1], sj4array[1];
bool j4valid[1]={false};
_nj4 = 1;
IkReal x5141=((IkReal(1.00000000000000))*(sj1));
IkReal x5142=((cj0)*(cj1));
IkReal x5143=((cj1)*(sj0));
IkReal x5144=((cj5)*(sj6));
IkReal x5145=((cj5)*(cj6));
IkReal x5146=((sj6)*(x5142));
IkReal x5147=((cj6)*(x5143));
if( IKabs(((gconst27)*(((((IkReal(-1.00000000000000))*(r11)*(sj6)*(x5143)))+(((IkReal(-1.00000000000000))*(cj6)*(r20)*(x5141)))+(((r10)*(x5147)))+(((IkReal(-1.00000000000000))*(r01)*(x5146)))+(((cj6)*(r00)*(x5142)))+(((r21)*(sj1)*(sj6))))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(((gconst27)*(((((IkReal(-1.00000000000000))*(r22)*(sj5)*(x5141)))+(((r01)*(x5142)*(x5145)))+(((r12)*(sj5)*(x5143)))+(((IkReal(-1.00000000000000))*(r20)*(x5141)*(x5144)))+(((r11)*(x5143)*(x5145)))+(((r00)*(x5142)*(x5144)))+(((r02)*(sj5)*(x5142)))+(((IkReal(-1.00000000000000))*(r21)*(x5141)*(x5145)))+(((r10)*(x5143)*(x5144))))))) < IKFAST_ATAN2_MAGTHRESH )
    continue;
j4array[0]=IKatan2(((gconst27)*(((((IkReal(-1.00000000000000))*(r11)*(sj6)*(x5143)))+(((IkReal(-1.00000000000000))*(cj6)*(r20)*(x5141)))+(((r10)*(x5147)))+(((IkReal(-1.00000000000000))*(r01)*(x5146)))+(((cj6)*(r00)*(x5142)))+(((r21)*(sj1)*(sj6)))))), ((gconst27)*(((((IkReal(-1.00000000000000))*(r22)*(sj5)*(x5141)))+(((r01)*(x5142)*(x5145)))+(((r12)*(sj5)*(x5143)))+(((IkReal(-1.00000000000000))*(r20)*(x5141)*(x5144)))+(((r11)*(x5143)*(x5145)))+(((r00)*(x5142)*(x5144)))+(((r02)*(sj5)*(x5142)))+(((IkReal(-1.00000000000000))*(r21)*(x5141)*(x5145)))+(((r10)*(x5143)*(x5144)))))));
sj4array[0]=IKsin(j4array[0]);
cj4array[0]=IKcos(j4array[0]);
if( j4array[0] > IKPI )
{
    j4array[0]-=IK2PI;
}
else if( j4array[0] < -IKPI )
{    j4array[0]+=IK2PI;
}
j4valid[0] = true;
for(int ij4 = 0; ij4 < 1; ++ij4)
{
if( !j4valid[ij4] )
{
    continue;
}
_ij4[0] = ij4; _ij4[1] = -1;
for(int iij4 = ij4+1; iij4 < 1; ++iij4)
{
if( j4valid[iij4] && IKabs(cj4array[ij4]-cj4array[iij4]) < IKFAST_SOLUTION_THRESH && IKabs(sj4array[ij4]-sj4array[iij4]) < IKFAST_SOLUTION_THRESH )
{
    j4valid[iij4]=false; _ij4[1] = iij4; break; 
}
}
j4 = j4array[ij4]; cj4 = cj4array[ij4]; sj4 = sj4array[ij4];
{
IkReal evalcond[3];
IkReal x5148=IKsin(j4);
IkReal x5149=IKcos(j4);
IkReal x5150=((r00)*(sj6));
IkReal x5151=((cj6)*(r01));
IkReal x5152=((IkReal(1.00000000000000))*(cj0));
IkReal x5153=((IkReal(1.00000000000000))*(sj0));
IkReal x5154=((r10)*(sj6));
IkReal x5155=((sj5)*(x5148));
IkReal x5156=((IkReal(1.00000000000000))*(cj6)*(r11));
IkReal x5157=((cj5)*(x5148));
IkReal x5158=((cj6)*(x5149));
IkReal x5159=((sj0)*(x5157));
IkReal x5160=((r01)*(sj6)*(x5149));
IkReal x5161=((r11)*(sj6)*(x5149));
evalcond[0]=((((IkReal(-1.00000000000000))*(r20)*(x5158)))+(((r21)*(sj6)*(x5149)))+(((r20)*(sj6)*(x5157)))+(cj1)+(((r22)*(x5155)))+(((cj6)*(r21)*(x5157))));
evalcond[1]=((((IkReal(-1.00000000000000))*(r00)*(x5153)*(x5158)))+(((IkReal(-1.00000000000000))*(r12)*(x5152)*(x5155)))+(((IkReal(-1.00000000000000))*(x5152)*(x5154)*(x5157)))+(((x5150)*(x5159)))+(((x5151)*(x5159)))+(((cj0)*(r10)*(x5158)))+(((r02)*(sj0)*(x5155)))+(((sj0)*(x5160)))+(((IkReal(-1.00000000000000))*(x5152)*(x5161)))+(((IkReal(-1.00000000000000))*(cj6)*(r11)*(x5152)*(x5157))));
evalcond[2]=((((r10)*(sj0)*(x5158)))+(((cj0)*(r00)*(x5158)))+(((IkReal(-1.00000000000000))*(cj6)*(r11)*(x5153)*(x5157)))+(((IkReal(-1.00000000000000))*(x5151)*(x5152)*(x5157)))+(((IkReal(-1.00000000000000))*(x5152)*(x5160)))+(((IkReal(-1.00000000000000))*(x5153)*(x5154)*(x5157)))+(((IkReal(-1.00000000000000))*(sj1)))+(((IkReal(-1.00000000000000))*(x5150)*(x5152)*(x5157)))+(((IkReal(-1.00000000000000))*(r02)*(x5152)*(x5155)))+(((IkReal(-1.00000000000000))*(r12)*(x5153)*(x5155)))+(((IkReal(-1.00000000000000))*(x5153)*(x5161))));
if( IKabs(evalcond[0]) > 0.000001  || IKabs(evalcond[1]) > 0.000001  || IKabs(evalcond[2]) > 0.000001  )
{
continue;
}
}

{
IkReal dummyeval[1];
IkReal gconst30;
gconst30=IKsign(sj1);
dummyeval[0]=sj1;
if( IKabs(dummyeval[0]) < 0.0000010000000000  )
{
{
IkReal dummyeval[1];
dummyeval[0]=sj1;
if( IKabs(dummyeval[0]) < 0.0000010000000000  )
{
{
IkReal dummyeval[1];
dummyeval[0]=cj1;
if( IKabs(dummyeval[0]) < 0.0000010000000000  )
{
{
IkReal evalcond[9];
IkReal x5162=((IkReal(1.00000000000000))*(cj0));
IkReal x5163=((cj4)*(sj6));
IkReal x5164=((sj0)*(sj6));
IkReal x5165=((cj5)*(sj4));
IkReal x5166=((IkReal(0.374290000000000))*(sj5));
IkReal x5167=((sj4)*(sj5));
IkReal x5168=((cj0)*(cj6));
IkReal x5169=((IkReal(0.0100000000000000))*(cj5));
IkReal x5170=((cj4)*(sj5));
IkReal x5171=((cj5)*(sj0));
IkReal x5172=((IkReal(0.374290000000000))*(r02));
IkReal x5173=((r20)*(sj6));
IkReal x5174=((cj6)*(r21));
IkReal x5175=((IkReal(1.00000000000000))*(sj0));
IkReal x5176=((cj0)*(sj6));
IkReal x5177=((cj4)*(cj6));
IkReal x5178=((IkReal(0.374290000000000))*(r12));
IkReal x5179=((cj0)*(cj5));
IkReal x5180=((cj6)*(sj5));
IkReal x5181=((cj6)*(r01));
IkReal x5182=((r00)*(sj6));
IkReal x5183=((IkReal(0.0100000000000000))*(sj5));
IkReal x5184=((cj6)*(r11));
IkReal x5185=((IkReal(1.00000000000000))*(r10));
IkReal x5186=((r02)*(sj0));
IkReal x5187=((cj6)*(sj4));
IkReal x5188=((r12)*(x5175));
evalcond[0]=((IkReal(-3.14159265358979))+(IKfmod(((IkReal(1.57079632679490))+(j1)), IkReal(6.28318530717959))));
evalcond[1]=((((IkReal(-1.00000000000000))*(r20)*(x5177)))+(((r21)*(x5163)))+(((x5165)*(x5173)))+(((r22)*(x5167)))+(((x5165)*(x5174))));
evalcond[2]=((IkReal(0.364420000000000))+(((x5166)*(x5174)))+(((IkReal(-1.00000000000000))*(x5169)*(x5174)))+(((IkReal(-1.00000000000000))*(x5169)*(x5173)))+(((IkReal(-1.00000000000000))*(r22)*(x5183)))+(((IkReal(-0.374290000000000))*(cj5)*(r22)))+(pz)+(((x5166)*(x5173))));
evalcond[3]=((((IkReal(-1.00000000000000))*(sj5)*(x5164)*(x5185)))+(((IkReal(-1.00000000000000))*(sj5)*(x5162)*(x5182)))+(((r02)*(x5179)))+(((IkReal(-1.00000000000000))*(r01)*(x5162)*(x5180)))+(((IkReal(-1.00000000000000))*(r11)*(x5175)*(x5180)))+(((r12)*(x5171))));
evalcond[4]=((((IkReal(-1.00000000000000))*(r11)*(x5162)*(x5163)))+(((cj4)*(r10)*(x5168)))+(((x5167)*(x5186)))+(((IkReal(-1.00000000000000))*(x5162)*(x5165)*(x5184)))+(((r00)*(x5164)*(x5165)))+(((IkReal(-1.00000000000000))*(r00)*(x5175)*(x5177)))+(((r01)*(sj0)*(x5163)))+(((IkReal(-1.00000000000000))*(r10)*(sj6)*(x5162)*(x5165)))+(((sj0)*(x5165)*(x5181)))+(((IkReal(-1.00000000000000))*(r12)*(x5162)*(x5167))));
evalcond[5]=((IkReal(-1.00000000000000))+(((IkReal(-1.00000000000000))*(r01)*(x5162)*(x5163)))+(((IkReal(-1.00000000000000))*(x5162)*(x5165)*(x5181)))+(((IkReal(-1.00000000000000))*(r02)*(x5162)*(x5167)))+(((r10)*(sj0)*(x5177)))+(((IkReal(-1.00000000000000))*(x5165)*(x5175)*(x5184)))+(((IkReal(-1.00000000000000))*(x5167)*(x5188)))+(((IkReal(-1.00000000000000))*(x5162)*(x5165)*(x5182)))+(((cj4)*(r00)*(x5168)))+(((IkReal(-1.00000000000000))*(r11)*(x5163)*(x5175)))+(((IkReal(-1.00000000000000))*(x5164)*(x5165)*(x5185))));
evalcond[6]=((IkReal(-0.0690000000000000))+(((r11)*(x5168)*(x5169)))+(((r10)*(x5169)*(x5176)))+(((IkReal(-1.00000000000000))*(py)*(x5162)))+(((IkReal(-1.00000000000000))*(r10)*(x5166)*(x5176)))+(((r00)*(x5164)*(x5166)))+(((x5178)*(x5179)))+(((IkReal(-1.00000000000000))*(x5171)*(x5172)))+(((cj0)*(r12)*(x5183)))+(((IkReal(-1.00000000000000))*(r11)*(x5166)*(x5168)))+(((IkReal(-1.00000000000000))*(r00)*(x5164)*(x5169)))+(((IkReal(-1.00000000000000))*(x5183)*(x5186)))+(((px)*(sj0)))+(((IkReal(-1.00000000000000))*(sj0)*(x5169)*(x5181)))+(((sj0)*(x5166)*(x5181))));
evalcond[7]=((((r01)*(sj4)*(x5176)))+(((IkReal(-1.00000000000000))*(r10)*(x5175)*(x5187)))+(((IkReal(-1.00000000000000))*(x5170)*(x5188)))+(((IkReal(-1.00000000000000))*(r11)*(x5171)*(x5177)))+(((IkReal(-1.00000000000000))*(cj5)*(r00)*(x5162)*(x5163)))+(((IkReal(-1.00000000000000))*(cj5)*(r01)*(x5162)*(x5177)))+(((IkReal(-1.00000000000000))*(x5163)*(x5171)*(x5185)))+(((IkReal(-1.00000000000000))*(r00)*(x5162)*(x5187)))+(((r11)*(sj4)*(x5164)))+(((IkReal(-1.00000000000000))*(r02)*(x5162)*(x5170))));
evalcond[8]=((IkReal(0.0690000000000000))+(((IkReal(-1.00000000000000))*(r01)*(x5166)*(x5168)))+(((r12)*(sj0)*(x5183)))+(((IkReal(-1.00000000000000))*(r00)*(x5166)*(x5176)))+(((r00)*(x5169)*(x5176)))+(((r01)*(x5168)*(x5169)))+(((r10)*(x5164)*(x5169)))+(((IkReal(-1.00000000000000))*(px)*(x5162)))+(((sj0)*(x5169)*(x5184)))+(((cj0)*(r02)*(x5183)))+(((IkReal(-1.00000000000000))*(r10)*(x5164)*(x5166)))+(((IkReal(-1.00000000000000))*(py)*(x5175)))+(((IkReal(-1.00000000000000))*(sj0)*(x5166)*(x5184)))+(((x5172)*(x5179)))+(((x5171)*(x5178))));
if( IKabs(evalcond[0]) < 0.0000010000000000  && IKabs(evalcond[1]) < 0.0000010000000000  && IKabs(evalcond[2]) < 0.0000010000000000  && IKabs(evalcond[3]) < 0.0000010000000000  && IKabs(evalcond[4]) < 0.0000010000000000  && IKabs(evalcond[5]) < 0.0000010000000000  && IKabs(evalcond[6]) < 0.0000010000000000  && IKabs(evalcond[7]) < 0.0000010000000000  && IKabs(evalcond[8]) < 0.0000010000000000  )
{
{
IkReal j3array[1], cj3array[1], sj3array[1];
bool j3valid[1]={false};
_nj3 = 1;
IkReal x5189=((r20)*(sj6));
IkReal x5190=((cj4)*(cj5));
IkReal x5191=((cj6)*(r21));
if( IKabs(((((IkReal(-1.00000000000000))*(r21)*(sj4)*(sj6)))+(((x5189)*(x5190)))+(((cj6)*(r20)*(sj4)))+(((cj4)*(r22)*(sj5)))+(((x5190)*(x5191))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(((((sj5)*(x5189)))+(((IkReal(-1.00000000000000))*(cj5)*(r22)))+(((sj5)*(x5191))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(IKsqr(((((IkReal(-1.00000000000000))*(r21)*(sj4)*(sj6)))+(((x5189)*(x5190)))+(((cj6)*(r20)*(sj4)))+(((cj4)*(r22)*(sj5)))+(((x5190)*(x5191)))))+IKsqr(((((sj5)*(x5189)))+(((IkReal(-1.00000000000000))*(cj5)*(r22)))+(((sj5)*(x5191)))))-1) <= IKFAST_SINCOS_THRESH )
    continue;
j3array[0]=IKatan2(((((IkReal(-1.00000000000000))*(r21)*(sj4)*(sj6)))+(((x5189)*(x5190)))+(((cj6)*(r20)*(sj4)))+(((cj4)*(r22)*(sj5)))+(((x5190)*(x5191)))), ((((sj5)*(x5189)))+(((IkReal(-1.00000000000000))*(cj5)*(r22)))+(((sj5)*(x5191)))));
sj3array[0]=IKsin(j3array[0]);
cj3array[0]=IKcos(j3array[0]);
if( j3array[0] > IKPI )
{
    j3array[0]-=IK2PI;
}
else if( j3array[0] < -IKPI )
{    j3array[0]+=IK2PI;
}
j3valid[0] = true;
for(int ij3 = 0; ij3 < 1; ++ij3)
{
if( !j3valid[ij3] )
{
    continue;
}
_ij3[0] = ij3; _ij3[1] = -1;
for(int iij3 = ij3+1; iij3 < 1; ++iij3)
{
if( j3valid[iij3] && IKabs(cj3array[ij3]-cj3array[iij3]) < IKFAST_SOLUTION_THRESH && IKabs(sj3array[ij3]-sj3array[iij3]) < IKFAST_SOLUTION_THRESH )
{
    j3valid[iij3]=false; _ij3[1] = iij3; break; 
}
}
j3 = j3array[ij3]; cj3 = cj3array[ij3]; sj3 = sj3array[ij3];
{
IkReal evalcond[4];
IkReal x5192=IKsin(j3);
IkReal x5193=((sj0)*(sj5));
IkReal x5194=((r00)*(sj6));
IkReal x5195=((cj6)*(r01));
IkReal x5196=((cj5)*(sj0));
IkReal x5197=((cj0)*(cj5));
IkReal x5198=((cj6)*(sj4));
IkReal x5199=((sj4)*(sj6));
IkReal x5200=((cj0)*(r11));
IkReal x5201=((cj4)*(cj6));
IkReal x5202=((cj4)*(sj6));
IkReal x5203=((IkReal(1.00000000000000))*(cj0));
IkReal x5204=((cj4)*(sj5));
IkReal x5205=((sj5)*(sj6));
IkReal x5206=((cj6)*(sj5));
IkReal x5207=((IkReal(1.00000000000000))*(IKcos(j3)));
evalcond[0]=((((IkReal(-1.00000000000000))*(x5207)))+(((r21)*(x5206)))+(((IkReal(-1.00000000000000))*(cj5)*(r22)))+(((r20)*(x5205))));
evalcond[1]=((((cj5)*(r21)*(x5201)))+(((cj5)*(r20)*(x5202)))+(((IkReal(-1.00000000000000))*(r21)*(x5199)))+(((r22)*(x5204)))+(((IkReal(-1.00000000000000))*(x5192)))+(((r20)*(x5198))));
evalcond[2]=((((IkReal(-1.00000000000000))*(x5200)*(x5206)))+(x5192)+(((r12)*(x5197)))+(((IkReal(-1.00000000000000))*(r10)*(x5203)*(x5205)))+(((x5193)*(x5194)))+(((IkReal(-1.00000000000000))*(r02)*(x5196)))+(((x5193)*(x5195))));
evalcond[3]=((((x5199)*(x5200)))+(((cj4)*(x5195)*(x5196)))+(((IkReal(-1.00000000000000))*(r11)*(x5197)*(x5201)))+(((IkReal(-1.00000000000000))*(r10)*(x5197)*(x5202)))+(((IkReal(-1.00000000000000))*(x5207)))+(((IkReal(-1.00000000000000))*(r01)*(sj0)*(x5199)))+(((IkReal(-1.00000000000000))*(r10)*(x5198)*(x5203)))+(((cj4)*(r02)*(x5193)))+(((IkReal(-1.00000000000000))*(r12)*(x5203)*(x5204)))+(((cj4)*(x5194)*(x5196)))+(((r00)*(sj0)*(x5198))));
if( IKabs(evalcond[0]) > 0.000001  || IKabs(evalcond[1]) > 0.000001  || IKabs(evalcond[2]) > 0.000001  || IKabs(evalcond[3]) > 0.000001  )
{
continue;
}
}

{
std::vector<IkSingleDOFSolutionBase<IkReal> > vinfos(7);
vinfos[0].jointtype = 1;
vinfos[0].foffset = j0;
vinfos[0].indices[0] = _ij0[0];
vinfos[0].indices[1] = _ij0[1];
vinfos[0].maxsolutions = _nj0;
vinfos[1].jointtype = 1;
vinfos[1].foffset = j1;
vinfos[1].indices[0] = _ij1[0];
vinfos[1].indices[1] = _ij1[1];
vinfos[1].maxsolutions = _nj1;
vinfos[2].jointtype = 1;
vinfos[2].foffset = j2;
vinfos[2].indices[0] = _ij2[0];
vinfos[2].indices[1] = _ij2[1];
vinfos[2].maxsolutions = _nj2;
vinfos[3].jointtype = 1;
vinfos[3].foffset = j3;
vinfos[3].indices[0] = _ij3[0];
vinfos[3].indices[1] = _ij3[1];
vinfos[3].maxsolutions = _nj3;
vinfos[4].jointtype = 1;
vinfos[4].foffset = j4;
vinfos[4].indices[0] = _ij4[0];
vinfos[4].indices[1] = _ij4[1];
vinfos[4].maxsolutions = _nj4;
vinfos[5].jointtype = 1;
vinfos[5].foffset = j5;
vinfos[5].indices[0] = _ij5[0];
vinfos[5].indices[1] = _ij5[1];
vinfos[5].maxsolutions = _nj5;
vinfos[6].jointtype = 1;
vinfos[6].foffset = j6;
vinfos[6].indices[0] = _ij6[0];
vinfos[6].indices[1] = _ij6[1];
vinfos[6].maxsolutions = _nj6;
std::vector<int> vfree(0);
solutions.AddSolution(vinfos,vfree);
}
}
}

} else
{
IkReal x5208=((IkReal(1.00000000000000))*(cj0));
IkReal x5209=((cj4)*(sj6));
IkReal x5210=((sj0)*(sj6));
IkReal x5211=((cj5)*(sj4));
IkReal x5212=((IkReal(0.374290000000000))*(sj5));
IkReal x5213=((sj4)*(sj5));
IkReal x5214=((cj0)*(cj6));
IkReal x5215=((IkReal(0.0100000000000000))*(cj5));
IkReal x5216=((cj4)*(sj5));
IkReal x5217=((cj5)*(sj0));
IkReal x5218=((IkReal(0.374290000000000))*(r02));
IkReal x5219=((r20)*(sj6));
IkReal x5220=((cj6)*(r21));
IkReal x5221=((IkReal(1.00000000000000))*(sj0));
IkReal x5222=((cj0)*(sj6));
IkReal x5223=((cj4)*(cj6));
IkReal x5224=((IkReal(0.374290000000000))*(r12));
IkReal x5225=((cj0)*(cj5));
IkReal x5226=((cj6)*(sj5));
IkReal x5227=((cj6)*(r01));
IkReal x5228=((r00)*(sj6));
IkReal x5229=((IkReal(0.0100000000000000))*(sj5));
IkReal x5230=((cj6)*(r11));
IkReal x5231=((IkReal(1.00000000000000))*(r10));
IkReal x5232=((r02)*(sj0));
IkReal x5233=((cj6)*(sj4));
IkReal x5234=((r12)*(x5221));
evalcond[0]=((IkReal(-3.14159265358979))+(IKfmod(((IkReal(4.71238898038469))+(j1)), IkReal(6.28318530717959))));
evalcond[1]=((((IkReal(-1.00000000000000))*(r20)*(x5223)))+(((x5211)*(x5220)))+(((r22)*(x5213)))+(((r21)*(x5209)))+(((x5211)*(x5219))));
evalcond[2]=((IkReal(-0.364420000000000))+(((IkReal(-1.00000000000000))*(r22)*(x5229)))+(((IkReal(-1.00000000000000))*(x5215)*(x5220)))+(((IkReal(-0.374290000000000))*(cj5)*(r22)))+(((IkReal(-1.00000000000000))*(x5215)*(x5219)))+(pz)+(((x5212)*(x5219)))+(((x5212)*(x5220))));
evalcond[3]=((((IkReal(-1.00000000000000))*(sj5)*(x5210)*(x5231)))+(((IkReal(-1.00000000000000))*(r01)*(x5208)*(x5226)))+(((IkReal(-1.00000000000000))*(r11)*(x5221)*(x5226)))+(((r12)*(x5217)))+(((r02)*(x5225)))+(((IkReal(-1.00000000000000))*(sj5)*(x5208)*(x5228))));
evalcond[4]=((((IkReal(-1.00000000000000))*(r12)*(x5208)*(x5213)))+(((r01)*(sj0)*(x5209)))+(((IkReal(-1.00000000000000))*(x5208)*(x5211)*(x5230)))+(((sj0)*(x5211)*(x5227)))+(((IkReal(-1.00000000000000))*(r00)*(x5221)*(x5223)))+(((IkReal(-1.00000000000000))*(r11)*(x5208)*(x5209)))+(((IkReal(-1.00000000000000))*(r10)*(sj6)*(x5208)*(x5211)))+(((cj4)*(r10)*(x5214)))+(((r00)*(x5210)*(x5211)))+(((x5213)*(x5232))));
evalcond[5]=((IkReal(1.00000000000000))+(((IkReal(-1.00000000000000))*(x5208)*(x5211)*(x5228)))+(((IkReal(-1.00000000000000))*(r01)*(x5208)*(x5209)))+(((IkReal(-1.00000000000000))*(r02)*(x5208)*(x5213)))+(((IkReal(-1.00000000000000))*(r11)*(x5209)*(x5221)))+(((IkReal(-1.00000000000000))*(x5210)*(x5211)*(x5231)))+(((IkReal(-1.00000000000000))*(x5208)*(x5211)*(x5227)))+(((IkReal(-1.00000000000000))*(x5211)*(x5221)*(x5230)))+(((r10)*(sj0)*(x5223)))+(((cj4)*(r00)*(x5214)))+(((IkReal(-1.00000000000000))*(x5213)*(x5234))));
evalcond[6]=((IkReal(-0.0690000000000000))+(((IkReal(-1.00000000000000))*(py)*(x5208)))+(((r11)*(x5214)*(x5215)))+(((IkReal(-1.00000000000000))*(r00)*(x5210)*(x5215)))+(((IkReal(-1.00000000000000))*(x5229)*(x5232)))+(((IkReal(-1.00000000000000))*(x5217)*(x5218)))+(((IkReal(-1.00000000000000))*(sj0)*(x5215)*(x5227)))+(((r00)*(x5210)*(x5212)))+(((cj0)*(r12)*(x5229)))+(((IkReal(-1.00000000000000))*(r11)*(x5212)*(x5214)))+(((IkReal(-1.00000000000000))*(r10)*(x5212)*(x5222)))+(((x5224)*(x5225)))+(((px)*(sj0)))+(((sj0)*(x5212)*(x5227)))+(((r10)*(x5215)*(x5222))));
evalcond[7]=((((r11)*(sj4)*(x5210)))+(((IkReal(-1.00000000000000))*(r11)*(x5217)*(x5223)))+(((IkReal(-1.00000000000000))*(r10)*(x5221)*(x5233)))+(((IkReal(-1.00000000000000))*(r02)*(x5208)*(x5216)))+(((IkReal(-1.00000000000000))*(cj5)*(r01)*(x5208)*(x5223)))+(((r01)*(sj4)*(x5222)))+(((IkReal(-1.00000000000000))*(x5216)*(x5234)))+(((IkReal(-1.00000000000000))*(x5209)*(x5217)*(x5231)))+(((IkReal(-1.00000000000000))*(cj5)*(r00)*(x5208)*(x5209)))+(((IkReal(-1.00000000000000))*(r00)*(x5208)*(x5233))));
evalcond[8]=((IkReal(0.0690000000000000))+(((r01)*(x5214)*(x5215)))+(((IkReal(-1.00000000000000))*(r01)*(x5212)*(x5214)))+(((sj0)*(x5215)*(x5230)))+(((r10)*(x5210)*(x5215)))+(((IkReal(-1.00000000000000))*(px)*(x5208)))+(((IkReal(-1.00000000000000))*(sj0)*(x5212)*(x5230)))+(((r00)*(x5215)*(x5222)))+(((IkReal(-1.00000000000000))*(r00)*(x5212)*(x5222)))+(((cj0)*(r02)*(x5229)))+(((r12)*(sj0)*(x5229)))+(((IkReal(-1.00000000000000))*(py)*(x5221)))+(((x5217)*(x5224)))+(((IkReal(-1.00000000000000))*(r10)*(x5210)*(x5212)))+(((x5218)*(x5225))));
if( IKabs(evalcond[0]) < 0.0000010000000000  && IKabs(evalcond[1]) < 0.0000010000000000  && IKabs(evalcond[2]) < 0.0000010000000000  && IKabs(evalcond[3]) < 0.0000010000000000  && IKabs(evalcond[4]) < 0.0000010000000000  && IKabs(evalcond[5]) < 0.0000010000000000  && IKabs(evalcond[6]) < 0.0000010000000000  && IKabs(evalcond[7]) < 0.0000010000000000  && IKabs(evalcond[8]) < 0.0000010000000000  )
{
{
IkReal j3array[1], cj3array[1], sj3array[1];
bool j3valid[1]={false};
_nj3 = 1;
IkReal x5235=((IkReal(1.00000000000000))*(sj5));
IkReal x5236=((cj6)*(r21));
IkReal x5237=((r20)*(sj6));
IkReal x5238=((IkReal(1.00000000000000))*(cj4)*(cj5));
if( IKabs(((((IkReal(-1.00000000000000))*(cj4)*(r22)*(x5235)))+(((IkReal(-1.00000000000000))*(x5237)*(x5238)))+(((r21)*(sj4)*(sj6)))+(((IkReal(-1.00000000000000))*(x5236)*(x5238)))+(((IkReal(-1.00000000000000))*(cj6)*(r20)*(sj4))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(((((IkReal(-1.00000000000000))*(x5235)*(x5236)))+(((IkReal(-1.00000000000000))*(x5235)*(x5237)))+(((cj5)*(r22))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(IKsqr(((((IkReal(-1.00000000000000))*(cj4)*(r22)*(x5235)))+(((IkReal(-1.00000000000000))*(x5237)*(x5238)))+(((r21)*(sj4)*(sj6)))+(((IkReal(-1.00000000000000))*(x5236)*(x5238)))+(((IkReal(-1.00000000000000))*(cj6)*(r20)*(sj4)))))+IKsqr(((((IkReal(-1.00000000000000))*(x5235)*(x5236)))+(((IkReal(-1.00000000000000))*(x5235)*(x5237)))+(((cj5)*(r22)))))-1) <= IKFAST_SINCOS_THRESH )
    continue;
j3array[0]=IKatan2(((((IkReal(-1.00000000000000))*(cj4)*(r22)*(x5235)))+(((IkReal(-1.00000000000000))*(x5237)*(x5238)))+(((r21)*(sj4)*(sj6)))+(((IkReal(-1.00000000000000))*(x5236)*(x5238)))+(((IkReal(-1.00000000000000))*(cj6)*(r20)*(sj4)))), ((((IkReal(-1.00000000000000))*(x5235)*(x5236)))+(((IkReal(-1.00000000000000))*(x5235)*(x5237)))+(((cj5)*(r22)))));
sj3array[0]=IKsin(j3array[0]);
cj3array[0]=IKcos(j3array[0]);
if( j3array[0] > IKPI )
{
    j3array[0]-=IK2PI;
}
else if( j3array[0] < -IKPI )
{    j3array[0]+=IK2PI;
}
j3valid[0] = true;
for(int ij3 = 0; ij3 < 1; ++ij3)
{
if( !j3valid[ij3] )
{
    continue;
}
_ij3[0] = ij3; _ij3[1] = -1;
for(int iij3 = ij3+1; iij3 < 1; ++iij3)
{
if( j3valid[iij3] && IKabs(cj3array[ij3]-cj3array[iij3]) < IKFAST_SOLUTION_THRESH && IKabs(sj3array[ij3]-sj3array[iij3]) < IKFAST_SOLUTION_THRESH )
{
    j3valid[iij3]=false; _ij3[1] = iij3; break; 
}
}
j3 = j3array[ij3]; cj3 = cj3array[ij3]; sj3 = sj3array[ij3];
{
IkReal evalcond[4];
IkReal x5239=IKsin(j3);
IkReal x5240=IKcos(j3);
IkReal x5241=((sj0)*(sj5));
IkReal x5242=((r00)*(sj6));
IkReal x5243=((cj6)*(r01));
IkReal x5244=((cj0)*(cj5));
IkReal x5245=((IkReal(1.00000000000000))*(cj5));
IkReal x5246=((cj4)*(cj5));
IkReal x5247=((cj6)*(sj4));
IkReal x5248=((sj4)*(sj6));
IkReal x5249=((cj0)*(r11));
IkReal x5250=((IkReal(1.00000000000000))*(cj4));
IkReal x5251=((cj6)*(r21));
IkReal x5252=((r20)*(sj6));
IkReal x5253=((cj0)*(sj5));
IkReal x5254=((r10)*(sj6));
evalcond[0]=((x5240)+(((IkReal(-1.00000000000000))*(r22)*(x5245)))+(((sj5)*(x5251)))+(((sj5)*(x5252))));
evalcond[1]=((((x5246)*(x5252)))+(x5239)+(((cj4)*(r22)*(sj5)))+(((r20)*(x5247)))+(((x5246)*(x5251)))+(((IkReal(-1.00000000000000))*(r21)*(x5248))));
evalcond[2]=((x5239)+(((r12)*(x5244)))+(((IkReal(-1.00000000000000))*(x5253)*(x5254)))+(((IkReal(-1.00000000000000))*(cj6)*(sj5)*(x5249)))+(((x5241)*(x5242)))+(((x5241)*(x5243)))+(((IkReal(-1.00000000000000))*(r02)*(sj0)*(x5245))));
evalcond[3]=((((sj0)*(x5242)*(x5246)))+(((IkReal(-1.00000000000000))*(r01)*(sj0)*(x5248)))+(((r00)*(sj0)*(x5247)))+(((IkReal(-1.00000000000000))*(x5244)*(x5250)*(x5254)))+(((sj0)*(x5243)*(x5246)))+(((IkReal(-1.00000000000000))*(cj0)*(r10)*(x5247)))+(((IkReal(-1.00000000000000))*(r12)*(x5250)*(x5253)))+(((x5248)*(x5249)))+(((IkReal(-1.00000000000000))*(x5240)))+(((cj4)*(r02)*(x5241)))+(((IkReal(-1.00000000000000))*(cj6)*(r11)*(x5244)*(x5250))));
if( IKabs(evalcond[0]) > 0.000001  || IKabs(evalcond[1]) > 0.000001  || IKabs(evalcond[2]) > 0.000001  || IKabs(evalcond[3]) > 0.000001  )
{
continue;
}
}

{
std::vector<IkSingleDOFSolutionBase<IkReal> > vinfos(7);
vinfos[0].jointtype = 1;
vinfos[0].foffset = j0;
vinfos[0].indices[0] = _ij0[0];
vinfos[0].indices[1] = _ij0[1];
vinfos[0].maxsolutions = _nj0;
vinfos[1].jointtype = 1;
vinfos[1].foffset = j1;
vinfos[1].indices[0] = _ij1[0];
vinfos[1].indices[1] = _ij1[1];
vinfos[1].maxsolutions = _nj1;
vinfos[2].jointtype = 1;
vinfos[2].foffset = j2;
vinfos[2].indices[0] = _ij2[0];
vinfos[2].indices[1] = _ij2[1];
vinfos[2].maxsolutions = _nj2;
vinfos[3].jointtype = 1;
vinfos[3].foffset = j3;
vinfos[3].indices[0] = _ij3[0];
vinfos[3].indices[1] = _ij3[1];
vinfos[3].maxsolutions = _nj3;
vinfos[4].jointtype = 1;
vinfos[4].foffset = j4;
vinfos[4].indices[0] = _ij4[0];
vinfos[4].indices[1] = _ij4[1];
vinfos[4].maxsolutions = _nj4;
vinfos[5].jointtype = 1;
vinfos[5].foffset = j5;
vinfos[5].indices[0] = _ij5[0];
vinfos[5].indices[1] = _ij5[1];
vinfos[5].maxsolutions = _nj5;
vinfos[6].jointtype = 1;
vinfos[6].foffset = j6;
vinfos[6].indices[0] = _ij6[0];
vinfos[6].indices[1] = _ij6[1];
vinfos[6].maxsolutions = _nj6;
std::vector<int> vfree(0);
solutions.AddSolution(vinfos,vfree);
}
}
}

} else
{
IkReal x5255=((IkReal(1.00000000000000))*(cj0));
IkReal x5256=((cj4)*(sj6));
IkReal x5257=((sj0)*(sj4));
IkReal x5258=((cj5)*(sj6));
IkReal x5259=((sj4)*(sj5));
IkReal x5260=((r12)*(sj5));
IkReal x5261=((IkReal(0.374290000000000))*(cj5));
IkReal x5262=((r02)*(sj0));
IkReal x5263=((r20)*(sj4));
IkReal x5264=((IkReal(1.00000000000000))*(sj0));
IkReal x5265=((IkReal(1.00000000000000))*(cj5));
IkReal x5266=((cj0)*(r10));
IkReal x5267=((cj4)*(cj6));
IkReal x5268=((r00)*(sj0));
IkReal x5269=((cj6)*(r21));
IkReal x5270=((IkReal(0.374290000000000))*(sj5));
IkReal x5271=((cj0)*(r00));
IkReal x5272=((IkReal(0.0100000000000000))*(sj5));
IkReal x5273=((cj0)*(r02));
IkReal x5274=((cj5)*(sj4));
IkReal x5275=((cj6)*(r01));
IkReal x5276=((cj6)*(r11));
IkReal x5277=((r01)*(sj0));
IkReal x5278=((r10)*(sj0));
IkReal x5279=((IkReal(0.0100000000000000))*(cj5)*(cj6));
IkReal x5280=((sj6)*(x5270));
IkReal x5281=((cj0)*(cj6)*(x5270));
evalcond[0]=((IkReal(-3.14159265358979))+(IKfmod(((IkReal(3.14159265358979))+(j1)), IkReal(6.28318530717959))));
evalcond[1]=((((sj5)*(x5269)))+(((r20)*(sj5)*(sj6)))+(((IkReal(-1.00000000000000))*(r22)*(x5265))));
evalcond[2]=((IkReal(1.00000000000000))+(((x5258)*(x5263)))+(((IkReal(-1.00000000000000))*(r20)*(x5267)))+(((x5269)*(x5274)))+(((r21)*(x5256)))+(((r22)*(x5259))));
evalcond[3]=((((IkReal(-1.00000000000000))*(r22)*(x5272)))+(((r20)*(x5280)))+(((IkReal(-0.0100000000000000))*(r20)*(x5258)))+(((IkReal(-0.0100000000000000))*(cj5)*(x5269)))+(pz)+(((x5269)*(x5270)))+(((IkReal(-1.00000000000000))*(r22)*(x5261))));
evalcond[4]=((((IkReal(-1.00000000000000))*(r21)*(sj4)*(sj6)))+(((cj6)*(x5263)))+(((cj5)*(r21)*(x5267)))+(((cj4)*(r22)*(sj5)))+(((cj5)*(r20)*(x5256))));
evalcond[5]=((((IkReal(-1.00000000000000))*(r12)*(x5255)*(x5259)))+(((r02)*(sj5)*(x5257)))+(((x5266)*(x5267)))+(((IkReal(-1.00000000000000))*(r10)*(sj4)*(x5255)*(x5258)))+(((r00)*(x5257)*(x5258)))+(((IkReal(-1.00000000000000))*(r11)*(x5255)*(x5256)))+(((cj5)*(x5257)*(x5275)))+(((x5256)*(x5277)))+(((IkReal(-1.00000000000000))*(r00)*(x5264)*(x5267)))+(((IkReal(-1.00000000000000))*(x5255)*(x5274)*(x5276))));
evalcond[6]=((((IkReal(-1.00000000000000))*(r11)*(x5256)*(x5264)))+(((IkReal(-1.00000000000000))*(r10)*(x5257)*(x5258)))+(((IkReal(-1.00000000000000))*(x5257)*(x5260)))+(((IkReal(-1.00000000000000))*(r02)*(x5255)*(x5259)))+(((IkReal(-1.00000000000000))*(x5257)*(x5265)*(x5276)))+(((x5267)*(x5271)))+(((IkReal(-1.00000000000000))*(x5255)*(x5274)*(x5275)))+(((IkReal(-1.00000000000000))*(r00)*(sj4)*(x5255)*(x5258)))+(((IkReal(-1.00000000000000))*(r01)*(x5255)*(x5256)))+(((x5267)*(x5278))));
evalcond[7]=((IkReal(-0.0690000000000000))+(((cj0)*(r12)*(x5261)))+(((IkReal(-0.0100000000000000))*(x5258)*(x5268)))+(((IkReal(-1.00000000000000))*(x5266)*(x5280)))+(((IkReal(0.0100000000000000))*(cj0)*(cj5)*(x5276)))+(((x5268)*(x5280)))+(((IkReal(-0.0100000000000000))*(cj5)*(sj0)*(x5275)))+(((sj0)*(x5270)*(x5275)))+(((IkReal(0.0100000000000000))*(x5258)*(x5266)))+(((IkReal(-1.00000000000000))*(py)*(x5255)))+(((IkReal(-1.00000000000000))*(cj0)*(x5270)*(x5276)))+(((IkReal(-1.00000000000000))*(x5262)*(x5272)))+(((IkReal(0.0100000000000000))*(cj0)*(x5260)))+(((px)*(sj0)))+(((IkReal(-1.00000000000000))*(x5261)*(x5262))));
evalcond[8]=((IkReal(0.433420000000000))+(((r12)*(sj0)*(x5261)))+(((IkReal(0.0100000000000000))*(x5258)*(x5278)))+(((IkReal(-1.00000000000000))*(sj0)*(x5270)*(x5276)))+(((IkReal(-1.00000000000000))*(py)*(x5264)))+(((IkReal(-1.00000000000000))*(px)*(x5255)))+(((x5272)*(x5273)))+(((IkReal(-1.00000000000000))*(x5271)*(x5280)))+(((IkReal(0.0100000000000000))*(cj5)*(sj0)*(x5276)))+(((x5261)*(x5273)))+(((IkReal(-1.00000000000000))*(x5278)*(x5280)))+(((IkReal(-1.00000000000000))*(cj0)*(x5270)*(x5275)))+(((IkReal(0.0100000000000000))*(cj0)*(cj5)*(x5275)))+(((IkReal(0.0100000000000000))*(sj0)*(x5260)))+(((IkReal(0.0100000000000000))*(x5258)*(x5271))));
if( IKabs(evalcond[0]) < 0.0000010000000000  && IKabs(evalcond[1]) < 0.0000010000000000  && IKabs(evalcond[2]) < 0.0000010000000000  && IKabs(evalcond[3]) < 0.0000010000000000  && IKabs(evalcond[4]) < 0.0000010000000000  && IKabs(evalcond[5]) < 0.0000010000000000  && IKabs(evalcond[6]) < 0.0000010000000000  && IKabs(evalcond[7]) < 0.0000010000000000  && IKabs(evalcond[8]) < 0.0000010000000000  )
{
{
IkReal j3array[1], cj3array[1], sj3array[1];
bool j3valid[1]={false};
_nj3 = 1;
IkReal x5282=((cj5)*(r02));
IkReal x5283=((cj0)*(sj5));
IkReal x5284=((r10)*(sj6));
IkReal x5285=((IkReal(1.00000000000000))*(cj6));
IkReal x5286=((sj0)*(sj5));
IkReal x5287=((cj5)*(r12));
IkReal x5288=((IkReal(1.00000000000000))*(r00)*(sj6));
if( IKabs(((((IkReal(-1.00000000000000))*(x5286)*(x5288)))+(((IkReal(-1.00000000000000))*(cj0)*(x5287)))+(((sj0)*(x5282)))+(((IkReal(-1.00000000000000))*(r01)*(x5285)*(x5286)))+(((cj6)*(r11)*(x5283)))+(((x5283)*(x5284))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(((((IkReal(-1.00000000000000))*(x5283)*(x5288)))+(((sj0)*(x5287)))+(((IkReal(-1.00000000000000))*(r11)*(x5285)*(x5286)))+(((IkReal(-1.00000000000000))*(r01)*(x5283)*(x5285)))+(((cj0)*(x5282)))+(((IkReal(-1.00000000000000))*(x5284)*(x5286))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(IKsqr(((((IkReal(-1.00000000000000))*(x5286)*(x5288)))+(((IkReal(-1.00000000000000))*(cj0)*(x5287)))+(((sj0)*(x5282)))+(((IkReal(-1.00000000000000))*(r01)*(x5285)*(x5286)))+(((cj6)*(r11)*(x5283)))+(((x5283)*(x5284)))))+IKsqr(((((IkReal(-1.00000000000000))*(x5283)*(x5288)))+(((sj0)*(x5287)))+(((IkReal(-1.00000000000000))*(r11)*(x5285)*(x5286)))+(((IkReal(-1.00000000000000))*(r01)*(x5283)*(x5285)))+(((cj0)*(x5282)))+(((IkReal(-1.00000000000000))*(x5284)*(x5286)))))-1) <= IKFAST_SINCOS_THRESH )
    continue;
j3array[0]=IKatan2(((((IkReal(-1.00000000000000))*(x5286)*(x5288)))+(((IkReal(-1.00000000000000))*(cj0)*(x5287)))+(((sj0)*(x5282)))+(((IkReal(-1.00000000000000))*(r01)*(x5285)*(x5286)))+(((cj6)*(r11)*(x5283)))+(((x5283)*(x5284)))), ((((IkReal(-1.00000000000000))*(x5283)*(x5288)))+(((sj0)*(x5287)))+(((IkReal(-1.00000000000000))*(r11)*(x5285)*(x5286)))+(((IkReal(-1.00000000000000))*(r01)*(x5283)*(x5285)))+(((cj0)*(x5282)))+(((IkReal(-1.00000000000000))*(x5284)*(x5286)))));
sj3array[0]=IKsin(j3array[0]);
cj3array[0]=IKcos(j3array[0]);
if( j3array[0] > IKPI )
{
    j3array[0]-=IK2PI;
}
else if( j3array[0] < -IKPI )
{    j3array[0]+=IK2PI;
}
j3valid[0] = true;
for(int ij3 = 0; ij3 < 1; ++ij3)
{
if( !j3valid[ij3] )
{
    continue;
}
_ij3[0] = ij3; _ij3[1] = -1;
for(int iij3 = ij3+1; iij3 < 1; ++iij3)
{
if( j3valid[iij3] && IKabs(cj3array[ij3]-cj3array[iij3]) < IKFAST_SOLUTION_THRESH && IKabs(sj3array[ij3]-sj3array[iij3]) < IKFAST_SOLUTION_THRESH )
{
    j3valid[iij3]=false; _ij3[1] = iij3; break; 
}
}
j3 = j3array[ij3]; cj3 = cj3array[ij3]; sj3 = sj3array[ij3];
{
IkReal evalcond[4];
IkReal x5289=IKsin(j3);
IkReal x5290=((sj0)*(sj5));
IkReal x5291=((r00)*(sj6));
IkReal x5292=((IkReal(1.00000000000000))*(cj4));
IkReal x5293=((cj6)*(sj0));
IkReal x5294=((r00)*(sj4));
IkReal x5295=((cj0)*(cj5));
IkReal x5296=((cj6)*(r01));
IkReal x5297=((cj5)*(sj0));
IkReal x5298=((cj0)*(sj5));
IkReal x5299=((cj6)*(r11));
IkReal x5300=((r10)*(sj6));
IkReal x5301=((r10)*(sj4));
IkReal x5302=((IkReal(1.00000000000000))*(IKcos(j3)));
IkReal x5303=((cj0)*(sj4)*(sj6));
IkReal x5304=((sj0)*(sj4)*(sj6));
IkReal x5305=((IkReal(1.00000000000000))*(cj0)*(cj6));
evalcond[0]=((x5289)+(((r12)*(x5295)))+(((x5290)*(x5296)))+(((IkReal(-1.00000000000000))*(r02)*(x5297)))+(((IkReal(-1.00000000000000))*(x5298)*(x5299)))+(((IkReal(-1.00000000000000))*(x5298)*(x5300)))+(((x5290)*(x5291))));
evalcond[1]=((((IkReal(-1.00000000000000))*(x5296)*(x5298)))+(((r12)*(x5297)))+(((IkReal(-1.00000000000000))*(x5290)*(x5300)))+(((IkReal(-1.00000000000000))*(x5290)*(x5299)))+(((IkReal(-1.00000000000000))*(x5302)))+(((IkReal(-1.00000000000000))*(x5291)*(x5298)))+(((r02)*(x5295))));
evalcond[2]=((((IkReal(-1.00000000000000))*(r12)*(x5292)*(x5298)))+(((cj4)*(cj5)*(r01)*(x5293)))+(((IkReal(-1.00000000000000))*(x5301)*(x5305)))+(((cj4)*(r02)*(x5290)))+(((cj4)*(x5291)*(x5297)))+(((x5293)*(x5294)))+(((IkReal(-1.00000000000000))*(x5302)))+(((r11)*(x5303)))+(((IkReal(-1.00000000000000))*(x5292)*(x5295)*(x5300)))+(((IkReal(-1.00000000000000))*(r01)*(x5304)))+(((IkReal(-1.00000000000000))*(x5292)*(x5295)*(x5299))));
evalcond[3]=((((IkReal(-1.00000000000000))*(x5292)*(x5297)*(x5300)))+(((IkReal(-1.00000000000000))*(x5291)*(x5292)*(x5295)))+(((IkReal(-1.00000000000000))*(cj5)*(r11)*(x5292)*(x5293)))+(((r11)*(x5304)))+(((r01)*(x5303)))+(((IkReal(-1.00000000000000))*(x5294)*(x5305)))+(((IkReal(-1.00000000000000))*(x5293)*(x5301)))+(((IkReal(-1.00000000000000))*(r12)*(x5290)*(x5292)))+(((IkReal(-1.00000000000000))*(x5289)))+(((IkReal(-1.00000000000000))*(x5292)*(x5295)*(x5296)))+(((IkReal(-1.00000000000000))*(r02)*(x5292)*(x5298))));
if( IKabs(evalcond[0]) > 0.000001  || IKabs(evalcond[1]) > 0.000001  || IKabs(evalcond[2]) > 0.000001  || IKabs(evalcond[3]) > 0.000001  )
{
continue;
}
}

{
std::vector<IkSingleDOFSolutionBase<IkReal> > vinfos(7);
vinfos[0].jointtype = 1;
vinfos[0].foffset = j0;
vinfos[0].indices[0] = _ij0[0];
vinfos[0].indices[1] = _ij0[1];
vinfos[0].maxsolutions = _nj0;
vinfos[1].jointtype = 1;
vinfos[1].foffset = j1;
vinfos[1].indices[0] = _ij1[0];
vinfos[1].indices[1] = _ij1[1];
vinfos[1].maxsolutions = _nj1;
vinfos[2].jointtype = 1;
vinfos[2].foffset = j2;
vinfos[2].indices[0] = _ij2[0];
vinfos[2].indices[1] = _ij2[1];
vinfos[2].maxsolutions = _nj2;
vinfos[3].jointtype = 1;
vinfos[3].foffset = j3;
vinfos[3].indices[0] = _ij3[0];
vinfos[3].indices[1] = _ij3[1];
vinfos[3].maxsolutions = _nj3;
vinfos[4].jointtype = 1;
vinfos[4].foffset = j4;
vinfos[4].indices[0] = _ij4[0];
vinfos[4].indices[1] = _ij4[1];
vinfos[4].maxsolutions = _nj4;
vinfos[5].jointtype = 1;
vinfos[5].foffset = j5;
vinfos[5].indices[0] = _ij5[0];
vinfos[5].indices[1] = _ij5[1];
vinfos[5].maxsolutions = _nj5;
vinfos[6].jointtype = 1;
vinfos[6].foffset = j6;
vinfos[6].indices[0] = _ij6[0];
vinfos[6].indices[1] = _ij6[1];
vinfos[6].maxsolutions = _nj6;
std::vector<int> vfree(0);
solutions.AddSolution(vinfos,vfree);
}
}
}

} else
{
IkReal x5306=((IkReal(1.00000000000000))*(cj0));
IkReal x5307=((cj4)*(sj6));
IkReal x5308=((sj0)*(sj4));
IkReal x5309=((cj5)*(sj6));
IkReal x5310=((sj4)*(sj5));
IkReal x5311=((r12)*(sj5));
IkReal x5312=((IkReal(0.374290000000000))*(cj5));
IkReal x5313=((r02)*(sj0));
IkReal x5314=((r20)*(sj4));
IkReal x5315=((IkReal(1.00000000000000))*(sj0));
IkReal x5316=((IkReal(1.00000000000000))*(cj5));
IkReal x5317=((cj0)*(r10));
IkReal x5318=((cj4)*(cj6));
IkReal x5319=((r00)*(sj0));
IkReal x5320=((cj6)*(r21));
IkReal x5321=((IkReal(0.374290000000000))*(sj5));
IkReal x5322=((cj0)*(r00));
IkReal x5323=((IkReal(0.0100000000000000))*(sj5));
IkReal x5324=((cj0)*(r02));
IkReal x5325=((cj5)*(sj4));
IkReal x5326=((cj6)*(r01));
IkReal x5327=((cj6)*(r11));
IkReal x5328=((r01)*(sj0));
IkReal x5329=((r10)*(sj0));
IkReal x5330=((IkReal(0.0100000000000000))*(cj5)*(cj6));
IkReal x5331=((sj6)*(x5321));
IkReal x5332=((cj0)*(cj6)*(x5321));
evalcond[0]=((IkReal(-3.14159265358979))+(IKfmod(j1, IkReal(6.28318530717959))));
evalcond[1]=((((IkReal(-1.00000000000000))*(r22)*(x5316)))+(((sj5)*(x5320)))+(((r20)*(sj5)*(sj6))));
evalcond[2]=((IkReal(-1.00000000000000))+(((IkReal(-1.00000000000000))*(r20)*(x5318)))+(((r21)*(x5307)))+(((x5320)*(x5325)))+(((r22)*(x5310)))+(((x5309)*(x5314))));
evalcond[3]=((((IkReal(-1.00000000000000))*(r22)*(x5323)))+(((IkReal(-1.00000000000000))*(r22)*(x5312)))+(((IkReal(-0.0100000000000000))*(r20)*(x5309)))+(((IkReal(-0.0100000000000000))*(cj5)*(x5320)))+(((x5320)*(x5321)))+(pz)+(((r20)*(x5331))));
evalcond[4]=((((cj5)*(r20)*(x5307)))+(((IkReal(-1.00000000000000))*(r21)*(sj4)*(sj6)))+(((cj6)*(x5314)))+(((cj4)*(r22)*(sj5)))+(((cj5)*(r21)*(x5318))));
evalcond[5]=((((IkReal(-1.00000000000000))*(r12)*(x5306)*(x5310)))+(((IkReal(-1.00000000000000))*(r11)*(x5306)*(x5307)))+(((r02)*(sj5)*(x5308)))+(((IkReal(-1.00000000000000))*(r00)*(x5315)*(x5318)))+(((x5307)*(x5328)))+(((r00)*(x5308)*(x5309)))+(((IkReal(-1.00000000000000))*(x5306)*(x5325)*(x5327)))+(((IkReal(-1.00000000000000))*(r10)*(sj4)*(x5306)*(x5309)))+(((x5317)*(x5318)))+(((cj5)*(x5308)*(x5326))));
evalcond[6]=((((x5318)*(x5322)))+(((IkReal(-1.00000000000000))*(x5308)*(x5311)))+(((IkReal(-1.00000000000000))*(x5308)*(x5316)*(x5327)))+(((IkReal(-1.00000000000000))*(r10)*(x5308)*(x5309)))+(((IkReal(-1.00000000000000))*(r02)*(x5306)*(x5310)))+(((IkReal(-1.00000000000000))*(x5306)*(x5325)*(x5326)))+(((IkReal(-1.00000000000000))*(r11)*(x5307)*(x5315)))+(((IkReal(-1.00000000000000))*(r00)*(sj4)*(x5306)*(x5309)))+(((IkReal(-1.00000000000000))*(r01)*(x5306)*(x5307)))+(((x5318)*(x5329))));
evalcond[7]=((IkReal(-0.0690000000000000))+(((sj0)*(x5321)*(x5326)))+(((x5319)*(x5331)))+(((cj0)*(r12)*(x5312)))+(((IkReal(-1.00000000000000))*(x5312)*(x5313)))+(((IkReal(0.0100000000000000))*(x5309)*(x5317)))+(((IkReal(-1.00000000000000))*(x5313)*(x5323)))+(((IkReal(-0.0100000000000000))*(x5309)*(x5319)))+(((IkReal(0.0100000000000000))*(cj0)*(cj5)*(x5327)))+(((IkReal(-1.00000000000000))*(py)*(x5306)))+(((IkReal(0.0100000000000000))*(cj0)*(x5311)))+(((IkReal(-1.00000000000000))*(x5317)*(x5331)))+(((px)*(sj0)))+(((IkReal(-0.0100000000000000))*(cj5)*(sj0)*(x5326)))+(((IkReal(-1.00000000000000))*(cj0)*(x5321)*(x5327))));
evalcond[8]=((IkReal(-0.295420000000000))+(((IkReal(0.0100000000000000))*(x5309)*(x5322)))+(((IkReal(-1.00000000000000))*(cj0)*(x5321)*(x5326)))+(((x5312)*(x5324)))+(((IkReal(-1.00000000000000))*(py)*(x5315)))+(((IkReal(0.0100000000000000))*(cj5)*(sj0)*(x5327)))+(((IkReal(-1.00000000000000))*(sj0)*(x5321)*(x5327)))+(((IkReal(-1.00000000000000))*(x5329)*(x5331)))+(((x5323)*(x5324)))+(((IkReal(-1.00000000000000))*(x5322)*(x5331)))+(((IkReal(0.0100000000000000))*(sj0)*(x5311)))+(((IkReal(-1.00000000000000))*(px)*(x5306)))+(((r12)*(sj0)*(x5312)))+(((IkReal(0.0100000000000000))*(cj0)*(cj5)*(x5326)))+(((IkReal(0.0100000000000000))*(x5309)*(x5329))));
if( IKabs(evalcond[0]) < 0.0000010000000000  && IKabs(evalcond[1]) < 0.0000010000000000  && IKabs(evalcond[2]) < 0.0000010000000000  && IKabs(evalcond[3]) < 0.0000010000000000  && IKabs(evalcond[4]) < 0.0000010000000000  && IKabs(evalcond[5]) < 0.0000010000000000  && IKabs(evalcond[6]) < 0.0000010000000000  && IKabs(evalcond[7]) < 0.0000010000000000  && IKabs(evalcond[8]) < 0.0000010000000000  )
{
{
IkReal j3array[1], cj3array[1], sj3array[1];
bool j3valid[1]={false};
_nj3 = 1;
IkReal x5333=((IkReal(1.00000000000000))*(cj5));
IkReal x5334=((r10)*(sj5)*(sj6));
IkReal x5335=((cj6)*(sj0)*(sj5));
IkReal x5336=((r00)*(sj5)*(sj6));
IkReal x5337=((cj0)*(cj6)*(sj5));
if( IKabs(((((cj0)*(x5334)))+(((IkReal(-1.00000000000000))*(sj0)*(x5336)))+(((IkReal(-1.00000000000000))*(r01)*(x5335)))+(((cj5)*(r02)*(sj0)))+(((IkReal(-1.00000000000000))*(cj0)*(r12)*(x5333)))+(((r11)*(x5337))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(((((sj0)*(x5334)))+(((cj0)*(x5336)))+(((IkReal(-1.00000000000000))*(cj0)*(r02)*(x5333)))+(((r01)*(x5337)))+(((IkReal(-1.00000000000000))*(r12)*(sj0)*(x5333)))+(((r11)*(x5335))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(IKsqr(((((cj0)*(x5334)))+(((IkReal(-1.00000000000000))*(sj0)*(x5336)))+(((IkReal(-1.00000000000000))*(r01)*(x5335)))+(((cj5)*(r02)*(sj0)))+(((IkReal(-1.00000000000000))*(cj0)*(r12)*(x5333)))+(((r11)*(x5337)))))+IKsqr(((((sj0)*(x5334)))+(((cj0)*(x5336)))+(((IkReal(-1.00000000000000))*(cj0)*(r02)*(x5333)))+(((r01)*(x5337)))+(((IkReal(-1.00000000000000))*(r12)*(sj0)*(x5333)))+(((r11)*(x5335)))))-1) <= IKFAST_SINCOS_THRESH )
    continue;
j3array[0]=IKatan2(((((cj0)*(x5334)))+(((IkReal(-1.00000000000000))*(sj0)*(x5336)))+(((IkReal(-1.00000000000000))*(r01)*(x5335)))+(((cj5)*(r02)*(sj0)))+(((IkReal(-1.00000000000000))*(cj0)*(r12)*(x5333)))+(((r11)*(x5337)))), ((((sj0)*(x5334)))+(((cj0)*(x5336)))+(((IkReal(-1.00000000000000))*(cj0)*(r02)*(x5333)))+(((r01)*(x5337)))+(((IkReal(-1.00000000000000))*(r12)*(sj0)*(x5333)))+(((r11)*(x5335)))));
sj3array[0]=IKsin(j3array[0]);
cj3array[0]=IKcos(j3array[0]);
if( j3array[0] > IKPI )
{
    j3array[0]-=IK2PI;
}
else if( j3array[0] < -IKPI )
{    j3array[0]+=IK2PI;
}
j3valid[0] = true;
for(int ij3 = 0; ij3 < 1; ++ij3)
{
if( !j3valid[ij3] )
{
    continue;
}
_ij3[0] = ij3; _ij3[1] = -1;
for(int iij3 = ij3+1; iij3 < 1; ++iij3)
{
if( j3valid[iij3] && IKabs(cj3array[ij3]-cj3array[iij3]) < IKFAST_SOLUTION_THRESH && IKabs(sj3array[ij3]-sj3array[iij3]) < IKFAST_SOLUTION_THRESH )
{
    j3valid[iij3]=false; _ij3[1] = iij3; break; 
}
}
j3 = j3array[ij3]; cj3 = cj3array[ij3]; sj3 = sj3array[ij3];
{
IkReal evalcond[4];
IkReal x5338=IKcos(j3);
IkReal x5339=IKsin(j3);
IkReal x5340=((sj0)*(sj5));
IkReal x5341=((r00)*(sj6));
IkReal x5342=((IkReal(1.00000000000000))*(cj4));
IkReal x5343=((cj6)*(sj0));
IkReal x5344=((r00)*(sj4));
IkReal x5345=((cj0)*(cj5));
IkReal x5346=((cj6)*(r01));
IkReal x5347=((cj5)*(sj0));
IkReal x5348=((cj0)*(sj5));
IkReal x5349=((cj6)*(r11));
IkReal x5350=((r10)*(sj6));
IkReal x5351=((r10)*(sj4));
IkReal x5352=((cj0)*(sj4)*(sj6));
IkReal x5353=((sj0)*(sj4)*(sj6));
IkReal x5354=((IkReal(1.00000000000000))*(cj0)*(cj6));
evalcond[0]=((((r12)*(x5345)))+(((IkReal(-1.00000000000000))*(x5348)*(x5350)))+(((IkReal(-1.00000000000000))*(x5348)*(x5349)))+(((IkReal(-1.00000000000000))*(r02)*(x5347)))+(((x5340)*(x5346)))+(((x5340)*(x5341)))+(x5339));
evalcond[1]=((((IkReal(-1.00000000000000))*(x5340)*(x5349)))+(((IkReal(-1.00000000000000))*(x5340)*(x5350)))+(((IkReal(-1.00000000000000))*(x5346)*(x5348)))+(((r02)*(x5345)))+(((IkReal(-1.00000000000000))*(x5341)*(x5348)))+(((r12)*(x5347)))+(x5338));
evalcond[2]=((((IkReal(-1.00000000000000))*(r01)*(x5353)))+(((IkReal(-1.00000000000000))*(r12)*(x5342)*(x5348)))+(((IkReal(-1.00000000000000))*(x5342)*(x5345)*(x5350)))+(((cj4)*(x5341)*(x5347)))+(((IkReal(-1.00000000000000))*(x5342)*(x5345)*(x5349)))+(((cj4)*(cj5)*(r01)*(x5343)))+(((IkReal(-1.00000000000000))*(x5338)))+(((x5343)*(x5344)))+(((r11)*(x5352)))+(((IkReal(-1.00000000000000))*(x5351)*(x5354)))+(((cj4)*(r02)*(x5340))));
evalcond[3]=((((IkReal(-1.00000000000000))*(r12)*(x5340)*(x5342)))+(((IkReal(-1.00000000000000))*(cj5)*(r11)*(x5342)*(x5343)))+(((IkReal(-1.00000000000000))*(x5343)*(x5351)))+(((IkReal(-1.00000000000000))*(x5341)*(x5342)*(x5345)))+(((IkReal(-1.00000000000000))*(x5342)*(x5345)*(x5346)))+(((IkReal(-1.00000000000000))*(x5344)*(x5354)))+(((IkReal(-1.00000000000000))*(r02)*(x5342)*(x5348)))+(((r11)*(x5353)))+(((r01)*(x5352)))+(((IkReal(-1.00000000000000))*(x5342)*(x5347)*(x5350)))+(x5339));
if( IKabs(evalcond[0]) > 0.000001  || IKabs(evalcond[1]) > 0.000001  || IKabs(evalcond[2]) > 0.000001  || IKabs(evalcond[3]) > 0.000001  )
{
continue;
}
}

{
std::vector<IkSingleDOFSolutionBase<IkReal> > vinfos(7);
vinfos[0].jointtype = 1;
vinfos[0].foffset = j0;
vinfos[0].indices[0] = _ij0[0];
vinfos[0].indices[1] = _ij0[1];
vinfos[0].maxsolutions = _nj0;
vinfos[1].jointtype = 1;
vinfos[1].foffset = j1;
vinfos[1].indices[0] = _ij1[0];
vinfos[1].indices[1] = _ij1[1];
vinfos[1].maxsolutions = _nj1;
vinfos[2].jointtype = 1;
vinfos[2].foffset = j2;
vinfos[2].indices[0] = _ij2[0];
vinfos[2].indices[1] = _ij2[1];
vinfos[2].maxsolutions = _nj2;
vinfos[3].jointtype = 1;
vinfos[3].foffset = j3;
vinfos[3].indices[0] = _ij3[0];
vinfos[3].indices[1] = _ij3[1];
vinfos[3].maxsolutions = _nj3;
vinfos[4].jointtype = 1;
vinfos[4].foffset = j4;
vinfos[4].indices[0] = _ij4[0];
vinfos[4].indices[1] = _ij4[1];
vinfos[4].maxsolutions = _nj4;
vinfos[5].jointtype = 1;
vinfos[5].foffset = j5;
vinfos[5].indices[0] = _ij5[0];
vinfos[5].indices[1] = _ij5[1];
vinfos[5].maxsolutions = _nj5;
vinfos[6].jointtype = 1;
vinfos[6].foffset = j6;
vinfos[6].indices[0] = _ij6[0];
vinfos[6].indices[1] = _ij6[1];
vinfos[6].maxsolutions = _nj6;
std::vector<int> vfree(0);
solutions.AddSolution(vinfos,vfree);
}
}
}

} else
{
if( 1 )
{
continue;

} else
{
}
}
}
}
}
}

} else
{
{
IkReal j3array[1], cj3array[1], sj3array[1];
bool j3valid[1]={false};
_nj3 = 1;
IkReal x5355=((cj5)*(r02));
IkReal x5356=((cj0)*(sj5));
IkReal x5357=((r10)*(sj6));
IkReal x5358=((IkReal(1.00000000000000))*(cj6));
IkReal x5359=((sj0)*(sj5));
IkReal x5360=((cj5)*(r12));
IkReal x5361=((IkReal(1.00000000000000))*(r00)*(sj6));
if( IKabs(((((x5356)*(x5357)))+(((cj6)*(r11)*(x5356)))+(((IkReal(-1.00000000000000))*(r01)*(x5358)*(x5359)))+(((sj0)*(x5355)))+(((IkReal(-1.00000000000000))*(x5359)*(x5361)))+(((IkReal(-1.00000000000000))*(cj0)*(x5360))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(((((IKabs(cj1) != 0)?((IkReal)1/(cj1)):(IkReal)1.0e30))*(((((IkReal(-1.00000000000000))*(x5357)*(x5359)))+(((sj0)*(x5360)))+(((IkReal(-1.00000000000000))*(r01)*(x5356)*(x5358)))+(((IkReal(-1.00000000000000))*(r11)*(x5358)*(x5359)))+(((IkReal(-1.00000000000000))*(x5356)*(x5361)))+(((cj0)*(x5355))))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(IKsqr(((((x5356)*(x5357)))+(((cj6)*(r11)*(x5356)))+(((IkReal(-1.00000000000000))*(r01)*(x5358)*(x5359)))+(((sj0)*(x5355)))+(((IkReal(-1.00000000000000))*(x5359)*(x5361)))+(((IkReal(-1.00000000000000))*(cj0)*(x5360)))))+IKsqr(((((IKabs(cj1) != 0)?((IkReal)1/(cj1)):(IkReal)1.0e30))*(((((IkReal(-1.00000000000000))*(x5357)*(x5359)))+(((sj0)*(x5360)))+(((IkReal(-1.00000000000000))*(r01)*(x5356)*(x5358)))+(((IkReal(-1.00000000000000))*(r11)*(x5358)*(x5359)))+(((IkReal(-1.00000000000000))*(x5356)*(x5361)))+(((cj0)*(x5355)))))))-1) <= IKFAST_SINCOS_THRESH )
    continue;
j3array[0]=IKatan2(((((x5356)*(x5357)))+(((cj6)*(r11)*(x5356)))+(((IkReal(-1.00000000000000))*(r01)*(x5358)*(x5359)))+(((sj0)*(x5355)))+(((IkReal(-1.00000000000000))*(x5359)*(x5361)))+(((IkReal(-1.00000000000000))*(cj0)*(x5360)))), ((((IKabs(cj1) != 0)?((IkReal)1/(cj1)):(IkReal)1.0e30))*(((((IkReal(-1.00000000000000))*(x5357)*(x5359)))+(((sj0)*(x5360)))+(((IkReal(-1.00000000000000))*(r01)*(x5356)*(x5358)))+(((IkReal(-1.00000000000000))*(r11)*(x5358)*(x5359)))+(((IkReal(-1.00000000000000))*(x5356)*(x5361)))+(((cj0)*(x5355)))))));
sj3array[0]=IKsin(j3array[0]);
cj3array[0]=IKcos(j3array[0]);
if( j3array[0] > IKPI )
{
    j3array[0]-=IK2PI;
}
else if( j3array[0] < -IKPI )
{    j3array[0]+=IK2PI;
}
j3valid[0] = true;
for(int ij3 = 0; ij3 < 1; ++ij3)
{
if( !j3valid[ij3] )
{
    continue;
}
_ij3[0] = ij3; _ij3[1] = -1;
for(int iij3 = ij3+1; iij3 < 1; ++iij3)
{
if( j3valid[iij3] && IKabs(cj3array[ij3]-cj3array[iij3]) < IKFAST_SOLUTION_THRESH && IKabs(sj3array[ij3]-sj3array[iij3]) < IKFAST_SOLUTION_THRESH )
{
    j3valid[iij3]=false; _ij3[1] = iij3; break; 
}
}
j3 = j3array[ij3]; cj3 = cj3array[ij3]; sj3 = sj3array[ij3];
{
IkReal evalcond[6];
IkReal x5362=IKsin(j3);
IkReal x5363=IKcos(j3);
IkReal x5364=((sj0)*(sj5));
IkReal x5365=((r00)*(sj6));
IkReal x5366=((IkReal(1.00000000000000))*(cj4));
IkReal x5367=((cj6)*(r01));
IkReal x5368=((cj0)*(cj5));
IkReal x5369=((cj5)*(sj0));
IkReal x5370=((cj6)*(r11));
IkReal x5371=((cj0)*(sj5));
IkReal x5372=((IkReal(1.00000000000000))*(cj1));
IkReal x5373=((cj6)*(sj4));
IkReal x5374=((IkReal(1.00000000000000))*(sj1));
IkReal x5375=((cj4)*(cj5));
IkReal x5376=((cj6)*(r21));
IkReal x5377=((r20)*(sj6));
IkReal x5378=((r10)*(sj6));
IkReal x5379=((IkReal(1.00000000000000))*(cj0));
IkReal x5380=((cj0)*(sj4)*(sj6));
IkReal x5381=((sj0)*(sj4)*(sj6));
evalcond[0]=((((sj5)*(x5377)))+(((sj5)*(x5376)))+(((IkReal(-1.00000000000000))*(cj5)*(r22)))+(((IkReal(-1.00000000000000))*(x5363)*(x5374))));
evalcond[1]=((((IkReal(-1.00000000000000))*(r21)*(sj4)*(sj6)))+(((IkReal(-1.00000000000000))*(x5362)*(x5374)))+(((cj4)*(r22)*(sj5)))+(((x5375)*(x5376)))+(((r20)*(x5373)))+(((x5375)*(x5377))));
evalcond[2]=((((IkReal(-1.00000000000000))*(x5371)*(x5378)))+(((x5364)*(x5367)))+(((r12)*(x5368)))+(((IkReal(-1.00000000000000))*(x5370)*(x5371)))+(((IkReal(-1.00000000000000))*(r02)*(x5369)))+(x5362)+(((x5364)*(x5365))));
evalcond[3]=((((IkReal(-1.00000000000000))*(x5363)*(x5372)))+(((r12)*(x5369)))+(((IkReal(-1.00000000000000))*(x5365)*(x5371)))+(((IkReal(-1.00000000000000))*(x5364)*(x5378)))+(((r02)*(x5368)))+(((IkReal(-1.00000000000000))*(x5367)*(x5371)))+(((IkReal(-1.00000000000000))*(x5364)*(x5370))));
evalcond[4]=((((IkReal(-1.00000000000000))*(r12)*(x5366)*(x5371)))+(((cj4)*(x5367)*(x5369)))+(((r00)*(sj0)*(x5373)))+(((IkReal(-1.00000000000000))*(r01)*(x5381)))+(((IkReal(-1.00000000000000))*(r10)*(x5373)*(x5379)))+(((IkReal(-1.00000000000000))*(x5363)))+(((r11)*(x5380)))+(((cj4)*(x5365)*(x5369)))+(((IkReal(-1.00000000000000))*(x5366)*(x5368)*(x5370)))+(((cj4)*(r02)*(x5364)))+(((IkReal(-1.00000000000000))*(x5366)*(x5368)*(x5378))));
evalcond[5]=((((IkReal(-1.00000000000000))*(x5362)*(x5372)))+(((IkReal(-1.00000000000000))*(r02)*(x5366)*(x5371)))+(((IkReal(-1.00000000000000))*(x5366)*(x5367)*(x5368)))+(((IkReal(-1.00000000000000))*(x5366)*(x5369)*(x5378)))+(((r01)*(x5380)))+(((r11)*(x5381)))+(((IkReal(-1.00000000000000))*(x5365)*(x5366)*(x5368)))+(((IkReal(-1.00000000000000))*(r10)*(sj0)*(x5373)))+(((IkReal(-1.00000000000000))*(r12)*(x5364)*(x5366)))+(((IkReal(-1.00000000000000))*(x5366)*(x5369)*(x5370)))+(((IkReal(-1.00000000000000))*(r00)*(x5373)*(x5379))));
if( IKabs(evalcond[0]) > 0.000001  || IKabs(evalcond[1]) > 0.000001  || IKabs(evalcond[2]) > 0.000001  || IKabs(evalcond[3]) > 0.000001  || IKabs(evalcond[4]) > 0.000001  || IKabs(evalcond[5]) > 0.000001  )
{
continue;
}
}

{
std::vector<IkSingleDOFSolutionBase<IkReal> > vinfos(7);
vinfos[0].jointtype = 1;
vinfos[0].foffset = j0;
vinfos[0].indices[0] = _ij0[0];
vinfos[0].indices[1] = _ij0[1];
vinfos[0].maxsolutions = _nj0;
vinfos[1].jointtype = 1;
vinfos[1].foffset = j1;
vinfos[1].indices[0] = _ij1[0];
vinfos[1].indices[1] = _ij1[1];
vinfos[1].maxsolutions = _nj1;
vinfos[2].jointtype = 1;
vinfos[2].foffset = j2;
vinfos[2].indices[0] = _ij2[0];
vinfos[2].indices[1] = _ij2[1];
vinfos[2].maxsolutions = _nj2;
vinfos[3].jointtype = 1;
vinfos[3].foffset = j3;
vinfos[3].indices[0] = _ij3[0];
vinfos[3].indices[1] = _ij3[1];
vinfos[3].maxsolutions = _nj3;
vinfos[4].jointtype = 1;
vinfos[4].foffset = j4;
vinfos[4].indices[0] = _ij4[0];
vinfos[4].indices[1] = _ij4[1];
vinfos[4].maxsolutions = _nj4;
vinfos[5].jointtype = 1;
vinfos[5].foffset = j5;
vinfos[5].indices[0] = _ij5[0];
vinfos[5].indices[1] = _ij5[1];
vinfos[5].maxsolutions = _nj5;
vinfos[6].jointtype = 1;
vinfos[6].foffset = j6;
vinfos[6].indices[0] = _ij6[0];
vinfos[6].indices[1] = _ij6[1];
vinfos[6].maxsolutions = _nj6;
std::vector<int> vfree(0);
solutions.AddSolution(vinfos,vfree);
}
}
}

}

}

} else
{
{
IkReal j3array[1], cj3array[1], sj3array[1];
bool j3valid[1]={false};
_nj3 = 1;
IkReal x5382=((sj5)*(sj6));
IkReal x5383=((IkReal(1.00000000000000))*(sj0));
IkReal x5384=((cj6)*(sj5));
IkReal x5385=((IkReal(1.00000000000000))*(cj5));
if( IKabs(((((cj0)*(r10)*(x5382)))+(((cj0)*(r11)*(x5384)))+(((IkReal(-1.00000000000000))*(r01)*(x5383)*(x5384)))+(((cj5)*(r02)*(sj0)))+(((IkReal(-1.00000000000000))*(r00)*(x5382)*(x5383)))+(((IkReal(-1.00000000000000))*(cj0)*(r12)*(x5385))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(((((IKabs(sj1) != 0)?((IkReal)1/(sj1)):(IkReal)1.0e30))*(((((IkReal(-1.00000000000000))*(r22)*(x5385)))+(((r21)*(x5384)))+(((r20)*(x5382))))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(IKsqr(((((cj0)*(r10)*(x5382)))+(((cj0)*(r11)*(x5384)))+(((IkReal(-1.00000000000000))*(r01)*(x5383)*(x5384)))+(((cj5)*(r02)*(sj0)))+(((IkReal(-1.00000000000000))*(r00)*(x5382)*(x5383)))+(((IkReal(-1.00000000000000))*(cj0)*(r12)*(x5385)))))+IKsqr(((((IKabs(sj1) != 0)?((IkReal)1/(sj1)):(IkReal)1.0e30))*(((((IkReal(-1.00000000000000))*(r22)*(x5385)))+(((r21)*(x5384)))+(((r20)*(x5382)))))))-1) <= IKFAST_SINCOS_THRESH )
    continue;
j3array[0]=IKatan2(((((cj0)*(r10)*(x5382)))+(((cj0)*(r11)*(x5384)))+(((IkReal(-1.00000000000000))*(r01)*(x5383)*(x5384)))+(((cj5)*(r02)*(sj0)))+(((IkReal(-1.00000000000000))*(r00)*(x5382)*(x5383)))+(((IkReal(-1.00000000000000))*(cj0)*(r12)*(x5385)))), ((((IKabs(sj1) != 0)?((IkReal)1/(sj1)):(IkReal)1.0e30))*(((((IkReal(-1.00000000000000))*(r22)*(x5385)))+(((r21)*(x5384)))+(((r20)*(x5382)))))));
sj3array[0]=IKsin(j3array[0]);
cj3array[0]=IKcos(j3array[0]);
if( j3array[0] > IKPI )
{
    j3array[0]-=IK2PI;
}
else if( j3array[0] < -IKPI )
{    j3array[0]+=IK2PI;
}
j3valid[0] = true;
for(int ij3 = 0; ij3 < 1; ++ij3)
{
if( !j3valid[ij3] )
{
    continue;
}
_ij3[0] = ij3; _ij3[1] = -1;
for(int iij3 = ij3+1; iij3 < 1; ++iij3)
{
if( j3valid[iij3] && IKabs(cj3array[ij3]-cj3array[iij3]) < IKFAST_SOLUTION_THRESH && IKabs(sj3array[ij3]-sj3array[iij3]) < IKFAST_SOLUTION_THRESH )
{
    j3valid[iij3]=false; _ij3[1] = iij3; break; 
}
}
j3 = j3array[ij3]; cj3 = cj3array[ij3]; sj3 = sj3array[ij3];
{
IkReal evalcond[6];
IkReal x5386=IKsin(j3);
IkReal x5387=IKcos(j3);
IkReal x5388=((sj0)*(sj5));
IkReal x5389=((r00)*(sj6));
IkReal x5390=((IkReal(1.00000000000000))*(cj4));
IkReal x5391=((cj6)*(r01));
IkReal x5392=((cj0)*(cj5));
IkReal x5393=((cj5)*(sj0));
IkReal x5394=((cj6)*(r11));
IkReal x5395=((cj0)*(sj5));
IkReal x5396=((IkReal(1.00000000000000))*(cj1));
IkReal x5397=((cj6)*(sj4));
IkReal x5398=((IkReal(1.00000000000000))*(sj1));
IkReal x5399=((cj4)*(cj5));
IkReal x5400=((cj6)*(r21));
IkReal x5401=((r20)*(sj6));
IkReal x5402=((r10)*(sj6));
IkReal x5403=((IkReal(1.00000000000000))*(cj0));
IkReal x5404=((cj0)*(sj4)*(sj6));
IkReal x5405=((sj0)*(sj4)*(sj6));
evalcond[0]=((((IkReal(-1.00000000000000))*(x5387)*(x5398)))+(((sj5)*(x5400)))+(((IkReal(-1.00000000000000))*(cj5)*(r22)))+(((sj5)*(x5401))));
evalcond[1]=((((IkReal(-1.00000000000000))*(r21)*(sj4)*(sj6)))+(((cj4)*(r22)*(sj5)))+(((x5399)*(x5400)))+(((IkReal(-1.00000000000000))*(x5386)*(x5398)))+(((x5399)*(x5401)))+(((r20)*(x5397))));
evalcond[2]=((((r12)*(x5392)))+(((IkReal(-1.00000000000000))*(r02)*(x5393)))+(((IkReal(-1.00000000000000))*(x5395)*(x5402)))+(((x5388)*(x5391)))+(((x5388)*(x5389)))+(x5386)+(((IkReal(-1.00000000000000))*(x5394)*(x5395))));
evalcond[3]=((((IkReal(-1.00000000000000))*(x5388)*(x5402)))+(((IkReal(-1.00000000000000))*(x5391)*(x5395)))+(((IkReal(-1.00000000000000))*(x5388)*(x5394)))+(((IkReal(-1.00000000000000))*(x5389)*(x5395)))+(((IkReal(-1.00000000000000))*(x5387)*(x5396)))+(((r02)*(x5392)))+(((r12)*(x5393))));
evalcond[4]=((((cj4)*(x5391)*(x5393)))+(((IkReal(-1.00000000000000))*(x5390)*(x5392)*(x5402)))+(((IkReal(-1.00000000000000))*(x5387)))+(((r11)*(x5404)))+(((IkReal(-1.00000000000000))*(r10)*(x5397)*(x5403)))+(((r00)*(sj0)*(x5397)))+(((IkReal(-1.00000000000000))*(r12)*(x5390)*(x5395)))+(((IkReal(-1.00000000000000))*(x5390)*(x5392)*(x5394)))+(((cj4)*(x5389)*(x5393)))+(((IkReal(-1.00000000000000))*(r01)*(x5405)))+(((cj4)*(r02)*(x5388))));
evalcond[5]=((((IkReal(-1.00000000000000))*(x5386)*(x5396)))+(((IkReal(-1.00000000000000))*(r12)*(x5388)*(x5390)))+(((r11)*(x5405)))+(((IkReal(-1.00000000000000))*(x5390)*(x5393)*(x5402)))+(((IkReal(-1.00000000000000))*(x5390)*(x5393)*(x5394)))+(((IkReal(-1.00000000000000))*(r10)*(sj0)*(x5397)))+(((IkReal(-1.00000000000000))*(r02)*(x5390)*(x5395)))+(((IkReal(-1.00000000000000))*(r00)*(x5397)*(x5403)))+(((r01)*(x5404)))+(((IkReal(-1.00000000000000))*(x5389)*(x5390)*(x5392)))+(((IkReal(-1.00000000000000))*(x5390)*(x5391)*(x5392))));
if( IKabs(evalcond[0]) > 0.000001  || IKabs(evalcond[1]) > 0.000001  || IKabs(evalcond[2]) > 0.000001  || IKabs(evalcond[3]) > 0.000001  || IKabs(evalcond[4]) > 0.000001  || IKabs(evalcond[5]) > 0.000001  )
{
continue;
}
}

{
std::vector<IkSingleDOFSolutionBase<IkReal> > vinfos(7);
vinfos[0].jointtype = 1;
vinfos[0].foffset = j0;
vinfos[0].indices[0] = _ij0[0];
vinfos[0].indices[1] = _ij0[1];
vinfos[0].maxsolutions = _nj0;
vinfos[1].jointtype = 1;
vinfos[1].foffset = j1;
vinfos[1].indices[0] = _ij1[0];
vinfos[1].indices[1] = _ij1[1];
vinfos[1].maxsolutions = _nj1;
vinfos[2].jointtype = 1;
vinfos[2].foffset = j2;
vinfos[2].indices[0] = _ij2[0];
vinfos[2].indices[1] = _ij2[1];
vinfos[2].maxsolutions = _nj2;
vinfos[3].jointtype = 1;
vinfos[3].foffset = j3;
vinfos[3].indices[0] = _ij3[0];
vinfos[3].indices[1] = _ij3[1];
vinfos[3].maxsolutions = _nj3;
vinfos[4].jointtype = 1;
vinfos[4].foffset = j4;
vinfos[4].indices[0] = _ij4[0];
vinfos[4].indices[1] = _ij4[1];
vinfos[4].maxsolutions = _nj4;
vinfos[5].jointtype = 1;
vinfos[5].foffset = j5;
vinfos[5].indices[0] = _ij5[0];
vinfos[5].indices[1] = _ij5[1];
vinfos[5].maxsolutions = _nj5;
vinfos[6].jointtype = 1;
vinfos[6].foffset = j6;
vinfos[6].indices[0] = _ij6[0];
vinfos[6].indices[1] = _ij6[1];
vinfos[6].maxsolutions = _nj6;
std::vector<int> vfree(0);
solutions.AddSolution(vinfos,vfree);
}
}
}

}

}

} else
{
{
IkReal j3array[1], cj3array[1], sj3array[1];
bool j3valid[1]={false};
_nj3 = 1;
IkReal x5406=((r20)*(sj6));
IkReal x5407=((cj4)*(cj5));
IkReal x5408=((cj6)*(r21));
if( IKabs(((gconst30)*(((((IkReal(-1.00000000000000))*(r21)*(sj4)*(sj6)))+(((cj6)*(r20)*(sj4)))+(((cj4)*(r22)*(sj5)))+(((x5406)*(x5407)))+(((x5407)*(x5408))))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(((gconst30)*(((((sj5)*(x5408)))+(((sj5)*(x5406)))+(((IkReal(-1.00000000000000))*(cj5)*(r22))))))) < IKFAST_ATAN2_MAGTHRESH )
    continue;
j3array[0]=IKatan2(((gconst30)*(((((IkReal(-1.00000000000000))*(r21)*(sj4)*(sj6)))+(((cj6)*(r20)*(sj4)))+(((cj4)*(r22)*(sj5)))+(((x5406)*(x5407)))+(((x5407)*(x5408)))))), ((gconst30)*(((((sj5)*(x5408)))+(((sj5)*(x5406)))+(((IkReal(-1.00000000000000))*(cj5)*(r22)))))));
sj3array[0]=IKsin(j3array[0]);
cj3array[0]=IKcos(j3array[0]);
if( j3array[0] > IKPI )
{
    j3array[0]-=IK2PI;
}
else if( j3array[0] < -IKPI )
{    j3array[0]+=IK2PI;
}
j3valid[0] = true;
for(int ij3 = 0; ij3 < 1; ++ij3)
{
if( !j3valid[ij3] )
{
    continue;
}
_ij3[0] = ij3; _ij3[1] = -1;
for(int iij3 = ij3+1; iij3 < 1; ++iij3)
{
if( j3valid[iij3] && IKabs(cj3array[ij3]-cj3array[iij3]) < IKFAST_SOLUTION_THRESH && IKabs(sj3array[ij3]-sj3array[iij3]) < IKFAST_SOLUTION_THRESH )
{
    j3valid[iij3]=false; _ij3[1] = iij3; break; 
}
}
j3 = j3array[ij3]; cj3 = cj3array[ij3]; sj3 = sj3array[ij3];
{
IkReal evalcond[6];
IkReal x5409=IKsin(j3);
IkReal x5410=IKcos(j3);
IkReal x5411=((sj0)*(sj5));
IkReal x5412=((r00)*(sj6));
IkReal x5413=((IkReal(1.00000000000000))*(cj4));
IkReal x5414=((cj6)*(r01));
IkReal x5415=((cj0)*(cj5));
IkReal x5416=((cj5)*(sj0));
IkReal x5417=((cj6)*(r11));
IkReal x5418=((cj0)*(sj5));
IkReal x5419=((IkReal(1.00000000000000))*(cj1));
IkReal x5420=((cj6)*(sj4));
IkReal x5421=((IkReal(1.00000000000000))*(sj1));
IkReal x5422=((cj4)*(cj5));
IkReal x5423=((cj6)*(r21));
IkReal x5424=((r20)*(sj6));
IkReal x5425=((r10)*(sj6));
IkReal x5426=((IkReal(1.00000000000000))*(cj0));
IkReal x5427=((cj0)*(sj4)*(sj6));
IkReal x5428=((sj0)*(sj4)*(sj6));
evalcond[0]=((((sj5)*(x5424)))+(((IkReal(-1.00000000000000))*(cj5)*(r22)))+(((IkReal(-1.00000000000000))*(x5410)*(x5421)))+(((sj5)*(x5423))));
evalcond[1]=((((IkReal(-1.00000000000000))*(r21)*(sj4)*(sj6)))+(((x5422)*(x5424)))+(((cj4)*(r22)*(sj5)))+(((r20)*(x5420)))+(((x5422)*(x5423)))+(((IkReal(-1.00000000000000))*(x5409)*(x5421))));
evalcond[2]=((((IkReal(-1.00000000000000))*(x5418)*(x5425)))+(((r12)*(x5415)))+(((x5411)*(x5412)))+(((x5411)*(x5414)))+(((IkReal(-1.00000000000000))*(r02)*(x5416)))+(((IkReal(-1.00000000000000))*(x5417)*(x5418)))+(x5409));
evalcond[3]=((((IkReal(-1.00000000000000))*(x5411)*(x5417)))+(((r02)*(x5415)))+(((IkReal(-1.00000000000000))*(x5414)*(x5418)))+(((IkReal(-1.00000000000000))*(x5412)*(x5418)))+(((IkReal(-1.00000000000000))*(x5410)*(x5419)))+(((r12)*(x5416)))+(((IkReal(-1.00000000000000))*(x5411)*(x5425))));
evalcond[4]=((((IkReal(-1.00000000000000))*(x5413)*(x5415)*(x5425)))+(((cj4)*(x5414)*(x5416)))+(((IkReal(-1.00000000000000))*(r01)*(x5428)))+(((cj4)*(x5412)*(x5416)))+(((IkReal(-1.00000000000000))*(r12)*(x5413)*(x5418)))+(((IkReal(-1.00000000000000))*(r10)*(x5420)*(x5426)))+(((cj4)*(r02)*(x5411)))+(((r11)*(x5427)))+(((IkReal(-1.00000000000000))*(x5413)*(x5415)*(x5417)))+(((IkReal(-1.00000000000000))*(x5410)))+(((r00)*(sj0)*(x5420))));
evalcond[5]=((((IkReal(-1.00000000000000))*(x5409)*(x5419)))+(((r01)*(x5427)))+(((IkReal(-1.00000000000000))*(x5412)*(x5413)*(x5415)))+(((IkReal(-1.00000000000000))*(x5413)*(x5414)*(x5415)))+(((IkReal(-1.00000000000000))*(r00)*(x5420)*(x5426)))+(((r11)*(x5428)))+(((IkReal(-1.00000000000000))*(x5413)*(x5416)*(x5425)))+(((IkReal(-1.00000000000000))*(r12)*(x5411)*(x5413)))+(((IkReal(-1.00000000000000))*(r10)*(sj0)*(x5420)))+(((IkReal(-1.00000000000000))*(r02)*(x5413)*(x5418)))+(((IkReal(-1.00000000000000))*(x5413)*(x5416)*(x5417))));
if( IKabs(evalcond[0]) > 0.000001  || IKabs(evalcond[1]) > 0.000001  || IKabs(evalcond[2]) > 0.000001  || IKabs(evalcond[3]) > 0.000001  || IKabs(evalcond[4]) > 0.000001  || IKabs(evalcond[5]) > 0.000001  )
{
continue;
}
}

{
std::vector<IkSingleDOFSolutionBase<IkReal> > vinfos(7);
vinfos[0].jointtype = 1;
vinfos[0].foffset = j0;
vinfos[0].indices[0] = _ij0[0];
vinfos[0].indices[1] = _ij0[1];
vinfos[0].maxsolutions = _nj0;
vinfos[1].jointtype = 1;
vinfos[1].foffset = j1;
vinfos[1].indices[0] = _ij1[0];
vinfos[1].indices[1] = _ij1[1];
vinfos[1].maxsolutions = _nj1;
vinfos[2].jointtype = 1;
vinfos[2].foffset = j2;
vinfos[2].indices[0] = _ij2[0];
vinfos[2].indices[1] = _ij2[1];
vinfos[2].maxsolutions = _nj2;
vinfos[3].jointtype = 1;
vinfos[3].foffset = j3;
vinfos[3].indices[0] = _ij3[0];
vinfos[3].indices[1] = _ij3[1];
vinfos[3].maxsolutions = _nj3;
vinfos[4].jointtype = 1;
vinfos[4].foffset = j4;
vinfos[4].indices[0] = _ij4[0];
vinfos[4].indices[1] = _ij4[1];
vinfos[4].maxsolutions = _nj4;
vinfos[5].jointtype = 1;
vinfos[5].foffset = j5;
vinfos[5].indices[0] = _ij5[0];
vinfos[5].indices[1] = _ij5[1];
vinfos[5].maxsolutions = _nj5;
vinfos[6].jointtype = 1;
vinfos[6].foffset = j6;
vinfos[6].indices[0] = _ij6[0];
vinfos[6].indices[1] = _ij6[1];
vinfos[6].maxsolutions = _nj6;
std::vector<int> vfree(0);
solutions.AddSolution(vinfos,vfree);
}
}
}

}

}
}
}

}

}

} else
{
{
IkReal j4array[1], cj4array[1], sj4array[1];
bool j4valid[1]={false};
_nj4 = 1;
IkReal x5429=((cj1)*(sj6));
IkReal x5430=((r01)*(sj0));
IkReal x5431=((cj0)*(r11));
IkReal x5432=((cj1)*(cj6));
IkReal x5433=((cj0)*(r10));
IkReal x5434=((IkReal(1.00000000000000))*(sj0));
IkReal x5435=((cj1)*(sj5));
if( IKabs(((gconst26)*(((((IkReal(-1.00000000000000))*(r00)*(x5432)*(x5434)))+(((IkReal(-1.00000000000000))*(x5429)*(x5431)))+(((x5432)*(x5433)))+(((x5429)*(x5430))))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(((gconst26)*(((((cj5)*(x5431)*(x5432)))+(((IkReal(-1.00000000000000))*(r02)*(x5434)*(x5435)))+(((IkReal(-1.00000000000000))*(cj5)*(x5430)*(x5432)))+(((IkReal(-1.00000000000000))*(cj5)*(r00)*(x5429)*(x5434)))+(((cj0)*(r12)*(x5435)))+(((cj5)*(x5429)*(x5433))))))) < IKFAST_ATAN2_MAGTHRESH )
    continue;
j4array[0]=IKatan2(((gconst26)*(((((IkReal(-1.00000000000000))*(r00)*(x5432)*(x5434)))+(((IkReal(-1.00000000000000))*(x5429)*(x5431)))+(((x5432)*(x5433)))+(((x5429)*(x5430)))))), ((gconst26)*(((((cj5)*(x5431)*(x5432)))+(((IkReal(-1.00000000000000))*(r02)*(x5434)*(x5435)))+(((IkReal(-1.00000000000000))*(cj5)*(x5430)*(x5432)))+(((IkReal(-1.00000000000000))*(cj5)*(r00)*(x5429)*(x5434)))+(((cj0)*(r12)*(x5435)))+(((cj5)*(x5429)*(x5433)))))));
sj4array[0]=IKsin(j4array[0]);
cj4array[0]=IKcos(j4array[0]);
if( j4array[0] > IKPI )
{
    j4array[0]-=IK2PI;
}
else if( j4array[0] < -IKPI )
{    j4array[0]+=IK2PI;
}
j4valid[0] = true;
for(int ij4 = 0; ij4 < 1; ++ij4)
{
if( !j4valid[ij4] )
{
    continue;
}
_ij4[0] = ij4; _ij4[1] = -1;
for(int iij4 = ij4+1; iij4 < 1; ++iij4)
{
if( j4valid[iij4] && IKabs(cj4array[ij4]-cj4array[iij4]) < IKFAST_SOLUTION_THRESH && IKabs(sj4array[ij4]-sj4array[iij4]) < IKFAST_SOLUTION_THRESH )
{
    j4valid[iij4]=false; _ij4[1] = iij4; break; 
}
}
j4 = j4array[ij4]; cj4 = cj4array[ij4]; sj4 = sj4array[ij4];
{
IkReal evalcond[3];
IkReal x5436=IKsin(j4);
IkReal x5437=IKcos(j4);
IkReal x5438=((r00)*(sj6));
IkReal x5439=((cj6)*(r01));
IkReal x5440=((IkReal(1.00000000000000))*(cj0));
IkReal x5441=((IkReal(1.00000000000000))*(sj0));
IkReal x5442=((r10)*(sj6));
IkReal x5443=((sj5)*(x5436));
IkReal x5444=((IkReal(1.00000000000000))*(cj6)*(r11));
IkReal x5445=((cj5)*(x5436));
IkReal x5446=((cj6)*(x5437));
IkReal x5447=((sj0)*(x5445));
IkReal x5448=((r01)*(sj6)*(x5437));
IkReal x5449=((r11)*(sj6)*(x5437));
evalcond[0]=((((r20)*(sj6)*(x5445)))+(((r22)*(x5443)))+(((r21)*(sj6)*(x5437)))+(cj1)+(((cj6)*(r21)*(x5445)))+(((IkReal(-1.00000000000000))*(r20)*(x5446))));
evalcond[1]=((((IkReal(-1.00000000000000))*(x5440)*(x5442)*(x5445)))+(((x5439)*(x5447)))+(((r02)*(sj0)*(x5443)))+(((IkReal(-1.00000000000000))*(r12)*(x5440)*(x5443)))+(((IkReal(-1.00000000000000))*(cj6)*(r11)*(x5440)*(x5445)))+(((cj0)*(r10)*(x5446)))+(((x5438)*(x5447)))+(((IkReal(-1.00000000000000))*(x5440)*(x5449)))+(((IkReal(-1.00000000000000))*(r00)*(x5441)*(x5446)))+(((sj0)*(x5448))));
evalcond[2]=((((IkReal(-1.00000000000000))*(x5438)*(x5440)*(x5445)))+(((IkReal(-1.00000000000000))*(x5441)*(x5449)))+(((IkReal(-1.00000000000000))*(x5439)*(x5440)*(x5445)))+(((IkReal(-1.00000000000000))*(r12)*(x5441)*(x5443)))+(((IkReal(-1.00000000000000))*(r02)*(x5440)*(x5443)))+(((IkReal(-1.00000000000000))*(sj1)))+(((r10)*(sj0)*(x5446)))+(((IkReal(-1.00000000000000))*(x5441)*(x5442)*(x5445)))+(((IkReal(-1.00000000000000))*(x5440)*(x5448)))+(((cj0)*(r00)*(x5446)))+(((IkReal(-1.00000000000000))*(cj6)*(r11)*(x5441)*(x5445))));
if( IKabs(evalcond[0]) > 0.000001  || IKabs(evalcond[1]) > 0.000001  || IKabs(evalcond[2]) > 0.000001  )
{
continue;
}
}

{
IkReal dummyeval[1];
IkReal gconst30;
gconst30=IKsign(sj1);
dummyeval[0]=sj1;
if( IKabs(dummyeval[0]) < 0.0000010000000000  )
{
{
IkReal dummyeval[1];
dummyeval[0]=sj1;
if( IKabs(dummyeval[0]) < 0.0000010000000000  )
{
{
IkReal dummyeval[1];
dummyeval[0]=cj1;
if( IKabs(dummyeval[0]) < 0.0000010000000000  )
{
{
IkReal evalcond[9];
IkReal x5450=((IkReal(1.00000000000000))*(cj0));
IkReal x5451=((cj4)*(sj6));
IkReal x5452=((sj0)*(sj6));
IkReal x5453=((cj5)*(sj4));
IkReal x5454=((IkReal(0.374290000000000))*(sj5));
IkReal x5455=((sj4)*(sj5));
IkReal x5456=((cj0)*(cj6));
IkReal x5457=((IkReal(0.0100000000000000))*(cj5));
IkReal x5458=((cj4)*(sj5));
IkReal x5459=((cj5)*(sj0));
IkReal x5460=((IkReal(0.374290000000000))*(r02));
IkReal x5461=((r20)*(sj6));
IkReal x5462=((cj6)*(r21));
IkReal x5463=((IkReal(1.00000000000000))*(sj0));
IkReal x5464=((cj0)*(sj6));
IkReal x5465=((cj4)*(cj6));
IkReal x5466=((IkReal(0.374290000000000))*(r12));
IkReal x5467=((cj0)*(cj5));
IkReal x5468=((cj6)*(sj5));
IkReal x5469=((cj6)*(r01));
IkReal x5470=((r00)*(sj6));
IkReal x5471=((IkReal(0.0100000000000000))*(sj5));
IkReal x5472=((cj6)*(r11));
IkReal x5473=((IkReal(1.00000000000000))*(r10));
IkReal x5474=((r02)*(sj0));
IkReal x5475=((cj6)*(sj4));
IkReal x5476=((r12)*(x5463));
evalcond[0]=((IkReal(-3.14159265358979))+(IKfmod(((IkReal(1.57079632679490))+(j1)), IkReal(6.28318530717959))));
evalcond[1]=((((IkReal(-1.00000000000000))*(r20)*(x5465)))+(((x5453)*(x5461)))+(((r22)*(x5455)))+(((x5453)*(x5462)))+(((r21)*(x5451))));
evalcond[2]=((IkReal(0.364420000000000))+(((x5454)*(x5461)))+(((IkReal(-1.00000000000000))*(x5457)*(x5461)))+(((IkReal(-1.00000000000000))*(x5457)*(x5462)))+(((IkReal(-0.374290000000000))*(cj5)*(r22)))+(((IkReal(-1.00000000000000))*(r22)*(x5471)))+(pz)+(((x5454)*(x5462))));
evalcond[3]=((((IkReal(-1.00000000000000))*(r11)*(x5463)*(x5468)))+(((r02)*(x5467)))+(((IkReal(-1.00000000000000))*(r01)*(x5450)*(x5468)))+(((IkReal(-1.00000000000000))*(sj5)*(x5450)*(x5470)))+(((r12)*(x5459)))+(((IkReal(-1.00000000000000))*(sj5)*(x5452)*(x5473))));
evalcond[4]=((((IkReal(-1.00000000000000))*(r12)*(x5450)*(x5455)))+(((IkReal(-1.00000000000000))*(r10)*(sj6)*(x5450)*(x5453)))+(((IkReal(-1.00000000000000))*(x5450)*(x5453)*(x5472)))+(((IkReal(-1.00000000000000))*(r11)*(x5450)*(x5451)))+(((sj0)*(x5453)*(x5469)))+(((x5455)*(x5474)))+(((r01)*(sj0)*(x5451)))+(((IkReal(-1.00000000000000))*(r00)*(x5463)*(x5465)))+(((cj4)*(r10)*(x5456)))+(((r00)*(x5452)*(x5453))));
evalcond[5]=((IkReal(-1.00000000000000))+(((r10)*(sj0)*(x5465)))+(((IkReal(-1.00000000000000))*(r01)*(x5450)*(x5451)))+(((cj4)*(r00)*(x5456)))+(((IkReal(-1.00000000000000))*(x5452)*(x5453)*(x5473)))+(((IkReal(-1.00000000000000))*(x5450)*(x5453)*(x5470)))+(((IkReal(-1.00000000000000))*(r02)*(x5450)*(x5455)))+(((IkReal(-1.00000000000000))*(x5450)*(x5453)*(x5469)))+(((IkReal(-1.00000000000000))*(r11)*(x5451)*(x5463)))+(((IkReal(-1.00000000000000))*(x5453)*(x5463)*(x5472)))+(((IkReal(-1.00000000000000))*(x5455)*(x5476))));
evalcond[6]=((IkReal(-0.0690000000000000))+(((IkReal(-1.00000000000000))*(r11)*(x5454)*(x5456)))+(((cj0)*(r12)*(x5471)))+(((r10)*(x5457)*(x5464)))+(((IkReal(-1.00000000000000))*(x5459)*(x5460)))+(((IkReal(-1.00000000000000))*(py)*(x5450)))+(((IkReal(-1.00000000000000))*(sj0)*(x5457)*(x5469)))+(((IkReal(-1.00000000000000))*(x5471)*(x5474)))+(((IkReal(-1.00000000000000))*(r00)*(x5452)*(x5457)))+(((r11)*(x5456)*(x5457)))+(((r00)*(x5452)*(x5454)))+(((px)*(sj0)))+(((x5466)*(x5467)))+(((sj0)*(x5454)*(x5469)))+(((IkReal(-1.00000000000000))*(r10)*(x5454)*(x5464))));
evalcond[7]=((((IkReal(-1.00000000000000))*(r00)*(x5450)*(x5475)))+(((IkReal(-1.00000000000000))*(x5451)*(x5459)*(x5473)))+(((IkReal(-1.00000000000000))*(x5458)*(x5476)))+(((IkReal(-1.00000000000000))*(cj5)*(r00)*(x5450)*(x5451)))+(((IkReal(-1.00000000000000))*(r11)*(x5459)*(x5465)))+(((r11)*(sj4)*(x5452)))+(((IkReal(-1.00000000000000))*(cj5)*(r01)*(x5450)*(x5465)))+(((IkReal(-1.00000000000000))*(r02)*(x5450)*(x5458)))+(((r01)*(sj4)*(x5464)))+(((IkReal(-1.00000000000000))*(r10)*(x5463)*(x5475))));
evalcond[8]=((IkReal(0.0690000000000000))+(((IkReal(-1.00000000000000))*(r10)*(x5452)*(x5454)))+(((cj0)*(r02)*(x5471)))+(((r01)*(x5456)*(x5457)))+(((x5460)*(x5467)))+(((r12)*(sj0)*(x5471)))+(((IkReal(-1.00000000000000))*(px)*(x5450)))+(((IkReal(-1.00000000000000))*(r01)*(x5454)*(x5456)))+(((x5459)*(x5466)))+(((IkReal(-1.00000000000000))*(py)*(x5463)))+(((r00)*(x5457)*(x5464)))+(((r10)*(x5452)*(x5457)))+(((IkReal(-1.00000000000000))*(sj0)*(x5454)*(x5472)))+(((IkReal(-1.00000000000000))*(r00)*(x5454)*(x5464)))+(((sj0)*(x5457)*(x5472))));
if( IKabs(evalcond[0]) < 0.0000010000000000  && IKabs(evalcond[1]) < 0.0000010000000000  && IKabs(evalcond[2]) < 0.0000010000000000  && IKabs(evalcond[3]) < 0.0000010000000000  && IKabs(evalcond[4]) < 0.0000010000000000  && IKabs(evalcond[5]) < 0.0000010000000000  && IKabs(evalcond[6]) < 0.0000010000000000  && IKabs(evalcond[7]) < 0.0000010000000000  && IKabs(evalcond[8]) < 0.0000010000000000  )
{
{
IkReal j3array[1], cj3array[1], sj3array[1];
bool j3valid[1]={false};
_nj3 = 1;
IkReal x5477=((r20)*(sj6));
IkReal x5478=((cj4)*(cj5));
IkReal x5479=((cj6)*(r21));
if( IKabs(((((IkReal(-1.00000000000000))*(r21)*(sj4)*(sj6)))+(((cj6)*(r20)*(sj4)))+(((cj4)*(r22)*(sj5)))+(((x5477)*(x5478)))+(((x5478)*(x5479))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(((((IkReal(-1.00000000000000))*(cj5)*(r22)))+(((sj5)*(x5477)))+(((sj5)*(x5479))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(IKsqr(((((IkReal(-1.00000000000000))*(r21)*(sj4)*(sj6)))+(((cj6)*(r20)*(sj4)))+(((cj4)*(r22)*(sj5)))+(((x5477)*(x5478)))+(((x5478)*(x5479)))))+IKsqr(((((IkReal(-1.00000000000000))*(cj5)*(r22)))+(((sj5)*(x5477)))+(((sj5)*(x5479)))))-1) <= IKFAST_SINCOS_THRESH )
    continue;
j3array[0]=IKatan2(((((IkReal(-1.00000000000000))*(r21)*(sj4)*(sj6)))+(((cj6)*(r20)*(sj4)))+(((cj4)*(r22)*(sj5)))+(((x5477)*(x5478)))+(((x5478)*(x5479)))), ((((IkReal(-1.00000000000000))*(cj5)*(r22)))+(((sj5)*(x5477)))+(((sj5)*(x5479)))));
sj3array[0]=IKsin(j3array[0]);
cj3array[0]=IKcos(j3array[0]);
if( j3array[0] > IKPI )
{
    j3array[0]-=IK2PI;
}
else if( j3array[0] < -IKPI )
{    j3array[0]+=IK2PI;
}
j3valid[0] = true;
for(int ij3 = 0; ij3 < 1; ++ij3)
{
if( !j3valid[ij3] )
{
    continue;
}
_ij3[0] = ij3; _ij3[1] = -1;
for(int iij3 = ij3+1; iij3 < 1; ++iij3)
{
if( j3valid[iij3] && IKabs(cj3array[ij3]-cj3array[iij3]) < IKFAST_SOLUTION_THRESH && IKabs(sj3array[ij3]-sj3array[iij3]) < IKFAST_SOLUTION_THRESH )
{
    j3valid[iij3]=false; _ij3[1] = iij3; break; 
}
}
j3 = j3array[ij3]; cj3 = cj3array[ij3]; sj3 = sj3array[ij3];
{
IkReal evalcond[4];
IkReal x5480=IKsin(j3);
IkReal x5481=((sj0)*(sj5));
IkReal x5482=((r00)*(sj6));
IkReal x5483=((cj6)*(r01));
IkReal x5484=((cj5)*(sj0));
IkReal x5485=((cj0)*(cj5));
IkReal x5486=((cj6)*(sj4));
IkReal x5487=((sj4)*(sj6));
IkReal x5488=((cj0)*(r11));
IkReal x5489=((cj4)*(cj6));
IkReal x5490=((cj4)*(sj6));
IkReal x5491=((IkReal(1.00000000000000))*(cj0));
IkReal x5492=((cj4)*(sj5));
IkReal x5493=((sj5)*(sj6));
IkReal x5494=((cj6)*(sj5));
IkReal x5495=((IkReal(1.00000000000000))*(IKcos(j3)));
evalcond[0]=((((IkReal(-1.00000000000000))*(cj5)*(r22)))+(((r21)*(x5494)))+(((r20)*(x5493)))+(((IkReal(-1.00000000000000))*(x5495))));
evalcond[1]=((((IkReal(-1.00000000000000))*(r21)*(x5487)))+(((cj5)*(r20)*(x5490)))+(((IkReal(-1.00000000000000))*(x5480)))+(((r20)*(x5486)))+(((cj5)*(r21)*(x5489)))+(((r22)*(x5492))));
evalcond[2]=((x5480)+(((IkReal(-1.00000000000000))*(r10)*(x5491)*(x5493)))+(((r12)*(x5485)))+(((IkReal(-1.00000000000000))*(r02)*(x5484)))+(((x5481)*(x5482)))+(((IkReal(-1.00000000000000))*(x5488)*(x5494)))+(((x5481)*(x5483))));
evalcond[3]=((((IkReal(-1.00000000000000))*(r11)*(x5485)*(x5489)))+(((cj4)*(x5482)*(x5484)))+(((IkReal(-1.00000000000000))*(r12)*(x5491)*(x5492)))+(((IkReal(-1.00000000000000))*(r10)*(x5485)*(x5490)))+(((IkReal(-1.00000000000000))*(r01)*(sj0)*(x5487)))+(((cj4)*(x5483)*(x5484)))+(((r00)*(sj0)*(x5486)))+(((cj4)*(r02)*(x5481)))+(((x5487)*(x5488)))+(((IkReal(-1.00000000000000))*(r10)*(x5486)*(x5491)))+(((IkReal(-1.00000000000000))*(x5495))));
if( IKabs(evalcond[0]) > 0.000001  || IKabs(evalcond[1]) > 0.000001  || IKabs(evalcond[2]) > 0.000001  || IKabs(evalcond[3]) > 0.000001  )
{
continue;
}
}

{
std::vector<IkSingleDOFSolutionBase<IkReal> > vinfos(7);
vinfos[0].jointtype = 1;
vinfos[0].foffset = j0;
vinfos[0].indices[0] = _ij0[0];
vinfos[0].indices[1] = _ij0[1];
vinfos[0].maxsolutions = _nj0;
vinfos[1].jointtype = 1;
vinfos[1].foffset = j1;
vinfos[1].indices[0] = _ij1[0];
vinfos[1].indices[1] = _ij1[1];
vinfos[1].maxsolutions = _nj1;
vinfos[2].jointtype = 1;
vinfos[2].foffset = j2;
vinfos[2].indices[0] = _ij2[0];
vinfos[2].indices[1] = _ij2[1];
vinfos[2].maxsolutions = _nj2;
vinfos[3].jointtype = 1;
vinfos[3].foffset = j3;
vinfos[3].indices[0] = _ij3[0];
vinfos[3].indices[1] = _ij3[1];
vinfos[3].maxsolutions = _nj3;
vinfos[4].jointtype = 1;
vinfos[4].foffset = j4;
vinfos[4].indices[0] = _ij4[0];
vinfos[4].indices[1] = _ij4[1];
vinfos[4].maxsolutions = _nj4;
vinfos[5].jointtype = 1;
vinfos[5].foffset = j5;
vinfos[5].indices[0] = _ij5[0];
vinfos[5].indices[1] = _ij5[1];
vinfos[5].maxsolutions = _nj5;
vinfos[6].jointtype = 1;
vinfos[6].foffset = j6;
vinfos[6].indices[0] = _ij6[0];
vinfos[6].indices[1] = _ij6[1];
vinfos[6].maxsolutions = _nj6;
std::vector<int> vfree(0);
solutions.AddSolution(vinfos,vfree);
}
}
}

} else
{
IkReal x5496=((IkReal(1.00000000000000))*(cj0));
IkReal x5497=((cj4)*(sj6));
IkReal x5498=((sj0)*(sj6));
IkReal x5499=((cj5)*(sj4));
IkReal x5500=((IkReal(0.374290000000000))*(sj5));
IkReal x5501=((sj4)*(sj5));
IkReal x5502=((cj0)*(cj6));
IkReal x5503=((IkReal(0.0100000000000000))*(cj5));
IkReal x5504=((cj4)*(sj5));
IkReal x5505=((cj5)*(sj0));
IkReal x5506=((IkReal(0.374290000000000))*(r02));
IkReal x5507=((r20)*(sj6));
IkReal x5508=((cj6)*(r21));
IkReal x5509=((IkReal(1.00000000000000))*(sj0));
IkReal x5510=((cj0)*(sj6));
IkReal x5511=((cj4)*(cj6));
IkReal x5512=((IkReal(0.374290000000000))*(r12));
IkReal x5513=((cj0)*(cj5));
IkReal x5514=((cj6)*(sj5));
IkReal x5515=((cj6)*(r01));
IkReal x5516=((r00)*(sj6));
IkReal x5517=((IkReal(0.0100000000000000))*(sj5));
IkReal x5518=((cj6)*(r11));
IkReal x5519=((IkReal(1.00000000000000))*(r10));
IkReal x5520=((r02)*(sj0));
IkReal x5521=((cj6)*(sj4));
IkReal x5522=((r12)*(x5509));
evalcond[0]=((IkReal(-3.14159265358979))+(IKfmod(((IkReal(4.71238898038469))+(j1)), IkReal(6.28318530717959))));
evalcond[1]=((((r21)*(x5497)))+(((x5499)*(x5508)))+(((x5499)*(x5507)))+(((r22)*(x5501)))+(((IkReal(-1.00000000000000))*(r20)*(x5511))));
evalcond[2]=((IkReal(-0.364420000000000))+(((IkReal(-1.00000000000000))*(r22)*(x5517)))+(((x5500)*(x5508)))+(((x5500)*(x5507)))+(((IkReal(-1.00000000000000))*(x5503)*(x5508)))+(((IkReal(-0.374290000000000))*(cj5)*(r22)))+(pz)+(((IkReal(-1.00000000000000))*(x5503)*(x5507))));
evalcond[3]=((((IkReal(-1.00000000000000))*(r11)*(x5509)*(x5514)))+(((r12)*(x5505)))+(((IkReal(-1.00000000000000))*(sj5)*(x5496)*(x5516)))+(((IkReal(-1.00000000000000))*(r01)*(x5496)*(x5514)))+(((IkReal(-1.00000000000000))*(sj5)*(x5498)*(x5519)))+(((r02)*(x5513))));
evalcond[4]=((((r00)*(x5498)*(x5499)))+(((IkReal(-1.00000000000000))*(r10)*(sj6)*(x5496)*(x5499)))+(((cj4)*(r10)*(x5502)))+(((sj0)*(x5499)*(x5515)))+(((r01)*(sj0)*(x5497)))+(((IkReal(-1.00000000000000))*(r11)*(x5496)*(x5497)))+(((IkReal(-1.00000000000000))*(r12)*(x5496)*(x5501)))+(((IkReal(-1.00000000000000))*(x5496)*(x5499)*(x5518)))+(((IkReal(-1.00000000000000))*(r00)*(x5509)*(x5511)))+(((x5501)*(x5520))));
evalcond[5]=((IkReal(1.00000000000000))+(((IkReal(-1.00000000000000))*(x5499)*(x5509)*(x5518)))+(((IkReal(-1.00000000000000))*(r02)*(x5496)*(x5501)))+(((IkReal(-1.00000000000000))*(x5496)*(x5499)*(x5516)))+(((IkReal(-1.00000000000000))*(r11)*(x5497)*(x5509)))+(((IkReal(-1.00000000000000))*(x5501)*(x5522)))+(((r10)*(sj0)*(x5511)))+(((cj4)*(r00)*(x5502)))+(((IkReal(-1.00000000000000))*(x5498)*(x5499)*(x5519)))+(((IkReal(-1.00000000000000))*(r01)*(x5496)*(x5497)))+(((IkReal(-1.00000000000000))*(x5496)*(x5499)*(x5515))));
evalcond[6]=((IkReal(-0.0690000000000000))+(((IkReal(-1.00000000000000))*(r10)*(x5500)*(x5510)))+(((IkReal(-1.00000000000000))*(x5505)*(x5506)))+(((IkReal(-1.00000000000000))*(sj0)*(x5503)*(x5515)))+(((cj0)*(r12)*(x5517)))+(((r10)*(x5503)*(x5510)))+(((r11)*(x5502)*(x5503)))+(((IkReal(-1.00000000000000))*(r00)*(x5498)*(x5503)))+(((IkReal(-1.00000000000000))*(py)*(x5496)))+(((r00)*(x5498)*(x5500)))+(((sj0)*(x5500)*(x5515)))+(((IkReal(-1.00000000000000))*(x5517)*(x5520)))+(((px)*(sj0)))+(((IkReal(-1.00000000000000))*(r11)*(x5500)*(x5502)))+(((x5512)*(x5513))));
evalcond[7]=((((IkReal(-1.00000000000000))*(cj5)*(r00)*(x5496)*(x5497)))+(((IkReal(-1.00000000000000))*(cj5)*(r01)*(x5496)*(x5511)))+(((IkReal(-1.00000000000000))*(x5504)*(x5522)))+(((IkReal(-1.00000000000000))*(r02)*(x5496)*(x5504)))+(((r01)*(sj4)*(x5510)))+(((IkReal(-1.00000000000000))*(x5497)*(x5505)*(x5519)))+(((IkReal(-1.00000000000000))*(r10)*(x5509)*(x5521)))+(((r11)*(sj4)*(x5498)))+(((IkReal(-1.00000000000000))*(r11)*(x5505)*(x5511)))+(((IkReal(-1.00000000000000))*(r00)*(x5496)*(x5521))));
evalcond[8]=((IkReal(0.0690000000000000))+(((IkReal(-1.00000000000000))*(py)*(x5509)))+(((r00)*(x5503)*(x5510)))+(((IkReal(-1.00000000000000))*(sj0)*(x5500)*(x5518)))+(((IkReal(-1.00000000000000))*(px)*(x5496)))+(((IkReal(-1.00000000000000))*(r10)*(x5498)*(x5500)))+(((r01)*(x5502)*(x5503)))+(((r10)*(x5498)*(x5503)))+(((IkReal(-1.00000000000000))*(r01)*(x5500)*(x5502)))+(((sj0)*(x5503)*(x5518)))+(((x5505)*(x5512)))+(((r12)*(sj0)*(x5517)))+(((x5506)*(x5513)))+(((IkReal(-1.00000000000000))*(r00)*(x5500)*(x5510)))+(((cj0)*(r02)*(x5517))));
if( IKabs(evalcond[0]) < 0.0000010000000000  && IKabs(evalcond[1]) < 0.0000010000000000  && IKabs(evalcond[2]) < 0.0000010000000000  && IKabs(evalcond[3]) < 0.0000010000000000  && IKabs(evalcond[4]) < 0.0000010000000000  && IKabs(evalcond[5]) < 0.0000010000000000  && IKabs(evalcond[6]) < 0.0000010000000000  && IKabs(evalcond[7]) < 0.0000010000000000  && IKabs(evalcond[8]) < 0.0000010000000000  )
{
{
IkReal j3array[1], cj3array[1], sj3array[1];
bool j3valid[1]={false};
_nj3 = 1;
IkReal x5523=((IkReal(1.00000000000000))*(sj5));
IkReal x5524=((cj6)*(r21));
IkReal x5525=((r20)*(sj6));
IkReal x5526=((IkReal(1.00000000000000))*(cj4)*(cj5));
if( IKabs(((((IkReal(-1.00000000000000))*(x5524)*(x5526)))+(((r21)*(sj4)*(sj6)))+(((IkReal(-1.00000000000000))*(x5525)*(x5526)))+(((IkReal(-1.00000000000000))*(cj4)*(r22)*(x5523)))+(((IkReal(-1.00000000000000))*(cj6)*(r20)*(sj4))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(((((IkReal(-1.00000000000000))*(x5523)*(x5525)))+(((IkReal(-1.00000000000000))*(x5523)*(x5524)))+(((cj5)*(r22))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(IKsqr(((((IkReal(-1.00000000000000))*(x5524)*(x5526)))+(((r21)*(sj4)*(sj6)))+(((IkReal(-1.00000000000000))*(x5525)*(x5526)))+(((IkReal(-1.00000000000000))*(cj4)*(r22)*(x5523)))+(((IkReal(-1.00000000000000))*(cj6)*(r20)*(sj4)))))+IKsqr(((((IkReal(-1.00000000000000))*(x5523)*(x5525)))+(((IkReal(-1.00000000000000))*(x5523)*(x5524)))+(((cj5)*(r22)))))-1) <= IKFAST_SINCOS_THRESH )
    continue;
j3array[0]=IKatan2(((((IkReal(-1.00000000000000))*(x5524)*(x5526)))+(((r21)*(sj4)*(sj6)))+(((IkReal(-1.00000000000000))*(x5525)*(x5526)))+(((IkReal(-1.00000000000000))*(cj4)*(r22)*(x5523)))+(((IkReal(-1.00000000000000))*(cj6)*(r20)*(sj4)))), ((((IkReal(-1.00000000000000))*(x5523)*(x5525)))+(((IkReal(-1.00000000000000))*(x5523)*(x5524)))+(((cj5)*(r22)))));
sj3array[0]=IKsin(j3array[0]);
cj3array[0]=IKcos(j3array[0]);
if( j3array[0] > IKPI )
{
    j3array[0]-=IK2PI;
}
else if( j3array[0] < -IKPI )
{    j3array[0]+=IK2PI;
}
j3valid[0] = true;
for(int ij3 = 0; ij3 < 1; ++ij3)
{
if( !j3valid[ij3] )
{
    continue;
}
_ij3[0] = ij3; _ij3[1] = -1;
for(int iij3 = ij3+1; iij3 < 1; ++iij3)
{
if( j3valid[iij3] && IKabs(cj3array[ij3]-cj3array[iij3]) < IKFAST_SOLUTION_THRESH && IKabs(sj3array[ij3]-sj3array[iij3]) < IKFAST_SOLUTION_THRESH )
{
    j3valid[iij3]=false; _ij3[1] = iij3; break; 
}
}
j3 = j3array[ij3]; cj3 = cj3array[ij3]; sj3 = sj3array[ij3];
{
IkReal evalcond[4];
IkReal x5527=IKsin(j3);
IkReal x5528=IKcos(j3);
IkReal x5529=((sj0)*(sj5));
IkReal x5530=((r00)*(sj6));
IkReal x5531=((cj6)*(r01));
IkReal x5532=((cj0)*(cj5));
IkReal x5533=((IkReal(1.00000000000000))*(cj5));
IkReal x5534=((cj4)*(cj5));
IkReal x5535=((cj6)*(sj4));
IkReal x5536=((sj4)*(sj6));
IkReal x5537=((cj0)*(r11));
IkReal x5538=((IkReal(1.00000000000000))*(cj4));
IkReal x5539=((cj6)*(r21));
IkReal x5540=((r20)*(sj6));
IkReal x5541=((cj0)*(sj5));
IkReal x5542=((r10)*(sj6));
evalcond[0]=((((sj5)*(x5540)))+(((IkReal(-1.00000000000000))*(r22)*(x5533)))+(x5528)+(((sj5)*(x5539))));
evalcond[1]=((((x5534)*(x5540)))+(((cj4)*(r22)*(sj5)))+(((x5534)*(x5539)))+(x5527)+(((r20)*(x5535)))+(((IkReal(-1.00000000000000))*(r21)*(x5536))));
evalcond[2]=((((x5529)*(x5531)))+(((IkReal(-1.00000000000000))*(cj6)*(sj5)*(x5537)))+(((r12)*(x5532)))+(x5527)+(((IkReal(-1.00000000000000))*(r02)*(sj0)*(x5533)))+(((x5529)*(x5530)))+(((IkReal(-1.00000000000000))*(x5541)*(x5542))));
evalcond[3]=((((IkReal(-1.00000000000000))*(r12)*(x5538)*(x5541)))+(((IkReal(-1.00000000000000))*(cj6)*(r11)*(x5532)*(x5538)))+(((r00)*(sj0)*(x5535)))+(((x5536)*(x5537)))+(((IkReal(-1.00000000000000))*(cj0)*(r10)*(x5535)))+(((IkReal(-1.00000000000000))*(x5528)))+(((IkReal(-1.00000000000000))*(r01)*(sj0)*(x5536)))+(((IkReal(-1.00000000000000))*(x5532)*(x5538)*(x5542)))+(((sj0)*(x5531)*(x5534)))+(((cj4)*(r02)*(x5529)))+(((sj0)*(x5530)*(x5534))));
if( IKabs(evalcond[0]) > 0.000001  || IKabs(evalcond[1]) > 0.000001  || IKabs(evalcond[2]) > 0.000001  || IKabs(evalcond[3]) > 0.000001  )
{
continue;
}
}

{
std::vector<IkSingleDOFSolutionBase<IkReal> > vinfos(7);
vinfos[0].jointtype = 1;
vinfos[0].foffset = j0;
vinfos[0].indices[0] = _ij0[0];
vinfos[0].indices[1] = _ij0[1];
vinfos[0].maxsolutions = _nj0;
vinfos[1].jointtype = 1;
vinfos[1].foffset = j1;
vinfos[1].indices[0] = _ij1[0];
vinfos[1].indices[1] = _ij1[1];
vinfos[1].maxsolutions = _nj1;
vinfos[2].jointtype = 1;
vinfos[2].foffset = j2;
vinfos[2].indices[0] = _ij2[0];
vinfos[2].indices[1] = _ij2[1];
vinfos[2].maxsolutions = _nj2;
vinfos[3].jointtype = 1;
vinfos[3].foffset = j3;
vinfos[3].indices[0] = _ij3[0];
vinfos[3].indices[1] = _ij3[1];
vinfos[3].maxsolutions = _nj3;
vinfos[4].jointtype = 1;
vinfos[4].foffset = j4;
vinfos[4].indices[0] = _ij4[0];
vinfos[4].indices[1] = _ij4[1];
vinfos[4].maxsolutions = _nj4;
vinfos[5].jointtype = 1;
vinfos[5].foffset = j5;
vinfos[5].indices[0] = _ij5[0];
vinfos[5].indices[1] = _ij5[1];
vinfos[5].maxsolutions = _nj5;
vinfos[6].jointtype = 1;
vinfos[6].foffset = j6;
vinfos[6].indices[0] = _ij6[0];
vinfos[6].indices[1] = _ij6[1];
vinfos[6].maxsolutions = _nj6;
std::vector<int> vfree(0);
solutions.AddSolution(vinfos,vfree);
}
}
}

} else
{
IkReal x5543=((IkReal(1.00000000000000))*(cj0));
IkReal x5544=((cj4)*(sj6));
IkReal x5545=((sj0)*(sj4));
IkReal x5546=((cj5)*(sj6));
IkReal x5547=((sj4)*(sj5));
IkReal x5548=((r12)*(sj5));
IkReal x5549=((IkReal(0.374290000000000))*(cj5));
IkReal x5550=((r02)*(sj0));
IkReal x5551=((r20)*(sj4));
IkReal x5552=((IkReal(1.00000000000000))*(sj0));
IkReal x5553=((IkReal(1.00000000000000))*(cj5));
IkReal x5554=((cj0)*(r10));
IkReal x5555=((cj4)*(cj6));
IkReal x5556=((r00)*(sj0));
IkReal x5557=((cj6)*(r21));
IkReal x5558=((IkReal(0.374290000000000))*(sj5));
IkReal x5559=((cj0)*(r00));
IkReal x5560=((IkReal(0.0100000000000000))*(sj5));
IkReal x5561=((cj0)*(r02));
IkReal x5562=((cj5)*(sj4));
IkReal x5563=((cj6)*(r01));
IkReal x5564=((cj6)*(r11));
IkReal x5565=((r01)*(sj0));
IkReal x5566=((r10)*(sj0));
IkReal x5567=((IkReal(0.0100000000000000))*(cj5)*(cj6));
IkReal x5568=((sj6)*(x5558));
IkReal x5569=((cj0)*(cj6)*(x5558));
evalcond[0]=((IkReal(-3.14159265358979))+(IKfmod(((IkReal(3.14159265358979))+(j1)), IkReal(6.28318530717959))));
evalcond[1]=((((IkReal(-1.00000000000000))*(r22)*(x5553)))+(((sj5)*(x5557)))+(((r20)*(sj5)*(sj6))));
evalcond[2]=((IkReal(1.00000000000000))+(((x5546)*(x5551)))+(((x5557)*(x5562)))+(((r22)*(x5547)))+(((IkReal(-1.00000000000000))*(r20)*(x5555)))+(((r21)*(x5544))));
evalcond[3]=((((IkReal(-1.00000000000000))*(r22)*(x5560)))+(((x5557)*(x5558)))+(((IkReal(-0.0100000000000000))*(cj5)*(x5557)))+(((r20)*(x5568)))+(pz)+(((IkReal(-1.00000000000000))*(r22)*(x5549)))+(((IkReal(-0.0100000000000000))*(r20)*(x5546))));
evalcond[4]=((((IkReal(-1.00000000000000))*(r21)*(sj4)*(sj6)))+(((cj6)*(x5551)))+(((cj4)*(r22)*(sj5)))+(((cj5)*(r21)*(x5555)))+(((cj5)*(r20)*(x5544))));
evalcond[5]=((((r02)*(sj5)*(x5545)))+(((cj5)*(x5545)*(x5563)))+(((r00)*(x5545)*(x5546)))+(((IkReal(-1.00000000000000))*(r10)*(sj4)*(x5543)*(x5546)))+(((IkReal(-1.00000000000000))*(x5543)*(x5562)*(x5564)))+(((IkReal(-1.00000000000000))*(r00)*(x5552)*(x5555)))+(((x5544)*(x5565)))+(((IkReal(-1.00000000000000))*(r11)*(x5543)*(x5544)))+(((IkReal(-1.00000000000000))*(r12)*(x5543)*(x5547)))+(((x5554)*(x5555))));
evalcond[6]=((((IkReal(-1.00000000000000))*(r02)*(x5543)*(x5547)))+(((IkReal(-1.00000000000000))*(r10)*(x5545)*(x5546)))+(((IkReal(-1.00000000000000))*(x5545)*(x5548)))+(((x5555)*(x5566)))+(((IkReal(-1.00000000000000))*(x5545)*(x5553)*(x5564)))+(((IkReal(-1.00000000000000))*(r00)*(sj4)*(x5543)*(x5546)))+(((IkReal(-1.00000000000000))*(x5543)*(x5562)*(x5563)))+(((IkReal(-1.00000000000000))*(r11)*(x5544)*(x5552)))+(((IkReal(-1.00000000000000))*(r01)*(x5543)*(x5544)))+(((x5555)*(x5559))));
evalcond[7]=((IkReal(-0.0690000000000000))+(((IkReal(-1.00000000000000))*(x5554)*(x5568)))+(((IkReal(-1.00000000000000))*(cj0)*(x5558)*(x5564)))+(((IkReal(0.0100000000000000))*(x5546)*(x5554)))+(((IkReal(-1.00000000000000))*(x5549)*(x5550)))+(((sj0)*(x5558)*(x5563)))+(((x5556)*(x5568)))+(((cj0)*(r12)*(x5549)))+(((IkReal(-0.0100000000000000))*(cj5)*(sj0)*(x5563)))+(((IkReal(0.0100000000000000))*(cj0)*(x5548)))+(((IkReal(-1.00000000000000))*(py)*(x5543)))+(((IkReal(-1.00000000000000))*(x5550)*(x5560)))+(((IkReal(-0.0100000000000000))*(x5546)*(x5556)))+(((px)*(sj0)))+(((IkReal(0.0100000000000000))*(cj0)*(cj5)*(x5564))));
evalcond[8]=((IkReal(0.433420000000000))+(((IkReal(0.0100000000000000))*(x5546)*(x5559)))+(((r12)*(sj0)*(x5549)))+(((x5549)*(x5561)))+(((IkReal(-1.00000000000000))*(x5566)*(x5568)))+(((IkReal(-1.00000000000000))*(py)*(x5552)))+(((IkReal(0.0100000000000000))*(x5546)*(x5566)))+(((IkReal(0.0100000000000000))*(sj0)*(x5548)))+(((x5560)*(x5561)))+(((IkReal(-1.00000000000000))*(sj0)*(x5558)*(x5564)))+(((IkReal(0.0100000000000000))*(cj5)*(sj0)*(x5564)))+(((IkReal(0.0100000000000000))*(cj0)*(cj5)*(x5563)))+(((IkReal(-1.00000000000000))*(cj0)*(x5558)*(x5563)))+(((IkReal(-1.00000000000000))*(x5559)*(x5568)))+(((IkReal(-1.00000000000000))*(px)*(x5543))));
if( IKabs(evalcond[0]) < 0.0000010000000000  && IKabs(evalcond[1]) < 0.0000010000000000  && IKabs(evalcond[2]) < 0.0000010000000000  && IKabs(evalcond[3]) < 0.0000010000000000  && IKabs(evalcond[4]) < 0.0000010000000000  && IKabs(evalcond[5]) < 0.0000010000000000  && IKabs(evalcond[6]) < 0.0000010000000000  && IKabs(evalcond[7]) < 0.0000010000000000  && IKabs(evalcond[8]) < 0.0000010000000000  )
{
{
IkReal j3array[1], cj3array[1], sj3array[1];
bool j3valid[1]={false};
_nj3 = 1;
IkReal x5570=((cj5)*(r02));
IkReal x5571=((cj0)*(sj5));
IkReal x5572=((r10)*(sj6));
IkReal x5573=((IkReal(1.00000000000000))*(cj6));
IkReal x5574=((sj0)*(sj5));
IkReal x5575=((cj5)*(r12));
IkReal x5576=((IkReal(1.00000000000000))*(r00)*(sj6));
if( IKabs(((((cj6)*(r11)*(x5571)))+(((IkReal(-1.00000000000000))*(cj0)*(x5575)))+(((x5571)*(x5572)))+(((IkReal(-1.00000000000000))*(x5574)*(x5576)))+(((IkReal(-1.00000000000000))*(r01)*(x5573)*(x5574)))+(((sj0)*(x5570))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(((((IkReal(-1.00000000000000))*(r11)*(x5573)*(x5574)))+(((IkReal(-1.00000000000000))*(x5571)*(x5576)))+(((IkReal(-1.00000000000000))*(r01)*(x5571)*(x5573)))+(((cj0)*(x5570)))+(((IkReal(-1.00000000000000))*(x5572)*(x5574)))+(((sj0)*(x5575))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(IKsqr(((((cj6)*(r11)*(x5571)))+(((IkReal(-1.00000000000000))*(cj0)*(x5575)))+(((x5571)*(x5572)))+(((IkReal(-1.00000000000000))*(x5574)*(x5576)))+(((IkReal(-1.00000000000000))*(r01)*(x5573)*(x5574)))+(((sj0)*(x5570)))))+IKsqr(((((IkReal(-1.00000000000000))*(r11)*(x5573)*(x5574)))+(((IkReal(-1.00000000000000))*(x5571)*(x5576)))+(((IkReal(-1.00000000000000))*(r01)*(x5571)*(x5573)))+(((cj0)*(x5570)))+(((IkReal(-1.00000000000000))*(x5572)*(x5574)))+(((sj0)*(x5575)))))-1) <= IKFAST_SINCOS_THRESH )
    continue;
j3array[0]=IKatan2(((((cj6)*(r11)*(x5571)))+(((IkReal(-1.00000000000000))*(cj0)*(x5575)))+(((x5571)*(x5572)))+(((IkReal(-1.00000000000000))*(x5574)*(x5576)))+(((IkReal(-1.00000000000000))*(r01)*(x5573)*(x5574)))+(((sj0)*(x5570)))), ((((IkReal(-1.00000000000000))*(r11)*(x5573)*(x5574)))+(((IkReal(-1.00000000000000))*(x5571)*(x5576)))+(((IkReal(-1.00000000000000))*(r01)*(x5571)*(x5573)))+(((cj0)*(x5570)))+(((IkReal(-1.00000000000000))*(x5572)*(x5574)))+(((sj0)*(x5575)))));
sj3array[0]=IKsin(j3array[0]);
cj3array[0]=IKcos(j3array[0]);
if( j3array[0] > IKPI )
{
    j3array[0]-=IK2PI;
}
else if( j3array[0] < -IKPI )
{    j3array[0]+=IK2PI;
}
j3valid[0] = true;
for(int ij3 = 0; ij3 < 1; ++ij3)
{
if( !j3valid[ij3] )
{
    continue;
}
_ij3[0] = ij3; _ij3[1] = -1;
for(int iij3 = ij3+1; iij3 < 1; ++iij3)
{
if( j3valid[iij3] && IKabs(cj3array[ij3]-cj3array[iij3]) < IKFAST_SOLUTION_THRESH && IKabs(sj3array[ij3]-sj3array[iij3]) < IKFAST_SOLUTION_THRESH )
{
    j3valid[iij3]=false; _ij3[1] = iij3; break; 
}
}
j3 = j3array[ij3]; cj3 = cj3array[ij3]; sj3 = sj3array[ij3];
{
IkReal evalcond[4];
IkReal x5577=IKsin(j3);
IkReal x5578=((sj0)*(sj5));
IkReal x5579=((r00)*(sj6));
IkReal x5580=((IkReal(1.00000000000000))*(cj4));
IkReal x5581=((cj6)*(sj0));
IkReal x5582=((r00)*(sj4));
IkReal x5583=((cj0)*(cj5));
IkReal x5584=((cj6)*(r01));
IkReal x5585=((cj5)*(sj0));
IkReal x5586=((cj0)*(sj5));
IkReal x5587=((cj6)*(r11));
IkReal x5588=((r10)*(sj6));
IkReal x5589=((r10)*(sj4));
IkReal x5590=((IkReal(1.00000000000000))*(IKcos(j3)));
IkReal x5591=((cj0)*(sj4)*(sj6));
IkReal x5592=((sj0)*(sj4)*(sj6));
IkReal x5593=((IkReal(1.00000000000000))*(cj0)*(cj6));
evalcond[0]=((((x5578)*(x5584)))+(((r12)*(x5583)))+(((IkReal(-1.00000000000000))*(x5586)*(x5587)))+(((x5578)*(x5579)))+(((IkReal(-1.00000000000000))*(x5586)*(x5588)))+(((IkReal(-1.00000000000000))*(r02)*(x5585)))+(x5577));
evalcond[1]=((((IkReal(-1.00000000000000))*(x5578)*(x5588)))+(((r02)*(x5583)))+(((r12)*(x5585)))+(((IkReal(-1.00000000000000))*(x5579)*(x5586)))+(((IkReal(-1.00000000000000))*(x5578)*(x5587)))+(((IkReal(-1.00000000000000))*(x5584)*(x5586)))+(((IkReal(-1.00000000000000))*(x5590))));
evalcond[2]=((((cj4)*(cj5)*(r01)*(x5581)))+(((cj4)*(r02)*(x5578)))+(((IkReal(-1.00000000000000))*(x5589)*(x5593)))+(((IkReal(-1.00000000000000))*(x5580)*(x5583)*(x5587)))+(((IkReal(-1.00000000000000))*(r12)*(x5580)*(x5586)))+(((cj4)*(x5579)*(x5585)))+(((r11)*(x5591)))+(((IkReal(-1.00000000000000))*(x5590)))+(((x5581)*(x5582)))+(((IkReal(-1.00000000000000))*(x5580)*(x5583)*(x5588)))+(((IkReal(-1.00000000000000))*(r01)*(x5592))));
evalcond[3]=((((IkReal(-1.00000000000000))*(r12)*(x5578)*(x5580)))+(((IkReal(-1.00000000000000))*(x5577)))+(((IkReal(-1.00000000000000))*(x5580)*(x5585)*(x5588)))+(((IkReal(-1.00000000000000))*(x5580)*(x5583)*(x5584)))+(((r01)*(x5591)))+(((IkReal(-1.00000000000000))*(x5579)*(x5580)*(x5583)))+(((IkReal(-1.00000000000000))*(cj5)*(r11)*(x5580)*(x5581)))+(((IkReal(-1.00000000000000))*(r02)*(x5580)*(x5586)))+(((IkReal(-1.00000000000000))*(x5582)*(x5593)))+(((IkReal(-1.00000000000000))*(x5581)*(x5589)))+(((r11)*(x5592))));
if( IKabs(evalcond[0]) > 0.000001  || IKabs(evalcond[1]) > 0.000001  || IKabs(evalcond[2]) > 0.000001  || IKabs(evalcond[3]) > 0.000001  )
{
continue;
}
}

{
std::vector<IkSingleDOFSolutionBase<IkReal> > vinfos(7);
vinfos[0].jointtype = 1;
vinfos[0].foffset = j0;
vinfos[0].indices[0] = _ij0[0];
vinfos[0].indices[1] = _ij0[1];
vinfos[0].maxsolutions = _nj0;
vinfos[1].jointtype = 1;
vinfos[1].foffset = j1;
vinfos[1].indices[0] = _ij1[0];
vinfos[1].indices[1] = _ij1[1];
vinfos[1].maxsolutions = _nj1;
vinfos[2].jointtype = 1;
vinfos[2].foffset = j2;
vinfos[2].indices[0] = _ij2[0];
vinfos[2].indices[1] = _ij2[1];
vinfos[2].maxsolutions = _nj2;
vinfos[3].jointtype = 1;
vinfos[3].foffset = j3;
vinfos[3].indices[0] = _ij3[0];
vinfos[3].indices[1] = _ij3[1];
vinfos[3].maxsolutions = _nj3;
vinfos[4].jointtype = 1;
vinfos[4].foffset = j4;
vinfos[4].indices[0] = _ij4[0];
vinfos[4].indices[1] = _ij4[1];
vinfos[4].maxsolutions = _nj4;
vinfos[5].jointtype = 1;
vinfos[5].foffset = j5;
vinfos[5].indices[0] = _ij5[0];
vinfos[5].indices[1] = _ij5[1];
vinfos[5].maxsolutions = _nj5;
vinfos[6].jointtype = 1;
vinfos[6].foffset = j6;
vinfos[6].indices[0] = _ij6[0];
vinfos[6].indices[1] = _ij6[1];
vinfos[6].maxsolutions = _nj6;
std::vector<int> vfree(0);
solutions.AddSolution(vinfos,vfree);
}
}
}

} else
{
IkReal x5594=((IkReal(1.00000000000000))*(cj0));
IkReal x5595=((cj4)*(sj6));
IkReal x5596=((sj0)*(sj4));
IkReal x5597=((cj5)*(sj6));
IkReal x5598=((sj4)*(sj5));
IkReal x5599=((r12)*(sj5));
IkReal x5600=((IkReal(0.374290000000000))*(cj5));
IkReal x5601=((r02)*(sj0));
IkReal x5602=((r20)*(sj4));
IkReal x5603=((IkReal(1.00000000000000))*(sj0));
IkReal x5604=((IkReal(1.00000000000000))*(cj5));
IkReal x5605=((cj0)*(r10));
IkReal x5606=((cj4)*(cj6));
IkReal x5607=((r00)*(sj0));
IkReal x5608=((cj6)*(r21));
IkReal x5609=((IkReal(0.374290000000000))*(sj5));
IkReal x5610=((cj0)*(r00));
IkReal x5611=((IkReal(0.0100000000000000))*(sj5));
IkReal x5612=((cj0)*(r02));
IkReal x5613=((cj5)*(sj4));
IkReal x5614=((cj6)*(r01));
IkReal x5615=((cj6)*(r11));
IkReal x5616=((r01)*(sj0));
IkReal x5617=((r10)*(sj0));
IkReal x5618=((IkReal(0.0100000000000000))*(cj5)*(cj6));
IkReal x5619=((sj6)*(x5609));
IkReal x5620=((cj0)*(cj6)*(x5609));
evalcond[0]=((IkReal(-3.14159265358979))+(IKfmod(j1, IkReal(6.28318530717959))));
evalcond[1]=((((sj5)*(x5608)))+(((IkReal(-1.00000000000000))*(r22)*(x5604)))+(((r20)*(sj5)*(sj6))));
evalcond[2]=((IkReal(-1.00000000000000))+(((x5597)*(x5602)))+(((x5608)*(x5613)))+(((r22)*(x5598)))+(((IkReal(-1.00000000000000))*(r20)*(x5606)))+(((r21)*(x5595))));
evalcond[3]=((((IkReal(-0.0100000000000000))*(r20)*(x5597)))+(((IkReal(-0.0100000000000000))*(cj5)*(x5608)))+(((IkReal(-1.00000000000000))*(r22)*(x5611)))+(((x5608)*(x5609)))+(pz)+(((IkReal(-1.00000000000000))*(r22)*(x5600)))+(((r20)*(x5619))));
evalcond[4]=((((cj5)*(r21)*(x5606)))+(((IkReal(-1.00000000000000))*(r21)*(sj4)*(sj6)))+(((cj4)*(r22)*(sj5)))+(((cj5)*(r20)*(x5595)))+(((cj6)*(x5602))));
evalcond[5]=((((IkReal(-1.00000000000000))*(x5594)*(x5613)*(x5615)))+(((x5595)*(x5616)))+(((IkReal(-1.00000000000000))*(r00)*(x5603)*(x5606)))+(((IkReal(-1.00000000000000))*(r11)*(x5594)*(x5595)))+(((cj5)*(x5596)*(x5614)))+(((IkReal(-1.00000000000000))*(r12)*(x5594)*(x5598)))+(((r02)*(sj5)*(x5596)))+(((IkReal(-1.00000000000000))*(r10)*(sj4)*(x5594)*(x5597)))+(((r00)*(x5596)*(x5597)))+(((x5605)*(x5606))));
evalcond[6]=((((IkReal(-1.00000000000000))*(r00)*(sj4)*(x5594)*(x5597)))+(((x5606)*(x5617)))+(((IkReal(-1.00000000000000))*(r02)*(x5594)*(x5598)))+(((IkReal(-1.00000000000000))*(x5596)*(x5604)*(x5615)))+(((IkReal(-1.00000000000000))*(x5596)*(x5599)))+(((IkReal(-1.00000000000000))*(r01)*(x5594)*(x5595)))+(((IkReal(-1.00000000000000))*(x5594)*(x5613)*(x5614)))+(((IkReal(-1.00000000000000))*(r11)*(x5595)*(x5603)))+(((x5606)*(x5610)))+(((IkReal(-1.00000000000000))*(r10)*(x5596)*(x5597))));
evalcond[7]=((IkReal(-0.0690000000000000))+(((cj0)*(r12)*(x5600)))+(((IkReal(-1.00000000000000))*(x5601)*(x5611)))+(((sj0)*(x5609)*(x5614)))+(((IkReal(-1.00000000000000))*(x5600)*(x5601)))+(((IkReal(0.0100000000000000))*(cj0)*(x5599)))+(((IkReal(-0.0100000000000000))*(cj5)*(sj0)*(x5614)))+(((IkReal(-0.0100000000000000))*(x5597)*(x5607)))+(((IkReal(0.0100000000000000))*(cj0)*(cj5)*(x5615)))+(((px)*(sj0)))+(((IkReal(-1.00000000000000))*(py)*(x5594)))+(((IkReal(0.0100000000000000))*(x5597)*(x5605)))+(((x5607)*(x5619)))+(((IkReal(-1.00000000000000))*(x5605)*(x5619)))+(((IkReal(-1.00000000000000))*(cj0)*(x5609)*(x5615))));
evalcond[8]=((IkReal(-0.295420000000000))+(((IkReal(0.0100000000000000))*(cj0)*(cj5)*(x5614)))+(((IkReal(-1.00000000000000))*(cj0)*(x5609)*(x5614)))+(((IkReal(0.0100000000000000))*(cj5)*(sj0)*(x5615)))+(((IkReal(0.0100000000000000))*(sj0)*(x5599)))+(((IkReal(-1.00000000000000))*(x5617)*(x5619)))+(((IkReal(-1.00000000000000))*(sj0)*(x5609)*(x5615)))+(((IkReal(0.0100000000000000))*(x5597)*(x5617)))+(((IkReal(-1.00000000000000))*(py)*(x5603)))+(((r12)*(sj0)*(x5600)))+(((IkReal(0.0100000000000000))*(x5597)*(x5610)))+(((x5611)*(x5612)))+(((x5600)*(x5612)))+(((IkReal(-1.00000000000000))*(x5610)*(x5619)))+(((IkReal(-1.00000000000000))*(px)*(x5594))));
if( IKabs(evalcond[0]) < 0.0000010000000000  && IKabs(evalcond[1]) < 0.0000010000000000  && IKabs(evalcond[2]) < 0.0000010000000000  && IKabs(evalcond[3]) < 0.0000010000000000  && IKabs(evalcond[4]) < 0.0000010000000000  && IKabs(evalcond[5]) < 0.0000010000000000  && IKabs(evalcond[6]) < 0.0000010000000000  && IKabs(evalcond[7]) < 0.0000010000000000  && IKabs(evalcond[8]) < 0.0000010000000000  )
{
{
IkReal j3array[1], cj3array[1], sj3array[1];
bool j3valid[1]={false};
_nj3 = 1;
IkReal x5621=((IkReal(1.00000000000000))*(cj5));
IkReal x5622=((r10)*(sj5)*(sj6));
IkReal x5623=((cj6)*(sj0)*(sj5));
IkReal x5624=((r00)*(sj5)*(sj6));
IkReal x5625=((cj0)*(cj6)*(sj5));
if( IKabs(((((r11)*(x5625)))+(((cj0)*(x5622)))+(((cj5)*(r02)*(sj0)))+(((IkReal(-1.00000000000000))*(sj0)*(x5624)))+(((IkReal(-1.00000000000000))*(r01)*(x5623)))+(((IkReal(-1.00000000000000))*(cj0)*(r12)*(x5621))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(((((IkReal(-1.00000000000000))*(r12)*(sj0)*(x5621)))+(((r11)*(x5623)))+(((sj0)*(x5622)))+(((cj0)*(x5624)))+(((IkReal(-1.00000000000000))*(cj0)*(r02)*(x5621)))+(((r01)*(x5625))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(IKsqr(((((r11)*(x5625)))+(((cj0)*(x5622)))+(((cj5)*(r02)*(sj0)))+(((IkReal(-1.00000000000000))*(sj0)*(x5624)))+(((IkReal(-1.00000000000000))*(r01)*(x5623)))+(((IkReal(-1.00000000000000))*(cj0)*(r12)*(x5621)))))+IKsqr(((((IkReal(-1.00000000000000))*(r12)*(sj0)*(x5621)))+(((r11)*(x5623)))+(((sj0)*(x5622)))+(((cj0)*(x5624)))+(((IkReal(-1.00000000000000))*(cj0)*(r02)*(x5621)))+(((r01)*(x5625)))))-1) <= IKFAST_SINCOS_THRESH )
    continue;
j3array[0]=IKatan2(((((r11)*(x5625)))+(((cj0)*(x5622)))+(((cj5)*(r02)*(sj0)))+(((IkReal(-1.00000000000000))*(sj0)*(x5624)))+(((IkReal(-1.00000000000000))*(r01)*(x5623)))+(((IkReal(-1.00000000000000))*(cj0)*(r12)*(x5621)))), ((((IkReal(-1.00000000000000))*(r12)*(sj0)*(x5621)))+(((r11)*(x5623)))+(((sj0)*(x5622)))+(((cj0)*(x5624)))+(((IkReal(-1.00000000000000))*(cj0)*(r02)*(x5621)))+(((r01)*(x5625)))));
sj3array[0]=IKsin(j3array[0]);
cj3array[0]=IKcos(j3array[0]);
if( j3array[0] > IKPI )
{
    j3array[0]-=IK2PI;
}
else if( j3array[0] < -IKPI )
{    j3array[0]+=IK2PI;
}
j3valid[0] = true;
for(int ij3 = 0; ij3 < 1; ++ij3)
{
if( !j3valid[ij3] )
{
    continue;
}
_ij3[0] = ij3; _ij3[1] = -1;
for(int iij3 = ij3+1; iij3 < 1; ++iij3)
{
if( j3valid[iij3] && IKabs(cj3array[ij3]-cj3array[iij3]) < IKFAST_SOLUTION_THRESH && IKabs(sj3array[ij3]-sj3array[iij3]) < IKFAST_SOLUTION_THRESH )
{
    j3valid[iij3]=false; _ij3[1] = iij3; break; 
}
}
j3 = j3array[ij3]; cj3 = cj3array[ij3]; sj3 = sj3array[ij3];
{
IkReal evalcond[4];
IkReal x5626=IKcos(j3);
IkReal x5627=IKsin(j3);
IkReal x5628=((sj0)*(sj5));
IkReal x5629=((r00)*(sj6));
IkReal x5630=((IkReal(1.00000000000000))*(cj4));
IkReal x5631=((cj6)*(sj0));
IkReal x5632=((r00)*(sj4));
IkReal x5633=((cj0)*(cj5));
IkReal x5634=((cj6)*(r01));
IkReal x5635=((cj5)*(sj0));
IkReal x5636=((cj0)*(sj5));
IkReal x5637=((cj6)*(r11));
IkReal x5638=((r10)*(sj6));
IkReal x5639=((r10)*(sj4));
IkReal x5640=((cj0)*(sj4)*(sj6));
IkReal x5641=((sj0)*(sj4)*(sj6));
IkReal x5642=((IkReal(1.00000000000000))*(cj0)*(cj6));
evalcond[0]=((((IkReal(-1.00000000000000))*(r02)*(x5635)))+(((x5628)*(x5629)))+(((IkReal(-1.00000000000000))*(x5636)*(x5638)))+(((r12)*(x5633)))+(((x5628)*(x5634)))+(x5627)+(((IkReal(-1.00000000000000))*(x5636)*(x5637))));
evalcond[1]=((((IkReal(-1.00000000000000))*(x5628)*(x5637)))+(((IkReal(-1.00000000000000))*(x5629)*(x5636)))+(((IkReal(-1.00000000000000))*(x5634)*(x5636)))+(((IkReal(-1.00000000000000))*(x5628)*(x5638)))+(((r02)*(x5633)))+(((r12)*(x5635)))+(x5626));
evalcond[2]=((((IkReal(-1.00000000000000))*(r01)*(x5641)))+(((IkReal(-1.00000000000000))*(r12)*(x5630)*(x5636)))+(((cj4)*(r02)*(x5628)))+(((IkReal(-1.00000000000000))*(x5630)*(x5633)*(x5638)))+(((cj4)*(cj5)*(r01)*(x5631)))+(((IkReal(-1.00000000000000))*(x5630)*(x5633)*(x5637)))+(((r11)*(x5640)))+(((cj4)*(x5629)*(x5635)))+(((x5631)*(x5632)))+(((IkReal(-1.00000000000000))*(x5639)*(x5642)))+(((IkReal(-1.00000000000000))*(x5626))));
evalcond[3]=((((IkReal(-1.00000000000000))*(x5630)*(x5635)*(x5638)))+(((r11)*(x5641)))+(((IkReal(-1.00000000000000))*(x5629)*(x5630)*(x5633)))+(((IkReal(-1.00000000000000))*(x5631)*(x5639)))+(((IkReal(-1.00000000000000))*(cj5)*(r11)*(x5630)*(x5631)))+(((IkReal(-1.00000000000000))*(x5630)*(x5633)*(x5634)))+(((r01)*(x5640)))+(((IkReal(-1.00000000000000))*(r12)*(x5628)*(x5630)))+(((IkReal(-1.00000000000000))*(x5632)*(x5642)))+(x5627)+(((IkReal(-1.00000000000000))*(r02)*(x5630)*(x5636))));
if( IKabs(evalcond[0]) > 0.000001  || IKabs(evalcond[1]) > 0.000001  || IKabs(evalcond[2]) > 0.000001  || IKabs(evalcond[3]) > 0.000001  )
{
continue;
}
}

{
std::vector<IkSingleDOFSolutionBase<IkReal> > vinfos(7);
vinfos[0].jointtype = 1;
vinfos[0].foffset = j0;
vinfos[0].indices[0] = _ij0[0];
vinfos[0].indices[1] = _ij0[1];
vinfos[0].maxsolutions = _nj0;
vinfos[1].jointtype = 1;
vinfos[1].foffset = j1;
vinfos[1].indices[0] = _ij1[0];
vinfos[1].indices[1] = _ij1[1];
vinfos[1].maxsolutions = _nj1;
vinfos[2].jointtype = 1;
vinfos[2].foffset = j2;
vinfos[2].indices[0] = _ij2[0];
vinfos[2].indices[1] = _ij2[1];
vinfos[2].maxsolutions = _nj2;
vinfos[3].jointtype = 1;
vinfos[3].foffset = j3;
vinfos[3].indices[0] = _ij3[0];
vinfos[3].indices[1] = _ij3[1];
vinfos[3].maxsolutions = _nj3;
vinfos[4].jointtype = 1;
vinfos[4].foffset = j4;
vinfos[4].indices[0] = _ij4[0];
vinfos[4].indices[1] = _ij4[1];
vinfos[4].maxsolutions = _nj4;
vinfos[5].jointtype = 1;
vinfos[5].foffset = j5;
vinfos[5].indices[0] = _ij5[0];
vinfos[5].indices[1] = _ij5[1];
vinfos[5].maxsolutions = _nj5;
vinfos[6].jointtype = 1;
vinfos[6].foffset = j6;
vinfos[6].indices[0] = _ij6[0];
vinfos[6].indices[1] = _ij6[1];
vinfos[6].maxsolutions = _nj6;
std::vector<int> vfree(0);
solutions.AddSolution(vinfos,vfree);
}
}
}

} else
{
if( 1 )
{
continue;

} else
{
}
}
}
}
}
}

} else
{
{
IkReal j3array[1], cj3array[1], sj3array[1];
bool j3valid[1]={false};
_nj3 = 1;
IkReal x5643=((cj5)*(r02));
IkReal x5644=((cj0)*(sj5));
IkReal x5645=((r10)*(sj6));
IkReal x5646=((IkReal(1.00000000000000))*(cj6));
IkReal x5647=((sj0)*(sj5));
IkReal x5648=((cj5)*(r12));
IkReal x5649=((IkReal(1.00000000000000))*(r00)*(sj6));
if( IKabs(((((cj6)*(r11)*(x5644)))+(((x5644)*(x5645)))+(((IkReal(-1.00000000000000))*(cj0)*(x5648)))+(((IkReal(-1.00000000000000))*(x5647)*(x5649)))+(((IkReal(-1.00000000000000))*(r01)*(x5646)*(x5647)))+(((sj0)*(x5643))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(((((IKabs(cj1) != 0)?((IkReal)1/(cj1)):(IkReal)1.0e30))*(((((sj0)*(x5648)))+(((IkReal(-1.00000000000000))*(x5645)*(x5647)))+(((cj0)*(x5643)))+(((IkReal(-1.00000000000000))*(x5644)*(x5649)))+(((IkReal(-1.00000000000000))*(r11)*(x5646)*(x5647)))+(((IkReal(-1.00000000000000))*(r01)*(x5644)*(x5646))))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(IKsqr(((((cj6)*(r11)*(x5644)))+(((x5644)*(x5645)))+(((IkReal(-1.00000000000000))*(cj0)*(x5648)))+(((IkReal(-1.00000000000000))*(x5647)*(x5649)))+(((IkReal(-1.00000000000000))*(r01)*(x5646)*(x5647)))+(((sj0)*(x5643)))))+IKsqr(((((IKabs(cj1) != 0)?((IkReal)1/(cj1)):(IkReal)1.0e30))*(((((sj0)*(x5648)))+(((IkReal(-1.00000000000000))*(x5645)*(x5647)))+(((cj0)*(x5643)))+(((IkReal(-1.00000000000000))*(x5644)*(x5649)))+(((IkReal(-1.00000000000000))*(r11)*(x5646)*(x5647)))+(((IkReal(-1.00000000000000))*(r01)*(x5644)*(x5646)))))))-1) <= IKFAST_SINCOS_THRESH )
    continue;
j3array[0]=IKatan2(((((cj6)*(r11)*(x5644)))+(((x5644)*(x5645)))+(((IkReal(-1.00000000000000))*(cj0)*(x5648)))+(((IkReal(-1.00000000000000))*(x5647)*(x5649)))+(((IkReal(-1.00000000000000))*(r01)*(x5646)*(x5647)))+(((sj0)*(x5643)))), ((((IKabs(cj1) != 0)?((IkReal)1/(cj1)):(IkReal)1.0e30))*(((((sj0)*(x5648)))+(((IkReal(-1.00000000000000))*(x5645)*(x5647)))+(((cj0)*(x5643)))+(((IkReal(-1.00000000000000))*(x5644)*(x5649)))+(((IkReal(-1.00000000000000))*(r11)*(x5646)*(x5647)))+(((IkReal(-1.00000000000000))*(r01)*(x5644)*(x5646)))))));
sj3array[0]=IKsin(j3array[0]);
cj3array[0]=IKcos(j3array[0]);
if( j3array[0] > IKPI )
{
    j3array[0]-=IK2PI;
}
else if( j3array[0] < -IKPI )
{    j3array[0]+=IK2PI;
}
j3valid[0] = true;
for(int ij3 = 0; ij3 < 1; ++ij3)
{
if( !j3valid[ij3] )
{
    continue;
}
_ij3[0] = ij3; _ij3[1] = -1;
for(int iij3 = ij3+1; iij3 < 1; ++iij3)
{
if( j3valid[iij3] && IKabs(cj3array[ij3]-cj3array[iij3]) < IKFAST_SOLUTION_THRESH && IKabs(sj3array[ij3]-sj3array[iij3]) < IKFAST_SOLUTION_THRESH )
{
    j3valid[iij3]=false; _ij3[1] = iij3; break; 
}
}
j3 = j3array[ij3]; cj3 = cj3array[ij3]; sj3 = sj3array[ij3];
{
IkReal evalcond[6];
IkReal x5650=IKsin(j3);
IkReal x5651=IKcos(j3);
IkReal x5652=((sj0)*(sj5));
IkReal x5653=((r00)*(sj6));
IkReal x5654=((IkReal(1.00000000000000))*(cj4));
IkReal x5655=((cj6)*(r01));
IkReal x5656=((cj0)*(cj5));
IkReal x5657=((cj5)*(sj0));
IkReal x5658=((cj6)*(r11));
IkReal x5659=((cj0)*(sj5));
IkReal x5660=((IkReal(1.00000000000000))*(cj1));
IkReal x5661=((cj6)*(sj4));
IkReal x5662=((IkReal(1.00000000000000))*(sj1));
IkReal x5663=((cj4)*(cj5));
IkReal x5664=((cj6)*(r21));
IkReal x5665=((r20)*(sj6));
IkReal x5666=((r10)*(sj6));
IkReal x5667=((IkReal(1.00000000000000))*(cj0));
IkReal x5668=((cj0)*(sj4)*(sj6));
IkReal x5669=((sj0)*(sj4)*(sj6));
evalcond[0]=((((sj5)*(x5664)))+(((IkReal(-1.00000000000000))*(x5651)*(x5662)))+(((IkReal(-1.00000000000000))*(cj5)*(r22)))+(((sj5)*(x5665))));
evalcond[1]=((((IkReal(-1.00000000000000))*(r21)*(sj4)*(sj6)))+(((cj4)*(r22)*(sj5)))+(((r20)*(x5661)))+(((x5663)*(x5665)))+(((IkReal(-1.00000000000000))*(x5650)*(x5662)))+(((x5663)*(x5664))));
evalcond[2]=((((x5652)*(x5653)))+(((r12)*(x5656)))+(((x5652)*(x5655)))+(((IkReal(-1.00000000000000))*(x5659)*(x5666)))+(((IkReal(-1.00000000000000))*(x5658)*(x5659)))+(x5650)+(((IkReal(-1.00000000000000))*(r02)*(x5657))));
evalcond[3]=((((r12)*(x5657)))+(((IkReal(-1.00000000000000))*(x5651)*(x5660)))+(((r02)*(x5656)))+(((IkReal(-1.00000000000000))*(x5655)*(x5659)))+(((IkReal(-1.00000000000000))*(x5652)*(x5666)))+(((IkReal(-1.00000000000000))*(x5652)*(x5658)))+(((IkReal(-1.00000000000000))*(x5653)*(x5659))));
evalcond[4]=((((IkReal(-1.00000000000000))*(r01)*(x5669)))+(((cj4)*(x5655)*(x5657)))+(((IkReal(-1.00000000000000))*(x5654)*(x5656)*(x5658)))+(((r11)*(x5668)))+(((cj4)*(r02)*(x5652)))+(((IkReal(-1.00000000000000))*(x5654)*(x5656)*(x5666)))+(((IkReal(-1.00000000000000))*(r10)*(x5661)*(x5667)))+(((r00)*(sj0)*(x5661)))+(((cj4)*(x5653)*(x5657)))+(((IkReal(-1.00000000000000))*(r12)*(x5654)*(x5659)))+(((IkReal(-1.00000000000000))*(x5651))));
evalcond[5]=((((IkReal(-1.00000000000000))*(r02)*(x5654)*(x5659)))+(((IkReal(-1.00000000000000))*(x5650)*(x5660)))+(((r11)*(x5669)))+(((IkReal(-1.00000000000000))*(x5653)*(x5654)*(x5656)))+(((IkReal(-1.00000000000000))*(r12)*(x5652)*(x5654)))+(((IkReal(-1.00000000000000))*(r00)*(x5661)*(x5667)))+(((IkReal(-1.00000000000000))*(x5654)*(x5657)*(x5658)))+(((IkReal(-1.00000000000000))*(x5654)*(x5655)*(x5656)))+(((IkReal(-1.00000000000000))*(r10)*(sj0)*(x5661)))+(((IkReal(-1.00000000000000))*(x5654)*(x5657)*(x5666)))+(((r01)*(x5668))));
if( IKabs(evalcond[0]) > 0.000001  || IKabs(evalcond[1]) > 0.000001  || IKabs(evalcond[2]) > 0.000001  || IKabs(evalcond[3]) > 0.000001  || IKabs(evalcond[4]) > 0.000001  || IKabs(evalcond[5]) > 0.000001  )
{
continue;
}
}

{
std::vector<IkSingleDOFSolutionBase<IkReal> > vinfos(7);
vinfos[0].jointtype = 1;
vinfos[0].foffset = j0;
vinfos[0].indices[0] = _ij0[0];
vinfos[0].indices[1] = _ij0[1];
vinfos[0].maxsolutions = _nj0;
vinfos[1].jointtype = 1;
vinfos[1].foffset = j1;
vinfos[1].indices[0] = _ij1[0];
vinfos[1].indices[1] = _ij1[1];
vinfos[1].maxsolutions = _nj1;
vinfos[2].jointtype = 1;
vinfos[2].foffset = j2;
vinfos[2].indices[0] = _ij2[0];
vinfos[2].indices[1] = _ij2[1];
vinfos[2].maxsolutions = _nj2;
vinfos[3].jointtype = 1;
vinfos[3].foffset = j3;
vinfos[3].indices[0] = _ij3[0];
vinfos[3].indices[1] = _ij3[1];
vinfos[3].maxsolutions = _nj3;
vinfos[4].jointtype = 1;
vinfos[4].foffset = j4;
vinfos[4].indices[0] = _ij4[0];
vinfos[4].indices[1] = _ij4[1];
vinfos[4].maxsolutions = _nj4;
vinfos[5].jointtype = 1;
vinfos[5].foffset = j5;
vinfos[5].indices[0] = _ij5[0];
vinfos[5].indices[1] = _ij5[1];
vinfos[5].maxsolutions = _nj5;
vinfos[6].jointtype = 1;
vinfos[6].foffset = j6;
vinfos[6].indices[0] = _ij6[0];
vinfos[6].indices[1] = _ij6[1];
vinfos[6].maxsolutions = _nj6;
std::vector<int> vfree(0);
solutions.AddSolution(vinfos,vfree);
}
}
}

}

}

} else
{
{
IkReal j3array[1], cj3array[1], sj3array[1];
bool j3valid[1]={false};
_nj3 = 1;
IkReal x5670=((sj5)*(sj6));
IkReal x5671=((IkReal(1.00000000000000))*(sj0));
IkReal x5672=((cj6)*(sj5));
IkReal x5673=((IkReal(1.00000000000000))*(cj5));
if( IKabs(((((IkReal(-1.00000000000000))*(r00)*(x5670)*(x5671)))+(((cj0)*(r10)*(x5670)))+(((cj0)*(r11)*(x5672)))+(((cj5)*(r02)*(sj0)))+(((IkReal(-1.00000000000000))*(r01)*(x5671)*(x5672)))+(((IkReal(-1.00000000000000))*(cj0)*(r12)*(x5673))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(((((IKabs(sj1) != 0)?((IkReal)1/(sj1)):(IkReal)1.0e30))*(((((r21)*(x5672)))+(((r20)*(x5670)))+(((IkReal(-1.00000000000000))*(r22)*(x5673))))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(IKsqr(((((IkReal(-1.00000000000000))*(r00)*(x5670)*(x5671)))+(((cj0)*(r10)*(x5670)))+(((cj0)*(r11)*(x5672)))+(((cj5)*(r02)*(sj0)))+(((IkReal(-1.00000000000000))*(r01)*(x5671)*(x5672)))+(((IkReal(-1.00000000000000))*(cj0)*(r12)*(x5673)))))+IKsqr(((((IKabs(sj1) != 0)?((IkReal)1/(sj1)):(IkReal)1.0e30))*(((((r21)*(x5672)))+(((r20)*(x5670)))+(((IkReal(-1.00000000000000))*(r22)*(x5673)))))))-1) <= IKFAST_SINCOS_THRESH )
    continue;
j3array[0]=IKatan2(((((IkReal(-1.00000000000000))*(r00)*(x5670)*(x5671)))+(((cj0)*(r10)*(x5670)))+(((cj0)*(r11)*(x5672)))+(((cj5)*(r02)*(sj0)))+(((IkReal(-1.00000000000000))*(r01)*(x5671)*(x5672)))+(((IkReal(-1.00000000000000))*(cj0)*(r12)*(x5673)))), ((((IKabs(sj1) != 0)?((IkReal)1/(sj1)):(IkReal)1.0e30))*(((((r21)*(x5672)))+(((r20)*(x5670)))+(((IkReal(-1.00000000000000))*(r22)*(x5673)))))));
sj3array[0]=IKsin(j3array[0]);
cj3array[0]=IKcos(j3array[0]);
if( j3array[0] > IKPI )
{
    j3array[0]-=IK2PI;
}
else if( j3array[0] < -IKPI )
{    j3array[0]+=IK2PI;
}
j3valid[0] = true;
for(int ij3 = 0; ij3 < 1; ++ij3)
{
if( !j3valid[ij3] )
{
    continue;
}
_ij3[0] = ij3; _ij3[1] = -1;
for(int iij3 = ij3+1; iij3 < 1; ++iij3)
{
if( j3valid[iij3] && IKabs(cj3array[ij3]-cj3array[iij3]) < IKFAST_SOLUTION_THRESH && IKabs(sj3array[ij3]-sj3array[iij3]) < IKFAST_SOLUTION_THRESH )
{
    j3valid[iij3]=false; _ij3[1] = iij3; break; 
}
}
j3 = j3array[ij3]; cj3 = cj3array[ij3]; sj3 = sj3array[ij3];
{
IkReal evalcond[6];
IkReal x5674=IKsin(j3);
IkReal x5675=IKcos(j3);
IkReal x5676=((sj0)*(sj5));
IkReal x5677=((r00)*(sj6));
IkReal x5678=((IkReal(1.00000000000000))*(cj4));
IkReal x5679=((cj6)*(r01));
IkReal x5680=((cj0)*(cj5));
IkReal x5681=((cj5)*(sj0));
IkReal x5682=((cj6)*(r11));
IkReal x5683=((cj0)*(sj5));
IkReal x5684=((IkReal(1.00000000000000))*(cj1));
IkReal x5685=((cj6)*(sj4));
IkReal x5686=((IkReal(1.00000000000000))*(sj1));
IkReal x5687=((cj4)*(cj5));
IkReal x5688=((cj6)*(r21));
IkReal x5689=((r20)*(sj6));
IkReal x5690=((r10)*(sj6));
IkReal x5691=((IkReal(1.00000000000000))*(cj0));
IkReal x5692=((cj0)*(sj4)*(sj6));
IkReal x5693=((sj0)*(sj4)*(sj6));
evalcond[0]=((((IkReal(-1.00000000000000))*(x5675)*(x5686)))+(((IkReal(-1.00000000000000))*(cj5)*(r22)))+(((sj5)*(x5689)))+(((sj5)*(x5688))));
evalcond[1]=((((IkReal(-1.00000000000000))*(r21)*(sj4)*(sj6)))+(((x5687)*(x5689)))+(((IkReal(-1.00000000000000))*(x5674)*(x5686)))+(((r20)*(x5685)))+(((cj4)*(r22)*(sj5)))+(((x5687)*(x5688))));
evalcond[2]=((x5674)+(((IkReal(-1.00000000000000))*(x5682)*(x5683)))+(((IkReal(-1.00000000000000))*(r02)*(x5681)))+(((x5676)*(x5677)))+(((IkReal(-1.00000000000000))*(x5683)*(x5690)))+(((x5676)*(x5679)))+(((r12)*(x5680))));
evalcond[3]=((((r02)*(x5680)))+(((IkReal(-1.00000000000000))*(x5675)*(x5684)))+(((IkReal(-1.00000000000000))*(x5679)*(x5683)))+(((IkReal(-1.00000000000000))*(x5676)*(x5690)))+(((r12)*(x5681)))+(((IkReal(-1.00000000000000))*(x5677)*(x5683)))+(((IkReal(-1.00000000000000))*(x5676)*(x5682))));
evalcond[4]=((((IkReal(-1.00000000000000))*(x5675)))+(((cj4)*(x5677)*(x5681)))+(((IkReal(-1.00000000000000))*(r01)*(x5693)))+(((r00)*(sj0)*(x5685)))+(((cj4)*(x5679)*(x5681)))+(((IkReal(-1.00000000000000))*(x5678)*(x5680)*(x5682)))+(((cj4)*(r02)*(x5676)))+(((IkReal(-1.00000000000000))*(r12)*(x5678)*(x5683)))+(((IkReal(-1.00000000000000))*(r10)*(x5685)*(x5691)))+(((r11)*(x5692)))+(((IkReal(-1.00000000000000))*(x5678)*(x5680)*(x5690))));
evalcond[5]=((((r01)*(x5692)))+(((IkReal(-1.00000000000000))*(x5674)*(x5684)))+(((IkReal(-1.00000000000000))*(r10)*(sj0)*(x5685)))+(((r11)*(x5693)))+(((IkReal(-1.00000000000000))*(r02)*(x5678)*(x5683)))+(((IkReal(-1.00000000000000))*(x5678)*(x5681)*(x5690)))+(((IkReal(-1.00000000000000))*(r12)*(x5676)*(x5678)))+(((IkReal(-1.00000000000000))*(x5677)*(x5678)*(x5680)))+(((IkReal(-1.00000000000000))*(x5678)*(x5681)*(x5682)))+(((IkReal(-1.00000000000000))*(x5678)*(x5679)*(x5680)))+(((IkReal(-1.00000000000000))*(r00)*(x5685)*(x5691))));
if( IKabs(evalcond[0]) > 0.000001  || IKabs(evalcond[1]) > 0.000001  || IKabs(evalcond[2]) > 0.000001  || IKabs(evalcond[3]) > 0.000001  || IKabs(evalcond[4]) > 0.000001  || IKabs(evalcond[5]) > 0.000001  )
{
continue;
}
}

{
std::vector<IkSingleDOFSolutionBase<IkReal> > vinfos(7);
vinfos[0].jointtype = 1;
vinfos[0].foffset = j0;
vinfos[0].indices[0] = _ij0[0];
vinfos[0].indices[1] = _ij0[1];
vinfos[0].maxsolutions = _nj0;
vinfos[1].jointtype = 1;
vinfos[1].foffset = j1;
vinfos[1].indices[0] = _ij1[0];
vinfos[1].indices[1] = _ij1[1];
vinfos[1].maxsolutions = _nj1;
vinfos[2].jointtype = 1;
vinfos[2].foffset = j2;
vinfos[2].indices[0] = _ij2[0];
vinfos[2].indices[1] = _ij2[1];
vinfos[2].maxsolutions = _nj2;
vinfos[3].jointtype = 1;
vinfos[3].foffset = j3;
vinfos[3].indices[0] = _ij3[0];
vinfos[3].indices[1] = _ij3[1];
vinfos[3].maxsolutions = _nj3;
vinfos[4].jointtype = 1;
vinfos[4].foffset = j4;
vinfos[4].indices[0] = _ij4[0];
vinfos[4].indices[1] = _ij4[1];
vinfos[4].maxsolutions = _nj4;
vinfos[5].jointtype = 1;
vinfos[5].foffset = j5;
vinfos[5].indices[0] = _ij5[0];
vinfos[5].indices[1] = _ij5[1];
vinfos[5].maxsolutions = _nj5;
vinfos[6].jointtype = 1;
vinfos[6].foffset = j6;
vinfos[6].indices[0] = _ij6[0];
vinfos[6].indices[1] = _ij6[1];
vinfos[6].maxsolutions = _nj6;
std::vector<int> vfree(0);
solutions.AddSolution(vinfos,vfree);
}
}
}

}

}

} else
{
{
IkReal j3array[1], cj3array[1], sj3array[1];
bool j3valid[1]={false};
_nj3 = 1;
IkReal x5694=((r20)*(sj6));
IkReal x5695=((cj4)*(cj5));
IkReal x5696=((cj6)*(r21));
if( IKabs(((gconst30)*(((((IkReal(-1.00000000000000))*(r21)*(sj4)*(sj6)))+(((x5695)*(x5696)))+(((cj6)*(r20)*(sj4)))+(((cj4)*(r22)*(sj5)))+(((x5694)*(x5695))))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(((gconst30)*(((((sj5)*(x5694)))+(((IkReal(-1.00000000000000))*(cj5)*(r22)))+(((sj5)*(x5696))))))) < IKFAST_ATAN2_MAGTHRESH )
    continue;
j3array[0]=IKatan2(((gconst30)*(((((IkReal(-1.00000000000000))*(r21)*(sj4)*(sj6)))+(((x5695)*(x5696)))+(((cj6)*(r20)*(sj4)))+(((cj4)*(r22)*(sj5)))+(((x5694)*(x5695)))))), ((gconst30)*(((((sj5)*(x5694)))+(((IkReal(-1.00000000000000))*(cj5)*(r22)))+(((sj5)*(x5696)))))));
sj3array[0]=IKsin(j3array[0]);
cj3array[0]=IKcos(j3array[0]);
if( j3array[0] > IKPI )
{
    j3array[0]-=IK2PI;
}
else if( j3array[0] < -IKPI )
{    j3array[0]+=IK2PI;
}
j3valid[0] = true;
for(int ij3 = 0; ij3 < 1; ++ij3)
{
if( !j3valid[ij3] )
{
    continue;
}
_ij3[0] = ij3; _ij3[1] = -1;
for(int iij3 = ij3+1; iij3 < 1; ++iij3)
{
if( j3valid[iij3] && IKabs(cj3array[ij3]-cj3array[iij3]) < IKFAST_SOLUTION_THRESH && IKabs(sj3array[ij3]-sj3array[iij3]) < IKFAST_SOLUTION_THRESH )
{
    j3valid[iij3]=false; _ij3[1] = iij3; break; 
}
}
j3 = j3array[ij3]; cj3 = cj3array[ij3]; sj3 = sj3array[ij3];
{
IkReal evalcond[6];
IkReal x5697=IKsin(j3);
IkReal x5698=IKcos(j3);
IkReal x5699=((sj0)*(sj5));
IkReal x5700=((r00)*(sj6));
IkReal x5701=((IkReal(1.00000000000000))*(cj4));
IkReal x5702=((cj6)*(r01));
IkReal x5703=((cj0)*(cj5));
IkReal x5704=((cj5)*(sj0));
IkReal x5705=((cj6)*(r11));
IkReal x5706=((cj0)*(sj5));
IkReal x5707=((IkReal(1.00000000000000))*(cj1));
IkReal x5708=((cj6)*(sj4));
IkReal x5709=((IkReal(1.00000000000000))*(sj1));
IkReal x5710=((cj4)*(cj5));
IkReal x5711=((cj6)*(r21));
IkReal x5712=((r20)*(sj6));
IkReal x5713=((r10)*(sj6));
IkReal x5714=((IkReal(1.00000000000000))*(cj0));
IkReal x5715=((cj0)*(sj4)*(sj6));
IkReal x5716=((sj0)*(sj4)*(sj6));
evalcond[0]=((((sj5)*(x5711)))+(((IkReal(-1.00000000000000))*(x5698)*(x5709)))+(((IkReal(-1.00000000000000))*(cj5)*(r22)))+(((sj5)*(x5712))));
evalcond[1]=((((IkReal(-1.00000000000000))*(r21)*(sj4)*(sj6)))+(((cj4)*(r22)*(sj5)))+(((x5710)*(x5711)))+(((r20)*(x5708)))+(((IkReal(-1.00000000000000))*(x5697)*(x5709)))+(((x5710)*(x5712))));
evalcond[2]=((x5697)+(((x5699)*(x5702)))+(((x5699)*(x5700)))+(((IkReal(-1.00000000000000))*(r02)*(x5704)))+(((IkReal(-1.00000000000000))*(x5706)*(x5713)))+(((IkReal(-1.00000000000000))*(x5705)*(x5706)))+(((r12)*(x5703))));
evalcond[3]=((((IkReal(-1.00000000000000))*(x5702)*(x5706)))+(((r02)*(x5703)))+(((IkReal(-1.00000000000000))*(x5700)*(x5706)))+(((IkReal(-1.00000000000000))*(x5699)*(x5705)))+(((IkReal(-1.00000000000000))*(x5698)*(x5707)))+(((r12)*(x5704)))+(((IkReal(-1.00000000000000))*(x5699)*(x5713))));
evalcond[4]=((((IkReal(-1.00000000000000))*(x5701)*(x5703)*(x5713)))+(((IkReal(-1.00000000000000))*(r01)*(x5716)))+(((IkReal(-1.00000000000000))*(x5698)))+(((IkReal(-1.00000000000000))*(r12)*(x5701)*(x5706)))+(((IkReal(-1.00000000000000))*(r10)*(x5708)*(x5714)))+(((r00)*(sj0)*(x5708)))+(((r11)*(x5715)))+(((cj4)*(x5702)*(x5704)))+(((cj4)*(x5700)*(x5704)))+(((IkReal(-1.00000000000000))*(x5701)*(x5703)*(x5705)))+(((cj4)*(r02)*(x5699))));
evalcond[5]=((((IkReal(-1.00000000000000))*(x5701)*(x5702)*(x5703)))+(((r01)*(x5715)))+(((IkReal(-1.00000000000000))*(x5700)*(x5701)*(x5703)))+(((IkReal(-1.00000000000000))*(r10)*(sj0)*(x5708)))+(((IkReal(-1.00000000000000))*(r00)*(x5708)*(x5714)))+(((IkReal(-1.00000000000000))*(x5697)*(x5707)))+(((IkReal(-1.00000000000000))*(r12)*(x5699)*(x5701)))+(((r11)*(x5716)))+(((IkReal(-1.00000000000000))*(x5701)*(x5704)*(x5705)))+(((IkReal(-1.00000000000000))*(x5701)*(x5704)*(x5713)))+(((IkReal(-1.00000000000000))*(r02)*(x5701)*(x5706))));
if( IKabs(evalcond[0]) > 0.000001  || IKabs(evalcond[1]) > 0.000001  || IKabs(evalcond[2]) > 0.000001  || IKabs(evalcond[3]) > 0.000001  || IKabs(evalcond[4]) > 0.000001  || IKabs(evalcond[5]) > 0.000001  )
{
continue;
}
}

{
std::vector<IkSingleDOFSolutionBase<IkReal> > vinfos(7);
vinfos[0].jointtype = 1;
vinfos[0].foffset = j0;
vinfos[0].indices[0] = _ij0[0];
vinfos[0].indices[1] = _ij0[1];
vinfos[0].maxsolutions = _nj0;
vinfos[1].jointtype = 1;
vinfos[1].foffset = j1;
vinfos[1].indices[0] = _ij1[0];
vinfos[1].indices[1] = _ij1[1];
vinfos[1].maxsolutions = _nj1;
vinfos[2].jointtype = 1;
vinfos[2].foffset = j2;
vinfos[2].indices[0] = _ij2[0];
vinfos[2].indices[1] = _ij2[1];
vinfos[2].maxsolutions = _nj2;
vinfos[3].jointtype = 1;
vinfos[3].foffset = j3;
vinfos[3].indices[0] = _ij3[0];
vinfos[3].indices[1] = _ij3[1];
vinfos[3].maxsolutions = _nj3;
vinfos[4].jointtype = 1;
vinfos[4].foffset = j4;
vinfos[4].indices[0] = _ij4[0];
vinfos[4].indices[1] = _ij4[1];
vinfos[4].maxsolutions = _nj4;
vinfos[5].jointtype = 1;
vinfos[5].foffset = j5;
vinfos[5].indices[0] = _ij5[0];
vinfos[5].indices[1] = _ij5[1];
vinfos[5].maxsolutions = _nj5;
vinfos[6].jointtype = 1;
vinfos[6].foffset = j6;
vinfos[6].indices[0] = _ij6[0];
vinfos[6].indices[1] = _ij6[1];
vinfos[6].maxsolutions = _nj6;
std::vector<int> vfree(0);
solutions.AddSolution(vinfos,vfree);
}
}
}

}

}
}
}

}

}

} else
{
if( 1 )
{
continue;

} else
{
}
}
}
}

} else
{
{
IkReal j3array[1], cj3array[1], sj3array[1];
bool j3valid[1]={false};
_nj3 = 1;
IkReal x5717=(cj1)*(cj1);
IkReal x5718=(sj1)*(sj1);
IkReal x5719=((r00)*(sj6));
IkReal x5720=((cj6)*(r01));
IkReal x5721=((IkReal(1.00000000000000))*(cj1));
IkReal x5722=((cj5)*(r22));
IkReal x5723=((sj5)*(sj6));
IkReal x5724=((r10)*(sj0));
IkReal x5725=((cj1)*(cj5));
IkReal x5726=((cj0)*(r02));
IkReal x5727=((r12)*(sj0));
IkReal x5728=((IkReal(1.00000000000000))*(sj1));
IkReal x5729=((cj6)*(sj5));
IkReal x5730=((cj0)*(sj5));
IkReal x5731=((r11)*(sj0));
IkReal x5732=((sj1)*(x5730));
if( IKabs(((((IKabs(((((cj2)*(x5717)))+(((cj2)*(x5718))))) != 0)?((IkReal)1/(((((cj2)*(x5717)))+(((cj2)*(x5718)))))):(IkReal)1.0e30))*(((((x5720)*(x5732)))+(((sj1)*(x5729)*(x5731)))+(((IkReal(-1.00000000000000))*(cj5)*(x5726)*(x5728)))+(((IkReal(-1.00000000000000))*(cj5)*(x5727)*(x5728)))+(((cj1)*(r21)*(x5729)))+(((cj1)*(r20)*(x5723)))+(((x5719)*(x5732)))+(((sj1)*(x5723)*(x5724)))+(((IkReal(-1.00000000000000))*(x5721)*(x5722))))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(((((IKabs(((x5718)+(x5717))) != 0)?((IkReal)1/(((x5718)+(x5717)))):(IkReal)1.0e30))*(((((x5725)*(x5726)))+(((IkReal(-1.00000000000000))*(x5721)*(x5723)*(x5724)))+(((IkReal(-1.00000000000000))*(x5719)*(x5721)*(x5730)))+(((x5725)*(x5727)))+(((IkReal(-1.00000000000000))*(x5722)*(x5728)))+(((r20)*(sj1)*(x5723)))+(((r21)*(sj1)*(x5729)))+(((IkReal(-1.00000000000000))*(x5720)*(x5721)*(x5730)))+(((IkReal(-1.00000000000000))*(x5721)*(x5729)*(x5731))))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(IKsqr(((((IKabs(((((cj2)*(x5717)))+(((cj2)*(x5718))))) != 0)?((IkReal)1/(((((cj2)*(x5717)))+(((cj2)*(x5718)))))):(IkReal)1.0e30))*(((((x5720)*(x5732)))+(((sj1)*(x5729)*(x5731)))+(((IkReal(-1.00000000000000))*(cj5)*(x5726)*(x5728)))+(((IkReal(-1.00000000000000))*(cj5)*(x5727)*(x5728)))+(((cj1)*(r21)*(x5729)))+(((cj1)*(r20)*(x5723)))+(((x5719)*(x5732)))+(((sj1)*(x5723)*(x5724)))+(((IkReal(-1.00000000000000))*(x5721)*(x5722)))))))+IKsqr(((((IKabs(((x5718)+(x5717))) != 0)?((IkReal)1/(((x5718)+(x5717)))):(IkReal)1.0e30))*(((((x5725)*(x5726)))+(((IkReal(-1.00000000000000))*(x5721)*(x5723)*(x5724)))+(((IkReal(-1.00000000000000))*(x5719)*(x5721)*(x5730)))+(((x5725)*(x5727)))+(((IkReal(-1.00000000000000))*(x5722)*(x5728)))+(((r20)*(sj1)*(x5723)))+(((r21)*(sj1)*(x5729)))+(((IkReal(-1.00000000000000))*(x5720)*(x5721)*(x5730)))+(((IkReal(-1.00000000000000))*(x5721)*(x5729)*(x5731)))))))-1) <= IKFAST_SINCOS_THRESH )
    continue;
j3array[0]=IKatan2(((((IKabs(((((cj2)*(x5717)))+(((cj2)*(x5718))))) != 0)?((IkReal)1/(((((cj2)*(x5717)))+(((cj2)*(x5718)))))):(IkReal)1.0e30))*(((((x5720)*(x5732)))+(((sj1)*(x5729)*(x5731)))+(((IkReal(-1.00000000000000))*(cj5)*(x5726)*(x5728)))+(((IkReal(-1.00000000000000))*(cj5)*(x5727)*(x5728)))+(((cj1)*(r21)*(x5729)))+(((cj1)*(r20)*(x5723)))+(((x5719)*(x5732)))+(((sj1)*(x5723)*(x5724)))+(((IkReal(-1.00000000000000))*(x5721)*(x5722)))))), ((((IKabs(((x5718)+(x5717))) != 0)?((IkReal)1/(((x5718)+(x5717)))):(IkReal)1.0e30))*(((((x5725)*(x5726)))+(((IkReal(-1.00000000000000))*(x5721)*(x5723)*(x5724)))+(((IkReal(-1.00000000000000))*(x5719)*(x5721)*(x5730)))+(((x5725)*(x5727)))+(((IkReal(-1.00000000000000))*(x5722)*(x5728)))+(((r20)*(sj1)*(x5723)))+(((r21)*(sj1)*(x5729)))+(((IkReal(-1.00000000000000))*(x5720)*(x5721)*(x5730)))+(((IkReal(-1.00000000000000))*(x5721)*(x5729)*(x5731)))))));
sj3array[0]=IKsin(j3array[0]);
cj3array[0]=IKcos(j3array[0]);
if( j3array[0] > IKPI )
{
    j3array[0]-=IK2PI;
}
else if( j3array[0] < -IKPI )
{    j3array[0]+=IK2PI;
}
j3valid[0] = true;
for(int ij3 = 0; ij3 < 1; ++ij3)
{
if( !j3valid[ij3] )
{
    continue;
}
_ij3[0] = ij3; _ij3[1] = -1;
for(int iij3 = ij3+1; iij3 < 1; ++iij3)
{
if( j3valid[iij3] && IKabs(cj3array[ij3]-cj3array[iij3]) < IKFAST_SOLUTION_THRESH && IKabs(sj3array[ij3]-sj3array[iij3]) < IKFAST_SOLUTION_THRESH )
{
    j3valid[iij3]=false; _ij3[1] = iij3; break; 
}
}
j3 = j3array[ij3]; cj3 = cj3array[ij3]; sj3 = sj3array[ij3];
{
IkReal evalcond[3];
IkReal x5733=IKsin(j3);
IkReal x5734=IKcos(j3);
IkReal x5735=((sj5)*(sj6));
IkReal x5736=((cj0)*(cj5));
IkReal x5737=((IkReal(1.00000000000000))*(cj0));
IkReal x5738=((IkReal(1.00000000000000))*(sj0));
IkReal x5739=((IkReal(1.00000000000000))*(x5734));
IkReal x5740=((IkReal(1.00000000000000))*(x5733));
IkReal x5741=((cj6)*(r01)*(sj5));
IkReal x5742=((cj6)*(r11)*(sj5));
evalcond[0]=((((cj6)*(r21)*(sj5)))+(((IkReal(-1.00000000000000))*(cj5)*(r22)))+(((IkReal(-1.00000000000000))*(sj1)*(x5739)))+(((IkReal(-1.00000000000000))*(cj1)*(cj2)*(x5740)))+(((r20)*(x5735))));
evalcond[1]=((((IkReal(-1.00000000000000))*(x5737)*(x5742)))+(((IkReal(-1.00000000000000))*(cj5)*(r02)*(x5738)))+(((r12)*(x5736)))+(((IkReal(-1.00000000000000))*(r10)*(x5735)*(x5737)))+(((sj0)*(x5741)))+(((IkReal(-1.00000000000000))*(sj2)*(x5740)))+(((r00)*(sj0)*(x5735))));
evalcond[2]=((((cj2)*(sj1)*(x5733)))+(((IkReal(-1.00000000000000))*(r00)*(x5735)*(x5737)))+(((IkReal(-1.00000000000000))*(x5738)*(x5742)))+(((cj5)*(r12)*(sj0)))+(((IkReal(-1.00000000000000))*(x5737)*(x5741)))+(((r02)*(x5736)))+(((IkReal(-1.00000000000000))*(r10)*(x5735)*(x5738)))+(((IkReal(-1.00000000000000))*(cj1)*(x5739))));
if( IKabs(evalcond[0]) > 0.000001  || IKabs(evalcond[1]) > 0.000001  || IKabs(evalcond[2]) > 0.000001  )
{
continue;
}
}

{
IkReal dummyeval[1];
IkReal gconst2;
IkReal x5743=(r21)*(r21);
IkReal x5744=(cj5)*(cj5);
IkReal x5745=(sj6)*(sj6);
IkReal x5746=(cj6)*(cj6);
IkReal x5747=(r20)*(r20);
IkReal x5748=((cj6)*(r21));
IkReal x5749=((IkReal(2.00000000000000))*(r20)*(sj6));
IkReal x5750=((cj5)*(r22)*(sj5));
IkReal x5751=((IkReal(1.00000000000000))*(x5745));
IkReal x5752=((IkReal(1.00000000000000))*(x5746));
gconst2=IKsign(((((x5748)*(x5749)))+(((IkReal(-1.00000000000000))*(x5749)*(x5750)))+(((IkReal(-1.00000000000000))*((r22)*(r22))*((sj5)*(sj5))))+(((IkReal(-2.00000000000000))*(x5748)*(x5750)))+(((IkReal(-1.00000000000000))*(x5744)*(x5747)*(x5751)))+(((IkReal(-1.00000000000000))*(x5743)*(x5744)*(x5752)))+(((IkReal(-1.00000000000000))*(x5743)*(x5751)))+(((IkReal(-1.00000000000000))*(x5747)*(x5752)))+(((IkReal(-1.00000000000000))*(x5744)*(x5748)*(x5749)))));
IkReal x5753=(r21)*(r21);
IkReal x5754=(cj5)*(cj5);
IkReal x5755=(sj6)*(sj6);
IkReal x5756=(cj6)*(cj6);
IkReal x5757=(r20)*(r20);
IkReal x5758=((cj6)*(r21));
IkReal x5759=((IkReal(2.00000000000000))*(r20)*(sj6));
IkReal x5760=((cj5)*(r22)*(sj5));
IkReal x5761=((IkReal(1.00000000000000))*(x5755));
IkReal x5762=((IkReal(1.00000000000000))*(x5756));
dummyeval[0]=((((IkReal(-2.00000000000000))*(x5758)*(x5760)))+(((IkReal(-1.00000000000000))*(x5753)*(x5761)))+(((IkReal(-1.00000000000000))*((r22)*(r22))*((sj5)*(sj5))))+(((IkReal(-1.00000000000000))*(x5754)*(x5758)*(x5759)))+(((IkReal(-1.00000000000000))*(x5754)*(x5757)*(x5761)))+(((IkReal(-1.00000000000000))*(x5759)*(x5760)))+(((x5758)*(x5759)))+(((IkReal(-1.00000000000000))*(x5753)*(x5754)*(x5762)))+(((IkReal(-1.00000000000000))*(x5757)*(x5762))));
if( IKabs(dummyeval[0]) < 0.0000010000000000  )
{
{
IkReal dummyeval[1];
IkReal gconst3;
IkReal x5763=(cj6)*(cj6);
IkReal x5764=(sj6)*(sj6);
IkReal x5765=((IkReal(1.00000000000000))*(r21));
IkReal x5766=((cj6)*(r20));
IkReal x5767=((r22)*(sj5));
IkReal x5768=((r01)*(sj0));
IkReal x5769=((r00)*(sj0));
IkReal x5770=((cj0)*(r10));
IkReal x5771=((r02)*(sj0)*(sj5));
IkReal x5772=((cj5)*(x5763));
IkReal x5773=((cj0)*(r12)*(sj5));
IkReal x5774=((IkReal(1.00000000000000))*(cj0)*(r11));
IkReal x5775=((cj5)*(x5764));
IkReal x5776=((r20)*(x5775));
gconst3=IKsign(((((IkReal(-1.00000000000000))*(x5765)*(x5769)*(x5775)))+(((sj6)*(x5767)*(x5768)))+(((IkReal(-1.00000000000000))*(x5774)*(x5776)))+(((x5768)*(x5776)))+(((r21)*(x5770)*(x5775)))+(((cj6)*(x5767)*(x5770)))+(((r21)*(x5770)*(x5772)))+(((IkReal(-1.00000000000000))*(r20)*(x5772)*(x5774)))+(((r21)*(sj6)*(x5773)))+(((IkReal(-1.00000000000000))*(x5766)*(x5773)))+(((IkReal(-1.00000000000000))*(sj6)*(x5767)*(x5774)))+(((IkReal(-1.00000000000000))*(cj6)*(x5767)*(x5769)))+(((IkReal(-1.00000000000000))*(x5765)*(x5769)*(x5772)))+(((r20)*(x5768)*(x5772)))+(((IkReal(-1.00000000000000))*(sj6)*(x5765)*(x5771)))+(((x5766)*(x5771)))));
IkReal x5777=(cj6)*(cj6);
IkReal x5778=(sj6)*(sj6);
IkReal x5779=((IkReal(1.00000000000000))*(r21));
IkReal x5780=((cj6)*(r20));
IkReal x5781=((r22)*(sj5));
IkReal x5782=((r01)*(sj0));
IkReal x5783=((r00)*(sj0));
IkReal x5784=((cj0)*(r10));
IkReal x5785=((r02)*(sj0)*(sj5));
IkReal x5786=((cj5)*(x5777));
IkReal x5787=((cj0)*(r12)*(sj5));
IkReal x5788=((IkReal(1.00000000000000))*(cj0)*(r11));
IkReal x5789=((cj5)*(x5778));
IkReal x5790=((r20)*(x5789));
dummyeval[0]=((((x5780)*(x5785)))+(((r20)*(x5782)*(x5786)))+(((sj6)*(x5781)*(x5782)))+(((x5782)*(x5790)))+(((IkReal(-1.00000000000000))*(cj6)*(x5781)*(x5783)))+(((r21)*(x5784)*(x5789)))+(((r21)*(sj6)*(x5787)))+(((IkReal(-1.00000000000000))*(r20)*(x5786)*(x5788)))+(((IkReal(-1.00000000000000))*(sj6)*(x5779)*(x5785)))+(((IkReal(-1.00000000000000))*(x5788)*(x5790)))+(((r21)*(x5784)*(x5786)))+(((IkReal(-1.00000000000000))*(sj6)*(x5781)*(x5788)))+(((IkReal(-1.00000000000000))*(x5779)*(x5783)*(x5786)))+(((IkReal(-1.00000000000000))*(x5780)*(x5787)))+(((cj6)*(x5781)*(x5784)))+(((IkReal(-1.00000000000000))*(x5779)*(x5783)*(x5789))));
if( IKabs(dummyeval[0]) < 0.0000010000000000  )
{
continue;

} else
{
{
IkReal j4array[1], cj4array[1], sj4array[1];
bool j4valid[1]={false};
_nj4 = 1;
IkReal x5791=((cj5)*(sj6));
IkReal x5792=((cj2)*(r21));
IkReal x5793=((cj5)*(cj6));
IkReal x5794=((IkReal(1.00000000000000))*(cj2)*(r20));
IkReal x5795=((cj0)*(cj1)*(sj2));
IkReal x5796=((IkReal(1.00000000000000))*(cj1)*(sj0)*(sj2));
IkReal x5797=((r10)*(x5795));
if( IKabs(((gconst3)*(((((IkReal(-1.00000000000000))*(r11)*(sj6)*(x5795)))+(((sj6)*(x5792)))+(((IkReal(-1.00000000000000))*(cj6)*(x5794)))+(((IkReal(-1.00000000000000))*(cj6)*(r00)*(x5796)))+(((cj1)*(r01)*(sj0)*(sj2)*(sj6)))+(((cj6)*(x5797))))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(((gconst3)*(((((IkReal(-1.00000000000000))*(x5792)*(x5793)))+(((r11)*(x5793)*(x5795)))+(((IkReal(-1.00000000000000))*(r02)*(sj5)*(x5796)))+(((x5791)*(x5797)))+(((IkReal(-1.00000000000000))*(r01)*(x5793)*(x5796)))+(((IkReal(-1.00000000000000))*(r00)*(x5791)*(x5796)))+(((IkReal(-1.00000000000000))*(cj2)*(r22)*(sj5)))+(((IkReal(-1.00000000000000))*(x5791)*(x5794)))+(((r12)*(sj5)*(x5795))))))) < IKFAST_ATAN2_MAGTHRESH )
    continue;
j4array[0]=IKatan2(((gconst3)*(((((IkReal(-1.00000000000000))*(r11)*(sj6)*(x5795)))+(((sj6)*(x5792)))+(((IkReal(-1.00000000000000))*(cj6)*(x5794)))+(((IkReal(-1.00000000000000))*(cj6)*(r00)*(x5796)))+(((cj1)*(r01)*(sj0)*(sj2)*(sj6)))+(((cj6)*(x5797)))))), ((gconst3)*(((((IkReal(-1.00000000000000))*(x5792)*(x5793)))+(((r11)*(x5793)*(x5795)))+(((IkReal(-1.00000000000000))*(r02)*(sj5)*(x5796)))+(((x5791)*(x5797)))+(((IkReal(-1.00000000000000))*(r01)*(x5793)*(x5796)))+(((IkReal(-1.00000000000000))*(r00)*(x5791)*(x5796)))+(((IkReal(-1.00000000000000))*(cj2)*(r22)*(sj5)))+(((IkReal(-1.00000000000000))*(x5791)*(x5794)))+(((r12)*(sj5)*(x5795)))))));
sj4array[0]=IKsin(j4array[0]);
cj4array[0]=IKcos(j4array[0]);
if( j4array[0] > IKPI )
{
    j4array[0]-=IK2PI;
}
else if( j4array[0] < -IKPI )
{    j4array[0]+=IK2PI;
}
j4valid[0] = true;
for(int ij4 = 0; ij4 < 1; ++ij4)
{
if( !j4valid[ij4] )
{
    continue;
}
_ij4[0] = ij4; _ij4[1] = -1;
for(int iij4 = ij4+1; iij4 < 1; ++iij4)
{
if( j4valid[iij4] && IKabs(cj4array[ij4]-cj4array[iij4]) < IKFAST_SOLUTION_THRESH && IKabs(sj4array[ij4]-sj4array[iij4]) < IKFAST_SOLUTION_THRESH )
{
    j4valid[iij4]=false; _ij4[1] = iij4; break; 
}
}
j4 = j4array[ij4]; cj4 = cj4array[ij4]; sj4 = sj4array[ij4];
{
IkReal evalcond[6];
IkReal x5798=IKsin(j4);
IkReal x5799=IKcos(j4);
IkReal x5800=((r00)*(sj6));
IkReal x5801=((IkReal(1.00000000000000))*(r12));
IkReal x5802=((IkReal(1.00000000000000))*(cj6));
IkReal x5803=((cj6)*(r01));
IkReal x5804=((IkReal(1.00000000000000))*(cj1));
IkReal x5805=((cj2)*(cj3));
IkReal x5806=((IkReal(1.00000000000000))*(sj1));
IkReal x5807=((r11)*(sj6));
IkReal x5808=((r01)*(sj6));
IkReal x5809=((IkReal(1.00000000000000))*(cj5));
IkReal x5810=((r10)*(sj6));
IkReal x5811=((cj5)*(r11));
IkReal x5812=((cj6)*(r00));
IkReal x5813=((r21)*(sj6));
IkReal x5814=((r02)*(sj5));
IkReal x5815=((cj6)*(r10));
IkReal x5816=((cj5)*(sj6));
IkReal x5817=((cj5)*(r01));
IkReal x5818=((sj5)*(x5798));
IkReal x5819=((cj0)*(x5799));
IkReal x5820=((cj0)*(x5798));
IkReal x5821=((sj0)*(x5799));
IkReal x5822=((sj0)*(x5798));
IkReal x5823=((r20)*(x5799));
IkReal x5824=((cj5)*(cj6)*(r21));
IkReal x5825=((r20)*(x5798));
IkReal x5826=((cj5)*(x5822));
evalcond[0]=((((IkReal(-1.00000000000000))*(sj2)*(x5804)))+(((x5816)*(x5825)))+(((r22)*(x5818)))+(((IkReal(-1.00000000000000))*(x5802)*(x5823)))+(((x5798)*(x5824)))+(((x5799)*(x5813))));
evalcond[1]=((((x5799)*(x5824)))+(((IkReal(-1.00000000000000))*(sj3)*(x5806)))+(((cj1)*(x5805)))+(((r22)*(sj5)*(x5799)))+(((IkReal(-1.00000000000000))*(x5798)*(x5813)))+(((x5816)*(x5823)))+(((cj6)*(x5825))));
evalcond[2]=((((IkReal(-1.00000000000000))*(r00)*(x5802)*(x5821)))+(((IkReal(-1.00000000000000))*(cj0)*(x5801)*(x5818)))+(((IkReal(-1.00000000000000))*(x5802)*(x5811)*(x5820)))+(((x5808)*(x5821)))+(cj2)+(((x5803)*(x5826)))+(((IkReal(-1.00000000000000))*(x5809)*(x5810)*(x5820)))+(((x5800)*(x5826)))+(((x5815)*(x5819)))+(((IkReal(-1.00000000000000))*(x5807)*(x5819)))+(((x5814)*(x5822))));
evalcond[3]=((((IkReal(-1.00000000000000))*(r10)*(x5802)*(x5820)))+(((cj5)*(x5803)*(x5821)))+(((IkReal(-1.00000000000000))*(sj5)*(x5801)*(x5819)))+(((x5807)*(x5820)))+(((IkReal(-1.00000000000000))*(x5808)*(x5822)))+(((x5814)*(x5821)))+(((x5812)*(x5822)))+(((IkReal(-1.00000000000000))*(x5809)*(x5810)*(x5819)))+(((cj3)*(sj2)))+(((cj5)*(x5800)*(x5821)))+(((IkReal(-1.00000000000000))*(x5802)*(x5811)*(x5819))));
evalcond[4]=((((IkReal(-1.00000000000000))*(x5809)*(x5810)*(x5822)))+(((x5815)*(x5821)))+(((IkReal(-1.00000000000000))*(x5814)*(x5820)))+(((IkReal(-1.00000000000000))*(x5808)*(x5819)))+(((x5812)*(x5819)))+(((IkReal(-1.00000000000000))*(sj0)*(x5801)*(x5818)))+(((IkReal(-1.00000000000000))*(x5807)*(x5821)))+(((IkReal(-1.00000000000000))*(x5800)*(x5809)*(x5820)))+(((sj1)*(sj2)))+(((IkReal(-1.00000000000000))*(x5802)*(x5811)*(x5822)))+(((IkReal(-1.00000000000000))*(x5802)*(x5817)*(x5820))));
evalcond[5]=((((IkReal(-1.00000000000000))*(sj5)*(x5801)*(x5821)))+(((IkReal(-1.00000000000000))*(x5802)*(x5817)*(x5819)))+(((IkReal(-1.00000000000000))*(x5805)*(x5806)))+(((IkReal(-1.00000000000000))*(x5814)*(x5819)))+(((IkReal(-1.00000000000000))*(r10)*(x5802)*(x5822)))+(((IkReal(-1.00000000000000))*(x5809)*(x5810)*(x5821)))+(((IkReal(-1.00000000000000))*(x5802)*(x5811)*(x5821)))+(((x5808)*(x5820)))+(((IkReal(-1.00000000000000))*(r00)*(x5802)*(x5820)))+(((x5807)*(x5822)))+(((IkReal(-1.00000000000000))*(sj3)*(x5804)))+(((IkReal(-1.00000000000000))*(x5800)*(x5809)*(x5819))));
if( IKabs(evalcond[0]) > 0.000001  || IKabs(evalcond[1]) > 0.000001  || IKabs(evalcond[2]) > 0.000001  || IKabs(evalcond[3]) > 0.000001  || IKabs(evalcond[4]) > 0.000001  || IKabs(evalcond[5]) > 0.000001  )
{
continue;
}
}

{
std::vector<IkSingleDOFSolutionBase<IkReal> > vinfos(7);
vinfos[0].jointtype = 1;
vinfos[0].foffset = j0;
vinfos[0].indices[0] = _ij0[0];
vinfos[0].indices[1] = _ij0[1];
vinfos[0].maxsolutions = _nj0;
vinfos[1].jointtype = 1;
vinfos[1].foffset = j1;
vinfos[1].indices[0] = _ij1[0];
vinfos[1].indices[1] = _ij1[1];
vinfos[1].maxsolutions = _nj1;
vinfos[2].jointtype = 1;
vinfos[2].foffset = j2;
vinfos[2].indices[0] = _ij2[0];
vinfos[2].indices[1] = _ij2[1];
vinfos[2].maxsolutions = _nj2;
vinfos[3].jointtype = 1;
vinfos[3].foffset = j3;
vinfos[3].indices[0] = _ij3[0];
vinfos[3].indices[1] = _ij3[1];
vinfos[3].maxsolutions = _nj3;
vinfos[4].jointtype = 1;
vinfos[4].foffset = j4;
vinfos[4].indices[0] = _ij4[0];
vinfos[4].indices[1] = _ij4[1];
vinfos[4].maxsolutions = _nj4;
vinfos[5].jointtype = 1;
vinfos[5].foffset = j5;
vinfos[5].indices[0] = _ij5[0];
vinfos[5].indices[1] = _ij5[1];
vinfos[5].maxsolutions = _nj5;
vinfos[6].jointtype = 1;
vinfos[6].foffset = j6;
vinfos[6].indices[0] = _ij6[0];
vinfos[6].indices[1] = _ij6[1];
vinfos[6].maxsolutions = _nj6;
std::vector<int> vfree(0);
solutions.AddSolution(vinfos,vfree);
}
}
}

}

}

} else
{
{
IkReal j4array[1], cj4array[1], sj4array[1];
bool j4valid[1]={false};
_nj4 = 1;
IkReal x5827=((cj1)*(sj2));
IkReal x5828=((cj6)*(r20));
IkReal x5829=((sj1)*(sj3));
IkReal x5830=((r21)*(sj6));
IkReal x5831=((IkReal(1.00000000000000))*(cj5));
IkReal x5832=((cj6)*(r21));
IkReal x5833=((r20)*(sj6));
IkReal x5834=((IkReal(1.00000000000000))*(r22)*(sj5));
IkReal x5835=((cj1)*(cj2)*(cj3));
if( IKabs(((gconst2)*(((((IkReal(-1.00000000000000))*(x5827)*(x5831)*(x5832)))+(((x5828)*(x5835)))+(((IkReal(-1.00000000000000))*(x5827)*(x5831)*(x5833)))+(((IkReal(-1.00000000000000))*(x5830)*(x5835)))+(((x5829)*(x5830)))+(((IkReal(-1.00000000000000))*(x5827)*(x5834)))+(((IkReal(-1.00000000000000))*(x5828)*(x5829))))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(((gconst2)*(((((IkReal(-1.00000000000000))*(x5829)*(x5831)*(x5832)))+(((IkReal(-1.00000000000000))*(x5829)*(x5834)))+(((cj5)*(x5833)*(x5835)))+(((IkReal(-1.00000000000000))*(x5827)*(x5830)))+(((x5827)*(x5828)))+(((r22)*(sj5)*(x5835)))+(((cj5)*(x5832)*(x5835)))+(((IkReal(-1.00000000000000))*(x5829)*(x5831)*(x5833))))))) < IKFAST_ATAN2_MAGTHRESH )
    continue;
j4array[0]=IKatan2(((gconst2)*(((((IkReal(-1.00000000000000))*(x5827)*(x5831)*(x5832)))+(((x5828)*(x5835)))+(((IkReal(-1.00000000000000))*(x5827)*(x5831)*(x5833)))+(((IkReal(-1.00000000000000))*(x5830)*(x5835)))+(((x5829)*(x5830)))+(((IkReal(-1.00000000000000))*(x5827)*(x5834)))+(((IkReal(-1.00000000000000))*(x5828)*(x5829)))))), ((gconst2)*(((((IkReal(-1.00000000000000))*(x5829)*(x5831)*(x5832)))+(((IkReal(-1.00000000000000))*(x5829)*(x5834)))+(((cj5)*(x5833)*(x5835)))+(((IkReal(-1.00000000000000))*(x5827)*(x5830)))+(((x5827)*(x5828)))+(((r22)*(sj5)*(x5835)))+(((cj5)*(x5832)*(x5835)))+(((IkReal(-1.00000000000000))*(x5829)*(x5831)*(x5833)))))));
sj4array[0]=IKsin(j4array[0]);
cj4array[0]=IKcos(j4array[0]);
if( j4array[0] > IKPI )
{
    j4array[0]-=IK2PI;
}
else if( j4array[0] < -IKPI )
{    j4array[0]+=IK2PI;
}
j4valid[0] = true;
for(int ij4 = 0; ij4 < 1; ++ij4)
{
if( !j4valid[ij4] )
{
    continue;
}
_ij4[0] = ij4; _ij4[1] = -1;
for(int iij4 = ij4+1; iij4 < 1; ++iij4)
{
if( j4valid[iij4] && IKabs(cj4array[ij4]-cj4array[iij4]) < IKFAST_SOLUTION_THRESH && IKabs(sj4array[ij4]-sj4array[iij4]) < IKFAST_SOLUTION_THRESH )
{
    j4valid[iij4]=false; _ij4[1] = iij4; break; 
}
}
j4 = j4array[ij4]; cj4 = cj4array[ij4]; sj4 = sj4array[ij4];
{
IkReal evalcond[6];
IkReal x5836=IKsin(j4);
IkReal x5837=IKcos(j4);
IkReal x5838=((r00)*(sj6));
IkReal x5839=((IkReal(1.00000000000000))*(r12));
IkReal x5840=((IkReal(1.00000000000000))*(cj6));
IkReal x5841=((cj6)*(r01));
IkReal x5842=((IkReal(1.00000000000000))*(cj1));
IkReal x5843=((cj2)*(cj3));
IkReal x5844=((IkReal(1.00000000000000))*(sj1));
IkReal x5845=((r11)*(sj6));
IkReal x5846=((r01)*(sj6));
IkReal x5847=((IkReal(1.00000000000000))*(cj5));
IkReal x5848=((r10)*(sj6));
IkReal x5849=((cj5)*(r11));
IkReal x5850=((cj6)*(r00));
IkReal x5851=((r21)*(sj6));
IkReal x5852=((r02)*(sj5));
IkReal x5853=((cj6)*(r10));
IkReal x5854=((cj5)*(sj6));
IkReal x5855=((cj5)*(r01));
IkReal x5856=((sj5)*(x5836));
IkReal x5857=((cj0)*(x5837));
IkReal x5858=((cj0)*(x5836));
IkReal x5859=((sj0)*(x5837));
IkReal x5860=((sj0)*(x5836));
IkReal x5861=((r20)*(x5837));
IkReal x5862=((cj5)*(cj6)*(r21));
IkReal x5863=((r20)*(x5836));
IkReal x5864=((cj5)*(x5860));
evalcond[0]=((((x5837)*(x5851)))+(((r22)*(x5856)))+(((x5836)*(x5862)))+(((IkReal(-1.00000000000000))*(x5840)*(x5861)))+(((x5854)*(x5863)))+(((IkReal(-1.00000000000000))*(sj2)*(x5842))));
evalcond[1]=((((x5837)*(x5862)))+(((IkReal(-1.00000000000000))*(sj3)*(x5844)))+(((IkReal(-1.00000000000000))*(x5836)*(x5851)))+(((x5854)*(x5861)))+(((cj1)*(x5843)))+(((cj6)*(x5863)))+(((r22)*(sj5)*(x5837))));
evalcond[2]=((((IkReal(-1.00000000000000))*(cj0)*(x5839)*(x5856)))+(((IkReal(-1.00000000000000))*(x5840)*(x5849)*(x5858)))+(((x5853)*(x5857)))+(((IkReal(-1.00000000000000))*(r00)*(x5840)*(x5859)))+(((IkReal(-1.00000000000000))*(x5845)*(x5857)))+(cj2)+(((IkReal(-1.00000000000000))*(x5847)*(x5848)*(x5858)))+(((x5846)*(x5859)))+(((x5841)*(x5864)))+(((x5838)*(x5864)))+(((x5852)*(x5860))));
evalcond[3]=((((cj5)*(x5838)*(x5859)))+(((cj5)*(x5841)*(x5859)))+(((x5852)*(x5859)))+(((x5850)*(x5860)))+(((IkReal(-1.00000000000000))*(sj5)*(x5839)*(x5857)))+(((x5845)*(x5858)))+(((IkReal(-1.00000000000000))*(x5840)*(x5849)*(x5857)))+(((IkReal(-1.00000000000000))*(r10)*(x5840)*(x5858)))+(((IkReal(-1.00000000000000))*(x5847)*(x5848)*(x5857)))+(((cj3)*(sj2)))+(((IkReal(-1.00000000000000))*(x5846)*(x5860))));
evalcond[4]=((((IkReal(-1.00000000000000))*(x5852)*(x5858)))+(((IkReal(-1.00000000000000))*(x5840)*(x5855)*(x5858)))+(((IkReal(-1.00000000000000))*(x5847)*(x5848)*(x5860)))+(((IkReal(-1.00000000000000))*(x5840)*(x5849)*(x5860)))+(((IkReal(-1.00000000000000))*(sj0)*(x5839)*(x5856)))+(((x5853)*(x5859)))+(((IkReal(-1.00000000000000))*(x5838)*(x5847)*(x5858)))+(((x5850)*(x5857)))+(((IkReal(-1.00000000000000))*(x5845)*(x5859)))+(((sj1)*(sj2)))+(((IkReal(-1.00000000000000))*(x5846)*(x5857))));
evalcond[5]=((((IkReal(-1.00000000000000))*(x5840)*(x5855)*(x5857)))+(((IkReal(-1.00000000000000))*(x5852)*(x5857)))+(((IkReal(-1.00000000000000))*(x5838)*(x5847)*(x5857)))+(((IkReal(-1.00000000000000))*(r10)*(x5840)*(x5860)))+(((IkReal(-1.00000000000000))*(x5847)*(x5848)*(x5859)))+(((x5845)*(x5860)))+(((IkReal(-1.00000000000000))*(x5840)*(x5849)*(x5859)))+(((IkReal(-1.00000000000000))*(r00)*(x5840)*(x5858)))+(((x5846)*(x5858)))+(((IkReal(-1.00000000000000))*(x5843)*(x5844)))+(((IkReal(-1.00000000000000))*(sj3)*(x5842)))+(((IkReal(-1.00000000000000))*(sj5)*(x5839)*(x5859))));
if( IKabs(evalcond[0]) > 0.000001  || IKabs(evalcond[1]) > 0.000001  || IKabs(evalcond[2]) > 0.000001  || IKabs(evalcond[3]) > 0.000001  || IKabs(evalcond[4]) > 0.000001  || IKabs(evalcond[5]) > 0.000001  )
{
continue;
}
}

{
std::vector<IkSingleDOFSolutionBase<IkReal> > vinfos(7);
vinfos[0].jointtype = 1;
vinfos[0].foffset = j0;
vinfos[0].indices[0] = _ij0[0];
vinfos[0].indices[1] = _ij0[1];
vinfos[0].maxsolutions = _nj0;
vinfos[1].jointtype = 1;
vinfos[1].foffset = j1;
vinfos[1].indices[0] = _ij1[0];
vinfos[1].indices[1] = _ij1[1];
vinfos[1].maxsolutions = _nj1;
vinfos[2].jointtype = 1;
vinfos[2].foffset = j2;
vinfos[2].indices[0] = _ij2[0];
vinfos[2].indices[1] = _ij2[1];
vinfos[2].maxsolutions = _nj2;
vinfos[3].jointtype = 1;
vinfos[3].foffset = j3;
vinfos[3].indices[0] = _ij3[0];
vinfos[3].indices[1] = _ij3[1];
vinfos[3].maxsolutions = _nj3;
vinfos[4].jointtype = 1;
vinfos[4].foffset = j4;
vinfos[4].indices[0] = _ij4[0];
vinfos[4].indices[1] = _ij4[1];
vinfos[4].maxsolutions = _nj4;
vinfos[5].jointtype = 1;
vinfos[5].foffset = j5;
vinfos[5].indices[0] = _ij5[0];
vinfos[5].indices[1] = _ij5[1];
vinfos[5].maxsolutions = _nj5;
vinfos[6].jointtype = 1;
vinfos[6].foffset = j6;
vinfos[6].indices[0] = _ij6[0];
vinfos[6].indices[1] = _ij6[1];
vinfos[6].maxsolutions = _nj6;
std::vector<int> vfree(0);
solutions.AddSolution(vinfos,vfree);
}
}
}

}

}
}
}

}

}

} else
{
{
IkReal j4array[1], cj4array[1], sj4array[1];
bool j4valid[1]={false};
_nj4 = 1;
IkReal x5865=((cj0)*(r00));
IkReal x5866=((r10)*(sj0));
IkReal x5867=((cj0)*(r01));
IkReal x5868=((IkReal(1.00000000000000))*(cj5));
IkReal x5869=((r11)*(sj0));
IkReal x5870=((sj2)*(sj5));
IkReal x5871=((IkReal(1.00000000000000))*(cj1));
IkReal x5872=((r20)*(sj1)*(sj2));
IkReal x5873=((cj1)*(sj2)*(sj6));
IkReal x5874=((r21)*(sj1)*(sj2));
IkReal x5875=((cj6)*(sj2)*(x5871));
if( IKabs(((gconst1)*(((((IkReal(-1.00000000000000))*(sj6)*(x5874)))+(((IkReal(-1.00000000000000))*(x5865)*(x5875)))+(((x5867)*(x5873)))+(((x5869)*(x5873)))+(((cj6)*(x5872)))+(((IkReal(-1.00000000000000))*(x5866)*(x5875))))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(((gconst1)*(((((IkReal(-1.00000000000000))*(r12)*(sj0)*(x5870)*(x5871)))+(((cj5)*(sj6)*(x5872)))+(((IkReal(-1.00000000000000))*(x5866)*(x5868)*(x5873)))+(((IkReal(-1.00000000000000))*(cj0)*(r02)*(x5870)*(x5871)))+(((IkReal(-1.00000000000000))*(cj1)*(cj6)*(sj2)*(x5868)*(x5869)))+(((r22)*(sj1)*(x5870)))+(((cj5)*(cj6)*(x5874)))+(((IkReal(-1.00000000000000))*(x5865)*(x5868)*(x5873)))+(((IkReal(-1.00000000000000))*(cj1)*(cj6)*(sj2)*(x5867)*(x5868))))))) < IKFAST_ATAN2_MAGTHRESH )
    continue;
j4array[0]=IKatan2(((gconst1)*(((((IkReal(-1.00000000000000))*(sj6)*(x5874)))+(((IkReal(-1.00000000000000))*(x5865)*(x5875)))+(((x5867)*(x5873)))+(((x5869)*(x5873)))+(((cj6)*(x5872)))+(((IkReal(-1.00000000000000))*(x5866)*(x5875)))))), ((gconst1)*(((((IkReal(-1.00000000000000))*(r12)*(sj0)*(x5870)*(x5871)))+(((cj5)*(sj6)*(x5872)))+(((IkReal(-1.00000000000000))*(x5866)*(x5868)*(x5873)))+(((IkReal(-1.00000000000000))*(cj0)*(r02)*(x5870)*(x5871)))+(((IkReal(-1.00000000000000))*(cj1)*(cj6)*(sj2)*(x5868)*(x5869)))+(((r22)*(sj1)*(x5870)))+(((cj5)*(cj6)*(x5874)))+(((IkReal(-1.00000000000000))*(x5865)*(x5868)*(x5873)))+(((IkReal(-1.00000000000000))*(cj1)*(cj6)*(sj2)*(x5867)*(x5868)))))));
sj4array[0]=IKsin(j4array[0]);
cj4array[0]=IKcos(j4array[0]);
if( j4array[0] > IKPI )
{
    j4array[0]-=IK2PI;
}
else if( j4array[0] < -IKPI )
{    j4array[0]+=IK2PI;
}
j4valid[0] = true;
for(int ij4 = 0; ij4 < 1; ++ij4)
{
if( !j4valid[ij4] )
{
    continue;
}
_ij4[0] = ij4; _ij4[1] = -1;
for(int iij4 = ij4+1; iij4 < 1; ++iij4)
{
if( j4valid[iij4] && IKabs(cj4array[ij4]-cj4array[iij4]) < IKFAST_SOLUTION_THRESH && IKabs(sj4array[ij4]-sj4array[iij4]) < IKFAST_SOLUTION_THRESH )
{
    j4valid[iij4]=false; _ij4[1] = iij4; break; 
}
}
j4 = j4array[ij4]; cj4 = cj4array[ij4]; sj4 = sj4array[ij4];
{
IkReal evalcond[3];
IkReal x5876=IKsin(j4);
IkReal x5877=IKcos(j4);
IkReal x5878=((r00)*(sj6));
IkReal x5879=((cj6)*(r01));
IkReal x5880=((IkReal(1.00000000000000))*(cj0));
IkReal x5881=((IkReal(1.00000000000000))*(sj0));
IkReal x5882=((r10)*(sj6));
IkReal x5883=((sj5)*(x5876));
IkReal x5884=((IkReal(1.00000000000000))*(cj6)*(r11));
IkReal x5885=((cj5)*(x5876));
IkReal x5886=((cj6)*(x5877));
IkReal x5887=((sj0)*(x5885));
IkReal x5888=((r01)*(sj6)*(x5877));
IkReal x5889=((r11)*(sj6)*(x5877));
evalcond[0]=((((cj6)*(r21)*(x5885)))+(((r22)*(x5883)))+(((IkReal(-1.00000000000000))*(cj1)*(sj2)))+(((r20)*(sj6)*(x5885)))+(((r21)*(sj6)*(x5877)))+(((IkReal(-1.00000000000000))*(r20)*(x5886))));
evalcond[1]=((((IkReal(-1.00000000000000))*(cj6)*(r11)*(x5880)*(x5885)))+(((IkReal(-1.00000000000000))*(x5880)*(x5889)))+(((r02)*(sj0)*(x5883)))+(((IkReal(-1.00000000000000))*(r00)*(x5881)*(x5886)))+(((IkReal(-1.00000000000000))*(r12)*(x5880)*(x5883)))+(((IkReal(-1.00000000000000))*(x5880)*(x5882)*(x5885)))+(cj2)+(((x5878)*(x5887)))+(((x5879)*(x5887)))+(((sj0)*(x5888)))+(((cj0)*(r10)*(x5886))));
evalcond[2]=((((IkReal(-1.00000000000000))*(x5878)*(x5880)*(x5885)))+(((IkReal(-1.00000000000000))*(x5880)*(x5888)))+(((IkReal(-1.00000000000000))*(x5879)*(x5880)*(x5885)))+(((IkReal(-1.00000000000000))*(x5881)*(x5882)*(x5885)))+(((r10)*(sj0)*(x5886)))+(((cj0)*(r00)*(x5886)))+(((IkReal(-1.00000000000000))*(x5881)*(x5889)))+(((IkReal(-1.00000000000000))*(r02)*(x5880)*(x5883)))+(((sj1)*(sj2)))+(((IkReal(-1.00000000000000))*(r12)*(x5881)*(x5883)))+(((IkReal(-1.00000000000000))*(cj6)*(r11)*(x5881)*(x5885))));
if( IKabs(evalcond[0]) > 0.000001  || IKabs(evalcond[1]) > 0.000001  || IKabs(evalcond[2]) > 0.000001  )
{
continue;
}
}

{
IkReal dummyeval[1];
IkReal gconst4;
gconst4=IKsign((((sj1)*(sj1))+((((cj1)*(cj1))*((cj2)*(cj2))))));
dummyeval[0]=(((sj1)*(sj1))+((((cj1)*(cj1))*((cj2)*(cj2)))));
if( IKabs(dummyeval[0]) < 0.0000010000000000  )
{
{
IkReal dummyeval[2];
IkReal x5890=(cj1)*(cj1);
IkReal x5891=(sj1)*(sj1);
dummyeval[0]=((((cj2)*(x5890)))+(((cj2)*(x5891))));
dummyeval[1]=((x5890)+(x5891));
if( IKabs(dummyeval[0]) < 0.0000010000000000  || IKabs(dummyeval[1]) < 0.0000010000000000  )
{
{
IkReal dummyeval[2];
dummyeval[0]=sj2;
dummyeval[1]=sj1;
if( IKabs(dummyeval[0]) < 0.0000010000000000  || IKabs(dummyeval[1]) < 0.0000010000000000  )
{
{
IkReal evalcond[9];
IkReal x5892=((cj5)*(sj4));
IkReal x5893=((IkReal(1.00000000000000))*(sj6));
IkReal x5894=((r10)*(sj0));
IkReal x5895=((sj4)*(sj5));
IkReal x5896=((cj4)*(cj5));
IkReal x5897=((IkReal(1.00000000000000))*(r02));
IkReal x5898=((IkReal(0.374290000000000))*(cj0));
IkReal x5899=((cj5)*(r12));
IkReal x5900=((cj6)*(sj5));
IkReal x5901=((cj0)*(r11));
IkReal x5902=((cj5)*(sj0));
IkReal x5903=((r20)*(sj6));
IkReal x5904=((IkReal(1.00000000000000))*(sj0));
IkReal x5905=((IkReal(1.00000000000000))*(cj6));
IkReal x5906=((IkReal(0.0100000000000000))*(cj5));
IkReal x5907=((IkReal(0.0100000000000000))*(sj5));
IkReal x5908=((sj5)*(sj6));
IkReal x5909=((cj0)*(r10));
IkReal x5910=((cj4)*(cj6));
IkReal x5911=((cj0)*(r01));
IkReal x5912=((cj0)*(r00));
IkReal x5913=((cj6)*(r21));
IkReal x5914=((IkReal(0.374290000000000))*(sj0));
IkReal x5915=((IkReal(0.374290000000000))*(sj5));
IkReal x5916=((cj6)*(r11));
IkReal x5917=((sj0)*(sj4));
IkReal x5918=((cj4)*(sj5));
IkReal x5919=((cj4)*(sj6));
IkReal x5920=((IkReal(1.00000000000000))*(cj0));
IkReal x5921=((r02)*(sj0));
IkReal x5922=((r00)*(sj0)*(sj6));
IkReal x5923=((cj6)*(r01)*(sj0));
IkReal x5924=((r00)*(x5910));
IkReal x5925=((r12)*(x5920));
evalcond[0]=((IkReal(-3.14159265358979))+(IKfmod(((IkReal(3.14159265358979))+(j2)), IkReal(6.28318530717959))));
evalcond[1]=((((x5892)*(x5913)))+(((x5892)*(x5903)))+(((IkReal(-1.00000000000000))*(cj4)*(r20)*(x5905)))+(((r21)*(x5919)))+(((r22)*(x5895))));
evalcond[2]=((((IkReal(-1.00000000000000))*(x5906)*(x5913)))+(((IkReal(0.364420000000000))*(sj1)))+(((IkReal(0.374290000000000))*(r21)*(x5900)))+(((IkReal(-1.00000000000000))*(r22)*(x5907)))+(((IkReal(-0.374290000000000))*(cj5)*(r22)))+(pz)+(((x5903)*(x5915)))+(((IkReal(-1.00000000000000))*(x5903)*(x5906)))+(((IkReal(0.0690000000000000))*(cj1))));
evalcond[3]=((((r01)*(sj0)*(x5900)))+(((IkReal(-1.00000000000000))*(x5900)*(x5901)))+(((r00)*(sj0)*(x5908)))+(((IkReal(-1.00000000000000))*(sj5)*(x5893)*(x5909)))+(((cj0)*(x5899)))+(((IkReal(-1.00000000000000))*(x5897)*(x5902))));
evalcond[4]=((IkReal(1.00000000000000))+(((x5892)*(x5922)))+(((IkReal(-1.00000000000000))*(x5892)*(x5901)*(x5905)))+(((IkReal(-1.00000000000000))*(x5904)*(x5924)))+(((x5895)*(x5921)))+(((x5909)*(x5910)))+(((IkReal(-1.00000000000000))*(cj4)*(x5893)*(x5901)))+(((r01)*(sj0)*(x5919)))+(((x5892)*(x5923)))+(((IkReal(-1.00000000000000))*(x5895)*(x5925)))+(((IkReal(-1.00000000000000))*(x5892)*(x5893)*(x5909))));
evalcond[5]=((((sj4)*(sj6)*(x5901)))+(((IkReal(-1.00000000000000))*(sj4)*(x5905)*(x5909)))+(((IkReal(-1.00000000000000))*(x5918)*(x5925)))+(((x5896)*(x5922)))+(((IkReal(-1.00000000000000))*(x5896)*(x5901)*(x5905)))+(((x5918)*(x5921)))+(((IkReal(-1.00000000000000))*(r01)*(x5893)*(x5917)))+(((cj6)*(r00)*(x5917)))+(((x5896)*(x5923)))+(((IkReal(-1.00000000000000))*(x5893)*(x5896)*(x5909))));
evalcond[6]=((((x5894)*(x5910)))+(((IkReal(-1.00000000000000))*(r12)*(x5895)*(x5904)))+(((IkReal(-1.00000000000000))*(x5892)*(x5893)*(x5894)))+(((IkReal(-1.00000000000000))*(x5892)*(x5905)*(x5911)))+(((IkReal(-1.00000000000000))*(x5892)*(x5893)*(x5912)))+(((IkReal(-1.00000000000000))*(cj4)*(r11)*(sj0)*(x5893)))+(((IkReal(-1.00000000000000))*(x5892)*(x5904)*(x5916)))+(((x5910)*(x5912)))+(((IkReal(-1.00000000000000))*(cj0)*(x5895)*(x5897)))+(((IkReal(-1.00000000000000))*(cj4)*(x5893)*(x5911))));
evalcond[7]=((((cj6)*(x5901)*(x5906)))+(((IkReal(-0.0100000000000000))*(cj6)*(r01)*(x5902)))+(((IkReal(-1.00000000000000))*(r10)*(x5898)*(x5908)))+(((IkReal(-1.00000000000000))*(x5907)*(x5921)))+(((sj6)*(x5906)*(x5909)))+(((IkReal(-1.00000000000000))*(r11)*(x5898)*(x5900)))+(((IkReal(-0.374290000000000))*(r02)*(x5902)))+(((r01)*(x5900)*(x5914)))+(((IkReal(-0.0100000000000000))*(r00)*(sj6)*(x5902)))+(((x5898)*(x5899)))+(((px)*(sj0)))+(((cj0)*(r12)*(x5907)))+(((IkReal(-1.00000000000000))*(py)*(x5920)))+(((r00)*(x5908)*(x5914))));
evalcond[8]=((IkReal(0.0690000000000000))+(((IkReal(-0.0690000000000000))*(sj1)))+(((sj6)*(x5906)*(x5912)))+(((r12)*(sj0)*(x5907)))+(((IkReal(-1.00000000000000))*(r01)*(x5898)*(x5900)))+(((IkReal(0.0100000000000000))*(x5902)*(x5916)))+(((cj5)*(r02)*(x5898)))+(((IkReal(-1.00000000000000))*(r00)*(x5898)*(x5908)))+(((x5899)*(x5914)))+(((cj6)*(x5906)*(x5911)))+(((IkReal(-1.00000000000000))*(px)*(x5920)))+(((IkReal(-1.00000000000000))*(py)*(x5904)))+(((IkReal(-0.374290000000000))*(x5894)*(x5908)))+(((IkReal(-1.00000000000000))*(r11)*(x5900)*(x5914)))+(((sj6)*(x5894)*(x5906)))+(((IkReal(0.364420000000000))*(cj1)))+(((cj0)*(r02)*(x5907))));
if( IKabs(evalcond[0]) < 0.0000010000000000  && IKabs(evalcond[1]) < 0.0000010000000000  && IKabs(evalcond[2]) < 0.0000010000000000  && IKabs(evalcond[3]) < 0.0000010000000000  && IKabs(evalcond[4]) < 0.0000010000000000  && IKabs(evalcond[5]) < 0.0000010000000000  && IKabs(evalcond[6]) < 0.0000010000000000  && IKabs(evalcond[7]) < 0.0000010000000000  && IKabs(evalcond[8]) < 0.0000010000000000  )
{
{
IkReal dummyeval[1];
IkReal gconst5;
gconst5=IKsign((((cj1)*(cj1))+((sj1)*(sj1))));
dummyeval[0]=(((cj1)*(cj1))+((sj1)*(sj1)));
if( IKabs(dummyeval[0]) < 0.0000010000000000  )
{
{
IkReal dummyeval[1];
IkReal gconst6;
gconst6=IKsign((((cj1)*(cj1))+((sj1)*(sj1))));
dummyeval[0]=(((cj1)*(cj1))+((sj1)*(sj1)));
if( IKabs(dummyeval[0]) < 0.0000010000000000  )
{
continue;

} else
{
{
IkReal j3array[1], cj3array[1], sj3array[1];
bool j3valid[1]={false};
_nj3 = 1;
IkReal x5926=((sj5)*(sj6));
IkReal x5927=((IkReal(1.00000000000000))*(sj0));
IkReal x5928=((cj5)*(r12));
IkReal x5929=((cj0)*(r00));
IkReal x5930=((cj0)*(cj1));
IkReal x5931=((cj6)*(sj5));
IkReal x5932=((cj5)*(r02));
IkReal x5933=((IkReal(1.00000000000000))*(cj1));
IkReal x5934=((sj0)*(sj1));
IkReal x5935=((cj0)*(sj1));
IkReal x5936=((cj5)*(r22));
if( IKabs(((gconst6)*(((((r10)*(x5926)*(x5934)))+(((IkReal(-1.00000000000000))*(x5932)*(x5935)))+(((IkReal(-1.00000000000000))*(sj1)*(x5927)*(x5928)))+(((r11)*(x5931)*(x5934)))+(((IkReal(-1.00000000000000))*(x5933)*(x5936)))+(((cj1)*(r20)*(x5926)))+(((r01)*(x5931)*(x5935)))+(((cj1)*(r21)*(x5931)))+(((sj1)*(x5926)*(x5929))))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(((gconst6)*(((((IkReal(-1.00000000000000))*(sj1)*(x5936)))+(((x5930)*(x5932)))+(((r20)*(sj1)*(x5926)))+(((IkReal(-1.00000000000000))*(r01)*(x5930)*(x5931)))+(((IkReal(-1.00000000000000))*(cj1)*(r10)*(x5926)*(x5927)))+(((r21)*(sj1)*(x5931)))+(((cj1)*(sj0)*(x5928)))+(((IkReal(-1.00000000000000))*(x5926)*(x5929)*(x5933)))+(((IkReal(-1.00000000000000))*(cj1)*(r11)*(x5927)*(x5931))))))) < IKFAST_ATAN2_MAGTHRESH )
    continue;
j3array[0]=IKatan2(((gconst6)*(((((r10)*(x5926)*(x5934)))+(((IkReal(-1.00000000000000))*(x5932)*(x5935)))+(((IkReal(-1.00000000000000))*(sj1)*(x5927)*(x5928)))+(((r11)*(x5931)*(x5934)))+(((IkReal(-1.00000000000000))*(x5933)*(x5936)))+(((cj1)*(r20)*(x5926)))+(((r01)*(x5931)*(x5935)))+(((cj1)*(r21)*(x5931)))+(((sj1)*(x5926)*(x5929)))))), ((gconst6)*(((((IkReal(-1.00000000000000))*(sj1)*(x5936)))+(((x5930)*(x5932)))+(((r20)*(sj1)*(x5926)))+(((IkReal(-1.00000000000000))*(r01)*(x5930)*(x5931)))+(((IkReal(-1.00000000000000))*(cj1)*(r10)*(x5926)*(x5927)))+(((r21)*(sj1)*(x5931)))+(((cj1)*(sj0)*(x5928)))+(((IkReal(-1.00000000000000))*(x5926)*(x5929)*(x5933)))+(((IkReal(-1.00000000000000))*(cj1)*(r11)*(x5927)*(x5931)))))));
sj3array[0]=IKsin(j3array[0]);
cj3array[0]=IKcos(j3array[0]);
if( j3array[0] > IKPI )
{
    j3array[0]-=IK2PI;
}
else if( j3array[0] < -IKPI )
{    j3array[0]+=IK2PI;
}
j3valid[0] = true;
for(int ij3 = 0; ij3 < 1; ++ij3)
{
if( !j3valid[ij3] )
{
    continue;
}
_ij3[0] = ij3; _ij3[1] = -1;
for(int iij3 = ij3+1; iij3 < 1; ++iij3)
{
if( j3valid[iij3] && IKabs(cj3array[ij3]-cj3array[iij3]) < IKFAST_SOLUTION_THRESH && IKabs(sj3array[ij3]-sj3array[iij3]) < IKFAST_SOLUTION_THRESH )
{
    j3valid[iij3]=false; _ij3[1] = iij3; break; 
}
}
j3 = j3array[ij3]; cj3 = cj3array[ij3]; sj3 = sj3array[ij3];
{
IkReal evalcond[4];
IkReal x5937=IKcos(j3);
IkReal x5938=IKsin(j3);
IkReal x5939=((IkReal(1.00000000000000))*(cj4));
IkReal x5940=((sj0)*(sj5));
IkReal x5941=((cj0)*(cj5));
IkReal x5942=((cj6)*(r01));
IkReal x5943=((r00)*(sj6));
IkReal x5944=((cj6)*(r11));
IkReal x5945=((cj5)*(sj0));
IkReal x5946=((cj6)*(sj4));
IkReal x5947=((sj4)*(sj6));
IkReal x5948=((cj4)*(cj5));
IkReal x5949=((cj6)*(r21));
IkReal x5950=((r20)*(sj6));
IkReal x5951=((r10)*(sj6));
IkReal x5952=((cj1)*(x5937));
IkReal x5953=((IkReal(1.00000000000000))*(cj0)*(sj5));
IkReal x5954=((IkReal(1.00000000000000))*(x5938));
IkReal x5955=((IkReal(1.00000000000000))*(sj1)*(x5937));
IkReal x5956=((cj1)*(x5954));
IkReal x5957=((x5955)+(x5956));
evalcond[0]=((((sj5)*(x5950)))+(((IkReal(-1.00000000000000))*(x5957)))+(((IkReal(-1.00000000000000))*(cj5)*(r22)))+(((sj5)*(x5949))));
evalcond[1]=((((r20)*(x5946)))+(((IkReal(-1.00000000000000))*(sj1)*(x5954)))+(((cj4)*(r22)*(sj5)))+(x5952)+(((x5948)*(x5950)))+(((x5948)*(x5949)))+(((IkReal(-1.00000000000000))*(r21)*(x5947))));
evalcond[2]=((((sj1)*(x5938)))+(((r12)*(x5945)))+(((IkReal(-1.00000000000000))*(x5940)*(x5944)))+(((IkReal(-1.00000000000000))*(x5942)*(x5953)))+(((r02)*(x5941)))+(((IkReal(-1.00000000000000))*(x5943)*(x5953)))+(((IkReal(-1.00000000000000))*(x5952)))+(((IkReal(-1.00000000000000))*(x5940)*(x5951))));
evalcond[3]=((((IkReal(-1.00000000000000))*(r12)*(x5939)*(x5940)))+(((IkReal(-1.00000000000000))*(cj0)*(r02)*(sj5)*(x5939)))+(((r11)*(sj0)*(x5947)))+(((cj0)*(r01)*(x5947)))+(((IkReal(-1.00000000000000))*(x5957)))+(((IkReal(-1.00000000000000))*(cj0)*(r00)*(x5946)))+(((IkReal(-1.00000000000000))*(x5939)*(x5945)*(x5951)))+(((IkReal(-1.00000000000000))*(r10)*(sj0)*(x5946)))+(((IkReal(-1.00000000000000))*(x5939)*(x5941)*(x5943)))+(((IkReal(-1.00000000000000))*(x5939)*(x5941)*(x5942)))+(((IkReal(-1.00000000000000))*(x5939)*(x5944)*(x5945))));
if( IKabs(evalcond[0]) > 0.000001  || IKabs(evalcond[1]) > 0.000001  || IKabs(evalcond[2]) > 0.000001  || IKabs(evalcond[3]) > 0.000001  )
{
continue;
}
}

{
std::vector<IkSingleDOFSolutionBase<IkReal> > vinfos(7);
vinfos[0].jointtype = 1;
vinfos[0].foffset = j0;
vinfos[0].indices[0] = _ij0[0];
vinfos[0].indices[1] = _ij0[1];
vinfos[0].maxsolutions = _nj0;
vinfos[1].jointtype = 1;
vinfos[1].foffset = j1;
vinfos[1].indices[0] = _ij1[0];
vinfos[1].indices[1] = _ij1[1];
vinfos[1].maxsolutions = _nj1;
vinfos[2].jointtype = 1;
vinfos[2].foffset = j2;
vinfos[2].indices[0] = _ij2[0];
vinfos[2].indices[1] = _ij2[1];
vinfos[2].maxsolutions = _nj2;
vinfos[3].jointtype = 1;
vinfos[3].foffset = j3;
vinfos[3].indices[0] = _ij3[0];
vinfos[3].indices[1] = _ij3[1];
vinfos[3].maxsolutions = _nj3;
vinfos[4].jointtype = 1;
vinfos[4].foffset = j4;
vinfos[4].indices[0] = _ij4[0];
vinfos[4].indices[1] = _ij4[1];
vinfos[4].maxsolutions = _nj4;
vinfos[5].jointtype = 1;
vinfos[5].foffset = j5;
vinfos[5].indices[0] = _ij5[0];
vinfos[5].indices[1] = _ij5[1];
vinfos[5].maxsolutions = _nj5;
vinfos[6].jointtype = 1;
vinfos[6].foffset = j6;
vinfos[6].indices[0] = _ij6[0];
vinfos[6].indices[1] = _ij6[1];
vinfos[6].maxsolutions = _nj6;
std::vector<int> vfree(0);
solutions.AddSolution(vinfos,vfree);
}
}
}

}

}

} else
{
{
IkReal j3array[1], cj3array[1], sj3array[1];
bool j3valid[1]={false};
_nj3 = 1;
IkReal x5958=((sj1)*(sj5));
IkReal x5959=((r20)*(sj6));
IkReal x5960=((cj4)*(r22));
IkReal x5961=((IkReal(1.00000000000000))*(cj1));
IkReal x5962=((cj5)*(sj1));
IkReal x5963=((cj6)*(r21));
IkReal x5964=((cj1)*(sj5));
IkReal x5965=((cj4)*(cj5));
IkReal x5966=((cj6)*(r20)*(sj4));
IkReal x5967=((r21)*(sj4)*(sj6));
if( IKabs(((gconst5)*(((((x5963)*(x5964)))+(((IkReal(-1.00000000000000))*(sj1)*(x5967)))+(((cj4)*(x5962)*(x5963)))+(((cj4)*(x5959)*(x5962)))+(((x5959)*(x5964)))+(((x5958)*(x5960)))+(((IkReal(-1.00000000000000))*(cj5)*(r22)*(x5961)))+(((sj1)*(x5966))))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(((gconst5)*(((((x5958)*(x5963)))+(((IkReal(-1.00000000000000))*(x5961)*(x5963)*(x5965)))+(((cj1)*(x5967)))+(((IkReal(-1.00000000000000))*(x5961)*(x5966)))+(((x5958)*(x5959)))+(((IkReal(-1.00000000000000))*(r22)*(x5962)))+(((IkReal(-1.00000000000000))*(sj5)*(x5960)*(x5961)))+(((IkReal(-1.00000000000000))*(x5959)*(x5961)*(x5965))))))) < IKFAST_ATAN2_MAGTHRESH )
    continue;
j3array[0]=IKatan2(((gconst5)*(((((x5963)*(x5964)))+(((IkReal(-1.00000000000000))*(sj1)*(x5967)))+(((cj4)*(x5962)*(x5963)))+(((cj4)*(x5959)*(x5962)))+(((x5959)*(x5964)))+(((x5958)*(x5960)))+(((IkReal(-1.00000000000000))*(cj5)*(r22)*(x5961)))+(((sj1)*(x5966)))))), ((gconst5)*(((((x5958)*(x5963)))+(((IkReal(-1.00000000000000))*(x5961)*(x5963)*(x5965)))+(((cj1)*(x5967)))+(((IkReal(-1.00000000000000))*(x5961)*(x5966)))+(((x5958)*(x5959)))+(((IkReal(-1.00000000000000))*(r22)*(x5962)))+(((IkReal(-1.00000000000000))*(sj5)*(x5960)*(x5961)))+(((IkReal(-1.00000000000000))*(x5959)*(x5961)*(x5965)))))));
sj3array[0]=IKsin(j3array[0]);
cj3array[0]=IKcos(j3array[0]);
if( j3array[0] > IKPI )
{
    j3array[0]-=IK2PI;
}
else if( j3array[0] < -IKPI )
{    j3array[0]+=IK2PI;
}
j3valid[0] = true;
for(int ij3 = 0; ij3 < 1; ++ij3)
{
if( !j3valid[ij3] )
{
    continue;
}
_ij3[0] = ij3; _ij3[1] = -1;
for(int iij3 = ij3+1; iij3 < 1; ++iij3)
{
if( j3valid[iij3] && IKabs(cj3array[ij3]-cj3array[iij3]) < IKFAST_SOLUTION_THRESH && IKabs(sj3array[ij3]-sj3array[iij3]) < IKFAST_SOLUTION_THRESH )
{
    j3valid[iij3]=false; _ij3[1] = iij3; break; 
}
}
j3 = j3array[ij3]; cj3 = cj3array[ij3]; sj3 = sj3array[ij3];
{
IkReal evalcond[4];
IkReal x5968=IKcos(j3);
IkReal x5969=IKsin(j3);
IkReal x5970=((IkReal(1.00000000000000))*(cj4));
IkReal x5971=((sj0)*(sj5));
IkReal x5972=((cj0)*(cj5));
IkReal x5973=((cj6)*(r01));
IkReal x5974=((r00)*(sj6));
IkReal x5975=((cj6)*(r11));
IkReal x5976=((cj5)*(sj0));
IkReal x5977=((cj6)*(sj4));
IkReal x5978=((sj4)*(sj6));
IkReal x5979=((cj4)*(cj5));
IkReal x5980=((cj6)*(r21));
IkReal x5981=((r20)*(sj6));
IkReal x5982=((r10)*(sj6));
IkReal x5983=((cj1)*(x5968));
IkReal x5984=((IkReal(1.00000000000000))*(cj0)*(sj5));
IkReal x5985=((IkReal(1.00000000000000))*(x5969));
IkReal x5986=((IkReal(1.00000000000000))*(sj1)*(x5968));
IkReal x5987=((cj1)*(x5985));
IkReal x5988=((x5986)+(x5987));
evalcond[0]=((((sj5)*(x5980)))+(((IkReal(-1.00000000000000))*(cj5)*(r22)))+(((sj5)*(x5981)))+(((IkReal(-1.00000000000000))*(x5988))));
evalcond[1]=((((IkReal(-1.00000000000000))*(r21)*(x5978)))+(((IkReal(-1.00000000000000))*(sj1)*(x5985)))+(x5983)+(((x5979)*(x5980)))+(((cj4)*(r22)*(sj5)))+(((r20)*(x5977)))+(((x5979)*(x5981))));
evalcond[2]=((((IkReal(-1.00000000000000))*(x5983)))+(((IkReal(-1.00000000000000))*(x5973)*(x5984)))+(((IkReal(-1.00000000000000))*(x5971)*(x5975)))+(((IkReal(-1.00000000000000))*(x5971)*(x5982)))+(((r12)*(x5976)))+(((IkReal(-1.00000000000000))*(x5974)*(x5984)))+(((sj1)*(x5969)))+(((r02)*(x5972))));
evalcond[3]=((((IkReal(-1.00000000000000))*(x5970)*(x5972)*(x5974)))+(((r11)*(sj0)*(x5978)))+(((IkReal(-1.00000000000000))*(r12)*(x5970)*(x5971)))+(((cj0)*(r01)*(x5978)))+(((IkReal(-1.00000000000000))*(cj0)*(r00)*(x5977)))+(((IkReal(-1.00000000000000))*(x5970)*(x5976)*(x5982)))+(((IkReal(-1.00000000000000))*(x5970)*(x5972)*(x5973)))+(((IkReal(-1.00000000000000))*(cj0)*(r02)*(sj5)*(x5970)))+(((IkReal(-1.00000000000000))*(x5988)))+(((IkReal(-1.00000000000000))*(x5970)*(x5975)*(x5976)))+(((IkReal(-1.00000000000000))*(r10)*(sj0)*(x5977))));
if( IKabs(evalcond[0]) > 0.000001  || IKabs(evalcond[1]) > 0.000001  || IKabs(evalcond[2]) > 0.000001  || IKabs(evalcond[3]) > 0.000001  )
{
continue;
}
}

{
std::vector<IkSingleDOFSolutionBase<IkReal> > vinfos(7);
vinfos[0].jointtype = 1;
vinfos[0].foffset = j0;
vinfos[0].indices[0] = _ij0[0];
vinfos[0].indices[1] = _ij0[1];
vinfos[0].maxsolutions = _nj0;
vinfos[1].jointtype = 1;
vinfos[1].foffset = j1;
vinfos[1].indices[0] = _ij1[0];
vinfos[1].indices[1] = _ij1[1];
vinfos[1].maxsolutions = _nj1;
vinfos[2].jointtype = 1;
vinfos[2].foffset = j2;
vinfos[2].indices[0] = _ij2[0];
vinfos[2].indices[1] = _ij2[1];
vinfos[2].maxsolutions = _nj2;
vinfos[3].jointtype = 1;
vinfos[3].foffset = j3;
vinfos[3].indices[0] = _ij3[0];
vinfos[3].indices[1] = _ij3[1];
vinfos[3].maxsolutions = _nj3;
vinfos[4].jointtype = 1;
vinfos[4].foffset = j4;
vinfos[4].indices[0] = _ij4[0];
vinfos[4].indices[1] = _ij4[1];
vinfos[4].maxsolutions = _nj4;
vinfos[5].jointtype = 1;
vinfos[5].foffset = j5;
vinfos[5].indices[0] = _ij5[0];
vinfos[5].indices[1] = _ij5[1];
vinfos[5].maxsolutions = _nj5;
vinfos[6].jointtype = 1;
vinfos[6].foffset = j6;
vinfos[6].indices[0] = _ij6[0];
vinfos[6].indices[1] = _ij6[1];
vinfos[6].maxsolutions = _nj6;
std::vector<int> vfree(0);
solutions.AddSolution(vinfos,vfree);
}
}
}

}

}

} else
{
IkReal x5989=((cj5)*(sj4));
IkReal x5990=((IkReal(1.00000000000000))*(sj6));
IkReal x5991=((r10)*(sj0));
IkReal x5992=((sj4)*(sj5));
IkReal x5993=((cj4)*(cj5));
IkReal x5994=((IkReal(1.00000000000000))*(r02));
IkReal x5995=((IkReal(0.374290000000000))*(cj0));
IkReal x5996=((cj5)*(r12));
IkReal x5997=((cj6)*(sj5));
IkReal x5998=((cj0)*(r11));
IkReal x5999=((cj5)*(sj0));
IkReal x6000=((r20)*(sj6));
IkReal x6001=((IkReal(1.00000000000000))*(sj0));
IkReal x6002=((IkReal(1.00000000000000))*(cj6));
IkReal x6003=((IkReal(0.0100000000000000))*(cj5));
IkReal x6004=((IkReal(0.0100000000000000))*(sj5));
IkReal x6005=((sj5)*(sj6));
IkReal x6006=((cj0)*(r10));
IkReal x6007=((cj4)*(cj6));
IkReal x6008=((cj0)*(r01));
IkReal x6009=((cj0)*(r00));
IkReal x6010=((cj6)*(r21));
IkReal x6011=((IkReal(0.374290000000000))*(sj0));
IkReal x6012=((IkReal(0.374290000000000))*(sj5));
IkReal x6013=((cj6)*(r11));
IkReal x6014=((sj0)*(sj4));
IkReal x6015=((cj4)*(sj5));
IkReal x6016=((cj4)*(sj6));
IkReal x6017=((IkReal(1.00000000000000))*(cj0));
IkReal x6018=((r02)*(sj0));
IkReal x6019=((r00)*(sj0)*(sj6));
IkReal x6020=((cj6)*(r01)*(sj0));
IkReal x6021=((r00)*(x6007));
IkReal x6022=((r12)*(x6017));
evalcond[0]=((IkReal(-3.14159265358979))+(IKfmod(j2, IkReal(6.28318530717959))));
evalcond[1]=((((r22)*(x5992)))+(((x5989)*(x6000)))+(((IkReal(-1.00000000000000))*(cj4)*(r20)*(x6002)))+(((x5989)*(x6010)))+(((r21)*(x6016))));
evalcond[2]=((((IkReal(-1.00000000000000))*(x6000)*(x6003)))+(((IkReal(0.364420000000000))*(sj1)))+(((IkReal(-0.0690000000000000))*(cj1)))+(((IkReal(-1.00000000000000))*(x6003)*(x6010)))+(((IkReal(-0.374290000000000))*(cj5)*(r22)))+(pz)+(((x6000)*(x6012)))+(((IkReal(0.374290000000000))*(r21)*(x5997)))+(((IkReal(-1.00000000000000))*(r22)*(x6004))));
evalcond[3]=((((IkReal(-1.00000000000000))*(sj5)*(x5990)*(x6006)))+(((cj0)*(x5996)))+(((IkReal(-1.00000000000000))*(x5994)*(x5999)))+(((r01)*(sj0)*(x5997)))+(((r00)*(sj0)*(x6005)))+(((IkReal(-1.00000000000000))*(x5997)*(x5998))));
evalcond[4]=((IkReal(-1.00000000000000))+(((x5989)*(x6020)))+(((x5992)*(x6018)))+(((r01)*(sj0)*(x6016)))+(((IkReal(-1.00000000000000))*(cj4)*(x5990)*(x5998)))+(((x6006)*(x6007)))+(((IkReal(-1.00000000000000))*(x5992)*(x6022)))+(((x5989)*(x6019)))+(((IkReal(-1.00000000000000))*(x6001)*(x6021)))+(((IkReal(-1.00000000000000))*(x5989)*(x5990)*(x6006)))+(((IkReal(-1.00000000000000))*(x5989)*(x5998)*(x6002))));
evalcond[5]=((((sj4)*(sj6)*(x5998)))+(((x5993)*(x6020)))+(((x5993)*(x6019)))+(((IkReal(-1.00000000000000))*(x5990)*(x5993)*(x6006)))+(((IkReal(-1.00000000000000))*(x5993)*(x5998)*(x6002)))+(((x6015)*(x6018)))+(((cj6)*(r00)*(x6014)))+(((IkReal(-1.00000000000000))*(x6015)*(x6022)))+(((IkReal(-1.00000000000000))*(r01)*(x5990)*(x6014)))+(((IkReal(-1.00000000000000))*(sj4)*(x6002)*(x6006))));
evalcond[6]=((((IkReal(-1.00000000000000))*(x5989)*(x6002)*(x6008)))+(((x5991)*(x6007)))+(((IkReal(-1.00000000000000))*(r12)*(x5992)*(x6001)))+(((IkReal(-1.00000000000000))*(x5989)*(x6001)*(x6013)))+(((IkReal(-1.00000000000000))*(cj4)*(x5990)*(x6008)))+(((x6007)*(x6009)))+(((IkReal(-1.00000000000000))*(x5989)*(x5990)*(x6009)))+(((IkReal(-1.00000000000000))*(cj4)*(r11)*(sj0)*(x5990)))+(((IkReal(-1.00000000000000))*(x5989)*(x5990)*(x5991)))+(((IkReal(-1.00000000000000))*(cj0)*(x5992)*(x5994))));
evalcond[7]=((((IkReal(-1.00000000000000))*(py)*(x6017)))+(((r01)*(x5997)*(x6011)))+(((IkReal(-1.00000000000000))*(x6004)*(x6018)))+(((IkReal(-1.00000000000000))*(r11)*(x5995)*(x5997)))+(((x5995)*(x5996)))+(((sj6)*(x6003)*(x6006)))+(((IkReal(-0.0100000000000000))*(r00)*(sj6)*(x5999)))+(((cj0)*(r12)*(x6004)))+(((IkReal(-0.0100000000000000))*(cj6)*(r01)*(x5999)))+(((IkReal(-0.374290000000000))*(r02)*(x5999)))+(((IkReal(-1.00000000000000))*(r10)*(x5995)*(x6005)))+(((r00)*(x6005)*(x6011)))+(((cj6)*(x5998)*(x6003)))+(((px)*(sj0))));
evalcond[8]=((IkReal(0.0690000000000000))+(((x5996)*(x6011)))+(((IkReal(-1.00000000000000))*(r01)*(x5995)*(x5997)))+(((IkReal(-1.00000000000000))*(r11)*(x5997)*(x6011)))+(((cj0)*(r02)*(x6004)))+(((cj6)*(x6003)*(x6008)))+(((IkReal(0.0690000000000000))*(sj1)))+(((IkReal(-1.00000000000000))*(r00)*(x5995)*(x6005)))+(((sj6)*(x6003)*(x6009)))+(((cj5)*(r02)*(x5995)))+(((IkReal(-0.374290000000000))*(x5991)*(x6005)))+(((IkReal(-1.00000000000000))*(px)*(x6017)))+(((IkReal(-1.00000000000000))*(py)*(x6001)))+(((IkReal(0.0100000000000000))*(x5999)*(x6013)))+(((r12)*(sj0)*(x6004)))+(((IkReal(0.364420000000000))*(cj1)))+(((sj6)*(x5991)*(x6003))));
if( IKabs(evalcond[0]) < 0.0000010000000000  && IKabs(evalcond[1]) < 0.0000010000000000  && IKabs(evalcond[2]) < 0.0000010000000000  && IKabs(evalcond[3]) < 0.0000010000000000  && IKabs(evalcond[4]) < 0.0000010000000000  && IKabs(evalcond[5]) < 0.0000010000000000  && IKabs(evalcond[6]) < 0.0000010000000000  && IKabs(evalcond[7]) < 0.0000010000000000  && IKabs(evalcond[8]) < 0.0000010000000000  )
{
{
IkReal dummyeval[1];
IkReal gconst7;
gconst7=IKsign((((cj1)*(cj1))+((sj1)*(sj1))));
dummyeval[0]=(((cj1)*(cj1))+((sj1)*(sj1)));
if( IKabs(dummyeval[0]) < 0.0000010000000000  )
{
{
IkReal dummyeval[1];
IkReal gconst8;
gconst8=IKsign((((cj1)*(cj1))+((sj1)*(sj1))));
dummyeval[0]=(((cj1)*(cj1))+((sj1)*(sj1)));
if( IKabs(dummyeval[0]) < 0.0000010000000000  )
{
continue;

} else
{
{
IkReal j3array[1], cj3array[1], sj3array[1];
bool j3valid[1]={false};
_nj3 = 1;
IkReal x6023=((IkReal(1.00000000000000))*(sj0));
IkReal x6024=((cj6)*(r21));
IkReal x6025=((cj0)*(r00));
IkReal x6026=((cj5)*(sj1));
IkReal x6027=((r12)*(sj0));
IkReal x6028=((cj1)*(cj5));
IkReal x6029=((cj0)*(r02));
IkReal x6030=((sj1)*(sj5));
IkReal x6031=((cj6)*(r11));
IkReal x6032=((cj1)*(sj5));
IkReal x6033=((sj6)*(x6030));
IkReal x6034=((IkReal(1.00000000000000))*(x6032));
IkReal x6035=((cj0)*(cj6)*(r01));
if( IKabs(((gconst8)*(((((x6026)*(x6029)))+(((IkReal(-1.00000000000000))*(x6023)*(x6030)*(x6031)))+(((IkReal(-1.00000000000000))*(r20)*(sj6)*(x6034)))+(((IkReal(-1.00000000000000))*(x6025)*(x6033)))+(((IkReal(-1.00000000000000))*(x6024)*(x6034)))+(((x6026)*(x6027)))+(((IkReal(-1.00000000000000))*(x6030)*(x6035)))+(((r22)*(x6028)))+(((IkReal(-1.00000000000000))*(r10)*(x6023)*(x6033))))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(((gconst8)*(((((IkReal(-1.00000000000000))*(r10)*(sj6)*(x6023)*(x6032)))+(((x6028)*(x6029)))+(((IkReal(-1.00000000000000))*(x6023)*(x6031)*(x6032)))+(((IkReal(-1.00000000000000))*(x6034)*(x6035)))+(((x6027)*(x6028)))+(((IkReal(-1.00000000000000))*(sj6)*(x6025)*(x6034)))+(((IkReal(-1.00000000000000))*(r22)*(x6026)))+(((r20)*(x6033)))+(((x6024)*(x6030))))))) < IKFAST_ATAN2_MAGTHRESH )
    continue;
j3array[0]=IKatan2(((gconst8)*(((((x6026)*(x6029)))+(((IkReal(-1.00000000000000))*(x6023)*(x6030)*(x6031)))+(((IkReal(-1.00000000000000))*(r20)*(sj6)*(x6034)))+(((IkReal(-1.00000000000000))*(x6025)*(x6033)))+(((IkReal(-1.00000000000000))*(x6024)*(x6034)))+(((x6026)*(x6027)))+(((IkReal(-1.00000000000000))*(x6030)*(x6035)))+(((r22)*(x6028)))+(((IkReal(-1.00000000000000))*(r10)*(x6023)*(x6033)))))), ((gconst8)*(((((IkReal(-1.00000000000000))*(r10)*(sj6)*(x6023)*(x6032)))+(((x6028)*(x6029)))+(((IkReal(-1.00000000000000))*(x6023)*(x6031)*(x6032)))+(((IkReal(-1.00000000000000))*(x6034)*(x6035)))+(((x6027)*(x6028)))+(((IkReal(-1.00000000000000))*(sj6)*(x6025)*(x6034)))+(((IkReal(-1.00000000000000))*(r22)*(x6026)))+(((r20)*(x6033)))+(((x6024)*(x6030)))))));
sj3array[0]=IKsin(j3array[0]);
cj3array[0]=IKcos(j3array[0]);
if( j3array[0] > IKPI )
{
    j3array[0]-=IK2PI;
}
else if( j3array[0] < -IKPI )
{    j3array[0]+=IK2PI;
}
j3valid[0] = true;
for(int ij3 = 0; ij3 < 1; ++ij3)
{
if( !j3valid[ij3] )
{
    continue;
}
_ij3[0] = ij3; _ij3[1] = -1;
for(int iij3 = ij3+1; iij3 < 1; ++iij3)
{
if( j3valid[iij3] && IKabs(cj3array[ij3]-cj3array[iij3]) < IKFAST_SOLUTION_THRESH && IKabs(sj3array[ij3]-sj3array[iij3]) < IKFAST_SOLUTION_THRESH )
{
    j3valid[iij3]=false; _ij3[1] = iij3; break; 
}
}
j3 = j3array[ij3]; cj3 = cj3array[ij3]; sj3 = sj3array[ij3];
{
IkReal evalcond[4];
IkReal x6036=IKsin(j3);
IkReal x6037=IKcos(j3);
IkReal x6038=((IkReal(1.00000000000000))*(cj4));
IkReal x6039=((sj0)*(sj5));
IkReal x6040=((cj0)*(cj5));
IkReal x6041=((cj6)*(r01));
IkReal x6042=((r00)*(sj6));
IkReal x6043=((cj6)*(r11));
IkReal x6044=((cj5)*(sj0));
IkReal x6045=((cj6)*(sj4));
IkReal x6046=((sj4)*(sj6));
IkReal x6047=((cj4)*(cj5));
IkReal x6048=((cj6)*(r21));
IkReal x6049=((r20)*(sj6));
IkReal x6050=((r10)*(sj6));
IkReal x6051=((cj1)*(x6036));
IkReal x6052=((IkReal(1.00000000000000))*(cj0)*(sj5));
IkReal x6053=((IkReal(1.00000000000000))*(x6037));
IkReal x6054=((IkReal(1.00000000000000))*(sj1)*(x6036));
IkReal x6055=((cj1)*(x6053));
IkReal x6056=((x6055)+(x6054));
evalcond[0]=((((sj5)*(x6049)))+(((IkReal(-1.00000000000000))*(sj1)*(x6053)))+(((IkReal(-1.00000000000000))*(cj5)*(r22)))+(x6051)+(((sj5)*(x6048))));
evalcond[1]=((((x6047)*(x6048)))+(((IkReal(-1.00000000000000))*(r21)*(x6046)))+(((cj4)*(r22)*(sj5)))+(((r20)*(x6045)))+(((x6047)*(x6049)))+(((IkReal(-1.00000000000000))*(x6056))));
evalcond[2]=((((IkReal(-1.00000000000000))*(x6039)*(x6043)))+(((IkReal(-1.00000000000000))*(x6042)*(x6052)))+(((r02)*(x6040)))+(((IkReal(-1.00000000000000))*(x6041)*(x6052)))+(((IkReal(-1.00000000000000))*(x6039)*(x6050)))+(((IkReal(-1.00000000000000))*(x6056)))+(((r12)*(x6044))));
evalcond[3]=((((IkReal(-1.00000000000000))*(r12)*(x6038)*(x6039)))+(((IkReal(-1.00000000000000))*(x6038)*(x6040)*(x6042)))+(((IkReal(-1.00000000000000))*(x6051)))+(((IkReal(-1.00000000000000))*(cj0)*(r00)*(x6045)))+(((sj1)*(x6037)))+(((IkReal(-1.00000000000000))*(r10)*(sj0)*(x6045)))+(((IkReal(-1.00000000000000))*(x6038)*(x6043)*(x6044)))+(((IkReal(-1.00000000000000))*(cj0)*(r02)*(sj5)*(x6038)))+(((IkReal(-1.00000000000000))*(x6038)*(x6040)*(x6041)))+(((IkReal(-1.00000000000000))*(x6038)*(x6044)*(x6050)))+(((r11)*(sj0)*(x6046)))+(((cj0)*(r01)*(x6046))));
if( IKabs(evalcond[0]) > 0.000001  || IKabs(evalcond[1]) > 0.000001  || IKabs(evalcond[2]) > 0.000001  || IKabs(evalcond[3]) > 0.000001  )
{
continue;
}
}

{
std::vector<IkSingleDOFSolutionBase<IkReal> > vinfos(7);
vinfos[0].jointtype = 1;
vinfos[0].foffset = j0;
vinfos[0].indices[0] = _ij0[0];
vinfos[0].indices[1] = _ij0[1];
vinfos[0].maxsolutions = _nj0;
vinfos[1].jointtype = 1;
vinfos[1].foffset = j1;
vinfos[1].indices[0] = _ij1[0];
vinfos[1].indices[1] = _ij1[1];
vinfos[1].maxsolutions = _nj1;
vinfos[2].jointtype = 1;
vinfos[2].foffset = j2;
vinfos[2].indices[0] = _ij2[0];
vinfos[2].indices[1] = _ij2[1];
vinfos[2].maxsolutions = _nj2;
vinfos[3].jointtype = 1;
vinfos[3].foffset = j3;
vinfos[3].indices[0] = _ij3[0];
vinfos[3].indices[1] = _ij3[1];
vinfos[3].maxsolutions = _nj3;
vinfos[4].jointtype = 1;
vinfos[4].foffset = j4;
vinfos[4].indices[0] = _ij4[0];
vinfos[4].indices[1] = _ij4[1];
vinfos[4].maxsolutions = _nj4;
vinfos[5].jointtype = 1;
vinfos[5].foffset = j5;
vinfos[5].indices[0] = _ij5[0];
vinfos[5].indices[1] = _ij5[1];
vinfos[5].maxsolutions = _nj5;
vinfos[6].jointtype = 1;
vinfos[6].foffset = j6;
vinfos[6].indices[0] = _ij6[0];
vinfos[6].indices[1] = _ij6[1];
vinfos[6].maxsolutions = _nj6;
std::vector<int> vfree(0);
solutions.AddSolution(vinfos,vfree);
}
}
}

}

}

} else
{
{
IkReal j3array[1], cj3array[1], sj3array[1];
bool j3valid[1]={false};
_nj3 = 1;
IkReal x6057=((sj1)*(sj6));
IkReal x6058=((r20)*(sj5));
IkReal x6059=((IkReal(1.00000000000000))*(r21));
IkReal x6060=((cj1)*(cj6));
IkReal x6061=((r20)*(sj4));
IkReal x6062=((cj6)*(sj1));
IkReal x6063=((cj4)*(cj5));
IkReal x6064=((cj1)*(sj6));
IkReal x6065=((cj5)*(r22));
IkReal x6066=((cj4)*(r22)*(sj5));
if( IKabs(((gconst7)*(((((IkReal(-1.00000000000000))*(sj5)*(x6059)*(x6060)))+(((r21)*(x6062)*(x6063)))+(((cj1)*(x6065)))+(((x6061)*(x6062)))+(((IkReal(-1.00000000000000))*(sj4)*(x6057)*(x6059)))+(((sj1)*(x6066)))+(((r20)*(x6057)*(x6063)))+(((IkReal(-1.00000000000000))*(x6058)*(x6064))))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(((gconst7)*(((((IkReal(-1.00000000000000))*(sj1)*(x6065)))+(((r20)*(x6063)*(x6064)))+(((cj1)*(x6066)))+(((IkReal(-1.00000000000000))*(sj4)*(x6059)*(x6064)))+(((x6057)*(x6058)))+(((r21)*(sj5)*(x6062)))+(((x6060)*(x6061)))+(((r21)*(x6060)*(x6063))))))) < IKFAST_ATAN2_MAGTHRESH )
    continue;
j3array[0]=IKatan2(((gconst7)*(((((IkReal(-1.00000000000000))*(sj5)*(x6059)*(x6060)))+(((r21)*(x6062)*(x6063)))+(((cj1)*(x6065)))+(((x6061)*(x6062)))+(((IkReal(-1.00000000000000))*(sj4)*(x6057)*(x6059)))+(((sj1)*(x6066)))+(((r20)*(x6057)*(x6063)))+(((IkReal(-1.00000000000000))*(x6058)*(x6064)))))), ((gconst7)*(((((IkReal(-1.00000000000000))*(sj1)*(x6065)))+(((r20)*(x6063)*(x6064)))+(((cj1)*(x6066)))+(((IkReal(-1.00000000000000))*(sj4)*(x6059)*(x6064)))+(((x6057)*(x6058)))+(((r21)*(sj5)*(x6062)))+(((x6060)*(x6061)))+(((r21)*(x6060)*(x6063)))))));
sj3array[0]=IKsin(j3array[0]);
cj3array[0]=IKcos(j3array[0]);
if( j3array[0] > IKPI )
{
    j3array[0]-=IK2PI;
}
else if( j3array[0] < -IKPI )
{    j3array[0]+=IK2PI;
}
j3valid[0] = true;
for(int ij3 = 0; ij3 < 1; ++ij3)
{
if( !j3valid[ij3] )
{
    continue;
}
_ij3[0] = ij3; _ij3[1] = -1;
for(int iij3 = ij3+1; iij3 < 1; ++iij3)
{
if( j3valid[iij3] && IKabs(cj3array[ij3]-cj3array[iij3]) < IKFAST_SOLUTION_THRESH && IKabs(sj3array[ij3]-sj3array[iij3]) < IKFAST_SOLUTION_THRESH )
{
    j3valid[iij3]=false; _ij3[1] = iij3; break; 
}
}
j3 = j3array[ij3]; cj3 = cj3array[ij3]; sj3 = sj3array[ij3];
{
IkReal evalcond[4];
IkReal x6067=IKsin(j3);
IkReal x6068=IKcos(j3);
IkReal x6069=((IkReal(1.00000000000000))*(cj4));
IkReal x6070=((sj0)*(sj5));
IkReal x6071=((cj0)*(cj5));
IkReal x6072=((cj6)*(r01));
IkReal x6073=((r00)*(sj6));
IkReal x6074=((cj6)*(r11));
IkReal x6075=((cj5)*(sj0));
IkReal x6076=((cj6)*(sj4));
IkReal x6077=((sj4)*(sj6));
IkReal x6078=((cj4)*(cj5));
IkReal x6079=((cj6)*(r21));
IkReal x6080=((r20)*(sj6));
IkReal x6081=((r10)*(sj6));
IkReal x6082=((cj1)*(x6067));
IkReal x6083=((IkReal(1.00000000000000))*(cj0)*(sj5));
IkReal x6084=((IkReal(1.00000000000000))*(x6068));
IkReal x6085=((IkReal(1.00000000000000))*(sj1)*(x6067));
IkReal x6086=((cj1)*(x6084));
IkReal x6087=((x6086)+(x6085));
evalcond[0]=((((sj5)*(x6080)))+(((IkReal(-1.00000000000000))*(sj1)*(x6084)))+(((IkReal(-1.00000000000000))*(cj5)*(r22)))+(x6082)+(((sj5)*(x6079))));
evalcond[1]=((((x6078)*(x6080)))+(((IkReal(-1.00000000000000))*(r21)*(x6077)))+(((cj4)*(r22)*(sj5)))+(((IkReal(-1.00000000000000))*(x6087)))+(((x6078)*(x6079)))+(((r20)*(x6076))));
evalcond[2]=((((IkReal(-1.00000000000000))*(x6070)*(x6074)))+(((IkReal(-1.00000000000000))*(x6072)*(x6083)))+(((IkReal(-1.00000000000000))*(x6073)*(x6083)))+(((r12)*(x6075)))+(((r02)*(x6071)))+(((IkReal(-1.00000000000000))*(x6087)))+(((IkReal(-1.00000000000000))*(x6070)*(x6081))));
evalcond[3]=((((IkReal(-1.00000000000000))*(x6069)*(x6071)*(x6073)))+(((IkReal(-1.00000000000000))*(r10)*(sj0)*(x6076)))+(((sj1)*(x6068)))+(((IkReal(-1.00000000000000))*(cj0)*(r02)*(sj5)*(x6069)))+(((IkReal(-1.00000000000000))*(r12)*(x6069)*(x6070)))+(((IkReal(-1.00000000000000))*(x6069)*(x6075)*(x6081)))+(((IkReal(-1.00000000000000))*(x6069)*(x6074)*(x6075)))+(((r11)*(sj0)*(x6077)))+(((IkReal(-1.00000000000000))*(x6069)*(x6071)*(x6072)))+(((cj0)*(r01)*(x6077)))+(((IkReal(-1.00000000000000))*(x6082)))+(((IkReal(-1.00000000000000))*(cj0)*(r00)*(x6076))));
if( IKabs(evalcond[0]) > 0.000001  || IKabs(evalcond[1]) > 0.000001  || IKabs(evalcond[2]) > 0.000001  || IKabs(evalcond[3]) > 0.000001  )
{
continue;
}
}

{
std::vector<IkSingleDOFSolutionBase<IkReal> > vinfos(7);
vinfos[0].jointtype = 1;
vinfos[0].foffset = j0;
vinfos[0].indices[0] = _ij0[0];
vinfos[0].indices[1] = _ij0[1];
vinfos[0].maxsolutions = _nj0;
vinfos[1].jointtype = 1;
vinfos[1].foffset = j1;
vinfos[1].indices[0] = _ij1[0];
vinfos[1].indices[1] = _ij1[1];
vinfos[1].maxsolutions = _nj1;
vinfos[2].jointtype = 1;
vinfos[2].foffset = j2;
vinfos[2].indices[0] = _ij2[0];
vinfos[2].indices[1] = _ij2[1];
vinfos[2].maxsolutions = _nj2;
vinfos[3].jointtype = 1;
vinfos[3].foffset = j3;
vinfos[3].indices[0] = _ij3[0];
vinfos[3].indices[1] = _ij3[1];
vinfos[3].maxsolutions = _nj3;
vinfos[4].jointtype = 1;
vinfos[4].foffset = j4;
vinfos[4].indices[0] = _ij4[0];
vinfos[4].indices[1] = _ij4[1];
vinfos[4].maxsolutions = _nj4;
vinfos[5].jointtype = 1;
vinfos[5].foffset = j5;
vinfos[5].indices[0] = _ij5[0];
vinfos[5].indices[1] = _ij5[1];
vinfos[5].maxsolutions = _nj5;
vinfos[6].jointtype = 1;
vinfos[6].foffset = j6;
vinfos[6].indices[0] = _ij6[0];
vinfos[6].indices[1] = _ij6[1];
vinfos[6].maxsolutions = _nj6;
std::vector<int> vfree(0);
solutions.AddSolution(vinfos,vfree);
}
}
}

}

}

} else
{
IkReal x6088=((IkReal(1.00000000000000))*(cj0));
IkReal x6089=((cj4)*(sj6));
IkReal x6090=((sj0)*(sj4));
IkReal x6091=((cj5)*(sj6));
IkReal x6092=((sj4)*(sj5));
IkReal x6093=((r12)*(sj5));
IkReal x6094=((IkReal(0.374290000000000))*(cj5));
IkReal x6095=((r02)*(sj0));
IkReal x6096=((cj6)*(r21));
IkReal x6097=((IkReal(0.0100000000000000))*(cj5));
IkReal x6098=((IkReal(1.00000000000000))*(sj0));
IkReal x6099=((cj0)*(r10));
IkReal x6100=((cj4)*(cj6));
IkReal x6101=((r00)*(sj0));
IkReal x6102=((IkReal(0.374290000000000))*(sj5));
IkReal x6103=((cj0)*(r00));
IkReal x6104=((IkReal(0.0100000000000000))*(sj5));
IkReal x6105=((cj0)*(r02));
IkReal x6106=((cj5)*(sj4));
IkReal x6107=((cj6)*(r01));
IkReal x6108=((cj6)*(r11));
IkReal x6109=((r10)*(sj0));
IkReal x6110=((sj6)*(x6102));
IkReal x6111=((cj0)*(cj6)*(x6102));
evalcond[0]=((IkReal(-3.14159265358979))+(IKfmod(((IkReal(3.14159265358979))+(j1)), IkReal(6.28318530717959))));
evalcond[1]=((((IkReal(-1.00000000000000))*(sj2)))+(((IkReal(-1.00000000000000))*(r20)*(x6100)))+(((r22)*(x6092)))+(((r20)*(sj4)*(x6091)))+(((x6096)*(x6106)))+(((r21)*(x6089))));
evalcond[2]=((((IkReal(-0.0100000000000000))*(r20)*(x6091)))+(((IkReal(-1.00000000000000))*(r22)*(x6094)))+(((IkReal(-1.00000000000000))*(r22)*(x6104)))+(pz)+(((r20)*(x6110)))+(((IkReal(-1.00000000000000))*(x6096)*(x6097)))+(((x6096)*(x6102)))+(((IkReal(0.0690000000000000))*(cj2))));
evalcond[3]=((((IkReal(-1.00000000000000))*(r11)*(x6088)*(x6089)))+(((x6099)*(x6100)))+(((IkReal(-1.00000000000000))*(x6088)*(x6106)*(x6108)))+(((r01)*(sj0)*(x6089)))+(((cj5)*(x6090)*(x6107)))+(((r00)*(x6090)*(x6091)))+(cj2)+(((IkReal(-1.00000000000000))*(r00)*(x6098)*(x6100)))+(((r02)*(sj5)*(x6090)))+(((IkReal(-1.00000000000000))*(r10)*(sj4)*(x6088)*(x6091)))+(((IkReal(-1.00000000000000))*(r12)*(x6088)*(x6092))));
evalcond[4]=((((IkReal(-1.00000000000000))*(x6090)*(x6093)))+(((IkReal(-1.00000000000000))*(r11)*(x6089)*(x6098)))+(((IkReal(-1.00000000000000))*(r01)*(x6088)*(x6089)))+(((IkReal(-1.00000000000000))*(r10)*(x6090)*(x6091)))+(((x6100)*(x6109)))+(((x6100)*(x6103)))+(((IkReal(-1.00000000000000))*(x6088)*(x6106)*(x6107)))+(((IkReal(-1.00000000000000))*(cj5)*(x6090)*(x6108)))+(((IkReal(-1.00000000000000))*(r02)*(x6088)*(x6092)))+(((IkReal(-1.00000000000000))*(r00)*(sj4)*(x6088)*(x6091))));
evalcond[5]=((((IkReal(-1.00000000000000))*(x6099)*(x6110)))+(((x6101)*(x6110)))+(((IkReal(-1.00000000000000))*(sj0)*(x6097)*(x6107)))+(((IkReal(-1.00000000000000))*(py)*(x6088)))+(((IkReal(-0.0100000000000000))*(x6091)*(x6101)))+(((IkReal(-1.00000000000000))*(cj0)*(x6102)*(x6108)))+(((IkReal(0.0690000000000000))*(sj2)))+(((cj0)*(x6097)*(x6108)))+(((IkReal(0.0100000000000000))*(cj0)*(x6093)))+(((IkReal(0.0100000000000000))*(x6091)*(x6099)))+(((px)*(sj0)))+(((cj0)*(r12)*(x6094)))+(((sj0)*(x6102)*(x6107)))+(((IkReal(-1.00000000000000))*(x6095)*(x6104)))+(((IkReal(-1.00000000000000))*(x6094)*(x6095))));
evalcond[6]=((IkReal(0.433420000000000))+(((x6094)*(x6105)))+(((IkReal(-1.00000000000000))*(px)*(x6088)))+(((IkReal(-1.00000000000000))*(py)*(x6098)))+(((sj0)*(x6097)*(x6108)))+(((IkReal(-1.00000000000000))*(x6103)*(x6110)))+(((IkReal(0.0100000000000000))*(x6091)*(x6109)))+(((r12)*(sj0)*(x6094)))+(((IkReal(-1.00000000000000))*(sj0)*(x6102)*(x6108)))+(((IkReal(-1.00000000000000))*(cj0)*(x6102)*(x6107)))+(((x6104)*(x6105)))+(((cj0)*(x6097)*(x6107)))+(((IkReal(-1.00000000000000))*(x6109)*(x6110)))+(((IkReal(0.0100000000000000))*(x6091)*(x6103)))+(((IkReal(0.0100000000000000))*(sj0)*(x6093))));
if( IKabs(evalcond[0]) < 0.0000010000000000  && IKabs(evalcond[1]) < 0.0000010000000000  && IKabs(evalcond[2]) < 0.0000010000000000  && IKabs(evalcond[3]) < 0.0000010000000000  && IKabs(evalcond[4]) < 0.0000010000000000  && IKabs(evalcond[5]) < 0.0000010000000000  && IKabs(evalcond[6]) < 0.0000010000000000  )
{
{
IkReal dummyeval[1];
IkReal gconst9;
gconst9=IKsign(cj2);
dummyeval[0]=cj2;
if( IKabs(dummyeval[0]) < 0.0000010000000000  )
{
{
IkReal dummyeval[1];
dummyeval[0]=cj2;
if( IKabs(dummyeval[0]) < 0.0000010000000000  )
{
{
IkReal dummyeval[1];
dummyeval[0]=sj2;
if( IKabs(dummyeval[0]) < 0.0000010000000000  )
{
{
IkReal evalcond[9];
IkReal x6112=((cj5)*(sj4));
IkReal x6113=((IkReal(1.00000000000000))*(sj6));
IkReal x6114=((r10)*(sj0));
IkReal x6115=((sj4)*(sj5));
IkReal x6116=((cj5)*(cj6));
IkReal x6117=((r01)*(sj0));
IkReal x6118=((IkReal(1.00000000000000))*(r02));
IkReal x6119=((IkReal(0.374290000000000))*(cj0));
IkReal x6120=((cj5)*(r12));
IkReal x6121=((cj6)*(sj5));
IkReal x6122=((cj0)*(r11));
IkReal x6123=((cj5)*(sj0));
IkReal x6124=((r20)*(sj6));
IkReal x6125=((IkReal(1.00000000000000))*(sj0));
IkReal x6126=((cj4)*(cj5));
IkReal x6127=((IkReal(1.00000000000000))*(cj6));
IkReal x6128=((IkReal(0.0100000000000000))*(sj5));
IkReal x6129=((sj5)*(sj6));
IkReal x6130=((cj0)*(r10));
IkReal x6131=((cj4)*(cj6));
IkReal x6132=((cj0)*(r01));
IkReal x6133=((IkReal(1.00000000000000))*(cj4));
IkReal x6134=((cj0)*(r00));
IkReal x6135=((IkReal(0.374290000000000))*(sj0));
IkReal x6136=((cj0)*(r12));
IkReal x6137=((IkReal(0.374290000000000))*(sj5));
IkReal x6138=((cj4)*(sj6));
IkReal x6139=((IkReal(1.00000000000000))*(cj0));
IkReal x6140=((r02)*(sj0));
IkReal x6141=((IkReal(0.0100000000000000))*(cj5));
IkReal x6142=((r11)*(sj0));
IkReal x6143=((r00)*(sj0)*(sj6));
IkReal x6144=((r00)*(x6131));
IkReal x6145=((sj6)*(x6141));
evalcond[0]=((IkReal(-3.14159265358979))+(IKfmod(((IkReal(3.14159265358979))+(j2)), IkReal(6.28318530717959))));
evalcond[1]=((((IkReal(-1.00000000000000))*(cj4)*(r20)*(x6127)))+(((cj6)*(r21)*(x6112)))+(((x6112)*(x6124)))+(((r21)*(x6138)))+(((r22)*(x6115))));
evalcond[2]=((IkReal(0.0690000000000000))+(((IkReal(-1.00000000000000))*(r22)*(x6128)))+(((IkReal(-1.00000000000000))*(x6124)*(x6141)))+(((IkReal(0.374290000000000))*(r21)*(x6121)))+(((IkReal(-0.374290000000000))*(cj5)*(r22)))+(((x6124)*(x6137)))+(pz)+(((IkReal(-0.0100000000000000))*(r21)*(x6116))));
evalcond[3]=((((IkReal(-1.00000000000000))*(x6121)*(x6122)))+(((x6117)*(x6121)))+(((r00)*(sj0)*(x6129)))+(((cj0)*(x6120)))+(((IkReal(-1.00000000000000))*(sj5)*(x6113)*(x6130)))+(((IkReal(-1.00000000000000))*(x6118)*(x6123))));
evalcond[4]=((IkReal(1.00000000000000))+(((IkReal(-1.00000000000000))*(x6115)*(x6136)))+(((IkReal(-1.00000000000000))*(x6125)*(x6144)))+(((cj6)*(x6112)*(x6117)))+(((x6112)*(x6143)))+(((x6115)*(x6140)))+(((IkReal(-1.00000000000000))*(x6112)*(x6122)*(x6127)))+(((x6130)*(x6131)))+(((IkReal(-1.00000000000000))*(cj4)*(x6113)*(x6122)))+(((x6117)*(x6138)))+(((IkReal(-1.00000000000000))*(x6112)*(x6113)*(x6130))));
evalcond[5]=((((sj4)*(sj6)*(x6122)))+(((cj4)*(sj5)*(x6140)))+(((r00)*(x6123)*(x6138)))+(((IkReal(-1.00000000000000))*(x6116)*(x6122)*(x6133)))+(((cj6)*(r00)*(sj0)*(sj4)))+(((IkReal(-1.00000000000000))*(sj4)*(x6127)*(x6130)))+(((cj4)*(x6116)*(x6117)))+(((IkReal(-1.00000000000000))*(sj4)*(x6113)*(x6117)))+(((IkReal(-1.00000000000000))*(sj5)*(x6133)*(x6136)))+(((IkReal(-1.00000000000000))*(x6113)*(x6126)*(x6130))));
evalcond[6]=((((IkReal(-1.00000000000000))*(cj4)*(x6113)*(x6132)))+(((IkReal(-1.00000000000000))*(x6112)*(x6113)*(x6114)))+(((IkReal(-1.00000000000000))*(cj4)*(x6113)*(x6142)))+(((IkReal(-1.00000000000000))*(r12)*(x6115)*(x6125)))+(((IkReal(-1.00000000000000))*(cj0)*(x6115)*(x6118)))+(((x6114)*(x6131)))+(((IkReal(-1.00000000000000))*(cj6)*(r11)*(x6112)*(x6125)))+(((x6131)*(x6134)))+(((IkReal(-1.00000000000000))*(x6112)*(x6113)*(x6134)))+(((IkReal(-1.00000000000000))*(x6112)*(x6127)*(x6132))));
evalcond[7]=((((IkReal(-0.0100000000000000))*(r00)*(sj6)*(x6123)))+(((x6128)*(x6136)))+(((IkReal(-0.0100000000000000))*(x6116)*(x6117)))+(((x6119)*(x6120)))+(((IkReal(0.0100000000000000))*(x6116)*(x6122)))+(((IkReal(-0.374290000000000))*(r02)*(x6123)))+(((IkReal(-1.00000000000000))*(py)*(x6139)))+(((IkReal(-1.00000000000000))*(r10)*(x6119)*(x6129)))+(((IkReal(-1.00000000000000))*(r11)*(x6119)*(x6121)))+(((px)*(sj0)))+(((x6130)*(x6145)))+(((IkReal(0.374290000000000))*(x6117)*(x6121)))+(((r00)*(x6129)*(x6135)))+(((IkReal(-1.00000000000000))*(x6128)*(x6140))));
evalcond[8]=((IkReal(0.433420000000000))+(((cj5)*(r02)*(x6119)))+(((r12)*(sj0)*(x6128)))+(((IkReal(0.0100000000000000))*(x6116)*(x6142)))+(((IkReal(-1.00000000000000))*(px)*(x6139)))+(((IkReal(-1.00000000000000))*(r00)*(x6119)*(x6129)))+(((cj0)*(r02)*(x6128)))+(((IkReal(-1.00000000000000))*(py)*(x6125)))+(((x6134)*(x6145)))+(((IkReal(-1.00000000000000))*(r11)*(x6121)*(x6135)))+(((IkReal(-0.374290000000000))*(x6114)*(x6129)))+(((IkReal(0.0100000000000000))*(x6116)*(x6132)))+(((x6114)*(x6145)))+(((x6120)*(x6135)))+(((IkReal(-1.00000000000000))*(r01)*(x6119)*(x6121))));
if( IKabs(evalcond[0]) < 0.0000010000000000  && IKabs(evalcond[1]) < 0.0000010000000000  && IKabs(evalcond[2]) < 0.0000010000000000  && IKabs(evalcond[3]) < 0.0000010000000000  && IKabs(evalcond[4]) < 0.0000010000000000  && IKabs(evalcond[5]) < 0.0000010000000000  && IKabs(evalcond[6]) < 0.0000010000000000  && IKabs(evalcond[7]) < 0.0000010000000000  && IKabs(evalcond[8]) < 0.0000010000000000  )
{
{
IkReal j3array[1], cj3array[1], sj3array[1];
bool j3valid[1]={false};
_nj3 = 1;
IkReal x6146=((IkReal(1.00000000000000))*(cj4));
IkReal x6147=((cj6)*(r21));
IkReal x6148=((r20)*(sj6));
if( IKabs(((((sj5)*(x6147)))+(((sj5)*(x6148)))+(((IkReal(-1.00000000000000))*(cj5)*(r22))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(((((IkReal(-1.00000000000000))*(cj5)*(x6146)*(x6148)))+(((IkReal(-1.00000000000000))*(cj5)*(x6146)*(x6147)))+(((r21)*(sj4)*(sj6)))+(((IkReal(-1.00000000000000))*(r22)*(sj5)*(x6146)))+(((IkReal(-1.00000000000000))*(cj6)*(r20)*(sj4))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(IKsqr(((((sj5)*(x6147)))+(((sj5)*(x6148)))+(((IkReal(-1.00000000000000))*(cj5)*(r22)))))+IKsqr(((((IkReal(-1.00000000000000))*(cj5)*(x6146)*(x6148)))+(((IkReal(-1.00000000000000))*(cj5)*(x6146)*(x6147)))+(((r21)*(sj4)*(sj6)))+(((IkReal(-1.00000000000000))*(r22)*(sj5)*(x6146)))+(((IkReal(-1.00000000000000))*(cj6)*(r20)*(sj4)))))-1) <= IKFAST_SINCOS_THRESH )
    continue;
j3array[0]=IKatan2(((((sj5)*(x6147)))+(((sj5)*(x6148)))+(((IkReal(-1.00000000000000))*(cj5)*(r22)))), ((((IkReal(-1.00000000000000))*(cj5)*(x6146)*(x6148)))+(((IkReal(-1.00000000000000))*(cj5)*(x6146)*(x6147)))+(((r21)*(sj4)*(sj6)))+(((IkReal(-1.00000000000000))*(r22)*(sj5)*(x6146)))+(((IkReal(-1.00000000000000))*(cj6)*(r20)*(sj4)))));
sj3array[0]=IKsin(j3array[0]);
cj3array[0]=IKcos(j3array[0]);
if( j3array[0] > IKPI )
{
    j3array[0]-=IK2PI;
}
else if( j3array[0] < -IKPI )
{    j3array[0]+=IK2PI;
}
j3valid[0] = true;
for(int ij3 = 0; ij3 < 1; ++ij3)
{
if( !j3valid[ij3] )
{
    continue;
}
_ij3[0] = ij3; _ij3[1] = -1;
for(int iij3 = ij3+1; iij3 < 1; ++iij3)
{
if( j3valid[iij3] && IKabs(cj3array[ij3]-cj3array[iij3]) < IKFAST_SOLUTION_THRESH && IKabs(sj3array[ij3]-sj3array[iij3]) < IKFAST_SOLUTION_THRESH )
{
    j3valid[iij3]=false; _ij3[1] = iij3; break; 
}
}
j3 = j3array[ij3]; cj3 = cj3array[ij3]; sj3 = sj3array[ij3];
{
IkReal evalcond[4];
IkReal x6149=IKcos(j3);
IkReal x6150=((IkReal(1.00000000000000))*(cj4));
IkReal x6151=((sj0)*(sj5));
IkReal x6152=((cj0)*(cj5));
IkReal x6153=((cj6)*(r01));
IkReal x6154=((r00)*(sj6));
IkReal x6155=((cj6)*(r11));
IkReal x6156=((cj5)*(sj0));
IkReal x6157=((cj6)*(sj4));
IkReal x6158=((sj4)*(sj6));
IkReal x6159=((cj4)*(cj5));
IkReal x6160=((cj6)*(r21));
IkReal x6161=((r20)*(sj6));
IkReal x6162=((r10)*(sj6));
IkReal x6163=((IkReal(1.00000000000000))*(IKsin(j3)));
IkReal x6164=((IkReal(1.00000000000000))*(cj0)*(sj5));
evalcond[0]=((((IkReal(-1.00000000000000))*(x6163)))+(((sj5)*(x6160)))+(((IkReal(-1.00000000000000))*(cj5)*(r22)))+(((sj5)*(x6161))));
evalcond[1]=((((x6159)*(x6160)))+(((cj4)*(r22)*(sj5)))+(((r20)*(x6157)))+(((IkReal(-1.00000000000000))*(r21)*(x6158)))+(x6149)+(((x6159)*(x6161))));
evalcond[2]=((((r02)*(x6152)))+(((r12)*(x6156)))+(((IkReal(-1.00000000000000))*(x6151)*(x6155)))+(((IkReal(-1.00000000000000))*(x6154)*(x6164)))+(((IkReal(-1.00000000000000))*(x6153)*(x6164)))+(((IkReal(-1.00000000000000))*(x6149)))+(((IkReal(-1.00000000000000))*(x6151)*(x6162))));
evalcond[3]=((((IkReal(-1.00000000000000))*(x6150)*(x6155)*(x6156)))+(((IkReal(-1.00000000000000))*(x6163)))+(((cj0)*(r01)*(x6158)))+(((r11)*(sj0)*(x6158)))+(((IkReal(-1.00000000000000))*(r10)*(sj0)*(x6157)))+(((IkReal(-1.00000000000000))*(cj0)*(r02)*(sj5)*(x6150)))+(((IkReal(-1.00000000000000))*(cj0)*(r00)*(x6157)))+(((IkReal(-1.00000000000000))*(x6150)*(x6156)*(x6162)))+(((IkReal(-1.00000000000000))*(x6150)*(x6152)*(x6154)))+(((IkReal(-1.00000000000000))*(r12)*(x6150)*(x6151)))+(((IkReal(-1.00000000000000))*(x6150)*(x6152)*(x6153))));
if( IKabs(evalcond[0]) > 0.000001  || IKabs(evalcond[1]) > 0.000001  || IKabs(evalcond[2]) > 0.000001  || IKabs(evalcond[3]) > 0.000001  )
{
continue;
}
}

{
std::vector<IkSingleDOFSolutionBase<IkReal> > vinfos(7);
vinfos[0].jointtype = 1;
vinfos[0].foffset = j0;
vinfos[0].indices[0] = _ij0[0];
vinfos[0].indices[1] = _ij0[1];
vinfos[0].maxsolutions = _nj0;
vinfos[1].jointtype = 1;
vinfos[1].foffset = j1;
vinfos[1].indices[0] = _ij1[0];
vinfos[1].indices[1] = _ij1[1];
vinfos[1].maxsolutions = _nj1;
vinfos[2].jointtype = 1;
vinfos[2].foffset = j2;
vinfos[2].indices[0] = _ij2[0];
vinfos[2].indices[1] = _ij2[1];
vinfos[2].maxsolutions = _nj2;
vinfos[3].jointtype = 1;
vinfos[3].foffset = j3;
vinfos[3].indices[0] = _ij3[0];
vinfos[3].indices[1] = _ij3[1];
vinfos[3].maxsolutions = _nj3;
vinfos[4].jointtype = 1;
vinfos[4].foffset = j4;
vinfos[4].indices[0] = _ij4[0];
vinfos[4].indices[1] = _ij4[1];
vinfos[4].maxsolutions = _nj4;
vinfos[5].jointtype = 1;
vinfos[5].foffset = j5;
vinfos[5].indices[0] = _ij5[0];
vinfos[5].indices[1] = _ij5[1];
vinfos[5].maxsolutions = _nj5;
vinfos[6].jointtype = 1;
vinfos[6].foffset = j6;
vinfos[6].indices[0] = _ij6[0];
vinfos[6].indices[1] = _ij6[1];
vinfos[6].maxsolutions = _nj6;
std::vector<int> vfree(0);
solutions.AddSolution(vinfos,vfree);
}
}
}

} else
{
IkReal x6165=((cj5)*(sj4));
IkReal x6166=((IkReal(1.00000000000000))*(sj6));
IkReal x6167=((r10)*(sj0));
IkReal x6168=((sj4)*(sj5));
IkReal x6169=((cj5)*(cj6));
IkReal x6170=((r01)*(sj0));
IkReal x6171=((IkReal(1.00000000000000))*(r02));
IkReal x6172=((IkReal(0.374290000000000))*(cj0));
IkReal x6173=((cj5)*(r12));
IkReal x6174=((cj6)*(sj5));
IkReal x6175=((cj0)*(r11));
IkReal x6176=((cj5)*(sj0));
IkReal x6177=((r20)*(sj6));
IkReal x6178=((IkReal(1.00000000000000))*(sj0));
IkReal x6179=((cj4)*(cj5));
IkReal x6180=((IkReal(1.00000000000000))*(cj6));
IkReal x6181=((IkReal(0.0100000000000000))*(sj5));
IkReal x6182=((sj5)*(sj6));
IkReal x6183=((cj0)*(r10));
IkReal x6184=((cj4)*(cj6));
IkReal x6185=((cj0)*(r01));
IkReal x6186=((IkReal(1.00000000000000))*(cj4));
IkReal x6187=((cj0)*(r00));
IkReal x6188=((IkReal(0.374290000000000))*(sj0));
IkReal x6189=((cj0)*(r12));
IkReal x6190=((IkReal(0.374290000000000))*(sj5));
IkReal x6191=((cj4)*(sj6));
IkReal x6192=((IkReal(1.00000000000000))*(cj0));
IkReal x6193=((r02)*(sj0));
IkReal x6194=((IkReal(0.0100000000000000))*(cj5));
IkReal x6195=((r11)*(sj0));
IkReal x6196=((r00)*(sj0)*(sj6));
IkReal x6197=((r00)*(x6184));
IkReal x6198=((sj6)*(x6194));
evalcond[0]=((IkReal(-3.14159265358979))+(IKfmod(j2, IkReal(6.28318530717959))));
evalcond[1]=((((cj6)*(r21)*(x6165)))+(((IkReal(-1.00000000000000))*(cj4)*(r20)*(x6180)))+(((x6165)*(x6177)))+(((r21)*(x6191)))+(((r22)*(x6168))));
evalcond[2]=((IkReal(-0.0690000000000000))+(((IkReal(-1.00000000000000))*(r22)*(x6181)))+(((IkReal(-1.00000000000000))*(x6177)*(x6194)))+(((IkReal(0.374290000000000))*(r21)*(x6174)))+(((IkReal(-0.374290000000000))*(cj5)*(r22)))+(((IkReal(-0.0100000000000000))*(r21)*(x6169)))+(pz)+(((x6177)*(x6190))));
evalcond[3]=((((IkReal(-1.00000000000000))*(sj5)*(x6166)*(x6183)))+(((IkReal(-1.00000000000000))*(x6174)*(x6175)))+(((r00)*(sj0)*(x6182)))+(((IkReal(-1.00000000000000))*(x6171)*(x6176)))+(((x6170)*(x6174)))+(((cj0)*(x6173))));
evalcond[4]=((IkReal(-1.00000000000000))+(((x6183)*(x6184)))+(((IkReal(-1.00000000000000))*(x6168)*(x6189)))+(((x6168)*(x6193)))+(((x6170)*(x6191)))+(((IkReal(-1.00000000000000))*(x6165)*(x6166)*(x6183)))+(((cj6)*(x6165)*(x6170)))+(((x6165)*(x6196)))+(((IkReal(-1.00000000000000))*(x6178)*(x6197)))+(((IkReal(-1.00000000000000))*(cj4)*(x6166)*(x6175)))+(((IkReal(-1.00000000000000))*(x6165)*(x6175)*(x6180))));
evalcond[5]=((((sj4)*(sj6)*(x6175)))+(((IkReal(-1.00000000000000))*(x6169)*(x6175)*(x6186)))+(((IkReal(-1.00000000000000))*(x6166)*(x6179)*(x6183)))+(((IkReal(-1.00000000000000))*(sj5)*(x6186)*(x6189)))+(((cj6)*(r00)*(sj0)*(sj4)))+(((cj4)*(x6169)*(x6170)))+(((IkReal(-1.00000000000000))*(sj4)*(x6166)*(x6170)))+(((IkReal(-1.00000000000000))*(sj4)*(x6180)*(x6183)))+(((r00)*(x6176)*(x6191)))+(((cj4)*(sj5)*(x6193))));
evalcond[6]=((((IkReal(-1.00000000000000))*(cj6)*(r11)*(x6165)*(x6178)))+(((x6167)*(x6184)))+(((x6184)*(x6187)))+(((IkReal(-1.00000000000000))*(x6165)*(x6180)*(x6185)))+(((IkReal(-1.00000000000000))*(cj4)*(x6166)*(x6185)))+(((IkReal(-1.00000000000000))*(x6165)*(x6166)*(x6167)))+(((IkReal(-1.00000000000000))*(r12)*(x6168)*(x6178)))+(((IkReal(-1.00000000000000))*(cj4)*(x6166)*(x6195)))+(((IkReal(-1.00000000000000))*(cj0)*(x6168)*(x6171)))+(((IkReal(-1.00000000000000))*(x6165)*(x6166)*(x6187))));
evalcond[7]=((((x6181)*(x6189)))+(((x6172)*(x6173)))+(((IkReal(0.374290000000000))*(x6170)*(x6174)))+(((IkReal(-1.00000000000000))*(r11)*(x6172)*(x6174)))+(((IkReal(-0.0100000000000000))*(x6169)*(x6170)))+(((IkReal(-0.0100000000000000))*(r00)*(sj6)*(x6176)))+(((r00)*(x6182)*(x6188)))+(((IkReal(-1.00000000000000))*(x6181)*(x6193)))+(((IkReal(0.0100000000000000))*(x6169)*(x6175)))+(((IkReal(-1.00000000000000))*(py)*(x6192)))+(((IkReal(-1.00000000000000))*(r10)*(x6172)*(x6182)))+(((IkReal(-0.374290000000000))*(r02)*(x6176)))+(((px)*(sj0)))+(((x6183)*(x6198))));
evalcond[8]=((IkReal(0.433420000000000))+(((x6173)*(x6188)))+(((IkReal(-1.00000000000000))*(py)*(x6178)))+(((cj0)*(r02)*(x6181)))+(((cj5)*(r02)*(x6172)))+(((IkReal(0.0100000000000000))*(x6169)*(x6185)))+(((IkReal(-1.00000000000000))*(px)*(x6192)))+(((IkReal(-1.00000000000000))*(r01)*(x6172)*(x6174)))+(((IkReal(-1.00000000000000))*(r11)*(x6174)*(x6188)))+(((r12)*(sj0)*(x6181)))+(((IkReal(-0.374290000000000))*(x6167)*(x6182)))+(((x6187)*(x6198)))+(((x6167)*(x6198)))+(((IkReal(-1.00000000000000))*(r00)*(x6172)*(x6182)))+(((IkReal(0.0100000000000000))*(x6169)*(x6195))));
if( IKabs(evalcond[0]) < 0.0000010000000000  && IKabs(evalcond[1]) < 0.0000010000000000  && IKabs(evalcond[2]) < 0.0000010000000000  && IKabs(evalcond[3]) < 0.0000010000000000  && IKabs(evalcond[4]) < 0.0000010000000000  && IKabs(evalcond[5]) < 0.0000010000000000  && IKabs(evalcond[6]) < 0.0000010000000000  && IKabs(evalcond[7]) < 0.0000010000000000  && IKabs(evalcond[8]) < 0.0000010000000000  )
{
{
IkReal j3array[1], cj3array[1], sj3array[1];
bool j3valid[1]={false};
_nj3 = 1;
IkReal x6199=((IkReal(1.00000000000000))*(r21));
IkReal x6200=((cj4)*(cj5));
IkReal x6201=((r20)*(sj6));
if( IKabs(((((IkReal(-1.00000000000000))*(sj5)*(x6201)))+(((IkReal(-1.00000000000000))*(cj6)*(sj5)*(x6199)))+(((cj5)*(r22))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(((((cj6)*(r21)*(x6200)))+(((cj6)*(r20)*(sj4)))+(((cj4)*(r22)*(sj5)))+(((IkReal(-1.00000000000000))*(sj4)*(sj6)*(x6199)))+(((x6200)*(x6201))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(IKsqr(((((IkReal(-1.00000000000000))*(sj5)*(x6201)))+(((IkReal(-1.00000000000000))*(cj6)*(sj5)*(x6199)))+(((cj5)*(r22)))))+IKsqr(((((cj6)*(r21)*(x6200)))+(((cj6)*(r20)*(sj4)))+(((cj4)*(r22)*(sj5)))+(((IkReal(-1.00000000000000))*(sj4)*(sj6)*(x6199)))+(((x6200)*(x6201)))))-1) <= IKFAST_SINCOS_THRESH )
    continue;
j3array[0]=IKatan2(((((IkReal(-1.00000000000000))*(sj5)*(x6201)))+(((IkReal(-1.00000000000000))*(cj6)*(sj5)*(x6199)))+(((cj5)*(r22)))), ((((cj6)*(r21)*(x6200)))+(((cj6)*(r20)*(sj4)))+(((cj4)*(r22)*(sj5)))+(((IkReal(-1.00000000000000))*(sj4)*(sj6)*(x6199)))+(((x6200)*(x6201)))));
sj3array[0]=IKsin(j3array[0]);
cj3array[0]=IKcos(j3array[0]);
if( j3array[0] > IKPI )
{
    j3array[0]-=IK2PI;
}
else if( j3array[0] < -IKPI )
{    j3array[0]+=IK2PI;
}
j3valid[0] = true;
for(int ij3 = 0; ij3 < 1; ++ij3)
{
if( !j3valid[ij3] )
{
    continue;
}
_ij3[0] = ij3; _ij3[1] = -1;
for(int iij3 = ij3+1; iij3 < 1; ++iij3)
{
if( j3valid[iij3] && IKabs(cj3array[ij3]-cj3array[iij3]) < IKFAST_SOLUTION_THRESH && IKabs(sj3array[ij3]-sj3array[iij3]) < IKFAST_SOLUTION_THRESH )
{
    j3valid[iij3]=false; _ij3[1] = iij3; break; 
}
}
j3 = j3array[ij3]; cj3 = cj3array[ij3]; sj3 = sj3array[ij3];
{
IkReal evalcond[4];
IkReal x6202=IKsin(j3);
IkReal x6203=((IkReal(1.00000000000000))*(cj4));
IkReal x6204=((sj0)*(sj5));
IkReal x6205=((cj0)*(cj5));
IkReal x6206=((cj6)*(r01));
IkReal x6207=((r00)*(sj6));
IkReal x6208=((cj6)*(r11));
IkReal x6209=((cj5)*(sj0));
IkReal x6210=((cj6)*(sj4));
IkReal x6211=((sj4)*(sj6));
IkReal x6212=((cj4)*(cj5));
IkReal x6213=((cj6)*(r21));
IkReal x6214=((r20)*(sj6));
IkReal x6215=((r10)*(sj6));
IkReal x6216=((IkReal(1.00000000000000))*(IKcos(j3)));
IkReal x6217=((IkReal(1.00000000000000))*(cj0)*(sj5));
evalcond[0]=((((sj5)*(x6213)))+(((IkReal(-1.00000000000000))*(cj5)*(r22)))+(x6202)+(((sj5)*(x6214))));
evalcond[1]=((((x6212)*(x6214)))+(((cj4)*(r22)*(sj5)))+(((x6212)*(x6213)))+(((IkReal(-1.00000000000000))*(r21)*(x6211)))+(((IkReal(-1.00000000000000))*(x6216)))+(((r20)*(x6210))));
evalcond[2]=((((r02)*(x6205)))+(((IkReal(-1.00000000000000))*(x6204)*(x6208)))+(((IkReal(-1.00000000000000))*(x6207)*(x6217)))+(((IkReal(-1.00000000000000))*(x6206)*(x6217)))+(((r12)*(x6209)))+(((IkReal(-1.00000000000000))*(x6216)))+(((IkReal(-1.00000000000000))*(x6204)*(x6215))));
evalcond[3]=((((IkReal(-1.00000000000000))*(r10)*(sj0)*(x6210)))+(((IkReal(-1.00000000000000))*(cj0)*(r02)*(sj5)*(x6203)))+(((r11)*(sj0)*(x6211)))+(((IkReal(-1.00000000000000))*(x6203)*(x6205)*(x6207)))+(((IkReal(-1.00000000000000))*(x6203)*(x6205)*(x6206)))+(((IkReal(-1.00000000000000))*(x6203)*(x6208)*(x6209)))+(((IkReal(-1.00000000000000))*(x6203)*(x6209)*(x6215)))+(((IkReal(-1.00000000000000))*(x6202)))+(((IkReal(-1.00000000000000))*(r12)*(x6203)*(x6204)))+(((IkReal(-1.00000000000000))*(cj0)*(r00)*(x6210)))+(((cj0)*(r01)*(x6211))));
if( IKabs(evalcond[0]) > 0.000001  || IKabs(evalcond[1]) > 0.000001  || IKabs(evalcond[2]) > 0.000001  || IKabs(evalcond[3]) > 0.000001  )
{
continue;
}
}

{
std::vector<IkSingleDOFSolutionBase<IkReal> > vinfos(7);
vinfos[0].jointtype = 1;
vinfos[0].foffset = j0;
vinfos[0].indices[0] = _ij0[0];
vinfos[0].indices[1] = _ij0[1];
vinfos[0].maxsolutions = _nj0;
vinfos[1].jointtype = 1;
vinfos[1].foffset = j1;
vinfos[1].indices[0] = _ij1[0];
vinfos[1].indices[1] = _ij1[1];
vinfos[1].maxsolutions = _nj1;
vinfos[2].jointtype = 1;
vinfos[2].foffset = j2;
vinfos[2].indices[0] = _ij2[0];
vinfos[2].indices[1] = _ij2[1];
vinfos[2].maxsolutions = _nj2;
vinfos[3].jointtype = 1;
vinfos[3].foffset = j3;
vinfos[3].indices[0] = _ij3[0];
vinfos[3].indices[1] = _ij3[1];
vinfos[3].maxsolutions = _nj3;
vinfos[4].jointtype = 1;
vinfos[4].foffset = j4;
vinfos[4].indices[0] = _ij4[0];
vinfos[4].indices[1] = _ij4[1];
vinfos[4].maxsolutions = _nj4;
vinfos[5].jointtype = 1;
vinfos[5].foffset = j5;
vinfos[5].indices[0] = _ij5[0];
vinfos[5].indices[1] = _ij5[1];
vinfos[5].maxsolutions = _nj5;
vinfos[6].jointtype = 1;
vinfos[6].foffset = j6;
vinfos[6].indices[0] = _ij6[0];
vinfos[6].indices[1] = _ij6[1];
vinfos[6].maxsolutions = _nj6;
std::vector<int> vfree(0);
solutions.AddSolution(vinfos,vfree);
}
}
}

} else
{
IkReal x6218=((IkReal(1.00000000000000))*(cj0));
IkReal x6219=((cj4)*(sj6));
IkReal x6220=((sj0)*(sj4));
IkReal x6221=((cj5)*(sj6));
IkReal x6222=((sj4)*(sj5));
IkReal x6223=((r12)*(sj5));
IkReal x6224=((IkReal(0.374290000000000))*(cj5));
IkReal x6225=((r02)*(sj0));
IkReal x6226=((r20)*(sj4));
IkReal x6227=((IkReal(1.00000000000000))*(sj0));
IkReal x6228=((IkReal(1.00000000000000))*(cj5));
IkReal x6229=((cj0)*(r10));
IkReal x6230=((cj4)*(cj6));
IkReal x6231=((r00)*(sj0));
IkReal x6232=((cj6)*(r21));
IkReal x6233=((IkReal(0.374290000000000))*(sj5));
IkReal x6234=((cj0)*(r00));
IkReal x6235=((IkReal(0.0100000000000000))*(sj5));
IkReal x6236=((cj0)*(r02));
IkReal x6237=((cj5)*(sj4));
IkReal x6238=((cj6)*(r01));
IkReal x6239=((cj6)*(r11));
IkReal x6240=((r01)*(sj0));
IkReal x6241=((r10)*(sj0));
IkReal x6242=((IkReal(0.0100000000000000))*(cj5)*(cj6));
IkReal x6243=((sj6)*(x6233));
IkReal x6244=((cj0)*(cj6)*(x6233));
evalcond[0]=((IkReal(-3.14159265358979))+(IKfmod(((IkReal(1.57079632679490))+(j2)), IkReal(6.28318530717959))));
evalcond[1]=((((sj5)*(x6232)))+(((IkReal(-1.00000000000000))*(r22)*(x6228)))+(((r20)*(sj5)*(sj6))));
evalcond[2]=((IkReal(-1.00000000000000))+(((r21)*(x6219)))+(((IkReal(-1.00000000000000))*(r20)*(x6230)))+(((x6232)*(x6237)))+(((r22)*(x6222)))+(((x6221)*(x6226))));
evalcond[3]=((((IkReal(-0.0100000000000000))*(r20)*(x6221)))+(((x6232)*(x6233)))+(pz)+(((IkReal(-1.00000000000000))*(r22)*(x6224)))+(((IkReal(-0.0100000000000000))*(cj5)*(x6232)))+(((r20)*(x6243)))+(((IkReal(-1.00000000000000))*(r22)*(x6235))));
evalcond[4]=((((IkReal(-1.00000000000000))*(r21)*(sj4)*(sj6)))+(((cj5)*(r20)*(x6219)))+(((cj6)*(x6226)))+(((cj4)*(r22)*(sj5)))+(((cj5)*(r21)*(x6230))));
evalcond[5]=((((r00)*(x6220)*(x6221)))+(((IkReal(-1.00000000000000))*(r10)*(sj4)*(x6218)*(x6221)))+(((cj5)*(x6220)*(x6238)))+(((IkReal(-1.00000000000000))*(x6218)*(x6237)*(x6239)))+(((IkReal(-1.00000000000000))*(r12)*(x6218)*(x6222)))+(((x6219)*(x6240)))+(((IkReal(-1.00000000000000))*(r00)*(x6227)*(x6230)))+(((IkReal(-1.00000000000000))*(r11)*(x6218)*(x6219)))+(((x6229)*(x6230)))+(((r02)*(sj5)*(x6220))));
evalcond[6]=((((IkReal(-1.00000000000000))*(r10)*(x6220)*(x6221)))+(((x6230)*(x6241)))+(((IkReal(-1.00000000000000))*(x6220)*(x6223)))+(((x6230)*(x6234)))+(((IkReal(-1.00000000000000))*(r02)*(x6218)*(x6222)))+(((IkReal(-1.00000000000000))*(r01)*(x6218)*(x6219)))+(((IkReal(-1.00000000000000))*(r11)*(x6219)*(x6227)))+(((IkReal(-1.00000000000000))*(r00)*(sj4)*(x6218)*(x6221)))+(((IkReal(-1.00000000000000))*(x6218)*(x6237)*(x6238)))+(((IkReal(-1.00000000000000))*(x6220)*(x6228)*(x6239))));
evalcond[7]=((IkReal(0.0690000000000000))+(((IkReal(0.0100000000000000))*(cj0)*(x6223)))+(((IkReal(-1.00000000000000))*(py)*(x6218)))+(((IkReal(-0.0100000000000000))*(cj5)*(sj0)*(x6238)))+(((IkReal(-1.00000000000000))*(x6225)*(x6235)))+(((IkReal(0.0100000000000000))*(cj0)*(cj5)*(x6239)))+(((cj0)*(r12)*(x6224)))+(((x6231)*(x6243)))+(((IkReal(-1.00000000000000))*(cj0)*(x6233)*(x6239)))+(((IkReal(0.0100000000000000))*(x6221)*(x6229)))+(((sj0)*(x6233)*(x6238)))+(((IkReal(-0.0100000000000000))*(x6221)*(x6231)))+(((px)*(sj0)))+(((IkReal(-1.00000000000000))*(x6229)*(x6243)))+(((IkReal(-1.00000000000000))*(x6224)*(x6225))));
evalcond[8]=((IkReal(0.433420000000000))+(((IkReal(0.0100000000000000))*(x6221)*(x6234)))+(((IkReal(0.0100000000000000))*(sj0)*(x6223)))+(((IkReal(0.0100000000000000))*(x6221)*(x6241)))+(((IkReal(-1.00000000000000))*(x6241)*(x6243)))+(((r12)*(sj0)*(x6224)))+(((IkReal(0.0100000000000000))*(cj5)*(sj0)*(x6239)))+(((IkReal(-1.00000000000000))*(x6234)*(x6243)))+(((IkReal(-1.00000000000000))*(sj0)*(x6233)*(x6239)))+(((IkReal(-1.00000000000000))*(px)*(x6218)))+(((x6224)*(x6236)))+(((IkReal(-1.00000000000000))*(py)*(x6227)))+(((IkReal(0.0100000000000000))*(cj0)*(cj5)*(x6238)))+(((IkReal(-1.00000000000000))*(cj0)*(x6233)*(x6238)))+(((x6235)*(x6236))));
if( IKabs(evalcond[0]) < 0.0000010000000000  && IKabs(evalcond[1]) < 0.0000010000000000  && IKabs(evalcond[2]) < 0.0000010000000000  && IKabs(evalcond[3]) < 0.0000010000000000  && IKabs(evalcond[4]) < 0.0000010000000000  && IKabs(evalcond[5]) < 0.0000010000000000  && IKabs(evalcond[6]) < 0.0000010000000000  && IKabs(evalcond[7]) < 0.0000010000000000  && IKabs(evalcond[8]) < 0.0000010000000000  )
{
{
IkReal j3array[1], cj3array[1], sj3array[1];
bool j3valid[1]={false};
_nj3 = 1;
IkReal x6245=((cj0)*(cj5));
IkReal x6246=((IkReal(1.00000000000000))*(cj0));
IkReal x6247=((cj6)*(r11));
IkReal x6248=((r10)*(sj6));
IkReal x6249=((cj5)*(sj0));
IkReal x6250=((r00)*(sj5)*(sj6));
IkReal x6251=((cj6)*(r01)*(sj5));
IkReal x6252=((IkReal(1.00000000000000))*(sj0)*(sj5));
if( IKabs(((((IkReal(-1.00000000000000))*(sj5)*(x6246)*(x6247)))+(((IkReal(-1.00000000000000))*(r02)*(x6249)))+(((IkReal(-1.00000000000000))*(sj5)*(x6246)*(x6248)))+(((sj0)*(x6251)))+(((sj0)*(x6250)))+(((r12)*(x6245))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(((((IkReal(-1.00000000000000))*(x6247)*(x6252)))+(((r02)*(x6245)))+(((IkReal(-1.00000000000000))*(x6246)*(x6251)))+(((r12)*(x6249)))+(((IkReal(-1.00000000000000))*(x6246)*(x6250)))+(((IkReal(-1.00000000000000))*(x6248)*(x6252))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(IKsqr(((((IkReal(-1.00000000000000))*(sj5)*(x6246)*(x6247)))+(((IkReal(-1.00000000000000))*(r02)*(x6249)))+(((IkReal(-1.00000000000000))*(sj5)*(x6246)*(x6248)))+(((sj0)*(x6251)))+(((sj0)*(x6250)))+(((r12)*(x6245)))))+IKsqr(((((IkReal(-1.00000000000000))*(x6247)*(x6252)))+(((r02)*(x6245)))+(((IkReal(-1.00000000000000))*(x6246)*(x6251)))+(((r12)*(x6249)))+(((IkReal(-1.00000000000000))*(x6246)*(x6250)))+(((IkReal(-1.00000000000000))*(x6248)*(x6252)))))-1) <= IKFAST_SINCOS_THRESH )
    continue;
j3array[0]=IKatan2(((((IkReal(-1.00000000000000))*(sj5)*(x6246)*(x6247)))+(((IkReal(-1.00000000000000))*(r02)*(x6249)))+(((IkReal(-1.00000000000000))*(sj5)*(x6246)*(x6248)))+(((sj0)*(x6251)))+(((sj0)*(x6250)))+(((r12)*(x6245)))), ((((IkReal(-1.00000000000000))*(x6247)*(x6252)))+(((r02)*(x6245)))+(((IkReal(-1.00000000000000))*(x6246)*(x6251)))+(((r12)*(x6249)))+(((IkReal(-1.00000000000000))*(x6246)*(x6250)))+(((IkReal(-1.00000000000000))*(x6248)*(x6252)))));
sj3array[0]=IKsin(j3array[0]);
cj3array[0]=IKcos(j3array[0]);
if( j3array[0] > IKPI )
{
    j3array[0]-=IK2PI;
}
else if( j3array[0] < -IKPI )
{    j3array[0]+=IK2PI;
}
j3valid[0] = true;
for(int ij3 = 0; ij3 < 1; ++ij3)
{
if( !j3valid[ij3] )
{
    continue;
}
_ij3[0] = ij3; _ij3[1] = -1;
for(int iij3 = ij3+1; iij3 < 1; ++iij3)
{
if( j3valid[iij3] && IKabs(cj3array[ij3]-cj3array[iij3]) < IKFAST_SOLUTION_THRESH && IKabs(sj3array[ij3]-sj3array[iij3]) < IKFAST_SOLUTION_THRESH )
{
    j3valid[iij3]=false; _ij3[1] = iij3; break; 
}
}
j3 = j3array[ij3]; cj3 = cj3array[ij3]; sj3 = sj3array[ij3];
{
IkReal evalcond[4];
IkReal x6253=IKcos(j3);
IkReal x6254=((sj0)*(sj5));
IkReal x6255=((r00)*(sj6));
IkReal x6256=((cj6)*(sj0));
IkReal x6257=((IkReal(1.00000000000000))*(cj4));
IkReal x6258=((r00)*(sj4));
IkReal x6259=((cj0)*(cj5));
IkReal x6260=((cj5)*(sj0));
IkReal x6261=((cj6)*(r11));
IkReal x6262=((r10)*(sj6));
IkReal x6263=((cj0)*(sj5));
IkReal x6264=((r10)*(sj4));
IkReal x6265=((IkReal(1.00000000000000))*(IKsin(j3)));
IkReal x6266=((cj4)*(cj5)*(r01));
IkReal x6267=((IkReal(1.00000000000000))*(cj0)*(cj6));
IkReal x6268=((cj0)*(sj4)*(sj6));
IkReal x6269=((sj0)*(sj4)*(sj6));
evalcond[0]=((((IkReal(-1.00000000000000))*(x6261)*(x6263)))+(((IkReal(-1.00000000000000))*(r02)*(x6260)))+(((cj6)*(r01)*(x6254)))+(((IkReal(-1.00000000000000))*(x6262)*(x6263)))+(((r12)*(x6259)))+(((IkReal(-1.00000000000000))*(x6265)))+(((x6254)*(x6255))));
evalcond[1]=((((r12)*(x6260)))+(((IkReal(-1.00000000000000))*(cj6)*(r01)*(x6263)))+(((r02)*(x6259)))+(((IkReal(-1.00000000000000))*(x6253)))+(((IkReal(-1.00000000000000))*(x6254)*(x6262)))+(((IkReal(-1.00000000000000))*(x6255)*(x6263)))+(((IkReal(-1.00000000000000))*(x6254)*(x6261))));
evalcond[2]=((((r11)*(x6268)))+(x6253)+(((IkReal(-1.00000000000000))*(r01)*(x6269)))+(((cj4)*(r02)*(x6254)))+(((IkReal(-1.00000000000000))*(r12)*(x6257)*(x6263)))+(((x6256)*(x6266)))+(((cj4)*(x6255)*(x6260)))+(((IkReal(-1.00000000000000))*(x6264)*(x6267)))+(((x6256)*(x6258)))+(((IkReal(-1.00000000000000))*(x6257)*(x6259)*(x6261)))+(((IkReal(-1.00000000000000))*(x6257)*(x6259)*(x6262))));
evalcond[3]=((((IkReal(-1.00000000000000))*(cj6)*(r01)*(x6257)*(x6259)))+(((IkReal(-1.00000000000000))*(x6257)*(x6260)*(x6262)))+(((IkReal(-1.00000000000000))*(cj5)*(r11)*(x6256)*(x6257)))+(((IkReal(-1.00000000000000))*(x6256)*(x6264)))+(((IkReal(-1.00000000000000))*(x6258)*(x6267)))+(((r01)*(x6268)))+(((IkReal(-1.00000000000000))*(x6265)))+(((IkReal(-1.00000000000000))*(r02)*(x6257)*(x6263)))+(((IkReal(-1.00000000000000))*(r12)*(x6254)*(x6257)))+(((r11)*(x6269)))+(((IkReal(-1.00000000000000))*(x6255)*(x6257)*(x6259))));
if( IKabs(evalcond[0]) > 0.000001  || IKabs(evalcond[1]) > 0.000001  || IKabs(evalcond[2]) > 0.000001  || IKabs(evalcond[3]) > 0.000001  )
{
continue;
}
}

{
std::vector<IkSingleDOFSolutionBase<IkReal> > vinfos(7);
vinfos[0].jointtype = 1;
vinfos[0].foffset = j0;
vinfos[0].indices[0] = _ij0[0];
vinfos[0].indices[1] = _ij0[1];
vinfos[0].maxsolutions = _nj0;
vinfos[1].jointtype = 1;
vinfos[1].foffset = j1;
vinfos[1].indices[0] = _ij1[0];
vinfos[1].indices[1] = _ij1[1];
vinfos[1].maxsolutions = _nj1;
vinfos[2].jointtype = 1;
vinfos[2].foffset = j2;
vinfos[2].indices[0] = _ij2[0];
vinfos[2].indices[1] = _ij2[1];
vinfos[2].maxsolutions = _nj2;
vinfos[3].jointtype = 1;
vinfos[3].foffset = j3;
vinfos[3].indices[0] = _ij3[0];
vinfos[3].indices[1] = _ij3[1];
vinfos[3].maxsolutions = _nj3;
vinfos[4].jointtype = 1;
vinfos[4].foffset = j4;
vinfos[4].indices[0] = _ij4[0];
vinfos[4].indices[1] = _ij4[1];
vinfos[4].maxsolutions = _nj4;
vinfos[5].jointtype = 1;
vinfos[5].foffset = j5;
vinfos[5].indices[0] = _ij5[0];
vinfos[5].indices[1] = _ij5[1];
vinfos[5].maxsolutions = _nj5;
vinfos[6].jointtype = 1;
vinfos[6].foffset = j6;
vinfos[6].indices[0] = _ij6[0];
vinfos[6].indices[1] = _ij6[1];
vinfos[6].maxsolutions = _nj6;
std::vector<int> vfree(0);
solutions.AddSolution(vinfos,vfree);
}
}
}

} else
{
IkReal x6270=((IkReal(1.00000000000000))*(cj0));
IkReal x6271=((cj4)*(sj6));
IkReal x6272=((sj0)*(sj4));
IkReal x6273=((cj5)*(sj6));
IkReal x6274=((sj4)*(sj5));
IkReal x6275=((r12)*(sj5));
IkReal x6276=((IkReal(0.374290000000000))*(cj5));
IkReal x6277=((r02)*(sj0));
IkReal x6278=((r20)*(sj4));
IkReal x6279=((IkReal(1.00000000000000))*(sj0));
IkReal x6280=((IkReal(1.00000000000000))*(cj5));
IkReal x6281=((cj0)*(r10));
IkReal x6282=((cj4)*(cj6));
IkReal x6283=((r00)*(sj0));
IkReal x6284=((cj6)*(r21));
IkReal x6285=((IkReal(0.374290000000000))*(sj5));
IkReal x6286=((cj0)*(r00));
IkReal x6287=((IkReal(0.0100000000000000))*(sj5));
IkReal x6288=((cj0)*(r02));
IkReal x6289=((cj5)*(sj4));
IkReal x6290=((cj6)*(r01));
IkReal x6291=((cj6)*(r11));
IkReal x6292=((r01)*(sj0));
IkReal x6293=((r10)*(sj0));
IkReal x6294=((IkReal(0.0100000000000000))*(cj5)*(cj6));
IkReal x6295=((sj6)*(x6285));
IkReal x6296=((cj0)*(cj6)*(x6285));
evalcond[0]=((IkReal(-3.14159265358979))+(IKfmod(((IkReal(4.71238898038469))+(j2)), IkReal(6.28318530717959))));
evalcond[1]=((((IkReal(-1.00000000000000))*(r22)*(x6280)))+(((sj5)*(x6284)))+(((r20)*(sj5)*(sj6))));
evalcond[2]=((IkReal(1.00000000000000))+(((x6273)*(x6278)))+(((x6284)*(x6289)))+(((r21)*(x6271)))+(((r22)*(x6274)))+(((IkReal(-1.00000000000000))*(r20)*(x6282))));
evalcond[3]=((((IkReal(-0.0100000000000000))*(r20)*(x6273)))+(((r20)*(x6295)))+(((IkReal(-1.00000000000000))*(r22)*(x6276)))+(((x6284)*(x6285)))+(pz)+(((IkReal(-1.00000000000000))*(r22)*(x6287)))+(((IkReal(-0.0100000000000000))*(cj5)*(x6284))));
evalcond[4]=((((IkReal(-1.00000000000000))*(r21)*(sj4)*(sj6)))+(((cj5)*(r21)*(x6282)))+(((cj4)*(r22)*(sj5)))+(((cj5)*(r20)*(x6271)))+(((cj6)*(x6278))));
evalcond[5]=((((r00)*(x6272)*(x6273)))+(((IkReal(-1.00000000000000))*(r11)*(x6270)*(x6271)))+(((r02)*(sj5)*(x6272)))+(((IkReal(-1.00000000000000))*(r12)*(x6270)*(x6274)))+(((x6281)*(x6282)))+(((IkReal(-1.00000000000000))*(x6270)*(x6289)*(x6291)))+(((x6271)*(x6292)))+(((IkReal(-1.00000000000000))*(r10)*(sj4)*(x6270)*(x6273)))+(((cj5)*(x6272)*(x6290)))+(((IkReal(-1.00000000000000))*(r00)*(x6279)*(x6282))));
evalcond[6]=((((IkReal(-1.00000000000000))*(r11)*(x6271)*(x6279)))+(((IkReal(-1.00000000000000))*(x6272)*(x6275)))+(((x6282)*(x6293)))+(((IkReal(-1.00000000000000))*(r00)*(sj4)*(x6270)*(x6273)))+(((x6282)*(x6286)))+(((IkReal(-1.00000000000000))*(x6270)*(x6289)*(x6290)))+(((IkReal(-1.00000000000000))*(r10)*(x6272)*(x6273)))+(((IkReal(-1.00000000000000))*(x6272)*(x6280)*(x6291)))+(((IkReal(-1.00000000000000))*(r02)*(x6270)*(x6274)))+(((IkReal(-1.00000000000000))*(r01)*(x6270)*(x6271))));
evalcond[7]=((IkReal(-0.0690000000000000))+(((IkReal(-1.00000000000000))*(x6276)*(x6277)))+(((IkReal(0.0100000000000000))*(x6273)*(x6281)))+(((sj0)*(x6285)*(x6290)))+(((cj0)*(r12)*(x6276)))+(((IkReal(-1.00000000000000))*(py)*(x6270)))+(((x6283)*(x6295)))+(((IkReal(0.0100000000000000))*(cj0)*(cj5)*(x6291)))+(((IkReal(-0.0100000000000000))*(cj5)*(sj0)*(x6290)))+(((IkReal(-1.00000000000000))*(cj0)*(x6285)*(x6291)))+(((IkReal(-1.00000000000000))*(x6281)*(x6295)))+(((px)*(sj0)))+(((IkReal(-1.00000000000000))*(x6277)*(x6287)))+(((IkReal(-0.0100000000000000))*(x6273)*(x6283)))+(((IkReal(0.0100000000000000))*(cj0)*(x6275))));
evalcond[8]=((IkReal(0.433420000000000))+(((IkReal(0.0100000000000000))*(x6273)*(x6293)))+(((IkReal(0.0100000000000000))*(x6273)*(x6286)))+(((IkReal(-1.00000000000000))*(py)*(x6279)))+(((IkReal(-1.00000000000000))*(x6286)*(x6295)))+(((x6276)*(x6288)))+(((IkReal(-1.00000000000000))*(px)*(x6270)))+(((IkReal(0.0100000000000000))*(cj5)*(sj0)*(x6291)))+(((x6287)*(x6288)))+(((r12)*(sj0)*(x6276)))+(((IkReal(-1.00000000000000))*(sj0)*(x6285)*(x6291)))+(((IkReal(-1.00000000000000))*(x6293)*(x6295)))+(((IkReal(0.0100000000000000))*(sj0)*(x6275)))+(((IkReal(0.0100000000000000))*(cj0)*(cj5)*(x6290)))+(((IkReal(-1.00000000000000))*(cj0)*(x6285)*(x6290))));
if( IKabs(evalcond[0]) < 0.0000010000000000  && IKabs(evalcond[1]) < 0.0000010000000000  && IKabs(evalcond[2]) < 0.0000010000000000  && IKabs(evalcond[3]) < 0.0000010000000000  && IKabs(evalcond[4]) < 0.0000010000000000  && IKabs(evalcond[5]) < 0.0000010000000000  && IKabs(evalcond[6]) < 0.0000010000000000  && IKabs(evalcond[7]) < 0.0000010000000000  && IKabs(evalcond[8]) < 0.0000010000000000  )
{
{
IkReal j3array[1], cj3array[1], sj3array[1];
bool j3valid[1]={false};
_nj3 = 1;
IkReal x6297=((cj5)*(r02));
IkReal x6298=((cj0)*(sj5));
IkReal x6299=((r10)*(sj6));
IkReal x6300=((IkReal(1.00000000000000))*(cj6));
IkReal x6301=((sj0)*(sj5));
IkReal x6302=((cj5)*(r12));
IkReal x6303=((IkReal(1.00000000000000))*(r00)*(sj6));
if( IKabs(((((sj0)*(x6297)))+(((IkReal(-1.00000000000000))*(x6301)*(x6303)))+(((cj6)*(r11)*(x6298)))+(((x6298)*(x6299)))+(((IkReal(-1.00000000000000))*(r01)*(x6300)*(x6301)))+(((IkReal(-1.00000000000000))*(cj0)*(x6302))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(((((IkReal(-1.00000000000000))*(x6299)*(x6301)))+(((cj0)*(x6297)))+(((IkReal(-1.00000000000000))*(r11)*(x6300)*(x6301)))+(((IkReal(-1.00000000000000))*(x6298)*(x6303)))+(((sj0)*(x6302)))+(((IkReal(-1.00000000000000))*(r01)*(x6298)*(x6300))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(IKsqr(((((sj0)*(x6297)))+(((IkReal(-1.00000000000000))*(x6301)*(x6303)))+(((cj6)*(r11)*(x6298)))+(((x6298)*(x6299)))+(((IkReal(-1.00000000000000))*(r01)*(x6300)*(x6301)))+(((IkReal(-1.00000000000000))*(cj0)*(x6302)))))+IKsqr(((((IkReal(-1.00000000000000))*(x6299)*(x6301)))+(((cj0)*(x6297)))+(((IkReal(-1.00000000000000))*(r11)*(x6300)*(x6301)))+(((IkReal(-1.00000000000000))*(x6298)*(x6303)))+(((sj0)*(x6302)))+(((IkReal(-1.00000000000000))*(r01)*(x6298)*(x6300)))))-1) <= IKFAST_SINCOS_THRESH )
    continue;
j3array[0]=IKatan2(((((sj0)*(x6297)))+(((IkReal(-1.00000000000000))*(x6301)*(x6303)))+(((cj6)*(r11)*(x6298)))+(((x6298)*(x6299)))+(((IkReal(-1.00000000000000))*(r01)*(x6300)*(x6301)))+(((IkReal(-1.00000000000000))*(cj0)*(x6302)))), ((((IkReal(-1.00000000000000))*(x6299)*(x6301)))+(((cj0)*(x6297)))+(((IkReal(-1.00000000000000))*(r11)*(x6300)*(x6301)))+(((IkReal(-1.00000000000000))*(x6298)*(x6303)))+(((sj0)*(x6302)))+(((IkReal(-1.00000000000000))*(r01)*(x6298)*(x6300)))));
sj3array[0]=IKsin(j3array[0]);
cj3array[0]=IKcos(j3array[0]);
if( j3array[0] > IKPI )
{
    j3array[0]-=IK2PI;
}
else if( j3array[0] < -IKPI )
{    j3array[0]+=IK2PI;
}
j3valid[0] = true;
for(int ij3 = 0; ij3 < 1; ++ij3)
{
if( !j3valid[ij3] )
{
    continue;
}
_ij3[0] = ij3; _ij3[1] = -1;
for(int iij3 = ij3+1; iij3 < 1; ++iij3)
{
if( j3valid[iij3] && IKabs(cj3array[ij3]-cj3array[iij3]) < IKFAST_SOLUTION_THRESH && IKabs(sj3array[ij3]-sj3array[iij3]) < IKFAST_SOLUTION_THRESH )
{
    j3valid[iij3]=false; _ij3[1] = iij3; break; 
}
}
j3 = j3array[ij3]; cj3 = cj3array[ij3]; sj3 = sj3array[ij3];
{
IkReal evalcond[4];
IkReal x6304=IKsin(j3);
IkReal x6305=((sj0)*(sj5));
IkReal x6306=((r00)*(sj6));
IkReal x6307=((IkReal(1.00000000000000))*(cj4));
IkReal x6308=((cj6)*(sj0));
IkReal x6309=((r00)*(sj4));
IkReal x6310=((cj0)*(cj5));
IkReal x6311=((cj6)*(r01));
IkReal x6312=((cj5)*(sj0));
IkReal x6313=((cj0)*(sj5));
IkReal x6314=((cj6)*(r11));
IkReal x6315=((r10)*(sj6));
IkReal x6316=((r10)*(sj4));
IkReal x6317=((IkReal(1.00000000000000))*(IKcos(j3)));
IkReal x6318=((cj0)*(sj4)*(sj6));
IkReal x6319=((sj0)*(sj4)*(sj6));
IkReal x6320=((IkReal(1.00000000000000))*(cj0)*(cj6));
evalcond[0]=((((x6305)*(x6311)))+(x6304)+(((IkReal(-1.00000000000000))*(x6313)*(x6314)))+(((x6305)*(x6306)))+(((IkReal(-1.00000000000000))*(x6313)*(x6315)))+(((r12)*(x6310)))+(((IkReal(-1.00000000000000))*(r02)*(x6312))));
evalcond[1]=((((IkReal(-1.00000000000000))*(x6311)*(x6313)))+(((IkReal(-1.00000000000000))*(x6317)))+(((IkReal(-1.00000000000000))*(x6305)*(x6315)))+(((IkReal(-1.00000000000000))*(x6306)*(x6313)))+(((IkReal(-1.00000000000000))*(x6305)*(x6314)))+(((r02)*(x6310)))+(((r12)*(x6312))));
evalcond[2]=((((IkReal(-1.00000000000000))*(r01)*(x6319)))+(((cj4)*(cj5)*(r01)*(x6308)))+(((cj4)*(r02)*(x6305)))+(((IkReal(-1.00000000000000))*(x6317)))+(((IkReal(-1.00000000000000))*(x6307)*(x6310)*(x6315)))+(((IkReal(-1.00000000000000))*(x6316)*(x6320)))+(((IkReal(-1.00000000000000))*(x6307)*(x6310)*(x6314)))+(((IkReal(-1.00000000000000))*(r12)*(x6307)*(x6313)))+(((x6308)*(x6309)))+(((cj4)*(x6306)*(x6312)))+(((r11)*(x6318))));
evalcond[3]=((((IkReal(-1.00000000000000))*(x6309)*(x6320)))+(((r11)*(x6319)))+(((IkReal(-1.00000000000000))*(x6307)*(x6310)*(x6311)))+(((IkReal(-1.00000000000000))*(x6304)))+(((IkReal(-1.00000000000000))*(x6307)*(x6312)*(x6315)))+(((IkReal(-1.00000000000000))*(r12)*(x6305)*(x6307)))+(((IkReal(-1.00000000000000))*(x6308)*(x6316)))+(((IkReal(-1.00000000000000))*(r02)*(x6307)*(x6313)))+(((r01)*(x6318)))+(((IkReal(-1.00000000000000))*(x6306)*(x6307)*(x6310)))+(((IkReal(-1.00000000000000))*(cj5)*(r11)*(x6307)*(x6308))));
if( IKabs(evalcond[0]) > 0.000001  || IKabs(evalcond[1]) > 0.000001  || IKabs(evalcond[2]) > 0.000001  || IKabs(evalcond[3]) > 0.000001  )
{
continue;
}
}

{
std::vector<IkSingleDOFSolutionBase<IkReal> > vinfos(7);
vinfos[0].jointtype = 1;
vinfos[0].foffset = j0;
vinfos[0].indices[0] = _ij0[0];
vinfos[0].indices[1] = _ij0[1];
vinfos[0].maxsolutions = _nj0;
vinfos[1].jointtype = 1;
vinfos[1].foffset = j1;
vinfos[1].indices[0] = _ij1[0];
vinfos[1].indices[1] = _ij1[1];
vinfos[1].maxsolutions = _nj1;
vinfos[2].jointtype = 1;
vinfos[2].foffset = j2;
vinfos[2].indices[0] = _ij2[0];
vinfos[2].indices[1] = _ij2[1];
vinfos[2].maxsolutions = _nj2;
vinfos[3].jointtype = 1;
vinfos[3].foffset = j3;
vinfos[3].indices[0] = _ij3[0];
vinfos[3].indices[1] = _ij3[1];
vinfos[3].maxsolutions = _nj3;
vinfos[4].jointtype = 1;
vinfos[4].foffset = j4;
vinfos[4].indices[0] = _ij4[0];
vinfos[4].indices[1] = _ij4[1];
vinfos[4].maxsolutions = _nj4;
vinfos[5].jointtype = 1;
vinfos[5].foffset = j5;
vinfos[5].indices[0] = _ij5[0];
vinfos[5].indices[1] = _ij5[1];
vinfos[5].maxsolutions = _nj5;
vinfos[6].jointtype = 1;
vinfos[6].foffset = j6;
vinfos[6].indices[0] = _ij6[0];
vinfos[6].indices[1] = _ij6[1];
vinfos[6].maxsolutions = _nj6;
std::vector<int> vfree(0);
solutions.AddSolution(vinfos,vfree);
}
}
}

} else
{
if( 1 )
{
continue;

} else
{
}
}
}
}
}
}

} else
{
{
IkReal j3array[1], cj3array[1], sj3array[1];
bool j3valid[1]={false};
_nj3 = 1;
IkReal x6321=((cj0)*(cj5));
IkReal x6322=((IkReal(1.00000000000000))*(cj0));
IkReal x6323=((cj6)*(r11));
IkReal x6324=((r10)*(sj6));
IkReal x6325=((cj5)*(sj0));
IkReal x6326=((r00)*(sj5)*(sj6));
IkReal x6327=((cj6)*(r01)*(sj5));
IkReal x6328=((IkReal(1.00000000000000))*(sj0)*(sj5));
if( IKabs(((((IKabs(sj2) != 0)?((IkReal)1/(sj2)):(IkReal)1.0e30))*(((((IkReal(-1.00000000000000))*(sj5)*(x6322)*(x6324)))+(((sj0)*(x6327)))+(((r12)*(x6321)))+(((sj0)*(x6326)))+(((IkReal(-1.00000000000000))*(sj5)*(x6322)*(x6323)))+(((IkReal(-1.00000000000000))*(r02)*(x6325))))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(((((IkReal(-1.00000000000000))*(x6323)*(x6328)))+(((IkReal(-1.00000000000000))*(x6324)*(x6328)))+(((r02)*(x6321)))+(((IkReal(-1.00000000000000))*(x6322)*(x6327)))+(((IkReal(-1.00000000000000))*(x6322)*(x6326)))+(((r12)*(x6325))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(IKsqr(((((IKabs(sj2) != 0)?((IkReal)1/(sj2)):(IkReal)1.0e30))*(((((IkReal(-1.00000000000000))*(sj5)*(x6322)*(x6324)))+(((sj0)*(x6327)))+(((r12)*(x6321)))+(((sj0)*(x6326)))+(((IkReal(-1.00000000000000))*(sj5)*(x6322)*(x6323)))+(((IkReal(-1.00000000000000))*(r02)*(x6325)))))))+IKsqr(((((IkReal(-1.00000000000000))*(x6323)*(x6328)))+(((IkReal(-1.00000000000000))*(x6324)*(x6328)))+(((r02)*(x6321)))+(((IkReal(-1.00000000000000))*(x6322)*(x6327)))+(((IkReal(-1.00000000000000))*(x6322)*(x6326)))+(((r12)*(x6325)))))-1) <= IKFAST_SINCOS_THRESH )
    continue;
j3array[0]=IKatan2(((((IKabs(sj2) != 0)?((IkReal)1/(sj2)):(IkReal)1.0e30))*(((((IkReal(-1.00000000000000))*(sj5)*(x6322)*(x6324)))+(((sj0)*(x6327)))+(((r12)*(x6321)))+(((sj0)*(x6326)))+(((IkReal(-1.00000000000000))*(sj5)*(x6322)*(x6323)))+(((IkReal(-1.00000000000000))*(r02)*(x6325)))))), ((((IkReal(-1.00000000000000))*(x6323)*(x6328)))+(((IkReal(-1.00000000000000))*(x6324)*(x6328)))+(((r02)*(x6321)))+(((IkReal(-1.00000000000000))*(x6322)*(x6327)))+(((IkReal(-1.00000000000000))*(x6322)*(x6326)))+(((r12)*(x6325)))));
sj3array[0]=IKsin(j3array[0]);
cj3array[0]=IKcos(j3array[0]);
if( j3array[0] > IKPI )
{
    j3array[0]-=IK2PI;
}
else if( j3array[0] < -IKPI )
{    j3array[0]+=IK2PI;
}
j3valid[0] = true;
for(int ij3 = 0; ij3 < 1; ++ij3)
{
if( !j3valid[ij3] )
{
    continue;
}
_ij3[0] = ij3; _ij3[1] = -1;
for(int iij3 = ij3+1; iij3 < 1; ++iij3)
{
if( j3valid[iij3] && IKabs(cj3array[ij3]-cj3array[iij3]) < IKFAST_SOLUTION_THRESH && IKabs(sj3array[ij3]-sj3array[iij3]) < IKFAST_SOLUTION_THRESH )
{
    j3valid[iij3]=false; _ij3[1] = iij3; break; 
}
}
j3 = j3array[ij3]; cj3 = cj3array[ij3]; sj3 = sj3array[ij3];
{
IkReal evalcond[6];
IkReal x6329=IKsin(j3);
IkReal x6330=IKcos(j3);
IkReal x6331=((sj0)*(sj5));
IkReal x6332=((r00)*(sj6));
IkReal x6333=((IkReal(1.00000000000000))*(cj4));
IkReal x6334=((cj6)*(r01));
IkReal x6335=((cj0)*(cj5));
IkReal x6336=((cj5)*(sj0));
IkReal x6337=((cj6)*(r11));
IkReal x6338=((cj0)*(sj5));
IkReal x6339=((cj6)*(sj4));
IkReal x6340=((cj4)*(cj5));
IkReal x6341=((cj6)*(r21));
IkReal x6342=((r20)*(sj6));
IkReal x6343=((r10)*(sj6));
IkReal x6344=((IkReal(1.00000000000000))*(cj0));
IkReal x6345=((IkReal(1.00000000000000))*(x6329));
IkReal x6346=((cj0)*(sj4)*(sj6));
IkReal x6347=((sj0)*(sj4)*(sj6));
evalcond[0]=((((sj5)*(x6341)))+(((sj5)*(x6342)))+(((IkReal(-1.00000000000000))*(cj2)*(x6345)))+(((IkReal(-1.00000000000000))*(cj5)*(r22))));
evalcond[1]=((((IkReal(-1.00000000000000))*(r21)*(sj4)*(sj6)))+(((r20)*(x6339)))+(((x6340)*(x6342)))+(((x6340)*(x6341)))+(((cj2)*(x6330)))+(((cj4)*(r22)*(sj5))));
evalcond[2]=((((IkReal(-1.00000000000000))*(x6338)*(x6343)))+(((r12)*(x6335)))+(((IkReal(-1.00000000000000))*(sj2)*(x6345)))+(((x6331)*(x6332)))+(((IkReal(-1.00000000000000))*(r02)*(x6336)))+(((IkReal(-1.00000000000000))*(x6337)*(x6338)))+(((x6331)*(x6334))));
evalcond[3]=((((r02)*(x6335)))+(((IkReal(-1.00000000000000))*(x6331)*(x6343)))+(((IkReal(-1.00000000000000))*(x6332)*(x6338)))+(((IkReal(-1.00000000000000))*(x6334)*(x6338)))+(((r12)*(x6336)))+(((IkReal(-1.00000000000000))*(x6330)))+(((IkReal(-1.00000000000000))*(x6331)*(x6337))));
evalcond[4]=((((IkReal(-1.00000000000000))*(r10)*(x6339)*(x6344)))+(((cj4)*(x6334)*(x6336)))+(((cj4)*(r02)*(x6331)))+(((IkReal(-1.00000000000000))*(x6333)*(x6335)*(x6337)))+(((IkReal(-1.00000000000000))*(r01)*(x6347)))+(((r11)*(x6346)))+(((IkReal(-1.00000000000000))*(x6333)*(x6335)*(x6343)))+(((IkReal(-1.00000000000000))*(r12)*(x6333)*(x6338)))+(((cj4)*(x6332)*(x6336)))+(((r00)*(sj0)*(x6339)))+(((sj2)*(x6330))));
evalcond[5]=((((IkReal(-1.00000000000000))*(x6333)*(x6336)*(x6337)))+(((IkReal(-1.00000000000000))*(x6332)*(x6333)*(x6335)))+(((IkReal(-1.00000000000000))*(r02)*(x6333)*(x6338)))+(((IkReal(-1.00000000000000))*(r10)*(sj0)*(x6339)))+(((IkReal(-1.00000000000000))*(r12)*(x6331)*(x6333)))+(((IkReal(-1.00000000000000))*(x6333)*(x6336)*(x6343)))+(((IkReal(-1.00000000000000))*(x6333)*(x6334)*(x6335)))+(((r11)*(x6347)))+(((r01)*(x6346)))+(((IkReal(-1.00000000000000))*(r00)*(x6339)*(x6344)))+(((IkReal(-1.00000000000000))*(x6345))));
if( IKabs(evalcond[0]) > 0.000001  || IKabs(evalcond[1]) > 0.000001  || IKabs(evalcond[2]) > 0.000001  || IKabs(evalcond[3]) > 0.000001  || IKabs(evalcond[4]) > 0.000001  || IKabs(evalcond[5]) > 0.000001  )
{
continue;
}
}

{
std::vector<IkSingleDOFSolutionBase<IkReal> > vinfos(7);
vinfos[0].jointtype = 1;
vinfos[0].foffset = j0;
vinfos[0].indices[0] = _ij0[0];
vinfos[0].indices[1] = _ij0[1];
vinfos[0].maxsolutions = _nj0;
vinfos[1].jointtype = 1;
vinfos[1].foffset = j1;
vinfos[1].indices[0] = _ij1[0];
vinfos[1].indices[1] = _ij1[1];
vinfos[1].maxsolutions = _nj1;
vinfos[2].jointtype = 1;
vinfos[2].foffset = j2;
vinfos[2].indices[0] = _ij2[0];
vinfos[2].indices[1] = _ij2[1];
vinfos[2].maxsolutions = _nj2;
vinfos[3].jointtype = 1;
vinfos[3].foffset = j3;
vinfos[3].indices[0] = _ij3[0];
vinfos[3].indices[1] = _ij3[1];
vinfos[3].maxsolutions = _nj3;
vinfos[4].jointtype = 1;
vinfos[4].foffset = j4;
vinfos[4].indices[0] = _ij4[0];
vinfos[4].indices[1] = _ij4[1];
vinfos[4].maxsolutions = _nj4;
vinfos[5].jointtype = 1;
vinfos[5].foffset = j5;
vinfos[5].indices[0] = _ij5[0];
vinfos[5].indices[1] = _ij5[1];
vinfos[5].maxsolutions = _nj5;
vinfos[6].jointtype = 1;
vinfos[6].foffset = j6;
vinfos[6].indices[0] = _ij6[0];
vinfos[6].indices[1] = _ij6[1];
vinfos[6].maxsolutions = _nj6;
std::vector<int> vfree(0);
solutions.AddSolution(vinfos,vfree);
}
}
}

}

}

} else
{
{
IkReal j3array[1], cj3array[1], sj3array[1];
bool j3valid[1]={false};
_nj3 = 1;
IkReal x6348=((sj5)*(sj6));
IkReal x6349=((IkReal(1.00000000000000))*(cj6)*(sj5));
if( IKabs(((((IKabs(cj2) != 0)?((IkReal)1/(cj2)):(IkReal)1.0e30))*(((((cj6)*(r21)*(sj5)))+(((r20)*(x6348)))+(((IkReal(-1.00000000000000))*(cj5)*(r22))))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(((((cj0)*(cj5)*(r02)))+(((IkReal(-1.00000000000000))*(r11)*(sj0)*(x6349)))+(((IkReal(-1.00000000000000))*(cj0)*(r00)*(x6348)))+(((cj5)*(r12)*(sj0)))+(((IkReal(-1.00000000000000))*(r10)*(sj0)*(x6348)))+(((IkReal(-1.00000000000000))*(cj0)*(r01)*(x6349))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(IKsqr(((((IKabs(cj2) != 0)?((IkReal)1/(cj2)):(IkReal)1.0e30))*(((((cj6)*(r21)*(sj5)))+(((r20)*(x6348)))+(((IkReal(-1.00000000000000))*(cj5)*(r22)))))))+IKsqr(((((cj0)*(cj5)*(r02)))+(((IkReal(-1.00000000000000))*(r11)*(sj0)*(x6349)))+(((IkReal(-1.00000000000000))*(cj0)*(r00)*(x6348)))+(((cj5)*(r12)*(sj0)))+(((IkReal(-1.00000000000000))*(r10)*(sj0)*(x6348)))+(((IkReal(-1.00000000000000))*(cj0)*(r01)*(x6349)))))-1) <= IKFAST_SINCOS_THRESH )
    continue;
j3array[0]=IKatan2(((((IKabs(cj2) != 0)?((IkReal)1/(cj2)):(IkReal)1.0e30))*(((((cj6)*(r21)*(sj5)))+(((r20)*(x6348)))+(((IkReal(-1.00000000000000))*(cj5)*(r22)))))), ((((cj0)*(cj5)*(r02)))+(((IkReal(-1.00000000000000))*(r11)*(sj0)*(x6349)))+(((IkReal(-1.00000000000000))*(cj0)*(r00)*(x6348)))+(((cj5)*(r12)*(sj0)))+(((IkReal(-1.00000000000000))*(r10)*(sj0)*(x6348)))+(((IkReal(-1.00000000000000))*(cj0)*(r01)*(x6349)))));
sj3array[0]=IKsin(j3array[0]);
cj3array[0]=IKcos(j3array[0]);
if( j3array[0] > IKPI )
{
    j3array[0]-=IK2PI;
}
else if( j3array[0] < -IKPI )
{    j3array[0]+=IK2PI;
}
j3valid[0] = true;
for(int ij3 = 0; ij3 < 1; ++ij3)
{
if( !j3valid[ij3] )
{
    continue;
}
_ij3[0] = ij3; _ij3[1] = -1;
for(int iij3 = ij3+1; iij3 < 1; ++iij3)
{
if( j3valid[iij3] && IKabs(cj3array[ij3]-cj3array[iij3]) < IKFAST_SOLUTION_THRESH && IKabs(sj3array[ij3]-sj3array[iij3]) < IKFAST_SOLUTION_THRESH )
{
    j3valid[iij3]=false; _ij3[1] = iij3; break; 
}
}
j3 = j3array[ij3]; cj3 = cj3array[ij3]; sj3 = sj3array[ij3];
{
IkReal evalcond[6];
IkReal x6350=IKsin(j3);
IkReal x6351=IKcos(j3);
IkReal x6352=((sj0)*(sj5));
IkReal x6353=((r00)*(sj6));
IkReal x6354=((IkReal(1.00000000000000))*(cj4));
IkReal x6355=((cj6)*(r01));
IkReal x6356=((cj0)*(cj5));
IkReal x6357=((cj5)*(sj0));
IkReal x6358=((cj6)*(r11));
IkReal x6359=((cj0)*(sj5));
IkReal x6360=((cj6)*(sj4));
IkReal x6361=((cj4)*(cj5));
IkReal x6362=((cj6)*(r21));
IkReal x6363=((r20)*(sj6));
IkReal x6364=((r10)*(sj6));
IkReal x6365=((IkReal(1.00000000000000))*(cj0));
IkReal x6366=((IkReal(1.00000000000000))*(x6350));
IkReal x6367=((cj0)*(sj4)*(sj6));
IkReal x6368=((sj0)*(sj4)*(sj6));
evalcond[0]=((((sj5)*(x6363)))+(((IkReal(-1.00000000000000))*(cj5)*(r22)))+(((sj5)*(x6362)))+(((IkReal(-1.00000000000000))*(cj2)*(x6366))));
evalcond[1]=((((x6361)*(x6363)))+(((IkReal(-1.00000000000000))*(r21)*(sj4)*(sj6)))+(((r20)*(x6360)))+(((x6361)*(x6362)))+(((cj2)*(x6351)))+(((cj4)*(r22)*(sj5))));
evalcond[2]=((((x6352)*(x6353)))+(((IkReal(-1.00000000000000))*(sj2)*(x6366)))+(((r12)*(x6356)))+(((x6352)*(x6355)))+(((IkReal(-1.00000000000000))*(x6358)*(x6359)))+(((IkReal(-1.00000000000000))*(r02)*(x6357)))+(((IkReal(-1.00000000000000))*(x6359)*(x6364))));
evalcond[3]=((((IkReal(-1.00000000000000))*(x6353)*(x6359)))+(((IkReal(-1.00000000000000))*(x6351)))+(((IkReal(-1.00000000000000))*(x6352)*(x6364)))+(((IkReal(-1.00000000000000))*(x6352)*(x6358)))+(((r02)*(x6356)))+(((r12)*(x6357)))+(((IkReal(-1.00000000000000))*(x6355)*(x6359))));
evalcond[4]=((((cj4)*(r02)*(x6352)))+(((r11)*(x6367)))+(((sj2)*(x6351)))+(((cj4)*(x6353)*(x6357)))+(((IkReal(-1.00000000000000))*(r10)*(x6360)*(x6365)))+(((IkReal(-1.00000000000000))*(x6354)*(x6356)*(x6358)))+(((IkReal(-1.00000000000000))*(x6354)*(x6356)*(x6364)))+(((cj4)*(x6355)*(x6357)))+(((IkReal(-1.00000000000000))*(r12)*(x6354)*(x6359)))+(((IkReal(-1.00000000000000))*(r01)*(x6368)))+(((r00)*(sj0)*(x6360))));
evalcond[5]=((((IkReal(-1.00000000000000))*(x6354)*(x6357)*(x6364)))+(((IkReal(-1.00000000000000))*(r12)*(x6352)*(x6354)))+(((r01)*(x6367)))+(((r11)*(x6368)))+(((IkReal(-1.00000000000000))*(x6366)))+(((IkReal(-1.00000000000000))*(x6354)*(x6355)*(x6356)))+(((IkReal(-1.00000000000000))*(r00)*(x6360)*(x6365)))+(((IkReal(-1.00000000000000))*(r02)*(x6354)*(x6359)))+(((IkReal(-1.00000000000000))*(r10)*(sj0)*(x6360)))+(((IkReal(-1.00000000000000))*(x6354)*(x6357)*(x6358)))+(((IkReal(-1.00000000000000))*(x6353)*(x6354)*(x6356))));
if( IKabs(evalcond[0]) > 0.000001  || IKabs(evalcond[1]) > 0.000001  || IKabs(evalcond[2]) > 0.000001  || IKabs(evalcond[3]) > 0.000001  || IKabs(evalcond[4]) > 0.000001  || IKabs(evalcond[5]) > 0.000001  )
{
continue;
}
}

{
std::vector<IkSingleDOFSolutionBase<IkReal> > vinfos(7);
vinfos[0].jointtype = 1;
vinfos[0].foffset = j0;
vinfos[0].indices[0] = _ij0[0];
vinfos[0].indices[1] = _ij0[1];
vinfos[0].maxsolutions = _nj0;
vinfos[1].jointtype = 1;
vinfos[1].foffset = j1;
vinfos[1].indices[0] = _ij1[0];
vinfos[1].indices[1] = _ij1[1];
vinfos[1].maxsolutions = _nj1;
vinfos[2].jointtype = 1;
vinfos[2].foffset = j2;
vinfos[2].indices[0] = _ij2[0];
vinfos[2].indices[1] = _ij2[1];
vinfos[2].maxsolutions = _nj2;
vinfos[3].jointtype = 1;
vinfos[3].foffset = j3;
vinfos[3].indices[0] = _ij3[0];
vinfos[3].indices[1] = _ij3[1];
vinfos[3].maxsolutions = _nj3;
vinfos[4].jointtype = 1;
vinfos[4].foffset = j4;
vinfos[4].indices[0] = _ij4[0];
vinfos[4].indices[1] = _ij4[1];
vinfos[4].maxsolutions = _nj4;
vinfos[5].jointtype = 1;
vinfos[5].foffset = j5;
vinfos[5].indices[0] = _ij5[0];
vinfos[5].indices[1] = _ij5[1];
vinfos[5].maxsolutions = _nj5;
vinfos[6].jointtype = 1;
vinfos[6].foffset = j6;
vinfos[6].indices[0] = _ij6[0];
vinfos[6].indices[1] = _ij6[1];
vinfos[6].maxsolutions = _nj6;
std::vector<int> vfree(0);
solutions.AddSolution(vinfos,vfree);
}
}
}

}

}

} else
{
{
IkReal j3array[1], cj3array[1], sj3array[1];
bool j3valid[1]={false};
_nj3 = 1;
IkReal x6369=((IkReal(1.00000000000000))*(cj4));
IkReal x6370=((cj6)*(r21));
IkReal x6371=((r20)*(sj6));
if( IKabs(((gconst9)*(((((sj5)*(x6371)))+(((sj5)*(x6370)))+(((IkReal(-1.00000000000000))*(cj5)*(r22))))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(((gconst9)*(((((IkReal(-1.00000000000000))*(cj5)*(x6369)*(x6370)))+(((r21)*(sj4)*(sj6)))+(((IkReal(-1.00000000000000))*(r22)*(sj5)*(x6369)))+(((IkReal(-1.00000000000000))*(cj5)*(x6369)*(x6371)))+(((IkReal(-1.00000000000000))*(cj6)*(r20)*(sj4))))))) < IKFAST_ATAN2_MAGTHRESH )
    continue;
j3array[0]=IKatan2(((gconst9)*(((((sj5)*(x6371)))+(((sj5)*(x6370)))+(((IkReal(-1.00000000000000))*(cj5)*(r22)))))), ((gconst9)*(((((IkReal(-1.00000000000000))*(cj5)*(x6369)*(x6370)))+(((r21)*(sj4)*(sj6)))+(((IkReal(-1.00000000000000))*(r22)*(sj5)*(x6369)))+(((IkReal(-1.00000000000000))*(cj5)*(x6369)*(x6371)))+(((IkReal(-1.00000000000000))*(cj6)*(r20)*(sj4)))))));
sj3array[0]=IKsin(j3array[0]);
cj3array[0]=IKcos(j3array[0]);
if( j3array[0] > IKPI )
{
    j3array[0]-=IK2PI;
}
else if( j3array[0] < -IKPI )
{    j3array[0]+=IK2PI;
}
j3valid[0] = true;
for(int ij3 = 0; ij3 < 1; ++ij3)
{
if( !j3valid[ij3] )
{
    continue;
}
_ij3[0] = ij3; _ij3[1] = -1;
for(int iij3 = ij3+1; iij3 < 1; ++iij3)
{
if( j3valid[iij3] && IKabs(cj3array[ij3]-cj3array[iij3]) < IKFAST_SOLUTION_THRESH && IKabs(sj3array[ij3]-sj3array[iij3]) < IKFAST_SOLUTION_THRESH )
{
    j3valid[iij3]=false; _ij3[1] = iij3; break; 
}
}
j3 = j3array[ij3]; cj3 = cj3array[ij3]; sj3 = sj3array[ij3];
{
IkReal evalcond[6];
IkReal x6372=IKsin(j3);
IkReal x6373=IKcos(j3);
IkReal x6374=((sj0)*(sj5));
IkReal x6375=((r00)*(sj6));
IkReal x6376=((IkReal(1.00000000000000))*(cj4));
IkReal x6377=((cj6)*(r01));
IkReal x6378=((cj0)*(cj5));
IkReal x6379=((cj5)*(sj0));
IkReal x6380=((cj6)*(r11));
IkReal x6381=((cj0)*(sj5));
IkReal x6382=((cj6)*(sj4));
IkReal x6383=((cj4)*(cj5));
IkReal x6384=((cj6)*(r21));
IkReal x6385=((r20)*(sj6));
IkReal x6386=((r10)*(sj6));
IkReal x6387=((IkReal(1.00000000000000))*(cj0));
IkReal x6388=((IkReal(1.00000000000000))*(x6372));
IkReal x6389=((cj0)*(sj4)*(sj6));
IkReal x6390=((sj0)*(sj4)*(sj6));
evalcond[0]=((((sj5)*(x6384)))+(((IkReal(-1.00000000000000))*(cj5)*(r22)))+(((sj5)*(x6385)))+(((IkReal(-1.00000000000000))*(cj2)*(x6388))));
evalcond[1]=((((IkReal(-1.00000000000000))*(r21)*(sj4)*(sj6)))+(((cj2)*(x6373)))+(((r20)*(x6382)))+(((cj4)*(r22)*(sj5)))+(((x6383)*(x6384)))+(((x6383)*(x6385))));
evalcond[2]=((((IkReal(-1.00000000000000))*(sj2)*(x6388)))+(((x6374)*(x6377)))+(((IkReal(-1.00000000000000))*(x6380)*(x6381)))+(((x6374)*(x6375)))+(((IkReal(-1.00000000000000))*(x6381)*(x6386)))+(((IkReal(-1.00000000000000))*(r02)*(x6379)))+(((r12)*(x6378))));
evalcond[3]=((((IkReal(-1.00000000000000))*(x6377)*(x6381)))+(((IkReal(-1.00000000000000))*(x6373)))+(((IkReal(-1.00000000000000))*(x6374)*(x6380)))+(((IkReal(-1.00000000000000))*(x6375)*(x6381)))+(((r12)*(x6379)))+(((IkReal(-1.00000000000000))*(x6374)*(x6386)))+(((r02)*(x6378))));
evalcond[4]=((((sj2)*(x6373)))+(((IkReal(-1.00000000000000))*(r12)*(x6376)*(x6381)))+(((IkReal(-1.00000000000000))*(r10)*(x6382)*(x6387)))+(((r11)*(x6389)))+(((r00)*(sj0)*(x6382)))+(((IkReal(-1.00000000000000))*(r01)*(x6390)))+(((cj4)*(x6375)*(x6379)))+(((cj4)*(r02)*(x6374)))+(((IkReal(-1.00000000000000))*(x6376)*(x6378)*(x6386)))+(((cj4)*(x6377)*(x6379)))+(((IkReal(-1.00000000000000))*(x6376)*(x6378)*(x6380))));
evalcond[5]=((((IkReal(-1.00000000000000))*(r02)*(x6376)*(x6381)))+(((IkReal(-1.00000000000000))*(r00)*(x6382)*(x6387)))+(((r11)*(x6390)))+(((IkReal(-1.00000000000000))*(x6376)*(x6377)*(x6378)))+(((r01)*(x6389)))+(((IkReal(-1.00000000000000))*(x6376)*(x6379)*(x6380)))+(((IkReal(-1.00000000000000))*(r10)*(sj0)*(x6382)))+(((IkReal(-1.00000000000000))*(x6375)*(x6376)*(x6378)))+(((IkReal(-1.00000000000000))*(r12)*(x6374)*(x6376)))+(((IkReal(-1.00000000000000))*(x6388)))+(((IkReal(-1.00000000000000))*(x6376)*(x6379)*(x6386))));
if( IKabs(evalcond[0]) > 0.000001  || IKabs(evalcond[1]) > 0.000001  || IKabs(evalcond[2]) > 0.000001  || IKabs(evalcond[3]) > 0.000001  || IKabs(evalcond[4]) > 0.000001  || IKabs(evalcond[5]) > 0.000001  )
{
continue;
}
}

{
std::vector<IkSingleDOFSolutionBase<IkReal> > vinfos(7);
vinfos[0].jointtype = 1;
vinfos[0].foffset = j0;
vinfos[0].indices[0] = _ij0[0];
vinfos[0].indices[1] = _ij0[1];
vinfos[0].maxsolutions = _nj0;
vinfos[1].jointtype = 1;
vinfos[1].foffset = j1;
vinfos[1].indices[0] = _ij1[0];
vinfos[1].indices[1] = _ij1[1];
vinfos[1].maxsolutions = _nj1;
vinfos[2].jointtype = 1;
vinfos[2].foffset = j2;
vinfos[2].indices[0] = _ij2[0];
vinfos[2].indices[1] = _ij2[1];
vinfos[2].maxsolutions = _nj2;
vinfos[3].jointtype = 1;
vinfos[3].foffset = j3;
vinfos[3].indices[0] = _ij3[0];
vinfos[3].indices[1] = _ij3[1];
vinfos[3].maxsolutions = _nj3;
vinfos[4].jointtype = 1;
vinfos[4].foffset = j4;
vinfos[4].indices[0] = _ij4[0];
vinfos[4].indices[1] = _ij4[1];
vinfos[4].maxsolutions = _nj4;
vinfos[5].jointtype = 1;
vinfos[5].foffset = j5;
vinfos[5].indices[0] = _ij5[0];
vinfos[5].indices[1] = _ij5[1];
vinfos[5].maxsolutions = _nj5;
vinfos[6].jointtype = 1;
vinfos[6].foffset = j6;
vinfos[6].indices[0] = _ij6[0];
vinfos[6].indices[1] = _ij6[1];
vinfos[6].maxsolutions = _nj6;
std::vector<int> vfree(0);
solutions.AddSolution(vinfos,vfree);
}
}
}

}

}

} else
{
IkReal x6391=((IkReal(1.00000000000000))*(cj0));
IkReal x6392=((cj4)*(sj6));
IkReal x6393=((sj0)*(sj4));
IkReal x6394=((cj5)*(sj6));
IkReal x6395=((sj4)*(sj5));
IkReal x6396=((r12)*(sj5));
IkReal x6397=((IkReal(0.374290000000000))*(cj5));
IkReal x6398=((r02)*(sj0));
IkReal x6399=((IkReal(1.00000000000000))*(sj0));
IkReal x6400=((cj0)*(r10));
IkReal x6401=((cj4)*(cj6));
IkReal x6402=((r00)*(sj0));
IkReal x6403=((cj6)*(r21));
IkReal x6404=((IkReal(0.374290000000000))*(sj5));
IkReal x6405=((cj0)*(r00));
IkReal x6406=((IkReal(0.0100000000000000))*(sj5));
IkReal x6407=((cj0)*(r02));
IkReal x6408=((cj5)*(sj4));
IkReal x6409=((cj6)*(r01));
IkReal x6410=((cj6)*(r11));
IkReal x6411=((r01)*(sj0));
IkReal x6412=((r10)*(sj0));
IkReal x6413=((IkReal(0.0100000000000000))*(cj5)*(cj6));
IkReal x6414=((sj6)*(x6404));
IkReal x6415=((cj0)*(cj6)*(x6404));
evalcond[0]=((IkReal(-3.14159265358979))+(IKfmod(j1, IkReal(6.28318530717959))));
evalcond[1]=((((r20)*(sj4)*(x6394)))+(((x6403)*(x6408)))+(sj2)+(((r22)*(x6395)))+(((r21)*(x6392)))+(((IkReal(-1.00000000000000))*(r20)*(x6401))));
evalcond[2]=((((IkReal(-1.00000000000000))*(r22)*(x6397)))+(((r20)*(x6414)))+(((IkReal(-0.0100000000000000))*(cj5)*(x6403)))+(((IkReal(-0.0690000000000000))*(cj2)))+(pz)+(((x6403)*(x6404)))+(((IkReal(-1.00000000000000))*(r22)*(x6406)))+(((IkReal(-0.0100000000000000))*(r20)*(x6394))));
evalcond[3]=((((IkReal(-1.00000000000000))*(r12)*(x6391)*(x6395)))+(((x6392)*(x6411)))+(((IkReal(-1.00000000000000))*(r11)*(x6391)*(x6392)))+(((IkReal(-1.00000000000000))*(r10)*(sj4)*(x6391)*(x6394)))+(((r00)*(x6393)*(x6394)))+(((x6400)*(x6401)))+(cj2)+(((cj5)*(x6393)*(x6409)))+(((r02)*(sj5)*(x6393)))+(((IkReal(-1.00000000000000))*(r00)*(x6399)*(x6401)))+(((IkReal(-1.00000000000000))*(x6391)*(x6408)*(x6410))));
evalcond[4]=((((IkReal(-1.00000000000000))*(cj5)*(x6393)*(x6410)))+(((IkReal(-1.00000000000000))*(r02)*(x6391)*(x6395)))+(((IkReal(-1.00000000000000))*(x6393)*(x6396)))+(((IkReal(-1.00000000000000))*(r00)*(sj4)*(x6391)*(x6394)))+(((IkReal(-1.00000000000000))*(x6391)*(x6408)*(x6409)))+(((x6401)*(x6405)))+(((IkReal(-1.00000000000000))*(r11)*(x6392)*(x6399)))+(((IkReal(-1.00000000000000))*(r01)*(x6391)*(x6392)))+(((IkReal(-1.00000000000000))*(r10)*(x6393)*(x6394)))+(((x6401)*(x6412))));
evalcond[5]=((((IkReal(-1.00000000000000))*(cj0)*(x6404)*(x6410)))+(((IkReal(-0.0100000000000000))*(x6394)*(x6402)))+(((IkReal(0.0690000000000000))*(sj2)))+(((IkReal(0.0100000000000000))*(cj0)*(x6396)))+(((IkReal(-1.00000000000000))*(x6397)*(x6398)))+(((IkReal(-0.0100000000000000))*(cj5)*(sj0)*(x6409)))+(((IkReal(0.0100000000000000))*(x6394)*(x6400)))+(((IkReal(0.0100000000000000))*(cj0)*(cj5)*(x6410)))+(((x6402)*(x6414)))+(((cj0)*(r12)*(x6397)))+(((IkReal(-1.00000000000000))*(x6400)*(x6414)))+(((sj0)*(x6404)*(x6409)))+(((px)*(sj0)))+(((IkReal(-1.00000000000000))*(x6398)*(x6406)))+(((IkReal(-1.00000000000000))*(py)*(x6391))));
evalcond[6]=((IkReal(-0.295420000000000))+(((x6406)*(x6407)))+(((IkReal(-1.00000000000000))*(px)*(x6391)))+(((IkReal(-1.00000000000000))*(x6405)*(x6414)))+(((IkReal(0.0100000000000000))*(x6394)*(x6405)))+(((IkReal(-1.00000000000000))*(x6412)*(x6414)))+(((IkReal(0.0100000000000000))*(cj5)*(sj0)*(x6410)))+(((IkReal(0.0100000000000000))*(x6394)*(x6412)))+(((r12)*(sj0)*(x6397)))+(((IkReal(-1.00000000000000))*(sj0)*(x6404)*(x6410)))+(((IkReal(-1.00000000000000))*(py)*(x6399)))+(((x6397)*(x6407)))+(((IkReal(0.0100000000000000))*(cj0)*(cj5)*(x6409)))+(((IkReal(0.0100000000000000))*(sj0)*(x6396)))+(((IkReal(-1.00000000000000))*(cj0)*(x6404)*(x6409))));
if( IKabs(evalcond[0]) < 0.0000010000000000  && IKabs(evalcond[1]) < 0.0000010000000000  && IKabs(evalcond[2]) < 0.0000010000000000  && IKabs(evalcond[3]) < 0.0000010000000000  && IKabs(evalcond[4]) < 0.0000010000000000  && IKabs(evalcond[5]) < 0.0000010000000000  && IKabs(evalcond[6]) < 0.0000010000000000  )
{
{
IkReal dummyeval[1];
IkReal gconst10;
gconst10=IKsign(cj2);
dummyeval[0]=cj2;
if( IKabs(dummyeval[0]) < 0.0000010000000000  )
{
{
IkReal dummyeval[1];
dummyeval[0]=cj2;
if( IKabs(dummyeval[0]) < 0.0000010000000000  )
{
{
IkReal dummyeval[1];
dummyeval[0]=sj2;
if( IKabs(dummyeval[0]) < 0.0000010000000000  )
{
{
IkReal evalcond[9];
IkReal x6416=((cj5)*(sj4));
IkReal x6417=((IkReal(1.00000000000000))*(sj6));
IkReal x6418=((r10)*(sj0));
IkReal x6419=((sj4)*(sj5));
IkReal x6420=((cj5)*(cj6));
IkReal x6421=((r01)*(sj0));
IkReal x6422=((IkReal(1.00000000000000))*(r02));
IkReal x6423=((IkReal(0.374290000000000))*(cj0));
IkReal x6424=((cj5)*(r12));
IkReal x6425=((cj6)*(sj5));
IkReal x6426=((cj0)*(r11));
IkReal x6427=((cj5)*(sj0));
IkReal x6428=((r20)*(sj6));
IkReal x6429=((IkReal(1.00000000000000))*(sj0));
IkReal x6430=((cj4)*(cj5));
IkReal x6431=((IkReal(1.00000000000000))*(cj6));
IkReal x6432=((IkReal(0.0100000000000000))*(sj5));
IkReal x6433=((sj5)*(sj6));
IkReal x6434=((cj0)*(r10));
IkReal x6435=((cj4)*(cj6));
IkReal x6436=((cj0)*(r01));
IkReal x6437=((IkReal(1.00000000000000))*(cj4));
IkReal x6438=((cj0)*(r00));
IkReal x6439=((IkReal(0.374290000000000))*(sj0));
IkReal x6440=((cj0)*(r12));
IkReal x6441=((IkReal(0.374290000000000))*(sj5));
IkReal x6442=((cj4)*(sj6));
IkReal x6443=((IkReal(1.00000000000000))*(cj0));
IkReal x6444=((r02)*(sj0));
IkReal x6445=((IkReal(0.0100000000000000))*(cj5));
IkReal x6446=((r11)*(sj0));
IkReal x6447=((r00)*(sj0)*(sj6));
IkReal x6448=((r00)*(x6435));
IkReal x6449=((sj6)*(x6445));
evalcond[0]=((IkReal(-3.14159265358979))+(IKfmod(((IkReal(3.14159265358979))+(j2)), IkReal(6.28318530717959))));
evalcond[1]=((((IkReal(-1.00000000000000))*(cj4)*(r20)*(x6431)))+(((r22)*(x6419)))+(((cj6)*(r21)*(x6416)))+(((x6416)*(x6428)))+(((r21)*(x6442))));
evalcond[2]=((IkReal(-0.0690000000000000))+(((IkReal(0.374290000000000))*(r21)*(x6425)))+(((x6428)*(x6441)))+(((IkReal(-0.374290000000000))*(cj5)*(r22)))+(pz)+(((IkReal(-1.00000000000000))*(r22)*(x6432)))+(((IkReal(-1.00000000000000))*(x6428)*(x6445)))+(((IkReal(-0.0100000000000000))*(r21)*(x6420))));
evalcond[3]=((((r00)*(sj0)*(x6433)))+(((IkReal(-1.00000000000000))*(sj5)*(x6417)*(x6434)))+(((IkReal(-1.00000000000000))*(x6422)*(x6427)))+(((x6421)*(x6425)))+(((cj0)*(x6424)))+(((IkReal(-1.00000000000000))*(x6425)*(x6426))));
evalcond[4]=((IkReal(1.00000000000000))+(((IkReal(-1.00000000000000))*(x6416)*(x6426)*(x6431)))+(((x6416)*(x6447)))+(((cj6)*(x6416)*(x6421)))+(((IkReal(-1.00000000000000))*(x6419)*(x6440)))+(((x6434)*(x6435)))+(((IkReal(-1.00000000000000))*(cj4)*(x6417)*(x6426)))+(((IkReal(-1.00000000000000))*(x6416)*(x6417)*(x6434)))+(((x6419)*(x6444)))+(((x6421)*(x6442)))+(((IkReal(-1.00000000000000))*(x6429)*(x6448))));
evalcond[5]=((((cj4)*(x6420)*(x6421)))+(((IkReal(-1.00000000000000))*(x6417)*(x6430)*(x6434)))+(((r00)*(x6427)*(x6442)))+(((sj4)*(sj6)*(x6426)))+(((cj6)*(r00)*(sj0)*(sj4)))+(((cj4)*(sj5)*(x6444)))+(((IkReal(-1.00000000000000))*(sj4)*(x6417)*(x6421)))+(((IkReal(-1.00000000000000))*(sj4)*(x6431)*(x6434)))+(((IkReal(-1.00000000000000))*(x6420)*(x6426)*(x6437)))+(((IkReal(-1.00000000000000))*(sj5)*(x6437)*(x6440))));
evalcond[6]=((((IkReal(-1.00000000000000))*(cj4)*(x6417)*(x6436)))+(((IkReal(-1.00000000000000))*(r12)*(x6419)*(x6429)))+(((IkReal(-1.00000000000000))*(cj6)*(r11)*(x6416)*(x6429)))+(((IkReal(-1.00000000000000))*(cj0)*(x6419)*(x6422)))+(((x6435)*(x6438)))+(((x6418)*(x6435)))+(((IkReal(-1.00000000000000))*(x6416)*(x6431)*(x6436)))+(((IkReal(-1.00000000000000))*(cj4)*(x6417)*(x6446)))+(((IkReal(-1.00000000000000))*(x6416)*(x6417)*(x6438)))+(((IkReal(-1.00000000000000))*(x6416)*(x6417)*(x6418))));
evalcond[7]=((((IkReal(-0.0100000000000000))*(x6420)*(x6421)))+(((IkReal(-1.00000000000000))*(py)*(x6443)))+(((IkReal(-1.00000000000000))*(r11)*(x6423)*(x6425)))+(((IkReal(0.374290000000000))*(x6421)*(x6425)))+(((x6434)*(x6449)))+(((x6432)*(x6440)))+(((x6423)*(x6424)))+(((IkReal(-1.00000000000000))*(r10)*(x6423)*(x6433)))+(((IkReal(-0.374290000000000))*(r02)*(x6427)))+(((IkReal(-1.00000000000000))*(x6432)*(x6444)))+(((IkReal(-0.0100000000000000))*(r00)*(sj6)*(x6427)))+(((IkReal(0.0100000000000000))*(x6420)*(x6426)))+(((px)*(sj0)))+(((r00)*(x6433)*(x6439))));
evalcond[8]=((IkReal(-0.295420000000000))+(((cj0)*(r02)*(x6432)))+(((IkReal(0.0100000000000000))*(x6420)*(x6436)))+(((x6424)*(x6439)))+(((r12)*(sj0)*(x6432)))+(((IkReal(-1.00000000000000))*(r00)*(x6423)*(x6433)))+(((IkReal(-1.00000000000000))*(r11)*(x6425)*(x6439)))+(((IkReal(-0.374290000000000))*(x6418)*(x6433)))+(((IkReal(-1.00000000000000))*(py)*(x6429)))+(((IkReal(-1.00000000000000))*(r01)*(x6423)*(x6425)))+(((IkReal(-1.00000000000000))*(px)*(x6443)))+(((x6438)*(x6449)))+(((x6418)*(x6449)))+(((IkReal(0.0100000000000000))*(x6420)*(x6446)))+(((cj5)*(r02)*(x6423))));
if( IKabs(evalcond[0]) < 0.0000010000000000  && IKabs(evalcond[1]) < 0.0000010000000000  && IKabs(evalcond[2]) < 0.0000010000000000  && IKabs(evalcond[3]) < 0.0000010000000000  && IKabs(evalcond[4]) < 0.0000010000000000  && IKabs(evalcond[5]) < 0.0000010000000000  && IKabs(evalcond[6]) < 0.0000010000000000  && IKabs(evalcond[7]) < 0.0000010000000000  && IKabs(evalcond[8]) < 0.0000010000000000  )
{
{
IkReal j3array[1], cj3array[1], sj3array[1];
bool j3valid[1]={false};
_nj3 = 1;
IkReal x6450=((IkReal(1.00000000000000))*(r21));
IkReal x6451=((cj4)*(cj5));
IkReal x6452=((r20)*(sj6));
if( IKabs(((((IkReal(-1.00000000000000))*(sj5)*(x6452)))+(((IkReal(-1.00000000000000))*(cj6)*(sj5)*(x6450)))+(((cj5)*(r22))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(((((IkReal(-1.00000000000000))*(sj4)*(sj6)*(x6450)))+(((x6451)*(x6452)))+(((cj6)*(r20)*(sj4)))+(((cj4)*(r22)*(sj5)))+(((cj6)*(r21)*(x6451))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(IKsqr(((((IkReal(-1.00000000000000))*(sj5)*(x6452)))+(((IkReal(-1.00000000000000))*(cj6)*(sj5)*(x6450)))+(((cj5)*(r22)))))+IKsqr(((((IkReal(-1.00000000000000))*(sj4)*(sj6)*(x6450)))+(((x6451)*(x6452)))+(((cj6)*(r20)*(sj4)))+(((cj4)*(r22)*(sj5)))+(((cj6)*(r21)*(x6451)))))-1) <= IKFAST_SINCOS_THRESH )
    continue;
j3array[0]=IKatan2(((((IkReal(-1.00000000000000))*(sj5)*(x6452)))+(((IkReal(-1.00000000000000))*(cj6)*(sj5)*(x6450)))+(((cj5)*(r22)))), ((((IkReal(-1.00000000000000))*(sj4)*(sj6)*(x6450)))+(((x6451)*(x6452)))+(((cj6)*(r20)*(sj4)))+(((cj4)*(r22)*(sj5)))+(((cj6)*(r21)*(x6451)))));
sj3array[0]=IKsin(j3array[0]);
cj3array[0]=IKcos(j3array[0]);
if( j3array[0] > IKPI )
{
    j3array[0]-=IK2PI;
}
else if( j3array[0] < -IKPI )
{    j3array[0]+=IK2PI;
}
j3valid[0] = true;
for(int ij3 = 0; ij3 < 1; ++ij3)
{
if( !j3valid[ij3] )
{
    continue;
}
_ij3[0] = ij3; _ij3[1] = -1;
for(int iij3 = ij3+1; iij3 < 1; ++iij3)
{
if( j3valid[iij3] && IKabs(cj3array[ij3]-cj3array[iij3]) < IKFAST_SOLUTION_THRESH && IKabs(sj3array[ij3]-sj3array[iij3]) < IKFAST_SOLUTION_THRESH )
{
    j3valid[iij3]=false; _ij3[1] = iij3; break; 
}
}
j3 = j3array[ij3]; cj3 = cj3array[ij3]; sj3 = sj3array[ij3];
{
IkReal evalcond[4];
IkReal x6453=IKcos(j3);
IkReal x6454=IKsin(j3);
IkReal x6455=((IkReal(1.00000000000000))*(cj4));
IkReal x6456=((sj0)*(sj5));
IkReal x6457=((cj0)*(cj5));
IkReal x6458=((cj6)*(r01));
IkReal x6459=((r00)*(sj6));
IkReal x6460=((cj6)*(r11));
IkReal x6461=((cj5)*(sj0));
IkReal x6462=((cj6)*(sj4));
IkReal x6463=((sj4)*(sj6));
IkReal x6464=((cj4)*(cj5));
IkReal x6465=((cj6)*(r21));
IkReal x6466=((r20)*(sj6));
IkReal x6467=((r10)*(sj6));
IkReal x6468=((IkReal(1.00000000000000))*(cj0)*(sj5));
evalcond[0]=((((sj5)*(x6465)))+(((sj5)*(x6466)))+(((IkReal(-1.00000000000000))*(cj5)*(r22)))+(x6454));
evalcond[1]=((((x6464)*(x6466)))+(((IkReal(-1.00000000000000))*(x6453)))+(((cj4)*(r22)*(sj5)))+(((r20)*(x6462)))+(((x6464)*(x6465)))+(((IkReal(-1.00000000000000))*(r21)*(x6463))));
evalcond[2]=((((IkReal(-1.00000000000000))*(x6456)*(x6460)))+(((IkReal(-1.00000000000000))*(x6458)*(x6468)))+(((IkReal(-1.00000000000000))*(x6459)*(x6468)))+(((r12)*(x6461)))+(((r02)*(x6457)))+(((IkReal(-1.00000000000000))*(x6456)*(x6467)))+(x6453));
evalcond[3]=((((IkReal(-1.00000000000000))*(cj0)*(r02)*(sj5)*(x6455)))+(((IkReal(-1.00000000000000))*(x6455)*(x6460)*(x6461)))+(((IkReal(-1.00000000000000))*(x6455)*(x6461)*(x6467)))+(((IkReal(-1.00000000000000))*(cj0)*(r00)*(x6462)))+(((IkReal(-1.00000000000000))*(x6455)*(x6457)*(x6458)))+(((r11)*(sj0)*(x6463)))+(((IkReal(-1.00000000000000))*(x6455)*(x6457)*(x6459)))+(((IkReal(-1.00000000000000))*(r10)*(sj0)*(x6462)))+(((cj0)*(r01)*(x6463)))+(x6454)+(((IkReal(-1.00000000000000))*(r12)*(x6455)*(x6456))));
if( IKabs(evalcond[0]) > 0.000001  || IKabs(evalcond[1]) > 0.000001  || IKabs(evalcond[2]) > 0.000001  || IKabs(evalcond[3]) > 0.000001  )
{
continue;
}
}

{
std::vector<IkSingleDOFSolutionBase<IkReal> > vinfos(7);
vinfos[0].jointtype = 1;
vinfos[0].foffset = j0;
vinfos[0].indices[0] = _ij0[0];
vinfos[0].indices[1] = _ij0[1];
vinfos[0].maxsolutions = _nj0;
vinfos[1].jointtype = 1;
vinfos[1].foffset = j1;
vinfos[1].indices[0] = _ij1[0];
vinfos[1].indices[1] = _ij1[1];
vinfos[1].maxsolutions = _nj1;
vinfos[2].jointtype = 1;
vinfos[2].foffset = j2;
vinfos[2].indices[0] = _ij2[0];
vinfos[2].indices[1] = _ij2[1];
vinfos[2].maxsolutions = _nj2;
vinfos[3].jointtype = 1;
vinfos[3].foffset = j3;
vinfos[3].indices[0] = _ij3[0];
vinfos[3].indices[1] = _ij3[1];
vinfos[3].maxsolutions = _nj3;
vinfos[4].jointtype = 1;
vinfos[4].foffset = j4;
vinfos[4].indices[0] = _ij4[0];
vinfos[4].indices[1] = _ij4[1];
vinfos[4].maxsolutions = _nj4;
vinfos[5].jointtype = 1;
vinfos[5].foffset = j5;
vinfos[5].indices[0] = _ij5[0];
vinfos[5].indices[1] = _ij5[1];
vinfos[5].maxsolutions = _nj5;
vinfos[6].jointtype = 1;
vinfos[6].foffset = j6;
vinfos[6].indices[0] = _ij6[0];
vinfos[6].indices[1] = _ij6[1];
vinfos[6].maxsolutions = _nj6;
std::vector<int> vfree(0);
solutions.AddSolution(vinfos,vfree);
}
}
}

} else
{
IkReal x6469=((cj5)*(sj4));
IkReal x6470=((IkReal(1.00000000000000))*(sj6));
IkReal x6471=((r10)*(sj0));
IkReal x6472=((sj4)*(sj5));
IkReal x6473=((cj5)*(cj6));
IkReal x6474=((r01)*(sj0));
IkReal x6475=((IkReal(1.00000000000000))*(r02));
IkReal x6476=((IkReal(0.374290000000000))*(cj0));
IkReal x6477=((cj5)*(r12));
IkReal x6478=((cj6)*(sj5));
IkReal x6479=((cj0)*(r11));
IkReal x6480=((cj5)*(sj0));
IkReal x6481=((r20)*(sj6));
IkReal x6482=((IkReal(1.00000000000000))*(sj0));
IkReal x6483=((cj4)*(cj5));
IkReal x6484=((IkReal(1.00000000000000))*(cj6));
IkReal x6485=((IkReal(0.0100000000000000))*(sj5));
IkReal x6486=((sj5)*(sj6));
IkReal x6487=((cj0)*(r10));
IkReal x6488=((cj4)*(cj6));
IkReal x6489=((cj0)*(r01));
IkReal x6490=((IkReal(1.00000000000000))*(cj4));
IkReal x6491=((cj0)*(r00));
IkReal x6492=((IkReal(0.374290000000000))*(sj0));
IkReal x6493=((cj0)*(r12));
IkReal x6494=((IkReal(0.374290000000000))*(sj5));
IkReal x6495=((cj4)*(sj6));
IkReal x6496=((IkReal(1.00000000000000))*(cj0));
IkReal x6497=((r02)*(sj0));
IkReal x6498=((IkReal(0.0100000000000000))*(cj5));
IkReal x6499=((r11)*(sj0));
IkReal x6500=((r00)*(sj0)*(sj6));
IkReal x6501=((r00)*(x6488));
IkReal x6502=((sj6)*(x6498));
evalcond[0]=((IkReal(-3.14159265358979))+(IKfmod(j2, IkReal(6.28318530717959))));
evalcond[1]=((((r22)*(x6472)))+(((x6469)*(x6481)))+(((cj6)*(r21)*(x6469)))+(((IkReal(-1.00000000000000))*(cj4)*(r20)*(x6484)))+(((r21)*(x6495))));
evalcond[2]=((IkReal(0.0690000000000000))+(((IkReal(-0.374290000000000))*(cj5)*(r22)))+(((IkReal(-0.0100000000000000))*(r21)*(x6473)))+(((IkReal(-1.00000000000000))*(r22)*(x6485)))+(((x6481)*(x6494)))+(pz)+(((IkReal(0.374290000000000))*(r21)*(x6478)))+(((IkReal(-1.00000000000000))*(x6481)*(x6498))));
evalcond[3]=((((r00)*(sj0)*(x6486)))+(((IkReal(-1.00000000000000))*(x6478)*(x6479)))+(((x6474)*(x6478)))+(((IkReal(-1.00000000000000))*(x6475)*(x6480)))+(((cj0)*(x6477)))+(((IkReal(-1.00000000000000))*(sj5)*(x6470)*(x6487))));
evalcond[4]=((IkReal(-1.00000000000000))+(((x6487)*(x6488)))+(((IkReal(-1.00000000000000))*(x6482)*(x6501)))+(((IkReal(-1.00000000000000))*(x6469)*(x6470)*(x6487)))+(((x6469)*(x6500)))+(((x6474)*(x6495)))+(((cj6)*(x6469)*(x6474)))+(((x6472)*(x6497)))+(((IkReal(-1.00000000000000))*(cj4)*(x6470)*(x6479)))+(((IkReal(-1.00000000000000))*(x6472)*(x6493)))+(((IkReal(-1.00000000000000))*(x6469)*(x6479)*(x6484))));
evalcond[5]=((((IkReal(-1.00000000000000))*(sj5)*(x6490)*(x6493)))+(((IkReal(-1.00000000000000))*(x6470)*(x6483)*(x6487)))+(((IkReal(-1.00000000000000))*(sj4)*(x6470)*(x6474)))+(((cj6)*(r00)*(sj0)*(sj4)))+(((IkReal(-1.00000000000000))*(x6473)*(x6479)*(x6490)))+(((IkReal(-1.00000000000000))*(sj4)*(x6484)*(x6487)))+(((sj4)*(sj6)*(x6479)))+(((cj4)*(sj5)*(x6497)))+(((cj4)*(x6473)*(x6474)))+(((r00)*(x6480)*(x6495))));
evalcond[6]=((((IkReal(-1.00000000000000))*(cj4)*(x6470)*(x6499)))+(((x6488)*(x6491)))+(((x6471)*(x6488)))+(((IkReal(-1.00000000000000))*(x6469)*(x6470)*(x6491)))+(((IkReal(-1.00000000000000))*(r12)*(x6472)*(x6482)))+(((IkReal(-1.00000000000000))*(x6469)*(x6484)*(x6489)))+(((IkReal(-1.00000000000000))*(x6469)*(x6470)*(x6471)))+(((IkReal(-1.00000000000000))*(cj0)*(x6472)*(x6475)))+(((IkReal(-1.00000000000000))*(cj4)*(x6470)*(x6489)))+(((IkReal(-1.00000000000000))*(cj6)*(r11)*(x6469)*(x6482))));
evalcond[7]=((((x6487)*(x6502)))+(((IkReal(0.374290000000000))*(x6474)*(x6478)))+(((IkReal(-0.0100000000000000))*(x6473)*(x6474)))+(((x6476)*(x6477)))+(((IkReal(-0.0100000000000000))*(r00)*(sj6)*(x6480)))+(((IkReal(-1.00000000000000))*(x6485)*(x6497)))+(((px)*(sj0)))+(((IkReal(-0.374290000000000))*(r02)*(x6480)))+(((IkReal(-1.00000000000000))*(r10)*(x6476)*(x6486)))+(((IkReal(-1.00000000000000))*(py)*(x6496)))+(((IkReal(-1.00000000000000))*(r11)*(x6476)*(x6478)))+(((x6485)*(x6493)))+(((r00)*(x6486)*(x6492)))+(((IkReal(0.0100000000000000))*(x6473)*(x6479))));
evalcond[8]=((IkReal(-0.295420000000000))+(((IkReal(-1.00000000000000))*(r00)*(x6476)*(x6486)))+(((IkReal(-1.00000000000000))*(px)*(x6496)))+(((cj0)*(r02)*(x6485)))+(((r12)*(sj0)*(x6485)))+(((IkReal(-0.374290000000000))*(x6471)*(x6486)))+(((cj5)*(r02)*(x6476)))+(((x6477)*(x6492)))+(((IkReal(-1.00000000000000))*(r01)*(x6476)*(x6478)))+(((x6471)*(x6502)))+(((IkReal(0.0100000000000000))*(x6473)*(x6499)))+(((IkReal(-1.00000000000000))*(py)*(x6482)))+(((IkReal(0.0100000000000000))*(x6473)*(x6489)))+(((IkReal(-1.00000000000000))*(r11)*(x6478)*(x6492)))+(((x6491)*(x6502))));
if( IKabs(evalcond[0]) < 0.0000010000000000  && IKabs(evalcond[1]) < 0.0000010000000000  && IKabs(evalcond[2]) < 0.0000010000000000  && IKabs(evalcond[3]) < 0.0000010000000000  && IKabs(evalcond[4]) < 0.0000010000000000  && IKabs(evalcond[5]) < 0.0000010000000000  && IKabs(evalcond[6]) < 0.0000010000000000  && IKabs(evalcond[7]) < 0.0000010000000000  && IKabs(evalcond[8]) < 0.0000010000000000  )
{
{
IkReal j3array[1], cj3array[1], sj3array[1];
bool j3valid[1]={false};
_nj3 = 1;
IkReal x6503=((IkReal(1.00000000000000))*(cj4));
IkReal x6504=((cj6)*(r21));
IkReal x6505=((r20)*(sj6));
if( IKabs(((((sj5)*(x6505)))+(((IkReal(-1.00000000000000))*(cj5)*(r22)))+(((sj5)*(x6504))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(((((IkReal(-1.00000000000000))*(cj5)*(x6503)*(x6505)))+(((IkReal(-1.00000000000000))*(cj5)*(x6503)*(x6504)))+(((r21)*(sj4)*(sj6)))+(((IkReal(-1.00000000000000))*(r22)*(sj5)*(x6503)))+(((IkReal(-1.00000000000000))*(cj6)*(r20)*(sj4))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(IKsqr(((((sj5)*(x6505)))+(((IkReal(-1.00000000000000))*(cj5)*(r22)))+(((sj5)*(x6504)))))+IKsqr(((((IkReal(-1.00000000000000))*(cj5)*(x6503)*(x6505)))+(((IkReal(-1.00000000000000))*(cj5)*(x6503)*(x6504)))+(((r21)*(sj4)*(sj6)))+(((IkReal(-1.00000000000000))*(r22)*(sj5)*(x6503)))+(((IkReal(-1.00000000000000))*(cj6)*(r20)*(sj4)))))-1) <= IKFAST_SINCOS_THRESH )
    continue;
j3array[0]=IKatan2(((((sj5)*(x6505)))+(((IkReal(-1.00000000000000))*(cj5)*(r22)))+(((sj5)*(x6504)))), ((((IkReal(-1.00000000000000))*(cj5)*(x6503)*(x6505)))+(((IkReal(-1.00000000000000))*(cj5)*(x6503)*(x6504)))+(((r21)*(sj4)*(sj6)))+(((IkReal(-1.00000000000000))*(r22)*(sj5)*(x6503)))+(((IkReal(-1.00000000000000))*(cj6)*(r20)*(sj4)))));
sj3array[0]=IKsin(j3array[0]);
cj3array[0]=IKcos(j3array[0]);
if( j3array[0] > IKPI )
{
    j3array[0]-=IK2PI;
}
else if( j3array[0] < -IKPI )
{    j3array[0]+=IK2PI;
}
j3valid[0] = true;
for(int ij3 = 0; ij3 < 1; ++ij3)
{
if( !j3valid[ij3] )
{
    continue;
}
_ij3[0] = ij3; _ij3[1] = -1;
for(int iij3 = ij3+1; iij3 < 1; ++iij3)
{
if( j3valid[iij3] && IKabs(cj3array[ij3]-cj3array[iij3]) < IKFAST_SOLUTION_THRESH && IKabs(sj3array[ij3]-sj3array[iij3]) < IKFAST_SOLUTION_THRESH )
{
    j3valid[iij3]=false; _ij3[1] = iij3; break; 
}
}
j3 = j3array[ij3]; cj3 = cj3array[ij3]; sj3 = sj3array[ij3];
{
IkReal evalcond[4];
IkReal x6506=IKcos(j3);
IkReal x6507=IKsin(j3);
IkReal x6508=((IkReal(1.00000000000000))*(cj4));
IkReal x6509=((sj0)*(sj5));
IkReal x6510=((cj0)*(cj5));
IkReal x6511=((cj6)*(r01));
IkReal x6512=((r00)*(sj6));
IkReal x6513=((cj6)*(r11));
IkReal x6514=((cj5)*(sj0));
IkReal x6515=((cj6)*(sj4));
IkReal x6516=((sj4)*(sj6));
IkReal x6517=((cj4)*(cj5));
IkReal x6518=((cj6)*(r21));
IkReal x6519=((r20)*(sj6));
IkReal x6520=((r10)*(sj6));
IkReal x6521=((IkReal(1.00000000000000))*(cj0)*(sj5));
evalcond[0]=((((sj5)*(x6518)))+(((IkReal(-1.00000000000000))*(x6507)))+(((IkReal(-1.00000000000000))*(cj5)*(r22)))+(((sj5)*(x6519))));
evalcond[1]=((((IkReal(-1.00000000000000))*(r21)*(x6516)))+(((x6517)*(x6518)))+(((x6517)*(x6519)))+(((cj4)*(r22)*(sj5)))+(((r20)*(x6515)))+(x6506));
evalcond[2]=((((IkReal(-1.00000000000000))*(x6509)*(x6513)))+(((IkReal(-1.00000000000000))*(x6511)*(x6521)))+(((r02)*(x6510)))+(((IkReal(-1.00000000000000))*(x6509)*(x6520)))+(x6506)+(((r12)*(x6514)))+(((IkReal(-1.00000000000000))*(x6512)*(x6521))));
evalcond[3]=((((IkReal(-1.00000000000000))*(x6508)*(x6510)*(x6511)))+(((IkReal(-1.00000000000000))*(r10)*(sj0)*(x6515)))+(((IkReal(-1.00000000000000))*(x6508)*(x6514)*(x6520)))+(((IkReal(-1.00000000000000))*(x6508)*(x6510)*(x6512)))+(((IkReal(-1.00000000000000))*(cj0)*(r00)*(x6515)))+(((cj0)*(r01)*(x6516)))+(((IkReal(-1.00000000000000))*(x6508)*(x6513)*(x6514)))+(((IkReal(-1.00000000000000))*(cj0)*(r02)*(sj5)*(x6508)))+(((r11)*(sj0)*(x6516)))+(((IkReal(-1.00000000000000))*(r12)*(x6508)*(x6509)))+(x6507));
if( IKabs(evalcond[0]) > 0.000001  || IKabs(evalcond[1]) > 0.000001  || IKabs(evalcond[2]) > 0.000001  || IKabs(evalcond[3]) > 0.000001  )
{
continue;
}
}

{
std::vector<IkSingleDOFSolutionBase<IkReal> > vinfos(7);
vinfos[0].jointtype = 1;
vinfos[0].foffset = j0;
vinfos[0].indices[0] = _ij0[0];
vinfos[0].indices[1] = _ij0[1];
vinfos[0].maxsolutions = _nj0;
vinfos[1].jointtype = 1;
vinfos[1].foffset = j1;
vinfos[1].indices[0] = _ij1[0];
vinfos[1].indices[1] = _ij1[1];
vinfos[1].maxsolutions = _nj1;
vinfos[2].jointtype = 1;
vinfos[2].foffset = j2;
vinfos[2].indices[0] = _ij2[0];
vinfos[2].indices[1] = _ij2[1];
vinfos[2].maxsolutions = _nj2;
vinfos[3].jointtype = 1;
vinfos[3].foffset = j3;
vinfos[3].indices[0] = _ij3[0];
vinfos[3].indices[1] = _ij3[1];
vinfos[3].maxsolutions = _nj3;
vinfos[4].jointtype = 1;
vinfos[4].foffset = j4;
vinfos[4].indices[0] = _ij4[0];
vinfos[4].indices[1] = _ij4[1];
vinfos[4].maxsolutions = _nj4;
vinfos[5].jointtype = 1;
vinfos[5].foffset = j5;
vinfos[5].indices[0] = _ij5[0];
vinfos[5].indices[1] = _ij5[1];
vinfos[5].maxsolutions = _nj5;
vinfos[6].jointtype = 1;
vinfos[6].foffset = j6;
vinfos[6].indices[0] = _ij6[0];
vinfos[6].indices[1] = _ij6[1];
vinfos[6].maxsolutions = _nj6;
std::vector<int> vfree(0);
solutions.AddSolution(vinfos,vfree);
}
}
}

} else
{
IkReal x6522=((IkReal(1.00000000000000))*(cj0));
IkReal x6523=((cj4)*(sj6));
IkReal x6524=((sj0)*(sj4));
IkReal x6525=((cj5)*(sj6));
IkReal x6526=((sj4)*(sj5));
IkReal x6527=((r12)*(sj5));
IkReal x6528=((IkReal(0.374290000000000))*(cj5));
IkReal x6529=((r02)*(sj0));
IkReal x6530=((r20)*(sj4));
IkReal x6531=((IkReal(1.00000000000000))*(sj0));
IkReal x6532=((IkReal(1.00000000000000))*(cj5));
IkReal x6533=((cj0)*(r10));
IkReal x6534=((cj4)*(cj6));
IkReal x6535=((r00)*(sj0));
IkReal x6536=((cj6)*(r21));
IkReal x6537=((IkReal(0.374290000000000))*(sj5));
IkReal x6538=((cj0)*(r00));
IkReal x6539=((IkReal(0.0100000000000000))*(sj5));
IkReal x6540=((cj0)*(r02));
IkReal x6541=((cj5)*(sj4));
IkReal x6542=((cj6)*(r01));
IkReal x6543=((cj6)*(r11));
IkReal x6544=((r01)*(sj0));
IkReal x6545=((r10)*(sj0));
IkReal x6546=((IkReal(0.0100000000000000))*(cj5)*(cj6));
IkReal x6547=((sj6)*(x6537));
IkReal x6548=((cj0)*(cj6)*(x6537));
evalcond[0]=((IkReal(-3.14159265358979))+(IKfmod(((IkReal(1.57079632679490))+(j2)), IkReal(6.28318530717959))));
evalcond[1]=((((sj5)*(x6536)))+(((IkReal(-1.00000000000000))*(r22)*(x6532)))+(((r20)*(sj5)*(sj6))));
evalcond[2]=((IkReal(1.00000000000000))+(((x6536)*(x6541)))+(((r21)*(x6523)))+(((r22)*(x6526)))+(((IkReal(-1.00000000000000))*(r20)*(x6534)))+(((x6525)*(x6530))));
evalcond[3]=((((IkReal(-0.0100000000000000))*(cj5)*(x6536)))+(((x6536)*(x6537)))+(pz)+(((IkReal(-1.00000000000000))*(r22)*(x6539)))+(((IkReal(-0.0100000000000000))*(r20)*(x6525)))+(((r20)*(x6547)))+(((IkReal(-1.00000000000000))*(r22)*(x6528))));
evalcond[4]=((((cj6)*(x6530)))+(((IkReal(-1.00000000000000))*(r21)*(sj4)*(sj6)))+(((cj4)*(r22)*(sj5)))+(((cj5)*(r21)*(x6534)))+(((cj5)*(r20)*(x6523))));
evalcond[5]=((((IkReal(-1.00000000000000))*(r12)*(x6522)*(x6526)))+(((r02)*(sj5)*(x6524)))+(((IkReal(-1.00000000000000))*(x6522)*(x6541)*(x6543)))+(((IkReal(-1.00000000000000))*(r10)*(sj4)*(x6522)*(x6525)))+(((x6523)*(x6544)))+(((x6533)*(x6534)))+(((IkReal(-1.00000000000000))*(r11)*(x6522)*(x6523)))+(((r00)*(x6524)*(x6525)))+(((cj5)*(x6524)*(x6542)))+(((IkReal(-1.00000000000000))*(r00)*(x6531)*(x6534))));
evalcond[6]=((((IkReal(-1.00000000000000))*(r01)*(x6522)*(x6523)))+(((IkReal(-1.00000000000000))*(x6524)*(x6532)*(x6543)))+(((IkReal(-1.00000000000000))*(r02)*(x6522)*(x6526)))+(((x6534)*(x6538)))+(((IkReal(-1.00000000000000))*(x6524)*(x6527)))+(((IkReal(-1.00000000000000))*(r11)*(x6523)*(x6531)))+(((IkReal(-1.00000000000000))*(x6522)*(x6541)*(x6542)))+(((IkReal(-1.00000000000000))*(r10)*(x6524)*(x6525)))+(((x6534)*(x6545)))+(((IkReal(-1.00000000000000))*(r00)*(sj4)*(x6522)*(x6525))));
evalcond[7]=((IkReal(0.0690000000000000))+(((IkReal(-1.00000000000000))*(cj0)*(x6537)*(x6543)))+(((IkReal(0.0100000000000000))*(x6525)*(x6533)))+(((IkReal(-1.00000000000000))*(x6533)*(x6547)))+(((cj0)*(r12)*(x6528)))+(((IkReal(-1.00000000000000))*(py)*(x6522)))+(((IkReal(-1.00000000000000))*(x6529)*(x6539)))+(((IkReal(-0.0100000000000000))*(x6525)*(x6535)))+(((IkReal(0.0100000000000000))*(cj0)*(cj5)*(x6543)))+(((IkReal(0.0100000000000000))*(cj0)*(x6527)))+(((IkReal(-1.00000000000000))*(x6528)*(x6529)))+(((sj0)*(x6537)*(x6542)))+(((x6535)*(x6547)))+(((IkReal(-0.0100000000000000))*(cj5)*(sj0)*(x6542)))+(((px)*(sj0))));
evalcond[8]=((IkReal(-0.295420000000000))+(((IkReal(0.0100000000000000))*(x6525)*(x6538)))+(((IkReal(-1.00000000000000))*(sj0)*(x6537)*(x6543)))+(((IkReal(-1.00000000000000))*(py)*(x6531)))+(((IkReal(-1.00000000000000))*(x6538)*(x6547)))+(((IkReal(0.0100000000000000))*(cj5)*(sj0)*(x6543)))+(((IkReal(-1.00000000000000))*(x6545)*(x6547)))+(((x6528)*(x6540)))+(((IkReal(0.0100000000000000))*(cj0)*(cj5)*(x6542)))+(((x6539)*(x6540)))+(((IkReal(-1.00000000000000))*(px)*(x6522)))+(((IkReal(0.0100000000000000))*(x6525)*(x6545)))+(((r12)*(sj0)*(x6528)))+(((IkReal(0.0100000000000000))*(sj0)*(x6527)))+(((IkReal(-1.00000000000000))*(cj0)*(x6537)*(x6542))));
if( IKabs(evalcond[0]) < 0.0000010000000000  && IKabs(evalcond[1]) < 0.0000010000000000  && IKabs(evalcond[2]) < 0.0000010000000000  && IKabs(evalcond[3]) < 0.0000010000000000  && IKabs(evalcond[4]) < 0.0000010000000000  && IKabs(evalcond[5]) < 0.0000010000000000  && IKabs(evalcond[6]) < 0.0000010000000000  && IKabs(evalcond[7]) < 0.0000010000000000  && IKabs(evalcond[8]) < 0.0000010000000000  )
{
{
IkReal j3array[1], cj3array[1], sj3array[1];
bool j3valid[1]={false};
_nj3 = 1;
IkReal x6549=((sj0)*(sj5));
IkReal x6550=((r00)*(sj6));
IkReal x6551=((IkReal(1.00000000000000))*(cj5));
IkReal x6552=((cj6)*(r11));
IkReal x6553=((cj6)*(r01));
IkReal x6554=((r10)*(sj6));
IkReal x6555=((cj0)*(sj5));
if( IKabs(((((IkReal(-1.00000000000000))*(x6552)*(x6555)))+(((IkReal(-1.00000000000000))*(x6554)*(x6555)))+(((x6549)*(x6550)))+(((x6549)*(x6553)))+(((cj0)*(cj5)*(r12)))+(((IkReal(-1.00000000000000))*(r02)*(sj0)*(x6551))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(((((x6553)*(x6555)))+(((x6549)*(x6554)))+(((x6549)*(x6552)))+(((x6550)*(x6555)))+(((IkReal(-1.00000000000000))*(r12)*(sj0)*(x6551)))+(((IkReal(-1.00000000000000))*(cj0)*(r02)*(x6551))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(IKsqr(((((IkReal(-1.00000000000000))*(x6552)*(x6555)))+(((IkReal(-1.00000000000000))*(x6554)*(x6555)))+(((x6549)*(x6550)))+(((x6549)*(x6553)))+(((cj0)*(cj5)*(r12)))+(((IkReal(-1.00000000000000))*(r02)*(sj0)*(x6551)))))+IKsqr(((((x6553)*(x6555)))+(((x6549)*(x6554)))+(((x6549)*(x6552)))+(((x6550)*(x6555)))+(((IkReal(-1.00000000000000))*(r12)*(sj0)*(x6551)))+(((IkReal(-1.00000000000000))*(cj0)*(r02)*(x6551)))))-1) <= IKFAST_SINCOS_THRESH )
    continue;
j3array[0]=IKatan2(((((IkReal(-1.00000000000000))*(x6552)*(x6555)))+(((IkReal(-1.00000000000000))*(x6554)*(x6555)))+(((x6549)*(x6550)))+(((x6549)*(x6553)))+(((cj0)*(cj5)*(r12)))+(((IkReal(-1.00000000000000))*(r02)*(sj0)*(x6551)))), ((((x6553)*(x6555)))+(((x6549)*(x6554)))+(((x6549)*(x6552)))+(((x6550)*(x6555)))+(((IkReal(-1.00000000000000))*(r12)*(sj0)*(x6551)))+(((IkReal(-1.00000000000000))*(cj0)*(r02)*(x6551)))));
sj3array[0]=IKsin(j3array[0]);
cj3array[0]=IKcos(j3array[0]);
if( j3array[0] > IKPI )
{
    j3array[0]-=IK2PI;
}
else if( j3array[0] < -IKPI )
{    j3array[0]+=IK2PI;
}
j3valid[0] = true;
for(int ij3 = 0; ij3 < 1; ++ij3)
{
if( !j3valid[ij3] )
{
    continue;
}
_ij3[0] = ij3; _ij3[1] = -1;
for(int iij3 = ij3+1; iij3 < 1; ++iij3)
{
if( j3valid[iij3] && IKabs(cj3array[ij3]-cj3array[iij3]) < IKFAST_SOLUTION_THRESH && IKabs(sj3array[ij3]-sj3array[iij3]) < IKFAST_SOLUTION_THRESH )
{
    j3valid[iij3]=false; _ij3[1] = iij3; break; 
}
}
j3 = j3array[ij3]; cj3 = cj3array[ij3]; sj3 = sj3array[ij3];
{
IkReal evalcond[4];
IkReal x6556=IKcos(j3);
IkReal x6557=IKsin(j3);
IkReal x6558=((sj0)*(sj5));
IkReal x6559=((r00)*(sj6));
IkReal x6560=((cj6)*(sj0));
IkReal x6561=((IkReal(1.00000000000000))*(cj4));
IkReal x6562=((r00)*(sj4));
IkReal x6563=((cj0)*(cj5));
IkReal x6564=((cj5)*(sj0));
IkReal x6565=((cj6)*(r11));
IkReal x6566=((r10)*(sj6));
IkReal x6567=((cj0)*(sj5));
IkReal x6568=((r10)*(sj4));
IkReal x6569=((cj4)*(cj5)*(r01));
IkReal x6570=((IkReal(1.00000000000000))*(cj0)*(cj6));
IkReal x6571=((cj0)*(sj4)*(sj6));
IkReal x6572=((sj0)*(sj4)*(sj6));
evalcond[0]=((((r12)*(x6563)))+(((IkReal(-1.00000000000000))*(r02)*(x6564)))+(((IkReal(-1.00000000000000))*(x6566)*(x6567)))+(((cj6)*(r01)*(x6558)))+(((x6558)*(x6559)))+(((IkReal(-1.00000000000000))*(x6557)))+(((IkReal(-1.00000000000000))*(x6565)*(x6567))));
evalcond[1]=((((r12)*(x6564)))+(((IkReal(-1.00000000000000))*(x6559)*(x6567)))+(((r02)*(x6563)))+(((IkReal(-1.00000000000000))*(x6558)*(x6565)))+(((IkReal(-1.00000000000000))*(x6558)*(x6566)))+(x6556)+(((IkReal(-1.00000000000000))*(cj6)*(r01)*(x6567))));
evalcond[2]=((((IkReal(-1.00000000000000))*(x6568)*(x6570)))+(((cj4)*(x6559)*(x6564)))+(((IkReal(-1.00000000000000))*(x6561)*(x6563)*(x6566)))+(((r11)*(x6571)))+(((x6560)*(x6562)))+(((IkReal(-1.00000000000000))*(r01)*(x6572)))+(((cj4)*(r02)*(x6558)))+(x6556)+(((IkReal(-1.00000000000000))*(r12)*(x6561)*(x6567)))+(((x6560)*(x6569)))+(((IkReal(-1.00000000000000))*(x6561)*(x6563)*(x6565))));
evalcond[3]=((((IkReal(-1.00000000000000))*(cj6)*(r01)*(x6561)*(x6563)))+(((IkReal(-1.00000000000000))*(x6560)*(x6568)))+(((r01)*(x6571)))+(((r11)*(x6572)))+(((IkReal(-1.00000000000000))*(cj5)*(r11)*(x6560)*(x6561)))+(x6557)+(((IkReal(-1.00000000000000))*(r02)*(x6561)*(x6567)))+(((IkReal(-1.00000000000000))*(x6562)*(x6570)))+(((IkReal(-1.00000000000000))*(x6559)*(x6561)*(x6563)))+(((IkReal(-1.00000000000000))*(r12)*(x6558)*(x6561)))+(((IkReal(-1.00000000000000))*(x6561)*(x6564)*(x6566))));
if( IKabs(evalcond[0]) > 0.000001  || IKabs(evalcond[1]) > 0.000001  || IKabs(evalcond[2]) > 0.000001  || IKabs(evalcond[3]) > 0.000001  )
{
continue;
}
}

{
std::vector<IkSingleDOFSolutionBase<IkReal> > vinfos(7);
vinfos[0].jointtype = 1;
vinfos[0].foffset = j0;
vinfos[0].indices[0] = _ij0[0];
vinfos[0].indices[1] = _ij0[1];
vinfos[0].maxsolutions = _nj0;
vinfos[1].jointtype = 1;
vinfos[1].foffset = j1;
vinfos[1].indices[0] = _ij1[0];
vinfos[1].indices[1] = _ij1[1];
vinfos[1].maxsolutions = _nj1;
vinfos[2].jointtype = 1;
vinfos[2].foffset = j2;
vinfos[2].indices[0] = _ij2[0];
vinfos[2].indices[1] = _ij2[1];
vinfos[2].maxsolutions = _nj2;
vinfos[3].jointtype = 1;
vinfos[3].foffset = j3;
vinfos[3].indices[0] = _ij3[0];
vinfos[3].indices[1] = _ij3[1];
vinfos[3].maxsolutions = _nj3;
vinfos[4].jointtype = 1;
vinfos[4].foffset = j4;
vinfos[4].indices[0] = _ij4[0];
vinfos[4].indices[1] = _ij4[1];
vinfos[4].maxsolutions = _nj4;
vinfos[5].jointtype = 1;
vinfos[5].foffset = j5;
vinfos[5].indices[0] = _ij5[0];
vinfos[5].indices[1] = _ij5[1];
vinfos[5].maxsolutions = _nj5;
vinfos[6].jointtype = 1;
vinfos[6].foffset = j6;
vinfos[6].indices[0] = _ij6[0];
vinfos[6].indices[1] = _ij6[1];
vinfos[6].maxsolutions = _nj6;
std::vector<int> vfree(0);
solutions.AddSolution(vinfos,vfree);
}
}
}

} else
{
IkReal x6573=((IkReal(1.00000000000000))*(cj0));
IkReal x6574=((cj4)*(sj6));
IkReal x6575=((sj0)*(sj4));
IkReal x6576=((cj5)*(sj6));
IkReal x6577=((sj4)*(sj5));
IkReal x6578=((r12)*(sj5));
IkReal x6579=((IkReal(0.374290000000000))*(cj5));
IkReal x6580=((r02)*(sj0));
IkReal x6581=((r20)*(sj4));
IkReal x6582=((IkReal(1.00000000000000))*(sj0));
IkReal x6583=((IkReal(1.00000000000000))*(cj5));
IkReal x6584=((cj0)*(r10));
IkReal x6585=((cj4)*(cj6));
IkReal x6586=((r00)*(sj0));
IkReal x6587=((cj6)*(r21));
IkReal x6588=((IkReal(0.374290000000000))*(sj5));
IkReal x6589=((cj0)*(r00));
IkReal x6590=((IkReal(0.0100000000000000))*(sj5));
IkReal x6591=((cj0)*(r02));
IkReal x6592=((cj5)*(sj4));
IkReal x6593=((cj6)*(r01));
IkReal x6594=((cj6)*(r11));
IkReal x6595=((r01)*(sj0));
IkReal x6596=((r10)*(sj0));
IkReal x6597=((IkReal(0.0100000000000000))*(cj5)*(cj6));
IkReal x6598=((sj6)*(x6588));
IkReal x6599=((cj0)*(cj6)*(x6588));
evalcond[0]=((IkReal(-3.14159265358979))+(IKfmod(((IkReal(4.71238898038469))+(j2)), IkReal(6.28318530717959))));
evalcond[1]=((((sj5)*(x6587)))+(((IkReal(-1.00000000000000))*(r22)*(x6583)))+(((r20)*(sj5)*(sj6))));
evalcond[2]=((IkReal(-1.00000000000000))+(((x6587)*(x6592)))+(((r22)*(x6577)))+(((x6576)*(x6581)))+(((r21)*(x6574)))+(((IkReal(-1.00000000000000))*(r20)*(x6585))));
evalcond[3]=((((r20)*(x6598)))+(((IkReal(-1.00000000000000))*(r22)*(x6579)))+(((x6587)*(x6588)))+(((IkReal(-0.0100000000000000))*(cj5)*(x6587)))+(((IkReal(-1.00000000000000))*(r22)*(x6590)))+(((IkReal(-0.0100000000000000))*(r20)*(x6576)))+(pz));
evalcond[4]=((((cj6)*(x6581)))+(((IkReal(-1.00000000000000))*(r21)*(sj4)*(sj6)))+(((cj4)*(r22)*(sj5)))+(((cj5)*(r21)*(x6585)))+(((cj5)*(r20)*(x6574))));
evalcond[5]=((((r00)*(x6575)*(x6576)))+(((IkReal(-1.00000000000000))*(r00)*(x6582)*(x6585)))+(((IkReal(-1.00000000000000))*(r11)*(x6573)*(x6574)))+(((x6584)*(x6585)))+(((IkReal(-1.00000000000000))*(x6573)*(x6592)*(x6594)))+(((cj5)*(x6575)*(x6593)))+(((IkReal(-1.00000000000000))*(r12)*(x6573)*(x6577)))+(((IkReal(-1.00000000000000))*(r10)*(sj4)*(x6573)*(x6576)))+(((r02)*(sj5)*(x6575)))+(((x6574)*(x6595))));
evalcond[6]=((((IkReal(-1.00000000000000))*(r01)*(x6573)*(x6574)))+(((IkReal(-1.00000000000000))*(x6575)*(x6583)*(x6594)))+(((IkReal(-1.00000000000000))*(r10)*(x6575)*(x6576)))+(((x6585)*(x6589)))+(((IkReal(-1.00000000000000))*(r02)*(x6573)*(x6577)))+(((IkReal(-1.00000000000000))*(r11)*(x6574)*(x6582)))+(((IkReal(-1.00000000000000))*(r00)*(sj4)*(x6573)*(x6576)))+(((IkReal(-1.00000000000000))*(x6575)*(x6578)))+(((x6585)*(x6596)))+(((IkReal(-1.00000000000000))*(x6573)*(x6592)*(x6593))));
evalcond[7]=((IkReal(-0.0690000000000000))+(((IkReal(0.0100000000000000))*(x6576)*(x6584)))+(((IkReal(-0.0100000000000000))*(x6576)*(x6586)))+(((IkReal(0.0100000000000000))*(cj0)*(x6578)))+(((sj0)*(x6588)*(x6593)))+(((IkReal(-1.00000000000000))*(x6579)*(x6580)))+(((IkReal(-0.0100000000000000))*(cj5)*(sj0)*(x6593)))+(((IkReal(0.0100000000000000))*(cj0)*(cj5)*(x6594)))+(((x6586)*(x6598)))+(((cj0)*(r12)*(x6579)))+(((px)*(sj0)))+(((IkReal(-1.00000000000000))*(cj0)*(x6588)*(x6594)))+(((IkReal(-1.00000000000000))*(py)*(x6573)))+(((IkReal(-1.00000000000000))*(x6584)*(x6598)))+(((IkReal(-1.00000000000000))*(x6580)*(x6590))));
evalcond[8]=((IkReal(-0.295420000000000))+(((IkReal(0.0100000000000000))*(sj0)*(x6578)))+(((IkReal(0.0100000000000000))*(cj0)*(cj5)*(x6593)))+(((IkReal(0.0100000000000000))*(cj5)*(sj0)*(x6594)))+(((IkReal(-1.00000000000000))*(cj0)*(x6588)*(x6593)))+(((r12)*(sj0)*(x6579)))+(((IkReal(-1.00000000000000))*(x6596)*(x6598)))+(((IkReal(0.0100000000000000))*(x6576)*(x6596)))+(((x6590)*(x6591)))+(((x6579)*(x6591)))+(((IkReal(-1.00000000000000))*(py)*(x6582)))+(((IkReal(-1.00000000000000))*(x6589)*(x6598)))+(((IkReal(0.0100000000000000))*(x6576)*(x6589)))+(((IkReal(-1.00000000000000))*(px)*(x6573)))+(((IkReal(-1.00000000000000))*(sj0)*(x6588)*(x6594))));
if( IKabs(evalcond[0]) < 0.0000010000000000  && IKabs(evalcond[1]) < 0.0000010000000000  && IKabs(evalcond[2]) < 0.0000010000000000  && IKabs(evalcond[3]) < 0.0000010000000000  && IKabs(evalcond[4]) < 0.0000010000000000  && IKabs(evalcond[5]) < 0.0000010000000000  && IKabs(evalcond[6]) < 0.0000010000000000  && IKabs(evalcond[7]) < 0.0000010000000000  && IKabs(evalcond[8]) < 0.0000010000000000  )
{
{
IkReal j3array[1], cj3array[1], sj3array[1];
bool j3valid[1]={false};
_nj3 = 1;
IkReal x6600=((IkReal(1.00000000000000))*(cj5));
IkReal x6601=((r10)*(sj5)*(sj6));
IkReal x6602=((cj6)*(sj0)*(sj5));
IkReal x6603=((r00)*(sj5)*(sj6));
IkReal x6604=((cj0)*(cj6)*(sj5));
if( IKabs(((((IkReal(-1.00000000000000))*(sj0)*(x6603)))+(((IkReal(-1.00000000000000))*(r01)*(x6602)))+(((IkReal(-1.00000000000000))*(cj0)*(r12)*(x6600)))+(((cj5)*(r02)*(sj0)))+(((cj0)*(x6601)))+(((r11)*(x6604))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(((((sj0)*(x6601)))+(((cj0)*(x6603)))+(((IkReal(-1.00000000000000))*(r12)*(sj0)*(x6600)))+(((IkReal(-1.00000000000000))*(cj0)*(r02)*(x6600)))+(((r01)*(x6604)))+(((r11)*(x6602))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(IKsqr(((((IkReal(-1.00000000000000))*(sj0)*(x6603)))+(((IkReal(-1.00000000000000))*(r01)*(x6602)))+(((IkReal(-1.00000000000000))*(cj0)*(r12)*(x6600)))+(((cj5)*(r02)*(sj0)))+(((cj0)*(x6601)))+(((r11)*(x6604)))))+IKsqr(((((sj0)*(x6601)))+(((cj0)*(x6603)))+(((IkReal(-1.00000000000000))*(r12)*(sj0)*(x6600)))+(((IkReal(-1.00000000000000))*(cj0)*(r02)*(x6600)))+(((r01)*(x6604)))+(((r11)*(x6602)))))-1) <= IKFAST_SINCOS_THRESH )
    continue;
j3array[0]=IKatan2(((((IkReal(-1.00000000000000))*(sj0)*(x6603)))+(((IkReal(-1.00000000000000))*(r01)*(x6602)))+(((IkReal(-1.00000000000000))*(cj0)*(r12)*(x6600)))+(((cj5)*(r02)*(sj0)))+(((cj0)*(x6601)))+(((r11)*(x6604)))), ((((sj0)*(x6601)))+(((cj0)*(x6603)))+(((IkReal(-1.00000000000000))*(r12)*(sj0)*(x6600)))+(((IkReal(-1.00000000000000))*(cj0)*(r02)*(x6600)))+(((r01)*(x6604)))+(((r11)*(x6602)))));
sj3array[0]=IKsin(j3array[0]);
cj3array[0]=IKcos(j3array[0]);
if( j3array[0] > IKPI )
{
    j3array[0]-=IK2PI;
}
else if( j3array[0] < -IKPI )
{    j3array[0]+=IK2PI;
}
j3valid[0] = true;
for(int ij3 = 0; ij3 < 1; ++ij3)
{
if( !j3valid[ij3] )
{
    continue;
}
_ij3[0] = ij3; _ij3[1] = -1;
for(int iij3 = ij3+1; iij3 < 1; ++iij3)
{
if( j3valid[iij3] && IKabs(cj3array[ij3]-cj3array[iij3]) < IKFAST_SOLUTION_THRESH && IKabs(sj3array[ij3]-sj3array[iij3]) < IKFAST_SOLUTION_THRESH )
{
    j3valid[iij3]=false; _ij3[1] = iij3; break; 
}
}
j3 = j3array[ij3]; cj3 = cj3array[ij3]; sj3 = sj3array[ij3];
{
IkReal evalcond[4];
IkReal x6605=IKcos(j3);
IkReal x6606=IKsin(j3);
IkReal x6607=((sj0)*(sj5));
IkReal x6608=((r00)*(sj6));
IkReal x6609=((IkReal(1.00000000000000))*(cj4));
IkReal x6610=((cj6)*(sj0));
IkReal x6611=((r00)*(sj4));
IkReal x6612=((cj0)*(cj5));
IkReal x6613=((cj6)*(r01));
IkReal x6614=((cj5)*(sj0));
IkReal x6615=((cj0)*(sj5));
IkReal x6616=((cj6)*(r11));
IkReal x6617=((r10)*(sj6));
IkReal x6618=((r10)*(sj4));
IkReal x6619=((cj0)*(sj4)*(sj6));
IkReal x6620=((sj0)*(sj4)*(sj6));
IkReal x6621=((IkReal(1.00000000000000))*(cj0)*(cj6));
evalcond[0]=((((IkReal(-1.00000000000000))*(x6615)*(x6617)))+(x6606)+(((r12)*(x6612)))+(((x6607)*(x6608)))+(((IkReal(-1.00000000000000))*(x6615)*(x6616)))+(((x6607)*(x6613)))+(((IkReal(-1.00000000000000))*(r02)*(x6614))));
evalcond[1]=((x6605)+(((IkReal(-1.00000000000000))*(x6613)*(x6615)))+(((r12)*(x6614)))+(((IkReal(-1.00000000000000))*(x6608)*(x6615)))+(((IkReal(-1.00000000000000))*(x6607)*(x6616)))+(((r02)*(x6612)))+(((IkReal(-1.00000000000000))*(x6607)*(x6617))));
evalcond[2]=((((IkReal(-1.00000000000000))*(x6605)))+(((r11)*(x6619)))+(((cj4)*(r02)*(x6607)))+(((IkReal(-1.00000000000000))*(r12)*(x6609)*(x6615)))+(((IkReal(-1.00000000000000))*(r01)*(x6620)))+(((IkReal(-1.00000000000000))*(x6609)*(x6612)*(x6617)))+(((IkReal(-1.00000000000000))*(x6609)*(x6612)*(x6616)))+(((IkReal(-1.00000000000000))*(x6618)*(x6621)))+(((cj4)*(x6608)*(x6614)))+(((cj4)*(cj5)*(r01)*(x6610)))+(((x6610)*(x6611))));
evalcond[3]=((x6606)+(((IkReal(-1.00000000000000))*(r02)*(x6609)*(x6615)))+(((IkReal(-1.00000000000000))*(cj5)*(r11)*(x6609)*(x6610)))+(((IkReal(-1.00000000000000))*(x6609)*(x6614)*(x6617)))+(((IkReal(-1.00000000000000))*(x6608)*(x6609)*(x6612)))+(((IkReal(-1.00000000000000))*(x6610)*(x6618)))+(((r01)*(x6619)))+(((IkReal(-1.00000000000000))*(x6609)*(x6612)*(x6613)))+(((IkReal(-1.00000000000000))*(x6611)*(x6621)))+(((r11)*(x6620)))+(((IkReal(-1.00000000000000))*(r12)*(x6607)*(x6609))));
if( IKabs(evalcond[0]) > 0.000001  || IKabs(evalcond[1]) > 0.000001  || IKabs(evalcond[2]) > 0.000001  || IKabs(evalcond[3]) > 0.000001  )
{
continue;
}
}

{
std::vector<IkSingleDOFSolutionBase<IkReal> > vinfos(7);
vinfos[0].jointtype = 1;
vinfos[0].foffset = j0;
vinfos[0].indices[0] = _ij0[0];
vinfos[0].indices[1] = _ij0[1];
vinfos[0].maxsolutions = _nj0;
vinfos[1].jointtype = 1;
vinfos[1].foffset = j1;
vinfos[1].indices[0] = _ij1[0];
vinfos[1].indices[1] = _ij1[1];
vinfos[1].maxsolutions = _nj1;
vinfos[2].jointtype = 1;
vinfos[2].foffset = j2;
vinfos[2].indices[0] = _ij2[0];
vinfos[2].indices[1] = _ij2[1];
vinfos[2].maxsolutions = _nj2;
vinfos[3].jointtype = 1;
vinfos[3].foffset = j3;
vinfos[3].indices[0] = _ij3[0];
vinfos[3].indices[1] = _ij3[1];
vinfos[3].maxsolutions = _nj3;
vinfos[4].jointtype = 1;
vinfos[4].foffset = j4;
vinfos[4].indices[0] = _ij4[0];
vinfos[4].indices[1] = _ij4[1];
vinfos[4].maxsolutions = _nj4;
vinfos[5].jointtype = 1;
vinfos[5].foffset = j5;
vinfos[5].indices[0] = _ij5[0];
vinfos[5].indices[1] = _ij5[1];
vinfos[5].maxsolutions = _nj5;
vinfos[6].jointtype = 1;
vinfos[6].foffset = j6;
vinfos[6].indices[0] = _ij6[0];
vinfos[6].indices[1] = _ij6[1];
vinfos[6].maxsolutions = _nj6;
std::vector<int> vfree(0);
solutions.AddSolution(vinfos,vfree);
}
}
}

} else
{
if( 1 )
{
continue;

} else
{
}
}
}
}
}
}

} else
{
{
IkReal j3array[1], cj3array[1], sj3array[1];
bool j3valid[1]={false};
_nj3 = 1;
IkReal x6622=((sj0)*(sj5));
IkReal x6623=((r00)*(sj6));
IkReal x6624=((IkReal(1.00000000000000))*(cj5));
IkReal x6625=((cj6)*(r11));
IkReal x6626=((cj6)*(r01));
IkReal x6627=((cj0)*(sj5));
IkReal x6628=((r10)*(sj6));
if( IKabs(((((IKabs(sj2) != 0)?((IkReal)1/(sj2)):(IkReal)1.0e30))*(((((x6622)*(x6623)))+(((IkReal(-1.00000000000000))*(r02)*(sj0)*(x6624)))+(((IkReal(-1.00000000000000))*(x6625)*(x6627)))+(((cj0)*(cj5)*(r12)))+(((IkReal(-1.00000000000000))*(x6627)*(x6628)))+(((x6622)*(x6626))))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(((((IkReal(-1.00000000000000))*(cj0)*(r02)*(x6624)))+(((IkReal(-1.00000000000000))*(r12)*(sj0)*(x6624)))+(((x6623)*(x6627)))+(((x6622)*(x6625)))+(((x6622)*(x6628)))+(((x6626)*(x6627))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(IKsqr(((((IKabs(sj2) != 0)?((IkReal)1/(sj2)):(IkReal)1.0e30))*(((((x6622)*(x6623)))+(((IkReal(-1.00000000000000))*(r02)*(sj0)*(x6624)))+(((IkReal(-1.00000000000000))*(x6625)*(x6627)))+(((cj0)*(cj5)*(r12)))+(((IkReal(-1.00000000000000))*(x6627)*(x6628)))+(((x6622)*(x6626)))))))+IKsqr(((((IkReal(-1.00000000000000))*(cj0)*(r02)*(x6624)))+(((IkReal(-1.00000000000000))*(r12)*(sj0)*(x6624)))+(((x6623)*(x6627)))+(((x6622)*(x6625)))+(((x6622)*(x6628)))+(((x6626)*(x6627)))))-1) <= IKFAST_SINCOS_THRESH )
    continue;
j3array[0]=IKatan2(((((IKabs(sj2) != 0)?((IkReal)1/(sj2)):(IkReal)1.0e30))*(((((x6622)*(x6623)))+(((IkReal(-1.00000000000000))*(r02)*(sj0)*(x6624)))+(((IkReal(-1.00000000000000))*(x6625)*(x6627)))+(((cj0)*(cj5)*(r12)))+(((IkReal(-1.00000000000000))*(x6627)*(x6628)))+(((x6622)*(x6626)))))), ((((IkReal(-1.00000000000000))*(cj0)*(r02)*(x6624)))+(((IkReal(-1.00000000000000))*(r12)*(sj0)*(x6624)))+(((x6623)*(x6627)))+(((x6622)*(x6625)))+(((x6622)*(x6628)))+(((x6626)*(x6627)))));
sj3array[0]=IKsin(j3array[0]);
cj3array[0]=IKcos(j3array[0]);
if( j3array[0] > IKPI )
{
    j3array[0]-=IK2PI;
}
else if( j3array[0] < -IKPI )
{    j3array[0]+=IK2PI;
}
j3valid[0] = true;
for(int ij3 = 0; ij3 < 1; ++ij3)
{
if( !j3valid[ij3] )
{
    continue;
}
_ij3[0] = ij3; _ij3[1] = -1;
for(int iij3 = ij3+1; iij3 < 1; ++iij3)
{
if( j3valid[iij3] && IKabs(cj3array[ij3]-cj3array[iij3]) < IKFAST_SOLUTION_THRESH && IKabs(sj3array[ij3]-sj3array[iij3]) < IKFAST_SOLUTION_THRESH )
{
    j3valid[iij3]=false; _ij3[1] = iij3; break; 
}
}
j3 = j3array[ij3]; cj3 = cj3array[ij3]; sj3 = sj3array[ij3];
{
IkReal evalcond[6];
IkReal x6629=IKsin(j3);
IkReal x6630=IKcos(j3);
IkReal x6631=((sj0)*(sj5));
IkReal x6632=((r00)*(sj6));
IkReal x6633=((IkReal(1.00000000000000))*(cj4));
IkReal x6634=((cj6)*(r01));
IkReal x6635=((cj0)*(cj5));
IkReal x6636=((cj5)*(sj0));
IkReal x6637=((cj6)*(r11));
IkReal x6638=((cj6)*(sj4));
IkReal x6639=((cj0)*(sj5));
IkReal x6640=((cj4)*(cj5));
IkReal x6641=((cj6)*(r21));
IkReal x6642=((r20)*(sj6));
IkReal x6643=((r10)*(sj6));
IkReal x6644=((IkReal(1.00000000000000))*(cj0));
IkReal x6645=((cj0)*(sj4)*(sj6));
IkReal x6646=((sj0)*(sj4)*(sj6));
evalcond[0]=((((IkReal(-1.00000000000000))*(cj5)*(r22)))+(((sj5)*(x6641)))+(((sj5)*(x6642)))+(((cj2)*(x6629))));
evalcond[1]=((((IkReal(-1.00000000000000))*(r21)*(sj4)*(sj6)))+(((x6640)*(x6642)))+(((IkReal(-1.00000000000000))*(cj2)*(x6630)))+(((r20)*(x6638)))+(((cj4)*(r22)*(sj5)))+(((x6640)*(x6641))));
evalcond[2]=((((x6631)*(x6632)))+(((r12)*(x6635)))+(((x6631)*(x6634)))+(((IkReal(-1.00000000000000))*(r02)*(x6636)))+(((IkReal(-1.00000000000000))*(x6639)*(x6643)))+(((IkReal(-1.00000000000000))*(sj2)*(x6629)))+(((IkReal(-1.00000000000000))*(x6637)*(x6639))));
evalcond[3]=((((IkReal(-1.00000000000000))*(x6631)*(x6643)))+(x6630)+(((r02)*(x6635)))+(((r12)*(x6636)))+(((IkReal(-1.00000000000000))*(x6634)*(x6639)))+(((IkReal(-1.00000000000000))*(x6631)*(x6637)))+(((IkReal(-1.00000000000000))*(x6632)*(x6639))));
evalcond[4]=((((IkReal(-1.00000000000000))*(r10)*(x6638)*(x6644)))+(((cj4)*(r02)*(x6631)))+(((sj2)*(x6630)))+(((cj4)*(x6632)*(x6636)))+(((IkReal(-1.00000000000000))*(x6633)*(x6635)*(x6643)))+(((IkReal(-1.00000000000000))*(r12)*(x6633)*(x6639)))+(((r11)*(x6645)))+(((IkReal(-1.00000000000000))*(r01)*(x6646)))+(((cj4)*(x6634)*(x6636)))+(((r00)*(sj0)*(x6638)))+(((IkReal(-1.00000000000000))*(x6633)*(x6635)*(x6637))));
evalcond[5]=((((IkReal(-1.00000000000000))*(x6632)*(x6633)*(x6635)))+(((IkReal(-1.00000000000000))*(r12)*(x6631)*(x6633)))+(((r11)*(x6646)))+(x6629)+(((IkReal(-1.00000000000000))*(x6633)*(x6636)*(x6643)))+(((IkReal(-1.00000000000000))*(r00)*(x6638)*(x6644)))+(((IkReal(-1.00000000000000))*(x6633)*(x6634)*(x6635)))+(((IkReal(-1.00000000000000))*(x6633)*(x6636)*(x6637)))+(((IkReal(-1.00000000000000))*(r02)*(x6633)*(x6639)))+(((r01)*(x6645)))+(((IkReal(-1.00000000000000))*(r10)*(sj0)*(x6638))));
if( IKabs(evalcond[0]) > 0.000001  || IKabs(evalcond[1]) > 0.000001  || IKabs(evalcond[2]) > 0.000001  || IKabs(evalcond[3]) > 0.000001  || IKabs(evalcond[4]) > 0.000001  || IKabs(evalcond[5]) > 0.000001  )
{
continue;
}
}

{
std::vector<IkSingleDOFSolutionBase<IkReal> > vinfos(7);
vinfos[0].jointtype = 1;
vinfos[0].foffset = j0;
vinfos[0].indices[0] = _ij0[0];
vinfos[0].indices[1] = _ij0[1];
vinfos[0].maxsolutions = _nj0;
vinfos[1].jointtype = 1;
vinfos[1].foffset = j1;
vinfos[1].indices[0] = _ij1[0];
vinfos[1].indices[1] = _ij1[1];
vinfos[1].maxsolutions = _nj1;
vinfos[2].jointtype = 1;
vinfos[2].foffset = j2;
vinfos[2].indices[0] = _ij2[0];
vinfos[2].indices[1] = _ij2[1];
vinfos[2].maxsolutions = _nj2;
vinfos[3].jointtype = 1;
vinfos[3].foffset = j3;
vinfos[3].indices[0] = _ij3[0];
vinfos[3].indices[1] = _ij3[1];
vinfos[3].maxsolutions = _nj3;
vinfos[4].jointtype = 1;
vinfos[4].foffset = j4;
vinfos[4].indices[0] = _ij4[0];
vinfos[4].indices[1] = _ij4[1];
vinfos[4].maxsolutions = _nj4;
vinfos[5].jointtype = 1;
vinfos[5].foffset = j5;
vinfos[5].indices[0] = _ij5[0];
vinfos[5].indices[1] = _ij5[1];
vinfos[5].maxsolutions = _nj5;
vinfos[6].jointtype = 1;
vinfos[6].foffset = j6;
vinfos[6].indices[0] = _ij6[0];
vinfos[6].indices[1] = _ij6[1];
vinfos[6].maxsolutions = _nj6;
std::vector<int> vfree(0);
solutions.AddSolution(vinfos,vfree);
}
}
}

}

}

} else
{
{
IkReal j3array[1], cj3array[1], sj3array[1];
bool j3valid[1]={false};
_nj3 = 1;
IkReal x6647=((cj6)*(sj5));
IkReal x6648=((IkReal(1.00000000000000))*(cj5));
IkReal x6649=((sj5)*(sj6));
if( IKabs(((((IKabs(cj2) != 0)?((IkReal)1/(cj2)):(IkReal)1.0e30))*(((((IkReal(-1.00000000000000))*(r20)*(x6649)))+(((IkReal(-1.00000000000000))*(r21)*(x6647)))+(((cj5)*(r22))))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(((((cj0)*(r00)*(x6649)))+(((r10)*(sj0)*(x6649)))+(((IkReal(-1.00000000000000))*(r12)*(sj0)*(x6648)))+(((cj0)*(r01)*(x6647)))+(((r11)*(sj0)*(x6647)))+(((IkReal(-1.00000000000000))*(cj0)*(r02)*(x6648))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(IKsqr(((((IKabs(cj2) != 0)?((IkReal)1/(cj2)):(IkReal)1.0e30))*(((((IkReal(-1.00000000000000))*(r20)*(x6649)))+(((IkReal(-1.00000000000000))*(r21)*(x6647)))+(((cj5)*(r22)))))))+IKsqr(((((cj0)*(r00)*(x6649)))+(((r10)*(sj0)*(x6649)))+(((IkReal(-1.00000000000000))*(r12)*(sj0)*(x6648)))+(((cj0)*(r01)*(x6647)))+(((r11)*(sj0)*(x6647)))+(((IkReal(-1.00000000000000))*(cj0)*(r02)*(x6648)))))-1) <= IKFAST_SINCOS_THRESH )
    continue;
j3array[0]=IKatan2(((((IKabs(cj2) != 0)?((IkReal)1/(cj2)):(IkReal)1.0e30))*(((((IkReal(-1.00000000000000))*(r20)*(x6649)))+(((IkReal(-1.00000000000000))*(r21)*(x6647)))+(((cj5)*(r22)))))), ((((cj0)*(r00)*(x6649)))+(((r10)*(sj0)*(x6649)))+(((IkReal(-1.00000000000000))*(r12)*(sj0)*(x6648)))+(((cj0)*(r01)*(x6647)))+(((r11)*(sj0)*(x6647)))+(((IkReal(-1.00000000000000))*(cj0)*(r02)*(x6648)))));
sj3array[0]=IKsin(j3array[0]);
cj3array[0]=IKcos(j3array[0]);
if( j3array[0] > IKPI )
{
    j3array[0]-=IK2PI;
}
else if( j3array[0] < -IKPI )
{    j3array[0]+=IK2PI;
}
j3valid[0] = true;
for(int ij3 = 0; ij3 < 1; ++ij3)
{
if( !j3valid[ij3] )
{
    continue;
}
_ij3[0] = ij3; _ij3[1] = -1;
for(int iij3 = ij3+1; iij3 < 1; ++iij3)
{
if( j3valid[iij3] && IKabs(cj3array[ij3]-cj3array[iij3]) < IKFAST_SOLUTION_THRESH && IKabs(sj3array[ij3]-sj3array[iij3]) < IKFAST_SOLUTION_THRESH )
{
    j3valid[iij3]=false; _ij3[1] = iij3; break; 
}
}
j3 = j3array[ij3]; cj3 = cj3array[ij3]; sj3 = sj3array[ij3];
{
IkReal evalcond[6];
IkReal x6650=IKsin(j3);
IkReal x6651=IKcos(j3);
IkReal x6652=((sj0)*(sj5));
IkReal x6653=((r00)*(sj6));
IkReal x6654=((IkReal(1.00000000000000))*(cj4));
IkReal x6655=((cj6)*(r01));
IkReal x6656=((cj0)*(cj5));
IkReal x6657=((cj5)*(sj0));
IkReal x6658=((cj6)*(r11));
IkReal x6659=((cj6)*(sj4));
IkReal x6660=((cj0)*(sj5));
IkReal x6661=((cj4)*(cj5));
IkReal x6662=((cj6)*(r21));
IkReal x6663=((r20)*(sj6));
IkReal x6664=((r10)*(sj6));
IkReal x6665=((IkReal(1.00000000000000))*(cj0));
IkReal x6666=((cj0)*(sj4)*(sj6));
IkReal x6667=((sj0)*(sj4)*(sj6));
evalcond[0]=((((sj5)*(x6663)))+(((sj5)*(x6662)))+(((IkReal(-1.00000000000000))*(cj5)*(r22)))+(((cj2)*(x6650))));
evalcond[1]=((((r20)*(x6659)))+(((IkReal(-1.00000000000000))*(r21)*(sj4)*(sj6)))+(((IkReal(-1.00000000000000))*(cj2)*(x6651)))+(((cj4)*(r22)*(sj5)))+(((x6661)*(x6662)))+(((x6661)*(x6663))));
evalcond[2]=((((IkReal(-1.00000000000000))*(r02)*(x6657)))+(((IkReal(-1.00000000000000))*(x6658)*(x6660)))+(((IkReal(-1.00000000000000))*(x6660)*(x6664)))+(((x6652)*(x6655)))+(((r12)*(x6656)))+(((IkReal(-1.00000000000000))*(sj2)*(x6650)))+(((x6652)*(x6653))));
evalcond[3]=((((r12)*(x6657)))+(((IkReal(-1.00000000000000))*(x6653)*(x6660)))+(((IkReal(-1.00000000000000))*(x6655)*(x6660)))+(((r02)*(x6656)))+(x6651)+(((IkReal(-1.00000000000000))*(x6652)*(x6664)))+(((IkReal(-1.00000000000000))*(x6652)*(x6658))));
evalcond[4]=((((r11)*(x6666)))+(((IkReal(-1.00000000000000))*(r10)*(x6659)*(x6665)))+(((r00)*(sj0)*(x6659)))+(((cj4)*(x6653)*(x6657)))+(((IkReal(-1.00000000000000))*(x6654)*(x6656)*(x6658)))+(((cj4)*(r02)*(x6652)))+(((IkReal(-1.00000000000000))*(r12)*(x6654)*(x6660)))+(((sj2)*(x6651)))+(((IkReal(-1.00000000000000))*(r01)*(x6667)))+(((cj4)*(x6655)*(x6657)))+(((IkReal(-1.00000000000000))*(x6654)*(x6656)*(x6664))));
evalcond[5]=((((IkReal(-1.00000000000000))*(x6654)*(x6657)*(x6664)))+(((IkReal(-1.00000000000000))*(x6653)*(x6654)*(x6656)))+(((IkReal(-1.00000000000000))*(r02)*(x6654)*(x6660)))+(((IkReal(-1.00000000000000))*(x6654)*(x6655)*(x6656)))+(((IkReal(-1.00000000000000))*(r12)*(x6652)*(x6654)))+(((IkReal(-1.00000000000000))*(r00)*(x6659)*(x6665)))+(x6650)+(((r11)*(x6667)))+(((r01)*(x6666)))+(((IkReal(-1.00000000000000))*(x6654)*(x6657)*(x6658)))+(((IkReal(-1.00000000000000))*(r10)*(sj0)*(x6659))));
if( IKabs(evalcond[0]) > 0.000001  || IKabs(evalcond[1]) > 0.000001  || IKabs(evalcond[2]) > 0.000001  || IKabs(evalcond[3]) > 0.000001  || IKabs(evalcond[4]) > 0.000001  || IKabs(evalcond[5]) > 0.000001  )
{
continue;
}
}

{
std::vector<IkSingleDOFSolutionBase<IkReal> > vinfos(7);
vinfos[0].jointtype = 1;
vinfos[0].foffset = j0;
vinfos[0].indices[0] = _ij0[0];
vinfos[0].indices[1] = _ij0[1];
vinfos[0].maxsolutions = _nj0;
vinfos[1].jointtype = 1;
vinfos[1].foffset = j1;
vinfos[1].indices[0] = _ij1[0];
vinfos[1].indices[1] = _ij1[1];
vinfos[1].maxsolutions = _nj1;
vinfos[2].jointtype = 1;
vinfos[2].foffset = j2;
vinfos[2].indices[0] = _ij2[0];
vinfos[2].indices[1] = _ij2[1];
vinfos[2].maxsolutions = _nj2;
vinfos[3].jointtype = 1;
vinfos[3].foffset = j3;
vinfos[3].indices[0] = _ij3[0];
vinfos[3].indices[1] = _ij3[1];
vinfos[3].maxsolutions = _nj3;
vinfos[4].jointtype = 1;
vinfos[4].foffset = j4;
vinfos[4].indices[0] = _ij4[0];
vinfos[4].indices[1] = _ij4[1];
vinfos[4].maxsolutions = _nj4;
vinfos[5].jointtype = 1;
vinfos[5].foffset = j5;
vinfos[5].indices[0] = _ij5[0];
vinfos[5].indices[1] = _ij5[1];
vinfos[5].maxsolutions = _nj5;
vinfos[6].jointtype = 1;
vinfos[6].foffset = j6;
vinfos[6].indices[0] = _ij6[0];
vinfos[6].indices[1] = _ij6[1];
vinfos[6].maxsolutions = _nj6;
std::vector<int> vfree(0);
solutions.AddSolution(vinfos,vfree);
}
}
}

}

}

} else
{
{
IkReal j3array[1], cj3array[1], sj3array[1];
bool j3valid[1]={false};
_nj3 = 1;
IkReal x6668=((IkReal(1.00000000000000))*(r21));
IkReal x6669=((cj4)*(cj5));
IkReal x6670=((r20)*(sj6));
if( IKabs(((gconst10)*(((((cj5)*(r22)))+(((IkReal(-1.00000000000000))*(cj6)*(sj5)*(x6668)))+(((IkReal(-1.00000000000000))*(sj5)*(x6670))))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(((gconst10)*(((((IkReal(-1.00000000000000))*(sj4)*(sj6)*(x6668)))+(((cj6)*(r20)*(sj4)))+(((cj4)*(r22)*(sj5)))+(((cj6)*(r21)*(x6669)))+(((x6669)*(x6670))))))) < IKFAST_ATAN2_MAGTHRESH )
    continue;
j3array[0]=IKatan2(((gconst10)*(((((cj5)*(r22)))+(((IkReal(-1.00000000000000))*(cj6)*(sj5)*(x6668)))+(((IkReal(-1.00000000000000))*(sj5)*(x6670)))))), ((gconst10)*(((((IkReal(-1.00000000000000))*(sj4)*(sj6)*(x6668)))+(((cj6)*(r20)*(sj4)))+(((cj4)*(r22)*(sj5)))+(((cj6)*(r21)*(x6669)))+(((x6669)*(x6670)))))));
sj3array[0]=IKsin(j3array[0]);
cj3array[0]=IKcos(j3array[0]);
if( j3array[0] > IKPI )
{
    j3array[0]-=IK2PI;
}
else if( j3array[0] < -IKPI )
{    j3array[0]+=IK2PI;
}
j3valid[0] = true;
for(int ij3 = 0; ij3 < 1; ++ij3)
{
if( !j3valid[ij3] )
{
    continue;
}
_ij3[0] = ij3; _ij3[1] = -1;
for(int iij3 = ij3+1; iij3 < 1; ++iij3)
{
if( j3valid[iij3] && IKabs(cj3array[ij3]-cj3array[iij3]) < IKFAST_SOLUTION_THRESH && IKabs(sj3array[ij3]-sj3array[iij3]) < IKFAST_SOLUTION_THRESH )
{
    j3valid[iij3]=false; _ij3[1] = iij3; break; 
}
}
j3 = j3array[ij3]; cj3 = cj3array[ij3]; sj3 = sj3array[ij3];
{
IkReal evalcond[6];
IkReal x6671=IKsin(j3);
IkReal x6672=IKcos(j3);
IkReal x6673=((sj0)*(sj5));
IkReal x6674=((r00)*(sj6));
IkReal x6675=((IkReal(1.00000000000000))*(cj4));
IkReal x6676=((cj6)*(r01));
IkReal x6677=((cj0)*(cj5));
IkReal x6678=((cj5)*(sj0));
IkReal x6679=((cj6)*(r11));
IkReal x6680=((cj6)*(sj4));
IkReal x6681=((cj0)*(sj5));
IkReal x6682=((cj4)*(cj5));
IkReal x6683=((cj6)*(r21));
IkReal x6684=((r20)*(sj6));
IkReal x6685=((r10)*(sj6));
IkReal x6686=((IkReal(1.00000000000000))*(cj0));
IkReal x6687=((cj0)*(sj4)*(sj6));
IkReal x6688=((sj0)*(sj4)*(sj6));
evalcond[0]=((((sj5)*(x6684)))+(((sj5)*(x6683)))+(((cj2)*(x6671)))+(((IkReal(-1.00000000000000))*(cj5)*(r22))));
evalcond[1]=((((x6682)*(x6683)))+(((IkReal(-1.00000000000000))*(r21)*(sj4)*(sj6)))+(((x6682)*(x6684)))+(((r20)*(x6680)))+(((cj4)*(r22)*(sj5)))+(((IkReal(-1.00000000000000))*(cj2)*(x6672))));
evalcond[2]=((((IkReal(-1.00000000000000))*(sj2)*(x6671)))+(((IkReal(-1.00000000000000))*(x6681)*(x6685)))+(((r12)*(x6677)))+(((x6673)*(x6676)))+(((IkReal(-1.00000000000000))*(r02)*(x6678)))+(((x6673)*(x6674)))+(((IkReal(-1.00000000000000))*(x6679)*(x6681))));
evalcond[3]=((((IkReal(-1.00000000000000))*(x6673)*(x6679)))+(((IkReal(-1.00000000000000))*(x6673)*(x6685)))+(((r12)*(x6678)))+(((IkReal(-1.00000000000000))*(x6674)*(x6681)))+(((IkReal(-1.00000000000000))*(x6676)*(x6681)))+(x6672)+(((r02)*(x6677))));
evalcond[4]=((((r00)*(sj0)*(x6680)))+(((IkReal(-1.00000000000000))*(r01)*(x6688)))+(((sj2)*(x6672)))+(((IkReal(-1.00000000000000))*(r10)*(x6680)*(x6686)))+(((cj4)*(x6674)*(x6678)))+(((IkReal(-1.00000000000000))*(r12)*(x6675)*(x6681)))+(((IkReal(-1.00000000000000))*(x6675)*(x6677)*(x6679)))+(((cj4)*(x6676)*(x6678)))+(((cj4)*(r02)*(x6673)))+(((IkReal(-1.00000000000000))*(x6675)*(x6677)*(x6685)))+(((r11)*(x6687))));
evalcond[5]=((((IkReal(-1.00000000000000))*(x6675)*(x6678)*(x6679)))+(((IkReal(-1.00000000000000))*(r10)*(sj0)*(x6680)))+(((IkReal(-1.00000000000000))*(x6675)*(x6676)*(x6677)))+(((r11)*(x6688)))+(((IkReal(-1.00000000000000))*(r00)*(x6680)*(x6686)))+(((IkReal(-1.00000000000000))*(x6674)*(x6675)*(x6677)))+(((IkReal(-1.00000000000000))*(r02)*(x6675)*(x6681)))+(x6671)+(((IkReal(-1.00000000000000))*(x6675)*(x6678)*(x6685)))+(((IkReal(-1.00000000000000))*(r12)*(x6673)*(x6675)))+(((r01)*(x6687))));
if( IKabs(evalcond[0]) > 0.000001  || IKabs(evalcond[1]) > 0.000001  || IKabs(evalcond[2]) > 0.000001  || IKabs(evalcond[3]) > 0.000001  || IKabs(evalcond[4]) > 0.000001  || IKabs(evalcond[5]) > 0.000001  )
{
continue;
}
}

{
std::vector<IkSingleDOFSolutionBase<IkReal> > vinfos(7);
vinfos[0].jointtype = 1;
vinfos[0].foffset = j0;
vinfos[0].indices[0] = _ij0[0];
vinfos[0].indices[1] = _ij0[1];
vinfos[0].maxsolutions = _nj0;
vinfos[1].jointtype = 1;
vinfos[1].foffset = j1;
vinfos[1].indices[0] = _ij1[0];
vinfos[1].indices[1] = _ij1[1];
vinfos[1].maxsolutions = _nj1;
vinfos[2].jointtype = 1;
vinfos[2].foffset = j2;
vinfos[2].indices[0] = _ij2[0];
vinfos[2].indices[1] = _ij2[1];
vinfos[2].maxsolutions = _nj2;
vinfos[3].jointtype = 1;
vinfos[3].foffset = j3;
vinfos[3].indices[0] = _ij3[0];
vinfos[3].indices[1] = _ij3[1];
vinfos[3].maxsolutions = _nj3;
vinfos[4].jointtype = 1;
vinfos[4].foffset = j4;
vinfos[4].indices[0] = _ij4[0];
vinfos[4].indices[1] = _ij4[1];
vinfos[4].maxsolutions = _nj4;
vinfos[5].jointtype = 1;
vinfos[5].foffset = j5;
vinfos[5].indices[0] = _ij5[0];
vinfos[5].indices[1] = _ij5[1];
vinfos[5].maxsolutions = _nj5;
vinfos[6].jointtype = 1;
vinfos[6].foffset = j6;
vinfos[6].indices[0] = _ij6[0];
vinfos[6].indices[1] = _ij6[1];
vinfos[6].maxsolutions = _nj6;
std::vector<int> vfree(0);
solutions.AddSolution(vinfos,vfree);
}
}
}

}

}

} else
{
IkReal x6689=((IkReal(1.00000000000000))*(cj0));
IkReal x6690=((cj4)*(sj6));
IkReal x6691=((sj0)*(sj4));
IkReal x6692=((cj5)*(sj6));
IkReal x6693=((sj4)*(sj5));
IkReal x6694=((r12)*(sj5));
IkReal x6695=((IkReal(0.374290000000000))*(cj5));
IkReal x6696=((r02)*(sj0));
IkReal x6697=((IkReal(1.00000000000000))*(sj0));
IkReal x6698=((cj0)*(r10));
IkReal x6699=((cj4)*(cj6));
IkReal x6700=((r00)*(sj0));
IkReal x6701=((cj6)*(r21));
IkReal x6702=((IkReal(0.374290000000000))*(sj5));
IkReal x6703=((IkReal(0.0100000000000000))*(sj5));
IkReal x6704=((cj0)*(r02));
IkReal x6705=((cj5)*(sj4));
IkReal x6706=((cj6)*(r01));
IkReal x6707=((cj0)*(r00));
IkReal x6708=((cj6)*(r11));
IkReal x6709=((r01)*(sj0));
IkReal x6710=((r10)*(sj0));
IkReal x6711=((IkReal(0.0100000000000000))*(cj5)*(cj6));
IkReal x6712=((sj6)*(x6702));
IkReal x6713=((cj0)*(cj6)*(x6702));
evalcond[0]=((IkReal(-3.14159265358979))+(IKfmod(((IkReal(1.57079632679490))+(j2)), IkReal(6.28318530717959))));
evalcond[1]=((((IkReal(-1.00000000000000))*(r20)*(x6699)))+(((r21)*(x6690)))+(((r20)*(sj4)*(x6692)))+(((IkReal(-1.00000000000000))*(cj1)))+(((x6701)*(x6705)))+(((r22)*(x6693))));
evalcond[2]=((((IkReal(-0.0100000000000000))*(r20)*(x6692)))+(((IkReal(0.364420000000000))*(sj1)))+(((r20)*(x6712)))+(((IkReal(-1.00000000000000))*(r22)*(x6703)))+(((IkReal(-0.0100000000000000))*(cj5)*(x6701)))+(pz)+(((x6701)*(x6702)))+(((IkReal(-1.00000000000000))*(r22)*(x6695))));
evalcond[3]=((((cj5)*(x6691)*(x6706)))+(((IkReal(-1.00000000000000))*(x6689)*(x6705)*(x6708)))+(((IkReal(-1.00000000000000))*(r11)*(x6689)*(x6690)))+(((r02)*(sj5)*(x6691)))+(((r00)*(x6691)*(x6692)))+(((IkReal(-1.00000000000000))*(r10)*(sj4)*(x6689)*(x6692)))+(((IkReal(-1.00000000000000))*(r12)*(x6689)*(x6693)))+(((IkReal(-1.00000000000000))*(r00)*(x6697)*(x6699)))+(((x6690)*(x6709)))+(((x6698)*(x6699))));
evalcond[4]=((((x6699)*(x6707)))+(((IkReal(-1.00000000000000))*(r01)*(x6689)*(x6690)))+(((IkReal(-1.00000000000000))*(cj5)*(x6691)*(x6708)))+(sj1)+(((IkReal(-1.00000000000000))*(x6691)*(x6694)))+(((IkReal(-1.00000000000000))*(x6689)*(x6705)*(x6706)))+(((x6699)*(x6710)))+(((IkReal(-1.00000000000000))*(r02)*(x6689)*(x6693)))+(((IkReal(-1.00000000000000))*(r11)*(x6690)*(x6697)))+(((IkReal(-1.00000000000000))*(r00)*(sj4)*(x6689)*(x6692)))+(((IkReal(-1.00000000000000))*(r10)*(x6691)*(x6692))));
evalcond[5]=((IkReal(0.0690000000000000))+(((x6700)*(x6712)))+(((IkReal(-1.00000000000000))*(x6698)*(x6712)))+(((IkReal(0.0100000000000000))*(cj0)*(cj5)*(x6708)))+(((IkReal(-1.00000000000000))*(py)*(x6689)))+(((IkReal(0.0100000000000000))*(cj0)*(x6694)))+(((cj0)*(r12)*(x6695)))+(((IkReal(0.0100000000000000))*(x6692)*(x6698)))+(((IkReal(-0.0100000000000000))*(cj5)*(sj0)*(x6706)))+(((sj0)*(x6702)*(x6706)))+(((IkReal(-1.00000000000000))*(cj0)*(x6702)*(x6708)))+(((IkReal(-1.00000000000000))*(x6696)*(x6703)))+(((px)*(sj0)))+(((IkReal(-1.00000000000000))*(x6695)*(x6696)))+(((IkReal(-0.0100000000000000))*(x6692)*(x6700))));
evalcond[6]=((IkReal(0.0690000000000000))+(((r12)*(sj0)*(x6695)))+(((x6703)*(x6704)))+(((IkReal(-1.00000000000000))*(cj0)*(x6702)*(x6706)))+(((IkReal(0.0100000000000000))*(cj0)*(cj5)*(x6706)))+(((IkReal(-1.00000000000000))*(x6707)*(x6712)))+(((IkReal(0.0100000000000000))*(cj5)*(sj0)*(x6708)))+(((IkReal(0.0100000000000000))*(x6692)*(x6707)))+(((x6695)*(x6704)))+(((IkReal(0.0100000000000000))*(x6692)*(x6710)))+(((IkReal(-1.00000000000000))*(py)*(x6697)))+(((IkReal(-1.00000000000000))*(px)*(x6689)))+(((IkReal(0.0100000000000000))*(sj0)*(x6694)))+(((IkReal(0.364420000000000))*(cj1)))+(((IkReal(-1.00000000000000))*(x6710)*(x6712)))+(((IkReal(-1.00000000000000))*(sj0)*(x6702)*(x6708))));
if( IKabs(evalcond[0]) < 0.0000010000000000  && IKabs(evalcond[1]) < 0.0000010000000000  && IKabs(evalcond[2]) < 0.0000010000000000  && IKabs(evalcond[3]) < 0.0000010000000000  && IKabs(evalcond[4]) < 0.0000010000000000  && IKabs(evalcond[5]) < 0.0000010000000000  && IKabs(evalcond[6]) < 0.0000010000000000  )
{
{
IkReal dummyeval[1];
IkReal gconst11;
gconst11=IKsign(sj1);
dummyeval[0]=sj1;
if( IKabs(dummyeval[0]) < 0.0000010000000000  )
{
{
IkReal dummyeval[1];
dummyeval[0]=sj1;
if( IKabs(dummyeval[0]) < 0.0000010000000000  )
{
{
IkReal dummyeval[1];
dummyeval[0]=cj1;
if( IKabs(dummyeval[0]) < 0.0000010000000000  )
{
{
IkReal evalcond[9];
IkReal x6714=((IkReal(1.00000000000000))*(cj0));
IkReal x6715=((cj4)*(sj6));
IkReal x6716=((sj0)*(sj6));
IkReal x6717=((cj5)*(sj4));
IkReal x6718=((IkReal(0.374290000000000))*(sj5));
IkReal x6719=((sj4)*(sj5));
IkReal x6720=((cj0)*(cj6));
IkReal x6721=((IkReal(0.0100000000000000))*(cj5));
IkReal x6722=((cj4)*(sj5));
IkReal x6723=((cj5)*(sj0));
IkReal x6724=((IkReal(0.374290000000000))*(r02));
IkReal x6725=((r20)*(sj6));
IkReal x6726=((cj6)*(r21));
IkReal x6727=((IkReal(1.00000000000000))*(sj0));
IkReal x6728=((cj0)*(sj6));
IkReal x6729=((cj4)*(cj6));
IkReal x6730=((IkReal(0.374290000000000))*(r12));
IkReal x6731=((cj0)*(cj5));
IkReal x6732=((cj6)*(sj5));
IkReal x6733=((cj6)*(r01));
IkReal x6734=((r00)*(sj6));
IkReal x6735=((IkReal(0.0100000000000000))*(sj5));
IkReal x6736=((cj6)*(r11));
IkReal x6737=((IkReal(1.00000000000000))*(r10));
IkReal x6738=((r02)*(sj0));
IkReal x6739=((cj6)*(sj4));
IkReal x6740=((r12)*(x6727));
evalcond[0]=((IkReal(-3.14159265358979))+(IKfmod(((IkReal(1.57079632679490))+(j1)), IkReal(6.28318530717959))));
evalcond[1]=((((x6717)*(x6726)))+(((r22)*(x6719)))+(((r21)*(x6715)))+(((x6717)*(x6725)))+(((IkReal(-1.00000000000000))*(r20)*(x6729))));
evalcond[2]=((IkReal(0.364420000000000))+(((x6718)*(x6725)))+(((x6718)*(x6726)))+(((IkReal(-1.00000000000000))*(x6721)*(x6726)))+(((IkReal(-1.00000000000000))*(r22)*(x6735)))+(((IkReal(-0.374290000000000))*(cj5)*(r22)))+(pz)+(((IkReal(-1.00000000000000))*(x6721)*(x6725))));
evalcond[3]=((((r02)*(x6731)))+(((IkReal(-1.00000000000000))*(r01)*(x6714)*(x6732)))+(((IkReal(-1.00000000000000))*(sj5)*(x6714)*(x6734)))+(((IkReal(-1.00000000000000))*(r11)*(x6727)*(x6732)))+(((IkReal(-1.00000000000000))*(sj5)*(x6716)*(x6737)))+(((r12)*(x6723))));
evalcond[4]=((((IkReal(-1.00000000000000))*(x6714)*(x6717)*(x6736)))+(((IkReal(-1.00000000000000))*(r11)*(x6714)*(x6715)))+(((sj0)*(x6717)*(x6733)))+(((r00)*(x6716)*(x6717)))+(((cj4)*(r10)*(x6720)))+(((r01)*(sj0)*(x6715)))+(((x6719)*(x6738)))+(((IkReal(-1.00000000000000))*(r10)*(sj6)*(x6714)*(x6717)))+(((IkReal(-1.00000000000000))*(r12)*(x6714)*(x6719)))+(((IkReal(-1.00000000000000))*(r00)*(x6727)*(x6729))));
evalcond[5]=((IkReal(1.00000000000000))+(((IkReal(-1.00000000000000))*(x6717)*(x6727)*(x6736)))+(((IkReal(-1.00000000000000))*(r11)*(x6715)*(x6727)))+(((IkReal(-1.00000000000000))*(r02)*(x6714)*(x6719)))+(((IkReal(-1.00000000000000))*(r01)*(x6714)*(x6715)))+(((IkReal(-1.00000000000000))*(x6716)*(x6717)*(x6737)))+(((IkReal(-1.00000000000000))*(x6714)*(x6717)*(x6734)))+(((IkReal(-1.00000000000000))*(x6714)*(x6717)*(x6733)))+(((r10)*(sj0)*(x6729)))+(((cj4)*(r00)*(x6720)))+(((IkReal(-1.00000000000000))*(x6719)*(x6740))));
evalcond[6]=((IkReal(0.0690000000000000))+(((sj0)*(x6718)*(x6733)))+(((x6730)*(x6731)))+(((IkReal(-1.00000000000000))*(r11)*(x6718)*(x6720)))+(((IkReal(-1.00000000000000))*(py)*(x6714)))+(((r10)*(x6721)*(x6728)))+(((r11)*(x6720)*(x6721)))+(((IkReal(-1.00000000000000))*(x6723)*(x6724)))+(((IkReal(-1.00000000000000))*(sj0)*(x6721)*(x6733)))+(((IkReal(-1.00000000000000))*(r00)*(x6716)*(x6721)))+(((r00)*(x6716)*(x6718)))+(((cj0)*(r12)*(x6735)))+(((px)*(sj0)))+(((IkReal(-1.00000000000000))*(x6735)*(x6738)))+(((IkReal(-1.00000000000000))*(r10)*(x6718)*(x6728))));
evalcond[7]=((((IkReal(-1.00000000000000))*(x6715)*(x6723)*(x6737)))+(((IkReal(-1.00000000000000))*(cj5)*(r00)*(x6714)*(x6715)))+(((IkReal(-1.00000000000000))*(r02)*(x6714)*(x6722)))+(((IkReal(-1.00000000000000))*(x6722)*(x6740)))+(((r01)*(sj4)*(x6728)))+(((IkReal(-1.00000000000000))*(r10)*(x6727)*(x6739)))+(((r11)*(sj4)*(x6716)))+(((IkReal(-1.00000000000000))*(r11)*(x6723)*(x6729)))+(((IkReal(-1.00000000000000))*(cj5)*(r01)*(x6714)*(x6729)))+(((IkReal(-1.00000000000000))*(r00)*(x6714)*(x6739))));
evalcond[8]=((IkReal(0.0690000000000000))+(((r00)*(x6721)*(x6728)))+(((IkReal(-1.00000000000000))*(r00)*(x6718)*(x6728)))+(((cj0)*(r02)*(x6735)))+(((IkReal(-1.00000000000000))*(py)*(x6727)))+(((x6723)*(x6730)))+(((IkReal(-1.00000000000000))*(px)*(x6714)))+(((r12)*(sj0)*(x6735)))+(((IkReal(-1.00000000000000))*(r10)*(x6716)*(x6718)))+(((r01)*(x6720)*(x6721)))+(((IkReal(-1.00000000000000))*(sj0)*(x6718)*(x6736)))+(((sj0)*(x6721)*(x6736)))+(((r10)*(x6716)*(x6721)))+(((IkReal(-1.00000000000000))*(r01)*(x6718)*(x6720)))+(((x6724)*(x6731))));
if( IKabs(evalcond[0]) < 0.0000010000000000  && IKabs(evalcond[1]) < 0.0000010000000000  && IKabs(evalcond[2]) < 0.0000010000000000  && IKabs(evalcond[3]) < 0.0000010000000000  && IKabs(evalcond[4]) < 0.0000010000000000  && IKabs(evalcond[5]) < 0.0000010000000000  && IKabs(evalcond[6]) < 0.0000010000000000  && IKabs(evalcond[7]) < 0.0000010000000000  && IKabs(evalcond[8]) < 0.0000010000000000  )
{
{
IkReal j3array[1], cj3array[1], sj3array[1];
bool j3valid[1]={false};
_nj3 = 1;
IkReal x6741=((r20)*(sj6));
IkReal x6742=((cj4)*(cj5));
IkReal x6743=((cj6)*(r21));
if( IKabs(((((x6742)*(x6743)))+(((IkReal(-1.00000000000000))*(r21)*(sj4)*(sj6)))+(((cj6)*(r20)*(sj4)))+(((cj4)*(r22)*(sj5)))+(((x6741)*(x6742))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(((((IkReal(-1.00000000000000))*(cj5)*(r22)))+(((sj5)*(x6741)))+(((sj5)*(x6743))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(IKsqr(((((x6742)*(x6743)))+(((IkReal(-1.00000000000000))*(r21)*(sj4)*(sj6)))+(((cj6)*(r20)*(sj4)))+(((cj4)*(r22)*(sj5)))+(((x6741)*(x6742)))))+IKsqr(((((IkReal(-1.00000000000000))*(cj5)*(r22)))+(((sj5)*(x6741)))+(((sj5)*(x6743)))))-1) <= IKFAST_SINCOS_THRESH )
    continue;
j3array[0]=IKatan2(((((x6742)*(x6743)))+(((IkReal(-1.00000000000000))*(r21)*(sj4)*(sj6)))+(((cj6)*(r20)*(sj4)))+(((cj4)*(r22)*(sj5)))+(((x6741)*(x6742)))), ((((IkReal(-1.00000000000000))*(cj5)*(r22)))+(((sj5)*(x6741)))+(((sj5)*(x6743)))));
sj3array[0]=IKsin(j3array[0]);
cj3array[0]=IKcos(j3array[0]);
if( j3array[0] > IKPI )
{
    j3array[0]-=IK2PI;
}
else if( j3array[0] < -IKPI )
{    j3array[0]+=IK2PI;
}
j3valid[0] = true;
for(int ij3 = 0; ij3 < 1; ++ij3)
{
if( !j3valid[ij3] )
{
    continue;
}
_ij3[0] = ij3; _ij3[1] = -1;
for(int iij3 = ij3+1; iij3 < 1; ++iij3)
{
if( j3valid[iij3] && IKabs(cj3array[ij3]-cj3array[iij3]) < IKFAST_SOLUTION_THRESH && IKabs(sj3array[ij3]-sj3array[iij3]) < IKFAST_SOLUTION_THRESH )
{
    j3valid[iij3]=false; _ij3[1] = iij3; break; 
}
}
j3 = j3array[ij3]; cj3 = cj3array[ij3]; sj3 = sj3array[ij3];
{
IkReal evalcond[4];
IkReal x6744=IKcos(j3);
IkReal x6745=((sj0)*(sj5));
IkReal x6746=((r00)*(sj6));
IkReal x6747=((cj6)*(r01));
IkReal x6748=((cj5)*(sj0));
IkReal x6749=((cj0)*(cj5));
IkReal x6750=((cj6)*(sj4));
IkReal x6751=((sj4)*(sj6));
IkReal x6752=((cj0)*(r11));
IkReal x6753=((cj4)*(cj6));
IkReal x6754=((cj4)*(sj6));
IkReal x6755=((IkReal(1.00000000000000))*(cj0));
IkReal x6756=((cj4)*(sj5));
IkReal x6757=((sj5)*(sj6));
IkReal x6758=((cj6)*(sj5));
IkReal x6759=((IkReal(1.00000000000000))*(IKsin(j3)));
evalcond[0]=((((r21)*(x6758)))+(((IkReal(-1.00000000000000))*(x6744)))+(((r20)*(x6757)))+(((IkReal(-1.00000000000000))*(cj5)*(r22))));
evalcond[1]=((((cj5)*(r20)*(x6754)))+(((r22)*(x6756)))+(((cj5)*(r21)*(x6753)))+(((IkReal(-1.00000000000000))*(r21)*(x6751)))+(((r20)*(x6750)))+(((IkReal(-1.00000000000000))*(x6759))));
evalcond[2]=((((IkReal(-1.00000000000000))*(r10)*(x6755)*(x6757)))+(((IkReal(-1.00000000000000))*(r02)*(x6748)))+(((r12)*(x6749)))+(((x6745)*(x6747)))+(((IkReal(-1.00000000000000))*(x6759)))+(((x6745)*(x6746)))+(((IkReal(-1.00000000000000))*(x6752)*(x6758))));
evalcond[3]=((((IkReal(-1.00000000000000))*(r12)*(x6755)*(x6756)))+(((IkReal(-1.00000000000000))*(r10)*(x6750)*(x6755)))+(((cj4)*(x6747)*(x6748)))+(((IkReal(-1.00000000000000))*(r10)*(x6749)*(x6754)))+(((cj4)*(r02)*(x6745)))+(((r00)*(sj0)*(x6750)))+(((IkReal(-1.00000000000000))*(r11)*(x6749)*(x6753)))+(((cj4)*(x6746)*(x6748)))+(((IkReal(-1.00000000000000))*(r01)*(sj0)*(x6751)))+(x6744)+(((x6751)*(x6752))));
if( IKabs(evalcond[0]) > 0.000001  || IKabs(evalcond[1]) > 0.000001  || IKabs(evalcond[2]) > 0.000001  || IKabs(evalcond[3]) > 0.000001  )
{
continue;
}
}

{
std::vector<IkSingleDOFSolutionBase<IkReal> > vinfos(7);
vinfos[0].jointtype = 1;
vinfos[0].foffset = j0;
vinfos[0].indices[0] = _ij0[0];
vinfos[0].indices[1] = _ij0[1];
vinfos[0].maxsolutions = _nj0;
vinfos[1].jointtype = 1;
vinfos[1].foffset = j1;
vinfos[1].indices[0] = _ij1[0];
vinfos[1].indices[1] = _ij1[1];
vinfos[1].maxsolutions = _nj1;
vinfos[2].jointtype = 1;
vinfos[2].foffset = j2;
vinfos[2].indices[0] = _ij2[0];
vinfos[2].indices[1] = _ij2[1];
vinfos[2].maxsolutions = _nj2;
vinfos[3].jointtype = 1;
vinfos[3].foffset = j3;
vinfos[3].indices[0] = _ij3[0];
vinfos[3].indices[1] = _ij3[1];
vinfos[3].maxsolutions = _nj3;
vinfos[4].jointtype = 1;
vinfos[4].foffset = j4;
vinfos[4].indices[0] = _ij4[0];
vinfos[4].indices[1] = _ij4[1];
vinfos[4].maxsolutions = _nj4;
vinfos[5].jointtype = 1;
vinfos[5].foffset = j5;
vinfos[5].indices[0] = _ij5[0];
vinfos[5].indices[1] = _ij5[1];
vinfos[5].maxsolutions = _nj5;
vinfos[6].jointtype = 1;
vinfos[6].foffset = j6;
vinfos[6].indices[0] = _ij6[0];
vinfos[6].indices[1] = _ij6[1];
vinfos[6].maxsolutions = _nj6;
std::vector<int> vfree(0);
solutions.AddSolution(vinfos,vfree);
}
}
}

} else
{
IkReal x6760=((IkReal(1.00000000000000))*(cj0));
IkReal x6761=((cj4)*(sj6));
IkReal x6762=((sj0)*(sj6));
IkReal x6763=((cj5)*(sj4));
IkReal x6764=((IkReal(0.374290000000000))*(sj5));
IkReal x6765=((sj4)*(sj5));
IkReal x6766=((cj0)*(cj6));
IkReal x6767=((IkReal(0.0100000000000000))*(cj5));
IkReal x6768=((cj4)*(sj5));
IkReal x6769=((cj5)*(sj0));
IkReal x6770=((IkReal(0.374290000000000))*(r02));
IkReal x6771=((r20)*(sj6));
IkReal x6772=((cj6)*(r21));
IkReal x6773=((IkReal(1.00000000000000))*(sj0));
IkReal x6774=((cj0)*(sj6));
IkReal x6775=((cj4)*(cj6));
IkReal x6776=((IkReal(0.374290000000000))*(r12));
IkReal x6777=((cj0)*(cj5));
IkReal x6778=((cj6)*(sj5));
IkReal x6779=((cj6)*(r01));
IkReal x6780=((r00)*(sj6));
IkReal x6781=((IkReal(0.0100000000000000))*(sj5));
IkReal x6782=((cj6)*(r11));
IkReal x6783=((IkReal(1.00000000000000))*(r10));
IkReal x6784=((r02)*(sj0));
IkReal x6785=((cj6)*(sj4));
IkReal x6786=((r12)*(x6773));
evalcond[0]=((IkReal(-3.14159265358979))+(IKfmod(((IkReal(4.71238898038469))+(j1)), IkReal(6.28318530717959))));
evalcond[1]=((((r22)*(x6765)))+(((x6763)*(x6772)))+(((r21)*(x6761)))+(((x6763)*(x6771)))+(((IkReal(-1.00000000000000))*(r20)*(x6775))));
evalcond[2]=((IkReal(-0.364420000000000))+(((IkReal(-1.00000000000000))*(x6767)*(x6772)))+(((IkReal(-0.374290000000000))*(cj5)*(r22)))+(((IkReal(-1.00000000000000))*(r22)*(x6781)))+(((x6764)*(x6771)))+(((x6764)*(x6772)))+(pz)+(((IkReal(-1.00000000000000))*(x6767)*(x6771))));
evalcond[3]=((((IkReal(-1.00000000000000))*(r11)*(x6773)*(x6778)))+(((r02)*(x6777)))+(((IkReal(-1.00000000000000))*(sj5)*(x6762)*(x6783)))+(((IkReal(-1.00000000000000))*(r01)*(x6760)*(x6778)))+(((r12)*(x6769)))+(((IkReal(-1.00000000000000))*(sj5)*(x6760)*(x6780))));
evalcond[4]=((((IkReal(-1.00000000000000))*(r00)*(x6773)*(x6775)))+(((IkReal(-1.00000000000000))*(r12)*(x6760)*(x6765)))+(((cj4)*(r10)*(x6766)))+(((r00)*(x6762)*(x6763)))+(((sj0)*(x6763)*(x6779)))+(((r01)*(sj0)*(x6761)))+(((x6765)*(x6784)))+(((IkReal(-1.00000000000000))*(r10)*(sj6)*(x6760)*(x6763)))+(((IkReal(-1.00000000000000))*(x6760)*(x6763)*(x6782)))+(((IkReal(-1.00000000000000))*(r11)*(x6760)*(x6761))));
evalcond[5]=((IkReal(-1.00000000000000))+(((IkReal(-1.00000000000000))*(x6760)*(x6763)*(x6780)))+(((IkReal(-1.00000000000000))*(r02)*(x6760)*(x6765)))+(((r10)*(sj0)*(x6775)))+(((IkReal(-1.00000000000000))*(x6760)*(x6763)*(x6779)))+(((IkReal(-1.00000000000000))*(x6762)*(x6763)*(x6783)))+(((IkReal(-1.00000000000000))*(r11)*(x6761)*(x6773)))+(((IkReal(-1.00000000000000))*(x6763)*(x6773)*(x6782)))+(((IkReal(-1.00000000000000))*(x6765)*(x6786)))+(((cj4)*(r00)*(x6766)))+(((IkReal(-1.00000000000000))*(r01)*(x6760)*(x6761))));
evalcond[6]=((IkReal(0.0690000000000000))+(((r10)*(x6767)*(x6774)))+(((IkReal(-1.00000000000000))*(r11)*(x6764)*(x6766)))+(((IkReal(-1.00000000000000))*(x6769)*(x6770)))+(((r11)*(x6766)*(x6767)))+(((cj0)*(r12)*(x6781)))+(((IkReal(-1.00000000000000))*(r00)*(x6762)*(x6767)))+(((r00)*(x6762)*(x6764)))+(((IkReal(-1.00000000000000))*(r10)*(x6764)*(x6774)))+(((IkReal(-1.00000000000000))*(x6781)*(x6784)))+(((sj0)*(x6764)*(x6779)))+(((px)*(sj0)))+(((IkReal(-1.00000000000000))*(sj0)*(x6767)*(x6779)))+(((IkReal(-1.00000000000000))*(py)*(x6760)))+(((x6776)*(x6777))));
evalcond[7]=((((IkReal(-1.00000000000000))*(r00)*(x6760)*(x6785)))+(((IkReal(-1.00000000000000))*(r10)*(x6773)*(x6785)))+(((IkReal(-1.00000000000000))*(cj5)*(r00)*(x6760)*(x6761)))+(((IkReal(-1.00000000000000))*(r02)*(x6760)*(x6768)))+(((IkReal(-1.00000000000000))*(r11)*(x6769)*(x6775)))+(((IkReal(-1.00000000000000))*(x6761)*(x6769)*(x6783)))+(((IkReal(-1.00000000000000))*(cj5)*(r01)*(x6760)*(x6775)))+(((IkReal(-1.00000000000000))*(x6768)*(x6786)))+(((r01)*(sj4)*(x6774)))+(((r11)*(sj4)*(x6762))));
evalcond[8]=((IkReal(0.0690000000000000))+(((r00)*(x6767)*(x6774)))+(((x6770)*(x6777)))+(((IkReal(-1.00000000000000))*(py)*(x6773)))+(((IkReal(-1.00000000000000))*(r10)*(x6762)*(x6764)))+(((r01)*(x6766)*(x6767)))+(((cj0)*(r02)*(x6781)))+(((IkReal(-1.00000000000000))*(r01)*(x6764)*(x6766)))+(((x6769)*(x6776)))+(((IkReal(-1.00000000000000))*(px)*(x6760)))+(((sj0)*(x6767)*(x6782)))+(((r10)*(x6762)*(x6767)))+(((IkReal(-1.00000000000000))*(r00)*(x6764)*(x6774)))+(((IkReal(-1.00000000000000))*(sj0)*(x6764)*(x6782)))+(((r12)*(sj0)*(x6781))));
if( IKabs(evalcond[0]) < 0.0000010000000000  && IKabs(evalcond[1]) < 0.0000010000000000  && IKabs(evalcond[2]) < 0.0000010000000000  && IKabs(evalcond[3]) < 0.0000010000000000  && IKabs(evalcond[4]) < 0.0000010000000000  && IKabs(evalcond[5]) < 0.0000010000000000  && IKabs(evalcond[6]) < 0.0000010000000000  && IKabs(evalcond[7]) < 0.0000010000000000  && IKabs(evalcond[8]) < 0.0000010000000000  )
{
{
IkReal j3array[1], cj3array[1], sj3array[1];
bool j3valid[1]={false};
_nj3 = 1;
IkReal x6787=((IkReal(1.00000000000000))*(sj5));
IkReal x6788=((cj6)*(r21));
IkReal x6789=((r20)*(sj6));
IkReal x6790=((IkReal(1.00000000000000))*(cj4)*(cj5));
if( IKabs(((((IkReal(-1.00000000000000))*(x6788)*(x6790)))+(((IkReal(-1.00000000000000))*(cj4)*(r22)*(x6787)))+(((r21)*(sj4)*(sj6)))+(((IkReal(-1.00000000000000))*(x6789)*(x6790)))+(((IkReal(-1.00000000000000))*(cj6)*(r20)*(sj4))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(((((IkReal(-1.00000000000000))*(x6787)*(x6788)))+(((cj5)*(r22)))+(((IkReal(-1.00000000000000))*(x6787)*(x6789))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(IKsqr(((((IkReal(-1.00000000000000))*(x6788)*(x6790)))+(((IkReal(-1.00000000000000))*(cj4)*(r22)*(x6787)))+(((r21)*(sj4)*(sj6)))+(((IkReal(-1.00000000000000))*(x6789)*(x6790)))+(((IkReal(-1.00000000000000))*(cj6)*(r20)*(sj4)))))+IKsqr(((((IkReal(-1.00000000000000))*(x6787)*(x6788)))+(((cj5)*(r22)))+(((IkReal(-1.00000000000000))*(x6787)*(x6789)))))-1) <= IKFAST_SINCOS_THRESH )
    continue;
j3array[0]=IKatan2(((((IkReal(-1.00000000000000))*(x6788)*(x6790)))+(((IkReal(-1.00000000000000))*(cj4)*(r22)*(x6787)))+(((r21)*(sj4)*(sj6)))+(((IkReal(-1.00000000000000))*(x6789)*(x6790)))+(((IkReal(-1.00000000000000))*(cj6)*(r20)*(sj4)))), ((((IkReal(-1.00000000000000))*(x6787)*(x6788)))+(((cj5)*(r22)))+(((IkReal(-1.00000000000000))*(x6787)*(x6789)))));
sj3array[0]=IKsin(j3array[0]);
cj3array[0]=IKcos(j3array[0]);
if( j3array[0] > IKPI )
{
    j3array[0]-=IK2PI;
}
else if( j3array[0] < -IKPI )
{    j3array[0]+=IK2PI;
}
j3valid[0] = true;
for(int ij3 = 0; ij3 < 1; ++ij3)
{
if( !j3valid[ij3] )
{
    continue;
}
_ij3[0] = ij3; _ij3[1] = -1;
for(int iij3 = ij3+1; iij3 < 1; ++iij3)
{
if( j3valid[iij3] && IKabs(cj3array[ij3]-cj3array[iij3]) < IKFAST_SOLUTION_THRESH && IKabs(sj3array[ij3]-sj3array[iij3]) < IKFAST_SOLUTION_THRESH )
{
    j3valid[iij3]=false; _ij3[1] = iij3; break; 
}
}
j3 = j3array[ij3]; cj3 = cj3array[ij3]; sj3 = sj3array[ij3];
{
IkReal evalcond[4];
IkReal x6791=IKsin(j3);
IkReal x6792=IKcos(j3);
IkReal x6793=((sj0)*(sj5));
IkReal x6794=((r00)*(sj6));
IkReal x6795=((cj6)*(r01));
IkReal x6796=((cj5)*(sj0));
IkReal x6797=((cj0)*(cj5));
IkReal x6798=((cj6)*(sj4));
IkReal x6799=((sj4)*(sj6));
IkReal x6800=((cj0)*(r11));
IkReal x6801=((cj4)*(cj6));
IkReal x6802=((cj4)*(sj6));
IkReal x6803=((IkReal(1.00000000000000))*(cj0));
IkReal x6804=((cj4)*(sj5));
IkReal x6805=((sj5)*(sj6));
IkReal x6806=((cj6)*(sj5));
evalcond[0]=((((IkReal(-1.00000000000000))*(cj5)*(r22)))+(x6792)+(((r21)*(x6806)))+(((r20)*(x6805))));
evalcond[1]=((((cj5)*(r21)*(x6801)))+(((IkReal(-1.00000000000000))*(r21)*(x6799)))+(((r20)*(x6798)))+(((cj5)*(r20)*(x6802)))+(((r22)*(x6804)))+(x6791));
evalcond[2]=((((IkReal(-1.00000000000000))*(x6791)))+(((r12)*(x6797)))+(((x6793)*(x6794)))+(((IkReal(-1.00000000000000))*(x6800)*(x6806)))+(((IkReal(-1.00000000000000))*(r02)*(x6796)))+(((x6793)*(x6795)))+(((IkReal(-1.00000000000000))*(r10)*(x6803)*(x6805))));
evalcond[3]=((((cj4)*(x6794)*(x6796)))+(((IkReal(-1.00000000000000))*(r10)*(x6797)*(x6802)))+(((cj4)*(x6795)*(x6796)))+(((x6799)*(x6800)))+(((IkReal(-1.00000000000000))*(r12)*(x6803)*(x6804)))+(((r00)*(sj0)*(x6798)))+(((cj4)*(r02)*(x6793)))+(x6792)+(((IkReal(-1.00000000000000))*(r11)*(x6797)*(x6801)))+(((IkReal(-1.00000000000000))*(r10)*(x6798)*(x6803)))+(((IkReal(-1.00000000000000))*(r01)*(sj0)*(x6799))));
if( IKabs(evalcond[0]) > 0.000001  || IKabs(evalcond[1]) > 0.000001  || IKabs(evalcond[2]) > 0.000001  || IKabs(evalcond[3]) > 0.000001  )
{
continue;
}
}

{
std::vector<IkSingleDOFSolutionBase<IkReal> > vinfos(7);
vinfos[0].jointtype = 1;
vinfos[0].foffset = j0;
vinfos[0].indices[0] = _ij0[0];
vinfos[0].indices[1] = _ij0[1];
vinfos[0].maxsolutions = _nj0;
vinfos[1].jointtype = 1;
vinfos[1].foffset = j1;
vinfos[1].indices[0] = _ij1[0];
vinfos[1].indices[1] = _ij1[1];
vinfos[1].maxsolutions = _nj1;
vinfos[2].jointtype = 1;
vinfos[2].foffset = j2;
vinfos[2].indices[0] = _ij2[0];
vinfos[2].indices[1] = _ij2[1];
vinfos[2].maxsolutions = _nj2;
vinfos[3].jointtype = 1;
vinfos[3].foffset = j3;
vinfos[3].indices[0] = _ij3[0];
vinfos[3].indices[1] = _ij3[1];
vinfos[3].maxsolutions = _nj3;
vinfos[4].jointtype = 1;
vinfos[4].foffset = j4;
vinfos[4].indices[0] = _ij4[0];
vinfos[4].indices[1] = _ij4[1];
vinfos[4].maxsolutions = _nj4;
vinfos[5].jointtype = 1;
vinfos[5].foffset = j5;
vinfos[5].indices[0] = _ij5[0];
vinfos[5].indices[1] = _ij5[1];
vinfos[5].maxsolutions = _nj5;
vinfos[6].jointtype = 1;
vinfos[6].foffset = j6;
vinfos[6].indices[0] = _ij6[0];
vinfos[6].indices[1] = _ij6[1];
vinfos[6].maxsolutions = _nj6;
std::vector<int> vfree(0);
solutions.AddSolution(vinfos,vfree);
}
}
}

} else
{
if( 1 )
{
continue;

} else
{
}
}
}
}

} else
{
{
IkReal j3array[1], cj3array[1], sj3array[1];
bool j3valid[1]={false};
_nj3 = 1;
IkReal x6807=((cj0)*(cj5));
IkReal x6808=((IkReal(1.00000000000000))*(cj0));
IkReal x6809=((cj6)*(r11));
IkReal x6810=((r10)*(sj6));
IkReal x6811=((cj5)*(sj0));
IkReal x6812=((r00)*(sj5)*(sj6));
IkReal x6813=((cj6)*(r01)*(sj5));
IkReal x6814=((IkReal(1.00000000000000))*(sj0)*(sj5));
if( IKabs(((((sj0)*(x6813)))+(((sj0)*(x6812)))+(((IkReal(-1.00000000000000))*(sj5)*(x6808)*(x6810)))+(((r12)*(x6807)))+(((IkReal(-1.00000000000000))*(r02)*(x6811)))+(((IkReal(-1.00000000000000))*(sj5)*(x6808)*(x6809))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(((((IKabs(cj1) != 0)?((IkReal)1/(cj1)):(IkReal)1.0e30))*(((((IkReal(-1.00000000000000))*(x6810)*(x6814)))+(((IkReal(-1.00000000000000))*(x6808)*(x6813)))+(((IkReal(-1.00000000000000))*(x6809)*(x6814)))+(((r12)*(x6811)))+(((IkReal(-1.00000000000000))*(x6808)*(x6812)))+(((r02)*(x6807))))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(IKsqr(((((sj0)*(x6813)))+(((sj0)*(x6812)))+(((IkReal(-1.00000000000000))*(sj5)*(x6808)*(x6810)))+(((r12)*(x6807)))+(((IkReal(-1.00000000000000))*(r02)*(x6811)))+(((IkReal(-1.00000000000000))*(sj5)*(x6808)*(x6809)))))+IKsqr(((((IKabs(cj1) != 0)?((IkReal)1/(cj1)):(IkReal)1.0e30))*(((((IkReal(-1.00000000000000))*(x6810)*(x6814)))+(((IkReal(-1.00000000000000))*(x6808)*(x6813)))+(((IkReal(-1.00000000000000))*(x6809)*(x6814)))+(((r12)*(x6811)))+(((IkReal(-1.00000000000000))*(x6808)*(x6812)))+(((r02)*(x6807)))))))-1) <= IKFAST_SINCOS_THRESH )
    continue;
j3array[0]=IKatan2(((((sj0)*(x6813)))+(((sj0)*(x6812)))+(((IkReal(-1.00000000000000))*(sj5)*(x6808)*(x6810)))+(((r12)*(x6807)))+(((IkReal(-1.00000000000000))*(r02)*(x6811)))+(((IkReal(-1.00000000000000))*(sj5)*(x6808)*(x6809)))), ((((IKabs(cj1) != 0)?((IkReal)1/(cj1)):(IkReal)1.0e30))*(((((IkReal(-1.00000000000000))*(x6810)*(x6814)))+(((IkReal(-1.00000000000000))*(x6808)*(x6813)))+(((IkReal(-1.00000000000000))*(x6809)*(x6814)))+(((r12)*(x6811)))+(((IkReal(-1.00000000000000))*(x6808)*(x6812)))+(((r02)*(x6807)))))));
sj3array[0]=IKsin(j3array[0]);
cj3array[0]=IKcos(j3array[0]);
if( j3array[0] > IKPI )
{
    j3array[0]-=IK2PI;
}
else if( j3array[0] < -IKPI )
{    j3array[0]+=IK2PI;
}
j3valid[0] = true;
for(int ij3 = 0; ij3 < 1; ++ij3)
{
if( !j3valid[ij3] )
{
    continue;
}
_ij3[0] = ij3; _ij3[1] = -1;
for(int iij3 = ij3+1; iij3 < 1; ++iij3)
{
if( j3valid[iij3] && IKabs(cj3array[ij3]-cj3array[iij3]) < IKFAST_SOLUTION_THRESH && IKabs(sj3array[ij3]-sj3array[iij3]) < IKFAST_SOLUTION_THRESH )
{
    j3valid[iij3]=false; _ij3[1] = iij3; break; 
}
}
j3 = j3array[ij3]; cj3 = cj3array[ij3]; sj3 = sj3array[ij3];
{
IkReal evalcond[6];
IkReal x6815=IKsin(j3);
IkReal x6816=IKcos(j3);
IkReal x6817=((sj0)*(sj5));
IkReal x6818=((r00)*(sj6));
IkReal x6819=((cj6)*(r01));
IkReal x6820=((cj4)*(cj5));
IkReal x6821=((IkReal(1.00000000000000))*(cj0));
IkReal x6822=((cj5)*(r12));
IkReal x6823=((IkReal(1.00000000000000))*(sj0));
IkReal x6824=((cj6)*(r11));
IkReal x6825=((cj5)*(r02));
IkReal x6826=((IkReal(1.00000000000000))*(cj1));
IkReal x6827=((cj6)*(sj4));
IkReal x6828=((cj6)*(r21));
IkReal x6829=((r20)*(sj6));
IkReal x6830=((r10)*(sj6));
IkReal x6831=((sj4)*(sj6));
IkReal x6832=((cj4)*(r02));
IkReal x6833=((IkReal(1.00000000000000))*(cj4)*(r12));
IkReal x6834=((IkReal(1.00000000000000))*(x6815));
IkReal x6835=((cj0)*(x6831));
evalcond[0]=((((IkReal(-1.00000000000000))*(sj1)*(x6816)))+(((sj5)*(x6829)))+(((sj5)*(x6828)))+(((IkReal(-1.00000000000000))*(cj5)*(r22))));
evalcond[1]=((((IkReal(-1.00000000000000))*(sj1)*(x6834)))+(((r20)*(x6827)))+(((x6820)*(x6829)))+(((cj4)*(r22)*(sj5)))+(((IkReal(-1.00000000000000))*(r21)*(x6831)))+(((x6820)*(x6828))));
evalcond[2]=((((IkReal(-1.00000000000000))*(sj5)*(x6821)*(x6824)))+(((cj0)*(x6822)))+(((IkReal(-1.00000000000000))*(sj5)*(x6821)*(x6830)))+(((x6817)*(x6819)))+(((IkReal(-1.00000000000000))*(x6834)))+(((x6817)*(x6818)))+(((IkReal(-1.00000000000000))*(x6823)*(x6825))));
evalcond[3]=((((sj0)*(x6822)))+(((IkReal(-1.00000000000000))*(x6817)*(x6830)))+(((IkReal(-1.00000000000000))*(sj5)*(x6818)*(x6821)))+(((cj0)*(x6825)))+(((IkReal(-1.00000000000000))*(x6817)*(x6824)))+(((IkReal(-1.00000000000000))*(sj5)*(x6819)*(x6821)))+(((IkReal(-1.00000000000000))*(x6816)*(x6826))));
evalcond[4]=((((x6817)*(x6832)))+(((IkReal(-1.00000000000000))*(x6820)*(x6821)*(x6830)))+(((sj0)*(x6819)*(x6820)))+(((IkReal(-1.00000000000000))*(r01)*(x6823)*(x6831)))+(((IkReal(-1.00000000000000))*(x6820)*(x6821)*(x6824)))+(((r00)*(sj0)*(x6827)))+(((IkReal(-1.00000000000000))*(cj4)*(r12)*(sj5)*(x6821)))+(((r11)*(x6835)))+(((sj0)*(x6818)*(x6820)))+(((IkReal(-1.00000000000000))*(r10)*(x6821)*(x6827)))+(x6816));
evalcond[5]=((((IkReal(-1.00000000000000))*(r10)*(x6823)*(x6827)))+(((IkReal(-1.00000000000000))*(x6819)*(x6820)*(x6821)))+(((IkReal(-1.00000000000000))*(sj5)*(x6821)*(x6832)))+(((IkReal(-1.00000000000000))*(x6817)*(x6833)))+(((IkReal(-1.00000000000000))*(x6820)*(x6823)*(x6824)))+(((IkReal(-1.00000000000000))*(x6818)*(x6820)*(x6821)))+(((IkReal(-1.00000000000000))*(x6815)*(x6826)))+(((r11)*(sj0)*(x6831)))+(((IkReal(-1.00000000000000))*(r00)*(x6821)*(x6827)))+(((r01)*(x6835)))+(((IkReal(-1.00000000000000))*(x6820)*(x6823)*(x6830))));
if( IKabs(evalcond[0]) > 0.000001  || IKabs(evalcond[1]) > 0.000001  || IKabs(evalcond[2]) > 0.000001  || IKabs(evalcond[3]) > 0.000001  || IKabs(evalcond[4]) > 0.000001  || IKabs(evalcond[5]) > 0.000001  )
{
continue;
}
}

{
std::vector<IkSingleDOFSolutionBase<IkReal> > vinfos(7);
vinfos[0].jointtype = 1;
vinfos[0].foffset = j0;
vinfos[0].indices[0] = _ij0[0];
vinfos[0].indices[1] = _ij0[1];
vinfos[0].maxsolutions = _nj0;
vinfos[1].jointtype = 1;
vinfos[1].foffset = j1;
vinfos[1].indices[0] = _ij1[0];
vinfos[1].indices[1] = _ij1[1];
vinfos[1].maxsolutions = _nj1;
vinfos[2].jointtype = 1;
vinfos[2].foffset = j2;
vinfos[2].indices[0] = _ij2[0];
vinfos[2].indices[1] = _ij2[1];
vinfos[2].maxsolutions = _nj2;
vinfos[3].jointtype = 1;
vinfos[3].foffset = j3;
vinfos[3].indices[0] = _ij3[0];
vinfos[3].indices[1] = _ij3[1];
vinfos[3].maxsolutions = _nj3;
vinfos[4].jointtype = 1;
vinfos[4].foffset = j4;
vinfos[4].indices[0] = _ij4[0];
vinfos[4].indices[1] = _ij4[1];
vinfos[4].maxsolutions = _nj4;
vinfos[5].jointtype = 1;
vinfos[5].foffset = j5;
vinfos[5].indices[0] = _ij5[0];
vinfos[5].indices[1] = _ij5[1];
vinfos[5].maxsolutions = _nj5;
vinfos[6].jointtype = 1;
vinfos[6].foffset = j6;
vinfos[6].indices[0] = _ij6[0];
vinfos[6].indices[1] = _ij6[1];
vinfos[6].maxsolutions = _nj6;
std::vector<int> vfree(0);
solutions.AddSolution(vinfos,vfree);
}
}
}

}

}

} else
{
{
IkReal j3array[1], cj3array[1], sj3array[1];
bool j3valid[1]={false};
_nj3 = 1;
IkReal x6836=((sj5)*(sj6));
IkReal x6837=((cj6)*(sj5));
IkReal x6838=((IkReal(1.00000000000000))*(cj0));
IkReal x6839=((IkReal(1.00000000000000))*(cj5));
if( IKabs(((((r01)*(sj0)*(x6837)))+(((IkReal(-1.00000000000000))*(r11)*(x6837)*(x6838)))+(((r00)*(sj0)*(x6836)))+(((cj0)*(cj5)*(r12)))+(((IkReal(-1.00000000000000))*(r02)*(sj0)*(x6839)))+(((IkReal(-1.00000000000000))*(r10)*(x6836)*(x6838))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(((((IKabs(sj1) != 0)?((IkReal)1/(sj1)):(IkReal)1.0e30))*(((((IkReal(-1.00000000000000))*(r22)*(x6839)))+(((r21)*(x6837)))+(((r20)*(x6836))))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(IKsqr(((((r01)*(sj0)*(x6837)))+(((IkReal(-1.00000000000000))*(r11)*(x6837)*(x6838)))+(((r00)*(sj0)*(x6836)))+(((cj0)*(cj5)*(r12)))+(((IkReal(-1.00000000000000))*(r02)*(sj0)*(x6839)))+(((IkReal(-1.00000000000000))*(r10)*(x6836)*(x6838)))))+IKsqr(((((IKabs(sj1) != 0)?((IkReal)1/(sj1)):(IkReal)1.0e30))*(((((IkReal(-1.00000000000000))*(r22)*(x6839)))+(((r21)*(x6837)))+(((r20)*(x6836)))))))-1) <= IKFAST_SINCOS_THRESH )
    continue;
j3array[0]=IKatan2(((((r01)*(sj0)*(x6837)))+(((IkReal(-1.00000000000000))*(r11)*(x6837)*(x6838)))+(((r00)*(sj0)*(x6836)))+(((cj0)*(cj5)*(r12)))+(((IkReal(-1.00000000000000))*(r02)*(sj0)*(x6839)))+(((IkReal(-1.00000000000000))*(r10)*(x6836)*(x6838)))), ((((IKabs(sj1) != 0)?((IkReal)1/(sj1)):(IkReal)1.0e30))*(((((IkReal(-1.00000000000000))*(r22)*(x6839)))+(((r21)*(x6837)))+(((r20)*(x6836)))))));
sj3array[0]=IKsin(j3array[0]);
cj3array[0]=IKcos(j3array[0]);
if( j3array[0] > IKPI )
{
    j3array[0]-=IK2PI;
}
else if( j3array[0] < -IKPI )
{    j3array[0]+=IK2PI;
}
j3valid[0] = true;
for(int ij3 = 0; ij3 < 1; ++ij3)
{
if( !j3valid[ij3] )
{
    continue;
}
_ij3[0] = ij3; _ij3[1] = -1;
for(int iij3 = ij3+1; iij3 < 1; ++iij3)
{
if( j3valid[iij3] && IKabs(cj3array[ij3]-cj3array[iij3]) < IKFAST_SOLUTION_THRESH && IKabs(sj3array[ij3]-sj3array[iij3]) < IKFAST_SOLUTION_THRESH )
{
    j3valid[iij3]=false; _ij3[1] = iij3; break; 
}
}
j3 = j3array[ij3]; cj3 = cj3array[ij3]; sj3 = sj3array[ij3];
{
IkReal evalcond[6];
IkReal x6840=IKsin(j3);
IkReal x6841=IKcos(j3);
IkReal x6842=((sj0)*(sj5));
IkReal x6843=((r00)*(sj6));
IkReal x6844=((cj6)*(r01));
IkReal x6845=((cj4)*(cj5));
IkReal x6846=((IkReal(1.00000000000000))*(cj0));
IkReal x6847=((cj5)*(r12));
IkReal x6848=((IkReal(1.00000000000000))*(sj0));
IkReal x6849=((cj6)*(r11));
IkReal x6850=((cj5)*(r02));
IkReal x6851=((IkReal(1.00000000000000))*(cj1));
IkReal x6852=((cj6)*(sj4));
IkReal x6853=((cj6)*(r21));
IkReal x6854=((r20)*(sj6));
IkReal x6855=((r10)*(sj6));
IkReal x6856=((sj4)*(sj6));
IkReal x6857=((cj4)*(r02));
IkReal x6858=((IkReal(1.00000000000000))*(cj4)*(r12));
IkReal x6859=((IkReal(1.00000000000000))*(x6840));
IkReal x6860=((cj0)*(x6856));
evalcond[0]=((((sj5)*(x6853)))+(((sj5)*(x6854)))+(((IkReal(-1.00000000000000))*(cj5)*(r22)))+(((IkReal(-1.00000000000000))*(sj1)*(x6841))));
evalcond[1]=((((x6845)*(x6853)))+(((IkReal(-1.00000000000000))*(sj1)*(x6859)))+(((cj4)*(r22)*(sj5)))+(((r20)*(x6852)))+(((IkReal(-1.00000000000000))*(r21)*(x6856)))+(((x6845)*(x6854))));
evalcond[2]=((((IkReal(-1.00000000000000))*(x6848)*(x6850)))+(((x6842)*(x6844)))+(((IkReal(-1.00000000000000))*(sj5)*(x6846)*(x6849)))+(((x6842)*(x6843)))+(((IkReal(-1.00000000000000))*(sj5)*(x6846)*(x6855)))+(((IkReal(-1.00000000000000))*(x6859)))+(((cj0)*(x6847))));
evalcond[3]=((((IkReal(-1.00000000000000))*(x6842)*(x6849)))+(((IkReal(-1.00000000000000))*(sj5)*(x6843)*(x6846)))+(((IkReal(-1.00000000000000))*(x6841)*(x6851)))+(((IkReal(-1.00000000000000))*(x6842)*(x6855)))+(((cj0)*(x6850)))+(((IkReal(-1.00000000000000))*(sj5)*(x6844)*(x6846)))+(((sj0)*(x6847))));
evalcond[4]=((((r11)*(x6860)))+(((r00)*(sj0)*(x6852)))+(((x6842)*(x6857)))+(x6841)+(((IkReal(-1.00000000000000))*(r10)*(x6846)*(x6852)))+(((IkReal(-1.00000000000000))*(r01)*(x6848)*(x6856)))+(((IkReal(-1.00000000000000))*(x6845)*(x6846)*(x6855)))+(((IkReal(-1.00000000000000))*(x6845)*(x6846)*(x6849)))+(((IkReal(-1.00000000000000))*(cj4)*(r12)*(sj5)*(x6846)))+(((sj0)*(x6843)*(x6845)))+(((sj0)*(x6844)*(x6845))));
evalcond[5]=((((IkReal(-1.00000000000000))*(x6842)*(x6858)))+(((IkReal(-1.00000000000000))*(x6840)*(x6851)))+(((IkReal(-1.00000000000000))*(x6844)*(x6845)*(x6846)))+(((r01)*(x6860)))+(((IkReal(-1.00000000000000))*(x6845)*(x6848)*(x6849)))+(((IkReal(-1.00000000000000))*(x6845)*(x6848)*(x6855)))+(((IkReal(-1.00000000000000))*(sj5)*(x6846)*(x6857)))+(((IkReal(-1.00000000000000))*(r10)*(x6848)*(x6852)))+(((r11)*(sj0)*(x6856)))+(((IkReal(-1.00000000000000))*(r00)*(x6846)*(x6852)))+(((IkReal(-1.00000000000000))*(x6843)*(x6845)*(x6846))));
if( IKabs(evalcond[0]) > 0.000001  || IKabs(evalcond[1]) > 0.000001  || IKabs(evalcond[2]) > 0.000001  || IKabs(evalcond[3]) > 0.000001  || IKabs(evalcond[4]) > 0.000001  || IKabs(evalcond[5]) > 0.000001  )
{
continue;
}
}

{
std::vector<IkSingleDOFSolutionBase<IkReal> > vinfos(7);
vinfos[0].jointtype = 1;
vinfos[0].foffset = j0;
vinfos[0].indices[0] = _ij0[0];
vinfos[0].indices[1] = _ij0[1];
vinfos[0].maxsolutions = _nj0;
vinfos[1].jointtype = 1;
vinfos[1].foffset = j1;
vinfos[1].indices[0] = _ij1[0];
vinfos[1].indices[1] = _ij1[1];
vinfos[1].maxsolutions = _nj1;
vinfos[2].jointtype = 1;
vinfos[2].foffset = j2;
vinfos[2].indices[0] = _ij2[0];
vinfos[2].indices[1] = _ij2[1];
vinfos[2].maxsolutions = _nj2;
vinfos[3].jointtype = 1;
vinfos[3].foffset = j3;
vinfos[3].indices[0] = _ij3[0];
vinfos[3].indices[1] = _ij3[1];
vinfos[3].maxsolutions = _nj3;
vinfos[4].jointtype = 1;
vinfos[4].foffset = j4;
vinfos[4].indices[0] = _ij4[0];
vinfos[4].indices[1] = _ij4[1];
vinfos[4].maxsolutions = _nj4;
vinfos[5].jointtype = 1;
vinfos[5].foffset = j5;
vinfos[5].indices[0] = _ij5[0];
vinfos[5].indices[1] = _ij5[1];
vinfos[5].maxsolutions = _nj5;
vinfos[6].jointtype = 1;
vinfos[6].foffset = j6;
vinfos[6].indices[0] = _ij6[0];
vinfos[6].indices[1] = _ij6[1];
vinfos[6].maxsolutions = _nj6;
std::vector<int> vfree(0);
solutions.AddSolution(vinfos,vfree);
}
}
}

}

}

} else
{
{
IkReal j3array[1], cj3array[1], sj3array[1];
bool j3valid[1]={false};
_nj3 = 1;
IkReal x6861=((r20)*(sj6));
IkReal x6862=((cj4)*(cj5));
IkReal x6863=((cj6)*(r21));
if( IKabs(((gconst11)*(((((IkReal(-1.00000000000000))*(r21)*(sj4)*(sj6)))+(((cj6)*(r20)*(sj4)))+(((cj4)*(r22)*(sj5)))+(((x6861)*(x6862)))+(((x6862)*(x6863))))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(((gconst11)*(((((sj5)*(x6863)))+(((sj5)*(x6861)))+(((IkReal(-1.00000000000000))*(cj5)*(r22))))))) < IKFAST_ATAN2_MAGTHRESH )
    continue;
j3array[0]=IKatan2(((gconst11)*(((((IkReal(-1.00000000000000))*(r21)*(sj4)*(sj6)))+(((cj6)*(r20)*(sj4)))+(((cj4)*(r22)*(sj5)))+(((x6861)*(x6862)))+(((x6862)*(x6863)))))), ((gconst11)*(((((sj5)*(x6863)))+(((sj5)*(x6861)))+(((IkReal(-1.00000000000000))*(cj5)*(r22)))))));
sj3array[0]=IKsin(j3array[0]);
cj3array[0]=IKcos(j3array[0]);
if( j3array[0] > IKPI )
{
    j3array[0]-=IK2PI;
}
else if( j3array[0] < -IKPI )
{    j3array[0]+=IK2PI;
}
j3valid[0] = true;
for(int ij3 = 0; ij3 < 1; ++ij3)
{
if( !j3valid[ij3] )
{
    continue;
}
_ij3[0] = ij3; _ij3[1] = -1;
for(int iij3 = ij3+1; iij3 < 1; ++iij3)
{
if( j3valid[iij3] && IKabs(cj3array[ij3]-cj3array[iij3]) < IKFAST_SOLUTION_THRESH && IKabs(sj3array[ij3]-sj3array[iij3]) < IKFAST_SOLUTION_THRESH )
{
    j3valid[iij3]=false; _ij3[1] = iij3; break; 
}
}
j3 = j3array[ij3]; cj3 = cj3array[ij3]; sj3 = sj3array[ij3];
{
IkReal evalcond[6];
IkReal x6864=IKsin(j3);
IkReal x6865=IKcos(j3);
IkReal x6866=((sj0)*(sj5));
IkReal x6867=((r00)*(sj6));
IkReal x6868=((cj6)*(r01));
IkReal x6869=((cj4)*(cj5));
IkReal x6870=((IkReal(1.00000000000000))*(cj0));
IkReal x6871=((cj5)*(r12));
IkReal x6872=((IkReal(1.00000000000000))*(sj0));
IkReal x6873=((cj6)*(r11));
IkReal x6874=((cj5)*(r02));
IkReal x6875=((IkReal(1.00000000000000))*(cj1));
IkReal x6876=((cj6)*(sj4));
IkReal x6877=((cj6)*(r21));
IkReal x6878=((r20)*(sj6));
IkReal x6879=((r10)*(sj6));
IkReal x6880=((sj4)*(sj6));
IkReal x6881=((cj4)*(r02));
IkReal x6882=((IkReal(1.00000000000000))*(cj4)*(r12));
IkReal x6883=((IkReal(1.00000000000000))*(x6864));
IkReal x6884=((cj0)*(x6880));
evalcond[0]=((((IkReal(-1.00000000000000))*(sj1)*(x6865)))+(((sj5)*(x6878)))+(((IkReal(-1.00000000000000))*(cj5)*(r22)))+(((sj5)*(x6877))));
evalcond[1]=((((r20)*(x6876)))+(((x6869)*(x6878)))+(((cj4)*(r22)*(sj5)))+(((IkReal(-1.00000000000000))*(r21)*(x6880)))+(((IkReal(-1.00000000000000))*(sj1)*(x6883)))+(((x6869)*(x6877))));
evalcond[2]=((((IkReal(-1.00000000000000))*(sj5)*(x6870)*(x6879)))+(((x6866)*(x6867)))+(((IkReal(-1.00000000000000))*(sj5)*(x6870)*(x6873)))+(((IkReal(-1.00000000000000))*(x6872)*(x6874)))+(((cj0)*(x6871)))+(((IkReal(-1.00000000000000))*(x6883)))+(((x6866)*(x6868))));
evalcond[3]=((((IkReal(-1.00000000000000))*(x6866)*(x6873)))+(((cj0)*(x6874)))+(((IkReal(-1.00000000000000))*(x6866)*(x6879)))+(((IkReal(-1.00000000000000))*(sj5)*(x6868)*(x6870)))+(((IkReal(-1.00000000000000))*(x6865)*(x6875)))+(((IkReal(-1.00000000000000))*(sj5)*(x6867)*(x6870)))+(((sj0)*(x6871))));
evalcond[4]=((((sj0)*(x6867)*(x6869)))+(((IkReal(-1.00000000000000))*(x6869)*(x6870)*(x6873)))+(((IkReal(-1.00000000000000))*(r10)*(x6870)*(x6876)))+(((r11)*(x6884)))+(((IkReal(-1.00000000000000))*(x6869)*(x6870)*(x6879)))+(x6865)+(((r00)*(sj0)*(x6876)))+(((IkReal(-1.00000000000000))*(cj4)*(r12)*(sj5)*(x6870)))+(((sj0)*(x6868)*(x6869)))+(((IkReal(-1.00000000000000))*(r01)*(x6872)*(x6880)))+(((x6866)*(x6881))));
evalcond[5]=((((IkReal(-1.00000000000000))*(x6868)*(x6869)*(x6870)))+(((r01)*(x6884)))+(((IkReal(-1.00000000000000))*(sj5)*(x6870)*(x6881)))+(((IkReal(-1.00000000000000))*(x6866)*(x6882)))+(((r11)*(sj0)*(x6880)))+(((IkReal(-1.00000000000000))*(x6869)*(x6872)*(x6873)))+(((IkReal(-1.00000000000000))*(x6869)*(x6872)*(x6879)))+(((IkReal(-1.00000000000000))*(r10)*(x6872)*(x6876)))+(((IkReal(-1.00000000000000))*(x6864)*(x6875)))+(((IkReal(-1.00000000000000))*(r00)*(x6870)*(x6876)))+(((IkReal(-1.00000000000000))*(x6867)*(x6869)*(x6870))));
if( IKabs(evalcond[0]) > 0.000001  || IKabs(evalcond[1]) > 0.000001  || IKabs(evalcond[2]) > 0.000001  || IKabs(evalcond[3]) > 0.000001  || IKabs(evalcond[4]) > 0.000001  || IKabs(evalcond[5]) > 0.000001  )
{
continue;
}
}

{
std::vector<IkSingleDOFSolutionBase<IkReal> > vinfos(7);
vinfos[0].jointtype = 1;
vinfos[0].foffset = j0;
vinfos[0].indices[0] = _ij0[0];
vinfos[0].indices[1] = _ij0[1];
vinfos[0].maxsolutions = _nj0;
vinfos[1].jointtype = 1;
vinfos[1].foffset = j1;
vinfos[1].indices[0] = _ij1[0];
vinfos[1].indices[1] = _ij1[1];
vinfos[1].maxsolutions = _nj1;
vinfos[2].jointtype = 1;
vinfos[2].foffset = j2;
vinfos[2].indices[0] = _ij2[0];
vinfos[2].indices[1] = _ij2[1];
vinfos[2].maxsolutions = _nj2;
vinfos[3].jointtype = 1;
vinfos[3].foffset = j3;
vinfos[3].indices[0] = _ij3[0];
vinfos[3].indices[1] = _ij3[1];
vinfos[3].maxsolutions = _nj3;
vinfos[4].jointtype = 1;
vinfos[4].foffset = j4;
vinfos[4].indices[0] = _ij4[0];
vinfos[4].indices[1] = _ij4[1];
vinfos[4].maxsolutions = _nj4;
vinfos[5].jointtype = 1;
vinfos[5].foffset = j5;
vinfos[5].indices[0] = _ij5[0];
vinfos[5].indices[1] = _ij5[1];
vinfos[5].maxsolutions = _nj5;
vinfos[6].jointtype = 1;
vinfos[6].foffset = j6;
vinfos[6].indices[0] = _ij6[0];
vinfos[6].indices[1] = _ij6[1];
vinfos[6].maxsolutions = _nj6;
std::vector<int> vfree(0);
solutions.AddSolution(vinfos,vfree);
}
}
}

}

}

} else
{
IkReal x6885=((IkReal(1.00000000000000))*(cj0));
IkReal x6886=((cj4)*(sj6));
IkReal x6887=((sj0)*(sj4));
IkReal x6888=((cj5)*(sj6));
IkReal x6889=((sj4)*(sj5));
IkReal x6890=((r12)*(sj5));
IkReal x6891=((IkReal(0.374290000000000))*(cj5));
IkReal x6892=((r02)*(sj0));
IkReal x6893=((IkReal(1.00000000000000))*(sj0));
IkReal x6894=((cj0)*(r10));
IkReal x6895=((cj4)*(cj6));
IkReal x6896=((r00)*(sj0));
IkReal x6897=((cj6)*(r21));
IkReal x6898=((IkReal(0.374290000000000))*(sj5));
IkReal x6899=((cj0)*(r00));
IkReal x6900=((IkReal(0.0100000000000000))*(sj5));
IkReal x6901=((cj0)*(r02));
IkReal x6902=((cj5)*(sj4));
IkReal x6903=((cj6)*(r01));
IkReal x6904=((cj6)*(r11));
IkReal x6905=((r01)*(sj0));
IkReal x6906=((r10)*(sj0));
IkReal x6907=((IkReal(0.0100000000000000))*(cj5)*(cj6));
IkReal x6908=((sj6)*(x6898));
IkReal x6909=((cj0)*(cj6)*(x6898));
evalcond[0]=((IkReal(-3.14159265358979))+(IKfmod(((IkReal(4.71238898038469))+(j2)), IkReal(6.28318530717959))));
evalcond[1]=((((IkReal(-1.00000000000000))*(r20)*(x6895)))+(((r21)*(x6886)))+(cj1)+(((r20)*(sj4)*(x6888)))+(((r22)*(x6889)))+(((x6897)*(x6902))));
evalcond[2]=((((IkReal(-1.00000000000000))*(r22)*(x6891)))+(((IkReal(0.364420000000000))*(sj1)))+(((x6897)*(x6898)))+(((r20)*(x6908)))+(((IkReal(-1.00000000000000))*(r22)*(x6900)))+(((IkReal(-0.0100000000000000))*(r20)*(x6888)))+(((IkReal(-0.0100000000000000))*(cj5)*(x6897)))+(pz));
evalcond[3]=((((IkReal(-1.00000000000000))*(r11)*(x6885)*(x6886)))+(((x6886)*(x6905)))+(((IkReal(-1.00000000000000))*(r10)*(sj4)*(x6885)*(x6888)))+(((IkReal(-1.00000000000000))*(r00)*(x6893)*(x6895)))+(((x6894)*(x6895)))+(((r00)*(x6887)*(x6888)))+(((IkReal(-1.00000000000000))*(x6885)*(x6902)*(x6904)))+(((IkReal(-1.00000000000000))*(r12)*(x6885)*(x6889)))+(((cj5)*(x6887)*(x6903)))+(((r02)*(sj5)*(x6887))));
evalcond[4]=((((IkReal(-1.00000000000000))*(cj5)*(x6887)*(x6904)))+(((x6895)*(x6906)))+(((IkReal(-1.00000000000000))*(x6885)*(x6902)*(x6903)))+(((IkReal(-1.00000000000000))*(r11)*(x6886)*(x6893)))+(((IkReal(-1.00000000000000))*(r10)*(x6887)*(x6888)))+(((IkReal(-1.00000000000000))*(r00)*(sj4)*(x6885)*(x6888)))+(((x6895)*(x6899)))+(((IkReal(-1.00000000000000))*(r02)*(x6885)*(x6889)))+(((IkReal(-1.00000000000000))*(sj1)))+(((IkReal(-1.00000000000000))*(r01)*(x6885)*(x6886)))+(((IkReal(-1.00000000000000))*(x6887)*(x6890))));
evalcond[5]=((IkReal(-0.0690000000000000))+(((sj0)*(x6898)*(x6903)))+(((IkReal(0.0100000000000000))*(cj0)*(x6890)))+(((IkReal(-1.00000000000000))*(x6891)*(x6892)))+(((IkReal(0.0100000000000000))*(cj0)*(cj5)*(x6904)))+(((IkReal(-0.0100000000000000))*(x6888)*(x6896)))+(((IkReal(-1.00000000000000))*(py)*(x6885)))+(((IkReal(-1.00000000000000))*(x6894)*(x6908)))+(((IkReal(-1.00000000000000))*(x6892)*(x6900)))+(((IkReal(-0.0100000000000000))*(cj5)*(sj0)*(x6903)))+(((cj0)*(r12)*(x6891)))+(((IkReal(0.0100000000000000))*(x6888)*(x6894)))+(((x6896)*(x6908)))+(((px)*(sj0)))+(((IkReal(-1.00000000000000))*(cj0)*(x6898)*(x6904))));
evalcond[6]=((IkReal(0.0690000000000000))+(((x6891)*(x6901)))+(((IkReal(0.0100000000000000))*(x6888)*(x6899)))+(((IkReal(0.0100000000000000))*(cj5)*(sj0)*(x6904)))+(((IkReal(0.0100000000000000))*(x6888)*(x6906)))+(((r12)*(sj0)*(x6891)))+(((IkReal(-1.00000000000000))*(x6906)*(x6908)))+(((IkReal(-1.00000000000000))*(py)*(x6893)))+(((IkReal(-1.00000000000000))*(sj0)*(x6898)*(x6904)))+(((IkReal(0.0100000000000000))*(cj0)*(cj5)*(x6903)))+(((x6900)*(x6901)))+(((IkReal(-1.00000000000000))*(px)*(x6885)))+(((IkReal(-1.00000000000000))*(cj0)*(x6898)*(x6903)))+(((IkReal(-1.00000000000000))*(x6899)*(x6908)))+(((IkReal(0.364420000000000))*(cj1)))+(((IkReal(0.0100000000000000))*(sj0)*(x6890))));
if( IKabs(evalcond[0]) < 0.0000010000000000  && IKabs(evalcond[1]) < 0.0000010000000000  && IKabs(evalcond[2]) < 0.0000010000000000  && IKabs(evalcond[3]) < 0.0000010000000000  && IKabs(evalcond[4]) < 0.0000010000000000  && IKabs(evalcond[5]) < 0.0000010000000000  && IKabs(evalcond[6]) < 0.0000010000000000  )
{
{
IkReal dummyeval[1];
IkReal gconst12;
gconst12=IKsign(sj1);
dummyeval[0]=sj1;
if( IKabs(dummyeval[0]) < 0.0000010000000000  )
{
{
IkReal dummyeval[1];
dummyeval[0]=sj1;
if( IKabs(dummyeval[0]) < 0.0000010000000000  )
{
{
IkReal dummyeval[1];
dummyeval[0]=cj1;
if( IKabs(dummyeval[0]) < 0.0000010000000000  )
{
{
IkReal evalcond[9];
IkReal x6910=((IkReal(1.00000000000000))*(cj0));
IkReal x6911=((cj4)*(sj6));
IkReal x6912=((sj0)*(sj6));
IkReal x6913=((cj5)*(sj4));
IkReal x6914=((IkReal(0.374290000000000))*(sj5));
IkReal x6915=((sj4)*(sj5));
IkReal x6916=((cj0)*(cj6));
IkReal x6917=((IkReal(0.0100000000000000))*(cj5));
IkReal x6918=((cj4)*(sj5));
IkReal x6919=((cj5)*(sj0));
IkReal x6920=((IkReal(0.374290000000000))*(r02));
IkReal x6921=((r20)*(sj6));
IkReal x6922=((cj6)*(r21));
IkReal x6923=((IkReal(1.00000000000000))*(sj0));
IkReal x6924=((cj0)*(sj6));
IkReal x6925=((cj4)*(cj6));
IkReal x6926=((IkReal(0.374290000000000))*(r12));
IkReal x6927=((cj0)*(cj5));
IkReal x6928=((cj6)*(sj5));
IkReal x6929=((cj6)*(r01));
IkReal x6930=((r00)*(sj6));
IkReal x6931=((IkReal(0.0100000000000000))*(sj5));
IkReal x6932=((cj6)*(r11));
IkReal x6933=((IkReal(1.00000000000000))*(r10));
IkReal x6934=((r02)*(sj0));
IkReal x6935=((cj6)*(sj4));
IkReal x6936=((r12)*(x6923));
evalcond[0]=((IkReal(-3.14159265358979))+(IKfmod(((IkReal(1.57079632679490))+(j1)), IkReal(6.28318530717959))));
evalcond[1]=((((r21)*(x6911)))+(((IkReal(-1.00000000000000))*(r20)*(x6925)))+(((x6913)*(x6921)))+(((r22)*(x6915)))+(((x6913)*(x6922))));
evalcond[2]=((IkReal(0.364420000000000))+(((IkReal(-0.374290000000000))*(cj5)*(r22)))+(((x6914)*(x6922)))+(((IkReal(-1.00000000000000))*(x6917)*(x6922)))+(pz)+(((IkReal(-1.00000000000000))*(r22)*(x6931)))+(((x6914)*(x6921)))+(((IkReal(-1.00000000000000))*(x6917)*(x6921))));
evalcond[3]=((((IkReal(-1.00000000000000))*(sj5)*(x6912)*(x6933)))+(((IkReal(-1.00000000000000))*(sj5)*(x6910)*(x6930)))+(((r12)*(x6919)))+(((r02)*(x6927)))+(((IkReal(-1.00000000000000))*(r01)*(x6910)*(x6928)))+(((IkReal(-1.00000000000000))*(r11)*(x6923)*(x6928))));
evalcond[4]=((((r00)*(x6912)*(x6913)))+(((x6915)*(x6934)))+(((cj4)*(r10)*(x6916)))+(((r01)*(sj0)*(x6911)))+(((IkReal(-1.00000000000000))*(r12)*(x6910)*(x6915)))+(((sj0)*(x6913)*(x6929)))+(((IkReal(-1.00000000000000))*(r11)*(x6910)*(x6911)))+(((IkReal(-1.00000000000000))*(r00)*(x6923)*(x6925)))+(((IkReal(-1.00000000000000))*(x6910)*(x6913)*(x6932)))+(((IkReal(-1.00000000000000))*(r10)*(sj6)*(x6910)*(x6913))));
evalcond[5]=((IkReal(-1.00000000000000))+(((IkReal(-1.00000000000000))*(r01)*(x6910)*(x6911)))+(((IkReal(-1.00000000000000))*(r11)*(x6911)*(x6923)))+(((IkReal(-1.00000000000000))*(x6913)*(x6923)*(x6932)))+(((IkReal(-1.00000000000000))*(x6915)*(x6936)))+(((r10)*(sj0)*(x6925)))+(((IkReal(-1.00000000000000))*(r02)*(x6910)*(x6915)))+(((IkReal(-1.00000000000000))*(x6910)*(x6913)*(x6930)))+(((cj4)*(r00)*(x6916)))+(((IkReal(-1.00000000000000))*(x6910)*(x6913)*(x6929)))+(((IkReal(-1.00000000000000))*(x6912)*(x6913)*(x6933))));
evalcond[6]=((IkReal(-0.0690000000000000))+(((IkReal(-1.00000000000000))*(r11)*(x6914)*(x6916)))+(((cj0)*(r12)*(x6931)))+(((IkReal(-1.00000000000000))*(sj0)*(x6917)*(x6929)))+(((r11)*(x6916)*(x6917)))+(((IkReal(-1.00000000000000))*(r00)*(x6912)*(x6917)))+(((r00)*(x6912)*(x6914)))+(((x6926)*(x6927)))+(((IkReal(-1.00000000000000))*(x6919)*(x6920)))+(((IkReal(-1.00000000000000))*(r10)*(x6914)*(x6924)))+(((IkReal(-1.00000000000000))*(x6931)*(x6934)))+(((px)*(sj0)))+(((IkReal(-1.00000000000000))*(py)*(x6910)))+(((sj0)*(x6914)*(x6929)))+(((r10)*(x6917)*(x6924))));
evalcond[7]=((((IkReal(-1.00000000000000))*(cj5)*(r01)*(x6910)*(x6925)))+(((IkReal(-1.00000000000000))*(r02)*(x6910)*(x6918)))+(((IkReal(-1.00000000000000))*(r11)*(x6919)*(x6925)))+(((IkReal(-1.00000000000000))*(r00)*(x6910)*(x6935)))+(((IkReal(-1.00000000000000))*(x6918)*(x6936)))+(((IkReal(-1.00000000000000))*(cj5)*(r00)*(x6910)*(x6911)))+(((IkReal(-1.00000000000000))*(r10)*(x6923)*(x6935)))+(((IkReal(-1.00000000000000))*(x6911)*(x6919)*(x6933)))+(((r11)*(sj4)*(x6912)))+(((r01)*(sj4)*(x6924))));
evalcond[8]=((IkReal(0.0690000000000000))+(((cj0)*(r02)*(x6931)))+(((sj0)*(x6917)*(x6932)))+(((r10)*(x6912)*(x6917)))+(((IkReal(-1.00000000000000))*(r10)*(x6912)*(x6914)))+(((IkReal(-1.00000000000000))*(py)*(x6923)))+(((IkReal(-1.00000000000000))*(r01)*(x6914)*(x6916)))+(((x6920)*(x6927)))+(((r12)*(sj0)*(x6931)))+(((IkReal(-1.00000000000000))*(px)*(x6910)))+(((IkReal(-1.00000000000000))*(sj0)*(x6914)*(x6932)))+(((r01)*(x6916)*(x6917)))+(((r00)*(x6917)*(x6924)))+(((x6919)*(x6926)))+(((IkReal(-1.00000000000000))*(r00)*(x6914)*(x6924))));
if( IKabs(evalcond[0]) < 0.0000010000000000  && IKabs(evalcond[1]) < 0.0000010000000000  && IKabs(evalcond[2]) < 0.0000010000000000  && IKabs(evalcond[3]) < 0.0000010000000000  && IKabs(evalcond[4]) < 0.0000010000000000  && IKabs(evalcond[5]) < 0.0000010000000000  && IKabs(evalcond[6]) < 0.0000010000000000  && IKabs(evalcond[7]) < 0.0000010000000000  && IKabs(evalcond[8]) < 0.0000010000000000  )
{
{
IkReal j3array[1], cj3array[1], sj3array[1];
bool j3valid[1]={false};
_nj3 = 1;
IkReal x6937=((r20)*(sj6));
IkReal x6938=((cj4)*(cj5));
IkReal x6939=((cj6)*(r21));
if( IKabs(((((IkReal(-1.00000000000000))*(r21)*(sj4)*(sj6)))+(((cj6)*(r20)*(sj4)))+(((cj4)*(r22)*(sj5)))+(((x6937)*(x6938)))+(((x6938)*(x6939))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(((((IkReal(-1.00000000000000))*(cj5)*(r22)))+(((sj5)*(x6939)))+(((sj5)*(x6937))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(IKsqr(((((IkReal(-1.00000000000000))*(r21)*(sj4)*(sj6)))+(((cj6)*(r20)*(sj4)))+(((cj4)*(r22)*(sj5)))+(((x6937)*(x6938)))+(((x6938)*(x6939)))))+IKsqr(((((IkReal(-1.00000000000000))*(cj5)*(r22)))+(((sj5)*(x6939)))+(((sj5)*(x6937)))))-1) <= IKFAST_SINCOS_THRESH )
    continue;
j3array[0]=IKatan2(((((IkReal(-1.00000000000000))*(r21)*(sj4)*(sj6)))+(((cj6)*(r20)*(sj4)))+(((cj4)*(r22)*(sj5)))+(((x6937)*(x6938)))+(((x6938)*(x6939)))), ((((IkReal(-1.00000000000000))*(cj5)*(r22)))+(((sj5)*(x6939)))+(((sj5)*(x6937)))));
sj3array[0]=IKsin(j3array[0]);
cj3array[0]=IKcos(j3array[0]);
if( j3array[0] > IKPI )
{
    j3array[0]-=IK2PI;
}
else if( j3array[0] < -IKPI )
{    j3array[0]+=IK2PI;
}
j3valid[0] = true;
for(int ij3 = 0; ij3 < 1; ++ij3)
{
if( !j3valid[ij3] )
{
    continue;
}
_ij3[0] = ij3; _ij3[1] = -1;
for(int iij3 = ij3+1; iij3 < 1; ++iij3)
{
if( j3valid[iij3] && IKabs(cj3array[ij3]-cj3array[iij3]) < IKFAST_SOLUTION_THRESH && IKabs(sj3array[ij3]-sj3array[iij3]) < IKFAST_SOLUTION_THRESH )
{
    j3valid[iij3]=false; _ij3[1] = iij3; break; 
}
}
j3 = j3array[ij3]; cj3 = cj3array[ij3]; sj3 = sj3array[ij3];
{
IkReal evalcond[4];
IkReal x6940=IKsin(j3);
IkReal x6941=((sj0)*(sj5));
IkReal x6942=((r00)*(sj6));
IkReal x6943=((cj6)*(r01));
IkReal x6944=((cj5)*(sj0));
IkReal x6945=((cj0)*(cj5));
IkReal x6946=((cj6)*(sj4));
IkReal x6947=((sj4)*(sj6));
IkReal x6948=((cj0)*(r11));
IkReal x6949=((cj4)*(cj6));
IkReal x6950=((cj4)*(sj6));
IkReal x6951=((IkReal(1.00000000000000))*(cj0));
IkReal x6952=((cj4)*(sj5));
IkReal x6953=((sj5)*(sj6));
IkReal x6954=((cj6)*(sj5));
IkReal x6955=((IkReal(1.00000000000000))*(IKcos(j3)));
evalcond[0]=((((IkReal(-1.00000000000000))*(x6955)))+(((IkReal(-1.00000000000000))*(cj5)*(r22)))+(((r20)*(x6953)))+(((r21)*(x6954))));
evalcond[1]=((((IkReal(-1.00000000000000))*(x6940)))+(((r20)*(x6946)))+(((IkReal(-1.00000000000000))*(r21)*(x6947)))+(((r22)*(x6952)))+(((cj5)*(r20)*(x6950)))+(((cj5)*(r21)*(x6949))));
evalcond[2]=((((x6941)*(x6942)))+(x6940)+(((x6941)*(x6943)))+(((r12)*(x6945)))+(((IkReal(-1.00000000000000))*(x6948)*(x6954)))+(((IkReal(-1.00000000000000))*(r02)*(x6944)))+(((IkReal(-1.00000000000000))*(r10)*(x6951)*(x6953))));
evalcond[3]=((((IkReal(-1.00000000000000))*(x6955)))+(((cj4)*(x6942)*(x6944)))+(((IkReal(-1.00000000000000))*(r10)*(x6945)*(x6950)))+(((x6947)*(x6948)))+(((IkReal(-1.00000000000000))*(r10)*(x6946)*(x6951)))+(((r00)*(sj0)*(x6946)))+(((IkReal(-1.00000000000000))*(r12)*(x6951)*(x6952)))+(((IkReal(-1.00000000000000))*(r01)*(sj0)*(x6947)))+(((cj4)*(r02)*(x6941)))+(((IkReal(-1.00000000000000))*(r11)*(x6945)*(x6949)))+(((cj4)*(x6943)*(x6944))));
if( IKabs(evalcond[0]) > 0.000001  || IKabs(evalcond[1]) > 0.000001  || IKabs(evalcond[2]) > 0.000001  || IKabs(evalcond[3]) > 0.000001  )
{
continue;
}
}

{
std::vector<IkSingleDOFSolutionBase<IkReal> > vinfos(7);
vinfos[0].jointtype = 1;
vinfos[0].foffset = j0;
vinfos[0].indices[0] = _ij0[0];
vinfos[0].indices[1] = _ij0[1];
vinfos[0].maxsolutions = _nj0;
vinfos[1].jointtype = 1;
vinfos[1].foffset = j1;
vinfos[1].indices[0] = _ij1[0];
vinfos[1].indices[1] = _ij1[1];
vinfos[1].maxsolutions = _nj1;
vinfos[2].jointtype = 1;
vinfos[2].foffset = j2;
vinfos[2].indices[0] = _ij2[0];
vinfos[2].indices[1] = _ij2[1];
vinfos[2].maxsolutions = _nj2;
vinfos[3].jointtype = 1;
vinfos[3].foffset = j3;
vinfos[3].indices[0] = _ij3[0];
vinfos[3].indices[1] = _ij3[1];
vinfos[3].maxsolutions = _nj3;
vinfos[4].jointtype = 1;
vinfos[4].foffset = j4;
vinfos[4].indices[0] = _ij4[0];
vinfos[4].indices[1] = _ij4[1];
vinfos[4].maxsolutions = _nj4;
vinfos[5].jointtype = 1;
vinfos[5].foffset = j5;
vinfos[5].indices[0] = _ij5[0];
vinfos[5].indices[1] = _ij5[1];
vinfos[5].maxsolutions = _nj5;
vinfos[6].jointtype = 1;
vinfos[6].foffset = j6;
vinfos[6].indices[0] = _ij6[0];
vinfos[6].indices[1] = _ij6[1];
vinfos[6].maxsolutions = _nj6;
std::vector<int> vfree(0);
solutions.AddSolution(vinfos,vfree);
}
}
}

} else
{
IkReal x6956=((IkReal(1.00000000000000))*(cj0));
IkReal x6957=((cj4)*(sj6));
IkReal x6958=((sj0)*(sj6));
IkReal x6959=((cj5)*(sj4));
IkReal x6960=((IkReal(0.374290000000000))*(sj5));
IkReal x6961=((sj4)*(sj5));
IkReal x6962=((cj0)*(cj6));
IkReal x6963=((IkReal(0.0100000000000000))*(cj5));
IkReal x6964=((cj4)*(sj5));
IkReal x6965=((cj5)*(sj0));
IkReal x6966=((IkReal(0.374290000000000))*(r02));
IkReal x6967=((r20)*(sj6));
IkReal x6968=((cj6)*(r21));
IkReal x6969=((IkReal(1.00000000000000))*(sj0));
IkReal x6970=((cj0)*(sj6));
IkReal x6971=((cj4)*(cj6));
IkReal x6972=((IkReal(0.374290000000000))*(r12));
IkReal x6973=((cj0)*(cj5));
IkReal x6974=((cj6)*(sj5));
IkReal x6975=((cj6)*(r01));
IkReal x6976=((r00)*(sj6));
IkReal x6977=((IkReal(0.0100000000000000))*(sj5));
IkReal x6978=((cj6)*(r11));
IkReal x6979=((IkReal(1.00000000000000))*(r10));
IkReal x6980=((r02)*(sj0));
IkReal x6981=((cj6)*(sj4));
IkReal x6982=((r12)*(x6969));
evalcond[0]=((IkReal(-3.14159265358979))+(IKfmod(((IkReal(4.71238898038469))+(j1)), IkReal(6.28318530717959))));
evalcond[1]=((((IkReal(-1.00000000000000))*(r20)*(x6971)))+(((r21)*(x6957)))+(((x6959)*(x6968)))+(((r22)*(x6961)))+(((x6959)*(x6967))));
evalcond[2]=((IkReal(-0.364420000000000))+(((IkReal(-1.00000000000000))*(r22)*(x6977)))+(((IkReal(-0.374290000000000))*(cj5)*(r22)))+(pz)+(((IkReal(-1.00000000000000))*(x6963)*(x6968)))+(((IkReal(-1.00000000000000))*(x6963)*(x6967)))+(((x6960)*(x6967)))+(((x6960)*(x6968))));
evalcond[3]=((((IkReal(-1.00000000000000))*(r01)*(x6956)*(x6974)))+(((IkReal(-1.00000000000000))*(r11)*(x6969)*(x6974)))+(((IkReal(-1.00000000000000))*(sj5)*(x6958)*(x6979)))+(((r02)*(x6973)))+(((r12)*(x6965)))+(((IkReal(-1.00000000000000))*(sj5)*(x6956)*(x6976))));
evalcond[4]=((((r00)*(x6958)*(x6959)))+(((IkReal(-1.00000000000000))*(r11)*(x6956)*(x6957)))+(((cj4)*(r10)*(x6962)))+(((IkReal(-1.00000000000000))*(r10)*(sj6)*(x6956)*(x6959)))+(((IkReal(-1.00000000000000))*(r12)*(x6956)*(x6961)))+(((IkReal(-1.00000000000000))*(r00)*(x6969)*(x6971)))+(((r01)*(sj0)*(x6957)))+(((IkReal(-1.00000000000000))*(x6956)*(x6959)*(x6978)))+(((sj0)*(x6959)*(x6975)))+(((x6961)*(x6980))));
evalcond[5]=((IkReal(1.00000000000000))+(((IkReal(-1.00000000000000))*(r01)*(x6956)*(x6957)))+(((cj4)*(r00)*(x6962)))+(((r10)*(sj0)*(x6971)))+(((IkReal(-1.00000000000000))*(r11)*(x6957)*(x6969)))+(((IkReal(-1.00000000000000))*(x6958)*(x6959)*(x6979)))+(((IkReal(-1.00000000000000))*(x6956)*(x6959)*(x6975)))+(((IkReal(-1.00000000000000))*(x6959)*(x6969)*(x6978)))+(((IkReal(-1.00000000000000))*(r02)*(x6956)*(x6961)))+(((IkReal(-1.00000000000000))*(x6961)*(x6982)))+(((IkReal(-1.00000000000000))*(x6956)*(x6959)*(x6976))));
evalcond[6]=((IkReal(-0.0690000000000000))+(((r11)*(x6962)*(x6963)))+(((r10)*(x6963)*(x6970)))+(((IkReal(-1.00000000000000))*(sj0)*(x6963)*(x6975)))+(((sj0)*(x6960)*(x6975)))+(((IkReal(-1.00000000000000))*(r10)*(x6960)*(x6970)))+(((IkReal(-1.00000000000000))*(x6977)*(x6980)))+(((IkReal(-1.00000000000000))*(py)*(x6956)))+(((IkReal(-1.00000000000000))*(x6965)*(x6966)))+(((x6972)*(x6973)))+(((cj0)*(r12)*(x6977)))+(((IkReal(-1.00000000000000))*(r00)*(x6958)*(x6963)))+(((r00)*(x6958)*(x6960)))+(((px)*(sj0)))+(((IkReal(-1.00000000000000))*(r11)*(x6960)*(x6962))));
evalcond[7]=((((r01)*(sj4)*(x6970)))+(((IkReal(-1.00000000000000))*(r10)*(x6969)*(x6981)))+(((IkReal(-1.00000000000000))*(r00)*(x6956)*(x6981)))+(((IkReal(-1.00000000000000))*(r11)*(x6965)*(x6971)))+(((IkReal(-1.00000000000000))*(cj5)*(r00)*(x6956)*(x6957)))+(((r11)*(sj4)*(x6958)))+(((IkReal(-1.00000000000000))*(r02)*(x6956)*(x6964)))+(((IkReal(-1.00000000000000))*(cj5)*(r01)*(x6956)*(x6971)))+(((IkReal(-1.00000000000000))*(x6964)*(x6982)))+(((IkReal(-1.00000000000000))*(x6957)*(x6965)*(x6979))));
evalcond[8]=((IkReal(0.0690000000000000))+(((IkReal(-1.00000000000000))*(r01)*(x6960)*(x6962)))+(((x6966)*(x6973)))+(((sj0)*(x6963)*(x6978)))+(((cj0)*(r02)*(x6977)))+(((r00)*(x6963)*(x6970)))+(((x6965)*(x6972)))+(((r12)*(sj0)*(x6977)))+(((IkReal(-1.00000000000000))*(r10)*(x6958)*(x6960)))+(((IkReal(-1.00000000000000))*(px)*(x6956)))+(((IkReal(-1.00000000000000))*(r00)*(x6960)*(x6970)))+(((IkReal(-1.00000000000000))*(py)*(x6969)))+(((IkReal(-1.00000000000000))*(sj0)*(x6960)*(x6978)))+(((r01)*(x6962)*(x6963)))+(((r10)*(x6958)*(x6963))));
if( IKabs(evalcond[0]) < 0.0000010000000000  && IKabs(evalcond[1]) < 0.0000010000000000  && IKabs(evalcond[2]) < 0.0000010000000000  && IKabs(evalcond[3]) < 0.0000010000000000  && IKabs(evalcond[4]) < 0.0000010000000000  && IKabs(evalcond[5]) < 0.0000010000000000  && IKabs(evalcond[6]) < 0.0000010000000000  && IKabs(evalcond[7]) < 0.0000010000000000  && IKabs(evalcond[8]) < 0.0000010000000000  )
{
{
IkReal j3array[1], cj3array[1], sj3array[1];
bool j3valid[1]={false};
_nj3 = 1;
IkReal x6983=((IkReal(1.00000000000000))*(sj5));
IkReal x6984=((cj6)*(r21));
IkReal x6985=((r20)*(sj6));
IkReal x6986=((IkReal(1.00000000000000))*(cj4)*(cj5));
if( IKabs(((((IkReal(-1.00000000000000))*(x6984)*(x6986)))+(((IkReal(-1.00000000000000))*(cj4)*(r22)*(x6983)))+(((IkReal(-1.00000000000000))*(x6985)*(x6986)))+(((r21)*(sj4)*(sj6)))+(((IkReal(-1.00000000000000))*(cj6)*(r20)*(sj4))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(((((IkReal(-1.00000000000000))*(x6983)*(x6984)))+(((IkReal(-1.00000000000000))*(x6983)*(x6985)))+(((cj5)*(r22))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(IKsqr(((((IkReal(-1.00000000000000))*(x6984)*(x6986)))+(((IkReal(-1.00000000000000))*(cj4)*(r22)*(x6983)))+(((IkReal(-1.00000000000000))*(x6985)*(x6986)))+(((r21)*(sj4)*(sj6)))+(((IkReal(-1.00000000000000))*(cj6)*(r20)*(sj4)))))+IKsqr(((((IkReal(-1.00000000000000))*(x6983)*(x6984)))+(((IkReal(-1.00000000000000))*(x6983)*(x6985)))+(((cj5)*(r22)))))-1) <= IKFAST_SINCOS_THRESH )
    continue;
j3array[0]=IKatan2(((((IkReal(-1.00000000000000))*(x6984)*(x6986)))+(((IkReal(-1.00000000000000))*(cj4)*(r22)*(x6983)))+(((IkReal(-1.00000000000000))*(x6985)*(x6986)))+(((r21)*(sj4)*(sj6)))+(((IkReal(-1.00000000000000))*(cj6)*(r20)*(sj4)))), ((((IkReal(-1.00000000000000))*(x6983)*(x6984)))+(((IkReal(-1.00000000000000))*(x6983)*(x6985)))+(((cj5)*(r22)))));
sj3array[0]=IKsin(j3array[0]);
cj3array[0]=IKcos(j3array[0]);
if( j3array[0] > IKPI )
{
    j3array[0]-=IK2PI;
}
else if( j3array[0] < -IKPI )
{    j3array[0]+=IK2PI;
}
j3valid[0] = true;
for(int ij3 = 0; ij3 < 1; ++ij3)
{
if( !j3valid[ij3] )
{
    continue;
}
_ij3[0] = ij3; _ij3[1] = -1;
for(int iij3 = ij3+1; iij3 < 1; ++iij3)
{
if( j3valid[iij3] && IKabs(cj3array[ij3]-cj3array[iij3]) < IKFAST_SOLUTION_THRESH && IKabs(sj3array[ij3]-sj3array[iij3]) < IKFAST_SOLUTION_THRESH )
{
    j3valid[iij3]=false; _ij3[1] = iij3; break; 
}
}
j3 = j3array[ij3]; cj3 = cj3array[ij3]; sj3 = sj3array[ij3];
{
IkReal evalcond[4];
IkReal x6987=IKsin(j3);
IkReal x6988=IKcos(j3);
IkReal x6989=((sj0)*(sj5));
IkReal x6990=((r00)*(sj6));
IkReal x6991=((cj6)*(r01));
IkReal x6992=((cj0)*(cj5));
IkReal x6993=((IkReal(1.00000000000000))*(cj5));
IkReal x6994=((cj4)*(cj5));
IkReal x6995=((cj6)*(sj4));
IkReal x6996=((sj4)*(sj6));
IkReal x6997=((cj0)*(r11));
IkReal x6998=((IkReal(1.00000000000000))*(cj4));
IkReal x6999=((cj6)*(r21));
IkReal x7000=((r20)*(sj6));
IkReal x7001=((cj0)*(sj5));
IkReal x7002=((r10)*(sj6));
evalcond[0]=((((sj5)*(x7000)))+(x6988)+(((sj5)*(x6999)))+(((IkReal(-1.00000000000000))*(r22)*(x6993))));
evalcond[1]=((((x6994)*(x6999)))+(((r20)*(x6995)))+(((IkReal(-1.00000000000000))*(r21)*(x6996)))+(((cj4)*(r22)*(sj5)))+(x6987)+(((x6994)*(x7000))));
evalcond[2]=((((IkReal(-1.00000000000000))*(cj6)*(sj5)*(x6997)))+(((IkReal(-1.00000000000000))*(r02)*(sj0)*(x6993)))+(((r12)*(x6992)))+(x6987)+(((IkReal(-1.00000000000000))*(x7001)*(x7002)))+(((x6989)*(x6990)))+(((x6989)*(x6991))));
evalcond[3]=((((IkReal(-1.00000000000000))*(x6992)*(x6998)*(x7002)))+(((IkReal(-1.00000000000000))*(r01)*(sj0)*(x6996)))+(((x6996)*(x6997)))+(((cj4)*(r02)*(x6989)))+(((IkReal(-1.00000000000000))*(x6988)))+(((r00)*(sj0)*(x6995)))+(((IkReal(-1.00000000000000))*(cj0)*(r10)*(x6995)))+(((IkReal(-1.00000000000000))*(cj6)*(r11)*(x6992)*(x6998)))+(((sj0)*(x6990)*(x6994)))+(((IkReal(-1.00000000000000))*(r12)*(x6998)*(x7001)))+(((sj0)*(x6991)*(x6994))));
if( IKabs(evalcond[0]) > 0.000001  || IKabs(evalcond[1]) > 0.000001  || IKabs(evalcond[2]) > 0.000001  || IKabs(evalcond[3]) > 0.000001  )
{
continue;
}
}

{
std::vector<IkSingleDOFSolutionBase<IkReal> > vinfos(7);
vinfos[0].jointtype = 1;
vinfos[0].foffset = j0;
vinfos[0].indices[0] = _ij0[0];
vinfos[0].indices[1] = _ij0[1];
vinfos[0].maxsolutions = _nj0;
vinfos[1].jointtype = 1;
vinfos[1].foffset = j1;
vinfos[1].indices[0] = _ij1[0];
vinfos[1].indices[1] = _ij1[1];
vinfos[1].maxsolutions = _nj1;
vinfos[2].jointtype = 1;
vinfos[2].foffset = j2;
vinfos[2].indices[0] = _ij2[0];
vinfos[2].indices[1] = _ij2[1];
vinfos[2].maxsolutions = _nj2;
vinfos[3].jointtype = 1;
vinfos[3].foffset = j3;
vinfos[3].indices[0] = _ij3[0];
vinfos[3].indices[1] = _ij3[1];
vinfos[3].maxsolutions = _nj3;
vinfos[4].jointtype = 1;
vinfos[4].foffset = j4;
vinfos[4].indices[0] = _ij4[0];
vinfos[4].indices[1] = _ij4[1];
vinfos[4].maxsolutions = _nj4;
vinfos[5].jointtype = 1;
vinfos[5].foffset = j5;
vinfos[5].indices[0] = _ij5[0];
vinfos[5].indices[1] = _ij5[1];
vinfos[5].maxsolutions = _nj5;
vinfos[6].jointtype = 1;
vinfos[6].foffset = j6;
vinfos[6].indices[0] = _ij6[0];
vinfos[6].indices[1] = _ij6[1];
vinfos[6].maxsolutions = _nj6;
std::vector<int> vfree(0);
solutions.AddSolution(vinfos,vfree);
}
}
}

} else
{
if( 1 )
{
continue;

} else
{
}
}
}
}

} else
{
{
IkReal j3array[1], cj3array[1], sj3array[1];
bool j3valid[1]={false};
_nj3 = 1;
IkReal x7003=((cj5)*(r02));
IkReal x7004=((cj0)*(sj5));
IkReal x7005=((r10)*(sj6));
IkReal x7006=((IkReal(1.00000000000000))*(cj6));
IkReal x7007=((sj0)*(sj5));
IkReal x7008=((cj5)*(r12));
IkReal x7009=((IkReal(1.00000000000000))*(r00)*(sj6));
if( IKabs(((((IkReal(-1.00000000000000))*(cj0)*(x7008)))+(((x7004)*(x7005)))+(((IkReal(-1.00000000000000))*(r01)*(x7006)*(x7007)))+(((cj6)*(r11)*(x7004)))+(((sj0)*(x7003)))+(((IkReal(-1.00000000000000))*(x7007)*(x7009))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(((((IKabs(cj1) != 0)?((IkReal)1/(cj1)):(IkReal)1.0e30))*(((((IkReal(-1.00000000000000))*(r01)*(x7004)*(x7006)))+(((cj0)*(x7003)))+(((IkReal(-1.00000000000000))*(x7005)*(x7007)))+(((sj0)*(x7008)))+(((IkReal(-1.00000000000000))*(r11)*(x7006)*(x7007)))+(((IkReal(-1.00000000000000))*(x7004)*(x7009))))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(IKsqr(((((IkReal(-1.00000000000000))*(cj0)*(x7008)))+(((x7004)*(x7005)))+(((IkReal(-1.00000000000000))*(r01)*(x7006)*(x7007)))+(((cj6)*(r11)*(x7004)))+(((sj0)*(x7003)))+(((IkReal(-1.00000000000000))*(x7007)*(x7009)))))+IKsqr(((((IKabs(cj1) != 0)?((IkReal)1/(cj1)):(IkReal)1.0e30))*(((((IkReal(-1.00000000000000))*(r01)*(x7004)*(x7006)))+(((cj0)*(x7003)))+(((IkReal(-1.00000000000000))*(x7005)*(x7007)))+(((sj0)*(x7008)))+(((IkReal(-1.00000000000000))*(r11)*(x7006)*(x7007)))+(((IkReal(-1.00000000000000))*(x7004)*(x7009)))))))-1) <= IKFAST_SINCOS_THRESH )
    continue;
j3array[0]=IKatan2(((((IkReal(-1.00000000000000))*(cj0)*(x7008)))+(((x7004)*(x7005)))+(((IkReal(-1.00000000000000))*(r01)*(x7006)*(x7007)))+(((cj6)*(r11)*(x7004)))+(((sj0)*(x7003)))+(((IkReal(-1.00000000000000))*(x7007)*(x7009)))), ((((IKabs(cj1) != 0)?((IkReal)1/(cj1)):(IkReal)1.0e30))*(((((IkReal(-1.00000000000000))*(r01)*(x7004)*(x7006)))+(((cj0)*(x7003)))+(((IkReal(-1.00000000000000))*(x7005)*(x7007)))+(((sj0)*(x7008)))+(((IkReal(-1.00000000000000))*(r11)*(x7006)*(x7007)))+(((IkReal(-1.00000000000000))*(x7004)*(x7009)))))));
sj3array[0]=IKsin(j3array[0]);
cj3array[0]=IKcos(j3array[0]);
if( j3array[0] > IKPI )
{
    j3array[0]-=IK2PI;
}
else if( j3array[0] < -IKPI )
{    j3array[0]+=IK2PI;
}
j3valid[0] = true;
for(int ij3 = 0; ij3 < 1; ++ij3)
{
if( !j3valid[ij3] )
{
    continue;
}
_ij3[0] = ij3; _ij3[1] = -1;
for(int iij3 = ij3+1; iij3 < 1; ++iij3)
{
if( j3valid[iij3] && IKabs(cj3array[ij3]-cj3array[iij3]) < IKFAST_SOLUTION_THRESH && IKabs(sj3array[ij3]-sj3array[iij3]) < IKFAST_SOLUTION_THRESH )
{
    j3valid[iij3]=false; _ij3[1] = iij3; break; 
}
}
j3 = j3array[ij3]; cj3 = cj3array[ij3]; sj3 = sj3array[ij3];
{
IkReal evalcond[6];
IkReal x7010=IKsin(j3);
IkReal x7011=IKcos(j3);
IkReal x7012=((sj0)*(sj5));
IkReal x7013=((r00)*(sj6));
IkReal x7014=((IkReal(1.00000000000000))*(cj4));
IkReal x7015=((cj6)*(r01));
IkReal x7016=((cj0)*(cj5));
IkReal x7017=((cj5)*(sj0));
IkReal x7018=((cj6)*(r11));
IkReal x7019=((cj0)*(sj5));
IkReal x7020=((IkReal(1.00000000000000))*(cj1));
IkReal x7021=((cj6)*(sj4));
IkReal x7022=((IkReal(1.00000000000000))*(sj1));
IkReal x7023=((cj4)*(cj5));
IkReal x7024=((cj6)*(r21));
IkReal x7025=((r20)*(sj6));
IkReal x7026=((r10)*(sj6));
IkReal x7027=((IkReal(1.00000000000000))*(cj0));
IkReal x7028=((cj0)*(sj4)*(sj6));
IkReal x7029=((sj0)*(sj4)*(sj6));
evalcond[0]=((((IkReal(-1.00000000000000))*(x7011)*(x7022)))+(((IkReal(-1.00000000000000))*(cj5)*(r22)))+(((sj5)*(x7024)))+(((sj5)*(x7025))));
evalcond[1]=((((IkReal(-1.00000000000000))*(r21)*(sj4)*(sj6)))+(((r20)*(x7021)))+(((x7023)*(x7024)))+(((x7023)*(x7025)))+(((cj4)*(r22)*(sj5)))+(((IkReal(-1.00000000000000))*(x7010)*(x7022))));
evalcond[2]=((((x7012)*(x7015)))+(((r12)*(x7016)))+(x7010)+(((x7012)*(x7013)))+(((IkReal(-1.00000000000000))*(x7019)*(x7026)))+(((IkReal(-1.00000000000000))*(r02)*(x7017)))+(((IkReal(-1.00000000000000))*(x7018)*(x7019))));
evalcond[3]=((((r12)*(x7017)))+(((IkReal(-1.00000000000000))*(x7015)*(x7019)))+(((IkReal(-1.00000000000000))*(x7012)*(x7018)))+(((r02)*(x7016)))+(((IkReal(-1.00000000000000))*(x7013)*(x7019)))+(((IkReal(-1.00000000000000))*(x7011)*(x7020)))+(((IkReal(-1.00000000000000))*(x7012)*(x7026))));
evalcond[4]=((((IkReal(-1.00000000000000))*(r10)*(x7021)*(x7027)))+(((r00)*(sj0)*(x7021)))+(((cj4)*(x7015)*(x7017)))+(((IkReal(-1.00000000000000))*(r01)*(x7029)))+(((cj4)*(r02)*(x7012)))+(((cj4)*(x7013)*(x7017)))+(((IkReal(-1.00000000000000))*(x7011)))+(((IkReal(-1.00000000000000))*(x7014)*(x7016)*(x7026)))+(((IkReal(-1.00000000000000))*(x7014)*(x7016)*(x7018)))+(((r11)*(x7028)))+(((IkReal(-1.00000000000000))*(r12)*(x7014)*(x7019))));
evalcond[5]=((((IkReal(-1.00000000000000))*(x7014)*(x7017)*(x7026)))+(((IkReal(-1.00000000000000))*(x7013)*(x7014)*(x7016)))+(((IkReal(-1.00000000000000))*(r02)*(x7014)*(x7019)))+(((IkReal(-1.00000000000000))*(x7014)*(x7017)*(x7018)))+(((IkReal(-1.00000000000000))*(x7014)*(x7015)*(x7016)))+(((r01)*(x7028)))+(((IkReal(-1.00000000000000))*(r00)*(x7021)*(x7027)))+(((IkReal(-1.00000000000000))*(x7010)*(x7020)))+(((IkReal(-1.00000000000000))*(r12)*(x7012)*(x7014)))+(((IkReal(-1.00000000000000))*(r10)*(sj0)*(x7021)))+(((r11)*(x7029))));
if( IKabs(evalcond[0]) > 0.000001  || IKabs(evalcond[1]) > 0.000001  || IKabs(evalcond[2]) > 0.000001  || IKabs(evalcond[3]) > 0.000001  || IKabs(evalcond[4]) > 0.000001  || IKabs(evalcond[5]) > 0.000001  )
{
continue;
}
}

{
std::vector<IkSingleDOFSolutionBase<IkReal> > vinfos(7);
vinfos[0].jointtype = 1;
vinfos[0].foffset = j0;
vinfos[0].indices[0] = _ij0[0];
vinfos[0].indices[1] = _ij0[1];
vinfos[0].maxsolutions = _nj0;
vinfos[1].jointtype = 1;
vinfos[1].foffset = j1;
vinfos[1].indices[0] = _ij1[0];
vinfos[1].indices[1] = _ij1[1];
vinfos[1].maxsolutions = _nj1;
vinfos[2].jointtype = 1;
vinfos[2].foffset = j2;
vinfos[2].indices[0] = _ij2[0];
vinfos[2].indices[1] = _ij2[1];
vinfos[2].maxsolutions = _nj2;
vinfos[3].jointtype = 1;
vinfos[3].foffset = j3;
vinfos[3].indices[0] = _ij3[0];
vinfos[3].indices[1] = _ij3[1];
vinfos[3].maxsolutions = _nj3;
vinfos[4].jointtype = 1;
vinfos[4].foffset = j4;
vinfos[4].indices[0] = _ij4[0];
vinfos[4].indices[1] = _ij4[1];
vinfos[4].maxsolutions = _nj4;
vinfos[5].jointtype = 1;
vinfos[5].foffset = j5;
vinfos[5].indices[0] = _ij5[0];
vinfos[5].indices[1] = _ij5[1];
vinfos[5].maxsolutions = _nj5;
vinfos[6].jointtype = 1;
vinfos[6].foffset = j6;
vinfos[6].indices[0] = _ij6[0];
vinfos[6].indices[1] = _ij6[1];
vinfos[6].maxsolutions = _nj6;
std::vector<int> vfree(0);
solutions.AddSolution(vinfos,vfree);
}
}
}

}

}

} else
{
{
IkReal j3array[1], cj3array[1], sj3array[1];
bool j3valid[1]={false};
_nj3 = 1;
IkReal x7030=((sj5)*(sj6));
IkReal x7031=((IkReal(1.00000000000000))*(sj0));
IkReal x7032=((cj6)*(sj5));
IkReal x7033=((IkReal(1.00000000000000))*(cj5));
if( IKabs(((((IkReal(-1.00000000000000))*(r00)*(x7030)*(x7031)))+(((cj5)*(r02)*(sj0)))+(((IkReal(-1.00000000000000))*(cj0)*(r12)*(x7033)))+(((cj0)*(r11)*(x7032)))+(((cj0)*(r10)*(x7030)))+(((IkReal(-1.00000000000000))*(r01)*(x7031)*(x7032))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(((((IKabs(sj1) != 0)?((IkReal)1/(sj1)):(IkReal)1.0e30))*(((((IkReal(-1.00000000000000))*(r22)*(x7033)))+(((r21)*(x7032)))+(((r20)*(x7030))))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(IKsqr(((((IkReal(-1.00000000000000))*(r00)*(x7030)*(x7031)))+(((cj5)*(r02)*(sj0)))+(((IkReal(-1.00000000000000))*(cj0)*(r12)*(x7033)))+(((cj0)*(r11)*(x7032)))+(((cj0)*(r10)*(x7030)))+(((IkReal(-1.00000000000000))*(r01)*(x7031)*(x7032)))))+IKsqr(((((IKabs(sj1) != 0)?((IkReal)1/(sj1)):(IkReal)1.0e30))*(((((IkReal(-1.00000000000000))*(r22)*(x7033)))+(((r21)*(x7032)))+(((r20)*(x7030)))))))-1) <= IKFAST_SINCOS_THRESH )
    continue;
j3array[0]=IKatan2(((((IkReal(-1.00000000000000))*(r00)*(x7030)*(x7031)))+(((cj5)*(r02)*(sj0)))+(((IkReal(-1.00000000000000))*(cj0)*(r12)*(x7033)))+(((cj0)*(r11)*(x7032)))+(((cj0)*(r10)*(x7030)))+(((IkReal(-1.00000000000000))*(r01)*(x7031)*(x7032)))), ((((IKabs(sj1) != 0)?((IkReal)1/(sj1)):(IkReal)1.0e30))*(((((IkReal(-1.00000000000000))*(r22)*(x7033)))+(((r21)*(x7032)))+(((r20)*(x7030)))))));
sj3array[0]=IKsin(j3array[0]);
cj3array[0]=IKcos(j3array[0]);
if( j3array[0] > IKPI )
{
    j3array[0]-=IK2PI;
}
else if( j3array[0] < -IKPI )
{    j3array[0]+=IK2PI;
}
j3valid[0] = true;
for(int ij3 = 0; ij3 < 1; ++ij3)
{
if( !j3valid[ij3] )
{
    continue;
}
_ij3[0] = ij3; _ij3[1] = -1;
for(int iij3 = ij3+1; iij3 < 1; ++iij3)
{
if( j3valid[iij3] && IKabs(cj3array[ij3]-cj3array[iij3]) < IKFAST_SOLUTION_THRESH && IKabs(sj3array[ij3]-sj3array[iij3]) < IKFAST_SOLUTION_THRESH )
{
    j3valid[iij3]=false; _ij3[1] = iij3; break; 
}
}
j3 = j3array[ij3]; cj3 = cj3array[ij3]; sj3 = sj3array[ij3];
{
IkReal evalcond[6];
IkReal x7034=IKsin(j3);
IkReal x7035=IKcos(j3);
IkReal x7036=((sj0)*(sj5));
IkReal x7037=((r00)*(sj6));
IkReal x7038=((IkReal(1.00000000000000))*(cj4));
IkReal x7039=((cj6)*(r01));
IkReal x7040=((cj0)*(cj5));
IkReal x7041=((cj5)*(sj0));
IkReal x7042=((cj6)*(r11));
IkReal x7043=((cj0)*(sj5));
IkReal x7044=((IkReal(1.00000000000000))*(cj1));
IkReal x7045=((cj6)*(sj4));
IkReal x7046=((IkReal(1.00000000000000))*(sj1));
IkReal x7047=((cj4)*(cj5));
IkReal x7048=((cj6)*(r21));
IkReal x7049=((r20)*(sj6));
IkReal x7050=((r10)*(sj6));
IkReal x7051=((IkReal(1.00000000000000))*(cj0));
IkReal x7052=((cj0)*(sj4)*(sj6));
IkReal x7053=((sj0)*(sj4)*(sj6));
evalcond[0]=((((IkReal(-1.00000000000000))*(x7035)*(x7046)))+(((sj5)*(x7049)))+(((IkReal(-1.00000000000000))*(cj5)*(r22)))+(((sj5)*(x7048))));
evalcond[1]=((((IkReal(-1.00000000000000))*(r21)*(sj4)*(sj6)))+(((cj4)*(r22)*(sj5)))+(((IkReal(-1.00000000000000))*(x7034)*(x7046)))+(((x7047)*(x7048)))+(((r20)*(x7045)))+(((x7047)*(x7049))));
evalcond[2]=((((x7036)*(x7037)))+(((IkReal(-1.00000000000000))*(x7043)*(x7050)))+(((IkReal(-1.00000000000000))*(r02)*(x7041)))+(x7034)+(((r12)*(x7040)))+(((x7036)*(x7039)))+(((IkReal(-1.00000000000000))*(x7042)*(x7043))));
evalcond[3]=((((IkReal(-1.00000000000000))*(x7039)*(x7043)))+(((IkReal(-1.00000000000000))*(x7037)*(x7043)))+(((IkReal(-1.00000000000000))*(x7035)*(x7044)))+(((IkReal(-1.00000000000000))*(x7036)*(x7042)))+(((IkReal(-1.00000000000000))*(x7036)*(x7050)))+(((r12)*(x7041)))+(((r02)*(x7040))));
evalcond[4]=((((cj4)*(r02)*(x7036)))+(((IkReal(-1.00000000000000))*(r10)*(x7045)*(x7051)))+(((cj4)*(x7039)*(x7041)))+(((r11)*(x7052)))+(((IkReal(-1.00000000000000))*(x7038)*(x7040)*(x7042)))+(((IkReal(-1.00000000000000))*(x7038)*(x7040)*(x7050)))+(((IkReal(-1.00000000000000))*(x7035)))+(((IkReal(-1.00000000000000))*(r01)*(x7053)))+(((r00)*(sj0)*(x7045)))+(((cj4)*(x7037)*(x7041)))+(((IkReal(-1.00000000000000))*(r12)*(x7038)*(x7043))));
evalcond[5]=((((IkReal(-1.00000000000000))*(r12)*(x7036)*(x7038)))+(((IkReal(-1.00000000000000))*(x7034)*(x7044)))+(((IkReal(-1.00000000000000))*(x7038)*(x7041)*(x7042)))+(((IkReal(-1.00000000000000))*(x7038)*(x7039)*(x7040)))+(((IkReal(-1.00000000000000))*(x7038)*(x7041)*(x7050)))+(((r01)*(x7052)))+(((IkReal(-1.00000000000000))*(r00)*(x7045)*(x7051)))+(((r11)*(x7053)))+(((IkReal(-1.00000000000000))*(x7037)*(x7038)*(x7040)))+(((IkReal(-1.00000000000000))*(r02)*(x7038)*(x7043)))+(((IkReal(-1.00000000000000))*(r10)*(sj0)*(x7045))));
if( IKabs(evalcond[0]) > 0.000001  || IKabs(evalcond[1]) > 0.000001  || IKabs(evalcond[2]) > 0.000001  || IKabs(evalcond[3]) > 0.000001  || IKabs(evalcond[4]) > 0.000001  || IKabs(evalcond[5]) > 0.000001  )
{
continue;
}
}

{
std::vector<IkSingleDOFSolutionBase<IkReal> > vinfos(7);
vinfos[0].jointtype = 1;
vinfos[0].foffset = j0;
vinfos[0].indices[0] = _ij0[0];
vinfos[0].indices[1] = _ij0[1];
vinfos[0].maxsolutions = _nj0;
vinfos[1].jointtype = 1;
vinfos[1].foffset = j1;
vinfos[1].indices[0] = _ij1[0];
vinfos[1].indices[1] = _ij1[1];
vinfos[1].maxsolutions = _nj1;
vinfos[2].jointtype = 1;
vinfos[2].foffset = j2;
vinfos[2].indices[0] = _ij2[0];
vinfos[2].indices[1] = _ij2[1];
vinfos[2].maxsolutions = _nj2;
vinfos[3].jointtype = 1;
vinfos[3].foffset = j3;
vinfos[3].indices[0] = _ij3[0];
vinfos[3].indices[1] = _ij3[1];
vinfos[3].maxsolutions = _nj3;
vinfos[4].jointtype = 1;
vinfos[4].foffset = j4;
vinfos[4].indices[0] = _ij4[0];
vinfos[4].indices[1] = _ij4[1];
vinfos[4].maxsolutions = _nj4;
vinfos[5].jointtype = 1;
vinfos[5].foffset = j5;
vinfos[5].indices[0] = _ij5[0];
vinfos[5].indices[1] = _ij5[1];
vinfos[5].maxsolutions = _nj5;
vinfos[6].jointtype = 1;
vinfos[6].foffset = j6;
vinfos[6].indices[0] = _ij6[0];
vinfos[6].indices[1] = _ij6[1];
vinfos[6].maxsolutions = _nj6;
std::vector<int> vfree(0);
solutions.AddSolution(vinfos,vfree);
}
}
}

}

}

} else
{
{
IkReal j3array[1], cj3array[1], sj3array[1];
bool j3valid[1]={false};
_nj3 = 1;
IkReal x7054=((r20)*(sj6));
IkReal x7055=((cj4)*(cj5));
IkReal x7056=((cj6)*(r21));
if( IKabs(((gconst12)*(((((IkReal(-1.00000000000000))*(r21)*(sj4)*(sj6)))+(((cj6)*(r20)*(sj4)))+(((cj4)*(r22)*(sj5)))+(((x7055)*(x7056)))+(((x7054)*(x7055))))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(((gconst12)*(((((sj5)*(x7054)))+(((IkReal(-1.00000000000000))*(cj5)*(r22)))+(((sj5)*(x7056))))))) < IKFAST_ATAN2_MAGTHRESH )
    continue;
j3array[0]=IKatan2(((gconst12)*(((((IkReal(-1.00000000000000))*(r21)*(sj4)*(sj6)))+(((cj6)*(r20)*(sj4)))+(((cj4)*(r22)*(sj5)))+(((x7055)*(x7056)))+(((x7054)*(x7055)))))), ((gconst12)*(((((sj5)*(x7054)))+(((IkReal(-1.00000000000000))*(cj5)*(r22)))+(((sj5)*(x7056)))))));
sj3array[0]=IKsin(j3array[0]);
cj3array[0]=IKcos(j3array[0]);
if( j3array[0] > IKPI )
{
    j3array[0]-=IK2PI;
}
else if( j3array[0] < -IKPI )
{    j3array[0]+=IK2PI;
}
j3valid[0] = true;
for(int ij3 = 0; ij3 < 1; ++ij3)
{
if( !j3valid[ij3] )
{
    continue;
}
_ij3[0] = ij3; _ij3[1] = -1;
for(int iij3 = ij3+1; iij3 < 1; ++iij3)
{
if( j3valid[iij3] && IKabs(cj3array[ij3]-cj3array[iij3]) < IKFAST_SOLUTION_THRESH && IKabs(sj3array[ij3]-sj3array[iij3]) < IKFAST_SOLUTION_THRESH )
{
    j3valid[iij3]=false; _ij3[1] = iij3; break; 
}
}
j3 = j3array[ij3]; cj3 = cj3array[ij3]; sj3 = sj3array[ij3];
{
IkReal evalcond[6];
IkReal x7057=IKsin(j3);
IkReal x7058=IKcos(j3);
IkReal x7059=((sj0)*(sj5));
IkReal x7060=((r00)*(sj6));
IkReal x7061=((IkReal(1.00000000000000))*(cj4));
IkReal x7062=((cj6)*(r01));
IkReal x7063=((cj0)*(cj5));
IkReal x7064=((cj5)*(sj0));
IkReal x7065=((cj6)*(r11));
IkReal x7066=((cj0)*(sj5));
IkReal x7067=((IkReal(1.00000000000000))*(cj1));
IkReal x7068=((cj6)*(sj4));
IkReal x7069=((IkReal(1.00000000000000))*(sj1));
IkReal x7070=((cj4)*(cj5));
IkReal x7071=((cj6)*(r21));
IkReal x7072=((r20)*(sj6));
IkReal x7073=((r10)*(sj6));
IkReal x7074=((IkReal(1.00000000000000))*(cj0));
IkReal x7075=((cj0)*(sj4)*(sj6));
IkReal x7076=((sj0)*(sj4)*(sj6));
evalcond[0]=((((sj5)*(x7072)))+(((IkReal(-1.00000000000000))*(x7058)*(x7069)))+(((sj5)*(x7071)))+(((IkReal(-1.00000000000000))*(cj5)*(r22))));
evalcond[1]=((((IkReal(-1.00000000000000))*(r21)*(sj4)*(sj6)))+(((cj4)*(r22)*(sj5)))+(((r20)*(x7068)))+(((x7070)*(x7071)))+(((IkReal(-1.00000000000000))*(x7057)*(x7069)))+(((x7070)*(x7072))));
evalcond[2]=((((x7059)*(x7062)))+(((x7059)*(x7060)))+(((r12)*(x7063)))+(x7057)+(((IkReal(-1.00000000000000))*(r02)*(x7064)))+(((IkReal(-1.00000000000000))*(x7066)*(x7073)))+(((IkReal(-1.00000000000000))*(x7065)*(x7066))));
evalcond[3]=((((IkReal(-1.00000000000000))*(x7060)*(x7066)))+(((IkReal(-1.00000000000000))*(x7059)*(x7073)))+(((r12)*(x7064)))+(((IkReal(-1.00000000000000))*(x7059)*(x7065)))+(((IkReal(-1.00000000000000))*(x7058)*(x7067)))+(((r02)*(x7063)))+(((IkReal(-1.00000000000000))*(x7062)*(x7066))));
evalcond[4]=((((IkReal(-1.00000000000000))*(r12)*(x7061)*(x7066)))+(((IkReal(-1.00000000000000))*(x7061)*(x7063)*(x7065)))+(((r00)*(sj0)*(x7068)))+(((r11)*(x7075)))+(((IkReal(-1.00000000000000))*(x7058)))+(((cj4)*(x7062)*(x7064)))+(((IkReal(-1.00000000000000))*(x7061)*(x7063)*(x7073)))+(((IkReal(-1.00000000000000))*(r10)*(x7068)*(x7074)))+(((cj4)*(r02)*(x7059)))+(((IkReal(-1.00000000000000))*(r01)*(x7076)))+(((cj4)*(x7060)*(x7064))));
evalcond[5]=((((IkReal(-1.00000000000000))*(x7061)*(x7062)*(x7063)))+(((IkReal(-1.00000000000000))*(r02)*(x7061)*(x7066)))+(((IkReal(-1.00000000000000))*(x7060)*(x7061)*(x7063)))+(((IkReal(-1.00000000000000))*(x7061)*(x7064)*(x7073)))+(((r01)*(x7075)))+(((IkReal(-1.00000000000000))*(r00)*(x7068)*(x7074)))+(((IkReal(-1.00000000000000))*(r12)*(x7059)*(x7061)))+(((IkReal(-1.00000000000000))*(r10)*(sj0)*(x7068)))+(((IkReal(-1.00000000000000))*(x7057)*(x7067)))+(((IkReal(-1.00000000000000))*(x7061)*(x7064)*(x7065)))+(((r11)*(x7076))));
if( IKabs(evalcond[0]) > 0.000001  || IKabs(evalcond[1]) > 0.000001  || IKabs(evalcond[2]) > 0.000001  || IKabs(evalcond[3]) > 0.000001  || IKabs(evalcond[4]) > 0.000001  || IKabs(evalcond[5]) > 0.000001  )
{
continue;
}
}

{
std::vector<IkSingleDOFSolutionBase<IkReal> > vinfos(7);
vinfos[0].jointtype = 1;
vinfos[0].foffset = j0;
vinfos[0].indices[0] = _ij0[0];
vinfos[0].indices[1] = _ij0[1];
vinfos[0].maxsolutions = _nj0;
vinfos[1].jointtype = 1;
vinfos[1].foffset = j1;
vinfos[1].indices[0] = _ij1[0];
vinfos[1].indices[1] = _ij1[1];
vinfos[1].maxsolutions = _nj1;
vinfos[2].jointtype = 1;
vinfos[2].foffset = j2;
vinfos[2].indices[0] = _ij2[0];
vinfos[2].indices[1] = _ij2[1];
vinfos[2].maxsolutions = _nj2;
vinfos[3].jointtype = 1;
vinfos[3].foffset = j3;
vinfos[3].indices[0] = _ij3[0];
vinfos[3].indices[1] = _ij3[1];
vinfos[3].maxsolutions = _nj3;
vinfos[4].jointtype = 1;
vinfos[4].foffset = j4;
vinfos[4].indices[0] = _ij4[0];
vinfos[4].indices[1] = _ij4[1];
vinfos[4].maxsolutions = _nj4;
vinfos[5].jointtype = 1;
vinfos[5].foffset = j5;
vinfos[5].indices[0] = _ij5[0];
vinfos[5].indices[1] = _ij5[1];
vinfos[5].maxsolutions = _nj5;
vinfos[6].jointtype = 1;
vinfos[6].foffset = j6;
vinfos[6].indices[0] = _ij6[0];
vinfos[6].indices[1] = _ij6[1];
vinfos[6].maxsolutions = _nj6;
std::vector<int> vfree(0);
solutions.AddSolution(vinfos,vfree);
}
}
}

}

}

} else
{
if( 1 )
{
continue;

} else
{
}
}
}
}
}
}
}
}

} else
{
{
IkReal j3array[1], cj3array[1], sj3array[1];
bool j3valid[1]={false};
_nj3 = 1;
IkReal x7077=((IKabs(sj2) != 0)?((IkReal)1/(sj2)):(IkReal)1.0e30);
IkReal x7078=((sj5)*(sj6));
IkReal x7079=((r00)*(sj0));
IkReal x7080=((cj1)*(cj2));
IkReal x7081=((cj0)*(r10));
IkReal x7082=((cj6)*(sj5));
IkReal x7083=((r01)*(sj0));
IkReal x7084=((IkReal(1.00000000000000))*(cj0));
IkReal x7085=((cj5)*(r12));
IkReal x7086=((IkReal(1.00000000000000))*(cj5));
IkReal x7087=((r02)*(sj0));
if( IKabs(((x7077)*(((((cj0)*(x7085)))+(((IkReal(-1.00000000000000))*(x7086)*(x7087)))+(((IkReal(-1.00000000000000))*(r11)*(x7082)*(x7084)))+(((IkReal(-1.00000000000000))*(x7078)*(x7081)))+(((x7078)*(x7079)))+(((x7082)*(x7083))))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(((x7077)*(((IKabs(sj1) != 0)?((IkReal)1/(sj1)):(IkReal)1.0e30))*(((((cj5)*(x7080)*(x7087)))+(((cj0)*(r11)*(x7080)*(x7082)))+(((IkReal(-1.00000000000000))*(x7078)*(x7079)*(x7080)))+(((IkReal(-1.00000000000000))*(r22)*(sj2)*(x7086)))+(((r21)*(sj2)*(x7082)))+(((r20)*(sj2)*(x7078)))+(((IkReal(-1.00000000000000))*(x7080)*(x7082)*(x7083)))+(((x7078)*(x7080)*(x7081)))+(((IkReal(-1.00000000000000))*(x7080)*(x7084)*(x7085))))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(IKsqr(((x7077)*(((((cj0)*(x7085)))+(((IkReal(-1.00000000000000))*(x7086)*(x7087)))+(((IkReal(-1.00000000000000))*(r11)*(x7082)*(x7084)))+(((IkReal(-1.00000000000000))*(x7078)*(x7081)))+(((x7078)*(x7079)))+(((x7082)*(x7083)))))))+IKsqr(((x7077)*(((IKabs(sj1) != 0)?((IkReal)1/(sj1)):(IkReal)1.0e30))*(((((cj5)*(x7080)*(x7087)))+(((cj0)*(r11)*(x7080)*(x7082)))+(((IkReal(-1.00000000000000))*(x7078)*(x7079)*(x7080)))+(((IkReal(-1.00000000000000))*(r22)*(sj2)*(x7086)))+(((r21)*(sj2)*(x7082)))+(((r20)*(sj2)*(x7078)))+(((IkReal(-1.00000000000000))*(x7080)*(x7082)*(x7083)))+(((x7078)*(x7080)*(x7081)))+(((IkReal(-1.00000000000000))*(x7080)*(x7084)*(x7085)))))))-1) <= IKFAST_SINCOS_THRESH )
    continue;
j3array[0]=IKatan2(((x7077)*(((((cj0)*(x7085)))+(((IkReal(-1.00000000000000))*(x7086)*(x7087)))+(((IkReal(-1.00000000000000))*(r11)*(x7082)*(x7084)))+(((IkReal(-1.00000000000000))*(x7078)*(x7081)))+(((x7078)*(x7079)))+(((x7082)*(x7083)))))), ((x7077)*(((IKabs(sj1) != 0)?((IkReal)1/(sj1)):(IkReal)1.0e30))*(((((cj5)*(x7080)*(x7087)))+(((cj0)*(r11)*(x7080)*(x7082)))+(((IkReal(-1.00000000000000))*(x7078)*(x7079)*(x7080)))+(((IkReal(-1.00000000000000))*(r22)*(sj2)*(x7086)))+(((r21)*(sj2)*(x7082)))+(((r20)*(sj2)*(x7078)))+(((IkReal(-1.00000000000000))*(x7080)*(x7082)*(x7083)))+(((x7078)*(x7080)*(x7081)))+(((IkReal(-1.00000000000000))*(x7080)*(x7084)*(x7085)))))));
sj3array[0]=IKsin(j3array[0]);
cj3array[0]=IKcos(j3array[0]);
if( j3array[0] > IKPI )
{
    j3array[0]-=IK2PI;
}
else if( j3array[0] < -IKPI )
{    j3array[0]+=IK2PI;
}
j3valid[0] = true;
for(int ij3 = 0; ij3 < 1; ++ij3)
{
if( !j3valid[ij3] )
{
    continue;
}
_ij3[0] = ij3; _ij3[1] = -1;
for(int iij3 = ij3+1; iij3 < 1; ++iij3)
{
if( j3valid[iij3] && IKabs(cj3array[ij3]-cj3array[iij3]) < IKFAST_SOLUTION_THRESH && IKabs(sj3array[ij3]-sj3array[iij3]) < IKFAST_SOLUTION_THRESH )
{
    j3valid[iij3]=false; _ij3[1] = iij3; break; 
}
}
j3 = j3array[ij3]; cj3 = cj3array[ij3]; sj3 = sj3array[ij3];
{
IkReal evalcond[6];
IkReal x7088=IKcos(j3);
IkReal x7089=IKsin(j3);
IkReal x7090=((sj0)*(sj5));
IkReal x7091=((r00)*(sj6));
IkReal x7092=((IkReal(1.00000000000000))*(cj4));
IkReal x7093=((cj6)*(r01));
IkReal x7094=((cj0)*(cj5));
IkReal x7095=((cj5)*(sj0));
IkReal x7096=((cj6)*(r11));
IkReal x7097=((cj6)*(sj4));
IkReal x7098=((IkReal(1.00000000000000))*(cj1));
IkReal x7099=((cj4)*(cj5));
IkReal x7100=((cj6)*(r21));
IkReal x7101=((r20)*(sj6));
IkReal x7102=((r10)*(sj6));
IkReal x7103=((cj0)*(sj5));
IkReal x7104=((IkReal(1.00000000000000))*(cj0));
IkReal x7105=((IkReal(1.00000000000000))*(x7103));
IkReal x7106=((IkReal(1.00000000000000))*(x7089));
IkReal x7107=((cj0)*(sj4)*(sj6));
IkReal x7108=((cj2)*(x7089));
IkReal x7109=((sj0)*(sj4)*(sj6));
IkReal x7110=((IkReal(1.00000000000000))*(sj1)*(x7088));
evalcond[0]=((((sj5)*(x7101)))+(((IkReal(-1.00000000000000))*(cj5)*(r22)))+(((IkReal(-1.00000000000000))*(x7110)))+(((IkReal(-1.00000000000000))*(x7098)*(x7108)))+(((sj5)*(x7100))));
evalcond[1]=((((IkReal(-1.00000000000000))*(r21)*(sj4)*(sj6)))+(((IkReal(-1.00000000000000))*(sj1)*(x7106)))+(((cj1)*(cj2)*(x7088)))+(((cj4)*(r22)*(sj5)))+(((x7099)*(x7100)))+(((x7099)*(x7101)))+(((r20)*(x7097))));
evalcond[2]=((((IkReal(-1.00000000000000))*(x7096)*(x7105)))+(((r12)*(x7094)))+(((IkReal(-1.00000000000000))*(x7102)*(x7105)))+(((x7090)*(x7091)))+(((x7090)*(x7093)))+(((IkReal(-1.00000000000000))*(sj2)*(x7106)))+(((IkReal(-1.00000000000000))*(r02)*(x7095))));
evalcond[3]=((((IkReal(-1.00000000000000))*(x7088)*(x7098)))+(((IkReal(-1.00000000000000))*(x7090)*(x7096)))+(((r12)*(x7095)))+(((sj1)*(x7108)))+(((IkReal(-1.00000000000000))*(x7091)*(x7105)))+(((IkReal(-1.00000000000000))*(x7090)*(x7102)))+(((r02)*(x7094)))+(((IkReal(-1.00000000000000))*(x7093)*(x7105))));
evalcond[4]=((((cj4)*(r02)*(x7090)))+(((sj2)*(x7088)))+(((r11)*(x7107)))+(((r00)*(sj0)*(x7097)))+(((IkReal(-1.00000000000000))*(r10)*(x7097)*(x7104)))+(((cj4)*(x7093)*(x7095)))+(((IkReal(-1.00000000000000))*(x7092)*(x7094)*(x7096)))+(((cj4)*(x7091)*(x7095)))+(((IkReal(-1.00000000000000))*(x7092)*(x7094)*(x7102)))+(((IkReal(-1.00000000000000))*(r12)*(x7092)*(x7103)))+(((IkReal(-1.00000000000000))*(r01)*(x7109))));
evalcond[5]=((((IkReal(-1.00000000000000))*(cj2)*(x7110)))+(((IkReal(-1.00000000000000))*(r10)*(sj0)*(x7097)))+(((IkReal(-1.00000000000000))*(r00)*(x7097)*(x7104)))+(((IkReal(-1.00000000000000))*(x7089)*(x7098)))+(((IkReal(-1.00000000000000))*(x7092)*(x7095)*(x7102)))+(((IkReal(-1.00000000000000))*(x7091)*(x7092)*(x7094)))+(((IkReal(-1.00000000000000))*(x7092)*(x7095)*(x7096)))+(((IkReal(-1.00000000000000))*(r12)*(x7090)*(x7092)))+(((r11)*(x7109)))+(((r01)*(x7107)))+(((IkReal(-1.00000000000000))*(x7092)*(x7093)*(x7094)))+(((IkReal(-1.00000000000000))*(r02)*(x7092)*(x7103))));
if( IKabs(evalcond[0]) > 0.000001  || IKabs(evalcond[1]) > 0.000001  || IKabs(evalcond[2]) > 0.000001  || IKabs(evalcond[3]) > 0.000001  || IKabs(evalcond[4]) > 0.000001  || IKabs(evalcond[5]) > 0.000001  )
{
continue;
}
}

{
std::vector<IkSingleDOFSolutionBase<IkReal> > vinfos(7);
vinfos[0].jointtype = 1;
vinfos[0].foffset = j0;
vinfos[0].indices[0] = _ij0[0];
vinfos[0].indices[1] = _ij0[1];
vinfos[0].maxsolutions = _nj0;
vinfos[1].jointtype = 1;
vinfos[1].foffset = j1;
vinfos[1].indices[0] = _ij1[0];
vinfos[1].indices[1] = _ij1[1];
vinfos[1].maxsolutions = _nj1;
vinfos[2].jointtype = 1;
vinfos[2].foffset = j2;
vinfos[2].indices[0] = _ij2[0];
vinfos[2].indices[1] = _ij2[1];
vinfos[2].maxsolutions = _nj2;
vinfos[3].jointtype = 1;
vinfos[3].foffset = j3;
vinfos[3].indices[0] = _ij3[0];
vinfos[3].indices[1] = _ij3[1];
vinfos[3].maxsolutions = _nj3;
vinfos[4].jointtype = 1;
vinfos[4].foffset = j4;
vinfos[4].indices[0] = _ij4[0];
vinfos[4].indices[1] = _ij4[1];
vinfos[4].maxsolutions = _nj4;
vinfos[5].jointtype = 1;
vinfos[5].foffset = j5;
vinfos[5].indices[0] = _ij5[0];
vinfos[5].indices[1] = _ij5[1];
vinfos[5].maxsolutions = _nj5;
vinfos[6].jointtype = 1;
vinfos[6].foffset = j6;
vinfos[6].indices[0] = _ij6[0];
vinfos[6].indices[1] = _ij6[1];
vinfos[6].maxsolutions = _nj6;
std::vector<int> vfree(0);
solutions.AddSolution(vinfos,vfree);
}
}
}

}

}

} else
{
{
IkReal j3array[1], cj3array[1], sj3array[1];
bool j3valid[1]={false};
_nj3 = 1;
IkReal x7111=(cj1)*(cj1);
IkReal x7112=(sj1)*(sj1);
IkReal x7113=((r00)*(sj6));
IkReal x7114=((cj6)*(r01));
IkReal x7115=((IkReal(1.00000000000000))*(cj1));
IkReal x7116=((cj5)*(r22));
IkReal x7117=((sj5)*(sj6));
IkReal x7118=((r10)*(sj0));
IkReal x7119=((cj1)*(cj5));
IkReal x7120=((cj0)*(r02));
IkReal x7121=((r12)*(sj0));
IkReal x7122=((IkReal(1.00000000000000))*(sj1));
IkReal x7123=((cj6)*(sj5));
IkReal x7124=((cj0)*(sj5));
IkReal x7125=((r11)*(sj0));
IkReal x7126=((sj1)*(x7124));
if( IKabs(((((IKabs(((((cj2)*(x7111)))+(((cj2)*(x7112))))) != 0)?((IkReal)1/(((((cj2)*(x7111)))+(((cj2)*(x7112)))))):(IkReal)1.0e30))*(((((sj1)*(x7123)*(x7125)))+(((IkReal(-1.00000000000000))*(x7115)*(x7116)))+(((IkReal(-1.00000000000000))*(cj5)*(x7121)*(x7122)))+(((sj1)*(x7117)*(x7118)))+(((cj1)*(r21)*(x7123)))+(((x7113)*(x7126)))+(((x7114)*(x7126)))+(((IkReal(-1.00000000000000))*(cj5)*(x7120)*(x7122)))+(((cj1)*(r20)*(x7117))))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(((((IKabs(((x7112)+(x7111))) != 0)?((IkReal)1/(((x7112)+(x7111)))):(IkReal)1.0e30))*(((((r21)*(sj1)*(x7123)))+(((IkReal(-1.00000000000000))*(x7114)*(x7115)*(x7124)))+(((r20)*(sj1)*(x7117)))+(((IkReal(-1.00000000000000))*(x7113)*(x7115)*(x7124)))+(((x7119)*(x7121)))+(((IkReal(-1.00000000000000))*(x7116)*(x7122)))+(((IkReal(-1.00000000000000))*(x7115)*(x7123)*(x7125)))+(((IkReal(-1.00000000000000))*(x7115)*(x7117)*(x7118)))+(((x7119)*(x7120))))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(IKsqr(((((IKabs(((((cj2)*(x7111)))+(((cj2)*(x7112))))) != 0)?((IkReal)1/(((((cj2)*(x7111)))+(((cj2)*(x7112)))))):(IkReal)1.0e30))*(((((sj1)*(x7123)*(x7125)))+(((IkReal(-1.00000000000000))*(x7115)*(x7116)))+(((IkReal(-1.00000000000000))*(cj5)*(x7121)*(x7122)))+(((sj1)*(x7117)*(x7118)))+(((cj1)*(r21)*(x7123)))+(((x7113)*(x7126)))+(((x7114)*(x7126)))+(((IkReal(-1.00000000000000))*(cj5)*(x7120)*(x7122)))+(((cj1)*(r20)*(x7117)))))))+IKsqr(((((IKabs(((x7112)+(x7111))) != 0)?((IkReal)1/(((x7112)+(x7111)))):(IkReal)1.0e30))*(((((r21)*(sj1)*(x7123)))+(((IkReal(-1.00000000000000))*(x7114)*(x7115)*(x7124)))+(((r20)*(sj1)*(x7117)))+(((IkReal(-1.00000000000000))*(x7113)*(x7115)*(x7124)))+(((x7119)*(x7121)))+(((IkReal(-1.00000000000000))*(x7116)*(x7122)))+(((IkReal(-1.00000000000000))*(x7115)*(x7123)*(x7125)))+(((IkReal(-1.00000000000000))*(x7115)*(x7117)*(x7118)))+(((x7119)*(x7120)))))))-1) <= IKFAST_SINCOS_THRESH )
    continue;
j3array[0]=IKatan2(((((IKabs(((((cj2)*(x7111)))+(((cj2)*(x7112))))) != 0)?((IkReal)1/(((((cj2)*(x7111)))+(((cj2)*(x7112)))))):(IkReal)1.0e30))*(((((sj1)*(x7123)*(x7125)))+(((IkReal(-1.00000000000000))*(x7115)*(x7116)))+(((IkReal(-1.00000000000000))*(cj5)*(x7121)*(x7122)))+(((sj1)*(x7117)*(x7118)))+(((cj1)*(r21)*(x7123)))+(((x7113)*(x7126)))+(((x7114)*(x7126)))+(((IkReal(-1.00000000000000))*(cj5)*(x7120)*(x7122)))+(((cj1)*(r20)*(x7117)))))), ((((IKabs(((x7112)+(x7111))) != 0)?((IkReal)1/(((x7112)+(x7111)))):(IkReal)1.0e30))*(((((r21)*(sj1)*(x7123)))+(((IkReal(-1.00000000000000))*(x7114)*(x7115)*(x7124)))+(((r20)*(sj1)*(x7117)))+(((IkReal(-1.00000000000000))*(x7113)*(x7115)*(x7124)))+(((x7119)*(x7121)))+(((IkReal(-1.00000000000000))*(x7116)*(x7122)))+(((IkReal(-1.00000000000000))*(x7115)*(x7123)*(x7125)))+(((IkReal(-1.00000000000000))*(x7115)*(x7117)*(x7118)))+(((x7119)*(x7120)))))));
sj3array[0]=IKsin(j3array[0]);
cj3array[0]=IKcos(j3array[0]);
if( j3array[0] > IKPI )
{
    j3array[0]-=IK2PI;
}
else if( j3array[0] < -IKPI )
{    j3array[0]+=IK2PI;
}
j3valid[0] = true;
for(int ij3 = 0; ij3 < 1; ++ij3)
{
if( !j3valid[ij3] )
{
    continue;
}
_ij3[0] = ij3; _ij3[1] = -1;
for(int iij3 = ij3+1; iij3 < 1; ++iij3)
{
if( j3valid[iij3] && IKabs(cj3array[ij3]-cj3array[iij3]) < IKFAST_SOLUTION_THRESH && IKabs(sj3array[ij3]-sj3array[iij3]) < IKFAST_SOLUTION_THRESH )
{
    j3valid[iij3]=false; _ij3[1] = iij3; break; 
}
}
j3 = j3array[ij3]; cj3 = cj3array[ij3]; sj3 = sj3array[ij3];
{
IkReal evalcond[6];
IkReal x7127=IKcos(j3);
IkReal x7128=IKsin(j3);
IkReal x7129=((sj0)*(sj5));
IkReal x7130=((r00)*(sj6));
IkReal x7131=((IkReal(1.00000000000000))*(cj4));
IkReal x7132=((cj6)*(r01));
IkReal x7133=((cj0)*(cj5));
IkReal x7134=((cj5)*(sj0));
IkReal x7135=((cj6)*(r11));
IkReal x7136=((cj6)*(sj4));
IkReal x7137=((IkReal(1.00000000000000))*(cj1));
IkReal x7138=((cj4)*(cj5));
IkReal x7139=((cj6)*(r21));
IkReal x7140=((r20)*(sj6));
IkReal x7141=((r10)*(sj6));
IkReal x7142=((cj0)*(sj5));
IkReal x7143=((IkReal(1.00000000000000))*(cj0));
IkReal x7144=((IkReal(1.00000000000000))*(x7142));
IkReal x7145=((IkReal(1.00000000000000))*(x7128));
IkReal x7146=((cj0)*(sj4)*(sj6));
IkReal x7147=((cj2)*(x7128));
IkReal x7148=((sj0)*(sj4)*(sj6));
IkReal x7149=((IkReal(1.00000000000000))*(sj1)*(x7127));
evalcond[0]=((((IkReal(-1.00000000000000))*(x7137)*(x7147)))+(((sj5)*(x7139)))+(((IkReal(-1.00000000000000))*(x7149)))+(((sj5)*(x7140)))+(((IkReal(-1.00000000000000))*(cj5)*(r22))));
evalcond[1]=((((IkReal(-1.00000000000000))*(r21)*(sj4)*(sj6)))+(((x7138)*(x7140)))+(((r20)*(x7136)))+(((cj4)*(r22)*(sj5)))+(((x7138)*(x7139)))+(((cj1)*(cj2)*(x7127)))+(((IkReal(-1.00000000000000))*(sj1)*(x7145))));
evalcond[2]=((((IkReal(-1.00000000000000))*(x7141)*(x7144)))+(((IkReal(-1.00000000000000))*(sj2)*(x7145)))+(((r12)*(x7133)))+(((IkReal(-1.00000000000000))*(r02)*(x7134)))+(((x7129)*(x7132)))+(((IkReal(-1.00000000000000))*(x7135)*(x7144)))+(((x7129)*(x7130))));
evalcond[3]=((((IkReal(-1.00000000000000))*(x7129)*(x7135)))+(((IkReal(-1.00000000000000))*(x7127)*(x7137)))+(((IkReal(-1.00000000000000))*(x7129)*(x7141)))+(((IkReal(-1.00000000000000))*(x7132)*(x7144)))+(((IkReal(-1.00000000000000))*(x7130)*(x7144)))+(((sj1)*(x7147)))+(((r02)*(x7133)))+(((r12)*(x7134))));
evalcond[4]=((((r11)*(x7146)))+(((cj4)*(x7132)*(x7134)))+(((IkReal(-1.00000000000000))*(r12)*(x7131)*(x7142)))+(((IkReal(-1.00000000000000))*(r10)*(x7136)*(x7143)))+(((r00)*(sj0)*(x7136)))+(((sj2)*(x7127)))+(((IkReal(-1.00000000000000))*(x7131)*(x7133)*(x7141)))+(((cj4)*(r02)*(x7129)))+(((IkReal(-1.00000000000000))*(r01)*(x7148)))+(((IkReal(-1.00000000000000))*(x7131)*(x7133)*(x7135)))+(((cj4)*(x7130)*(x7134))));
evalcond[5]=((((IkReal(-1.00000000000000))*(cj2)*(x7149)))+(((IkReal(-1.00000000000000))*(x7128)*(x7137)))+(((IkReal(-1.00000000000000))*(r00)*(x7136)*(x7143)))+(((r01)*(x7146)))+(((r11)*(x7148)))+(((IkReal(-1.00000000000000))*(x7131)*(x7134)*(x7141)))+(((IkReal(-1.00000000000000))*(r10)*(sj0)*(x7136)))+(((IkReal(-1.00000000000000))*(x7131)*(x7134)*(x7135)))+(((IkReal(-1.00000000000000))*(r12)*(x7129)*(x7131)))+(((IkReal(-1.00000000000000))*(x7130)*(x7131)*(x7133)))+(((IkReal(-1.00000000000000))*(r02)*(x7131)*(x7142)))+(((IkReal(-1.00000000000000))*(x7131)*(x7132)*(x7133))));
if( IKabs(evalcond[0]) > 0.000001  || IKabs(evalcond[1]) > 0.000001  || IKabs(evalcond[2]) > 0.000001  || IKabs(evalcond[3]) > 0.000001  || IKabs(evalcond[4]) > 0.000001  || IKabs(evalcond[5]) > 0.000001  )
{
continue;
}
}

{
std::vector<IkSingleDOFSolutionBase<IkReal> > vinfos(7);
vinfos[0].jointtype = 1;
vinfos[0].foffset = j0;
vinfos[0].indices[0] = _ij0[0];
vinfos[0].indices[1] = _ij0[1];
vinfos[0].maxsolutions = _nj0;
vinfos[1].jointtype = 1;
vinfos[1].foffset = j1;
vinfos[1].indices[0] = _ij1[0];
vinfos[1].indices[1] = _ij1[1];
vinfos[1].maxsolutions = _nj1;
vinfos[2].jointtype = 1;
vinfos[2].foffset = j2;
vinfos[2].indices[0] = _ij2[0];
vinfos[2].indices[1] = _ij2[1];
vinfos[2].maxsolutions = _nj2;
vinfos[3].jointtype = 1;
vinfos[3].foffset = j3;
vinfos[3].indices[0] = _ij3[0];
vinfos[3].indices[1] = _ij3[1];
vinfos[3].maxsolutions = _nj3;
vinfos[4].jointtype = 1;
vinfos[4].foffset = j4;
vinfos[4].indices[0] = _ij4[0];
vinfos[4].indices[1] = _ij4[1];
vinfos[4].maxsolutions = _nj4;
vinfos[5].jointtype = 1;
vinfos[5].foffset = j5;
vinfos[5].indices[0] = _ij5[0];
vinfos[5].indices[1] = _ij5[1];
vinfos[5].maxsolutions = _nj5;
vinfos[6].jointtype = 1;
vinfos[6].foffset = j6;
vinfos[6].indices[0] = _ij6[0];
vinfos[6].indices[1] = _ij6[1];
vinfos[6].maxsolutions = _nj6;
std::vector<int> vfree(0);
solutions.AddSolution(vinfos,vfree);
}
}
}

}

}

} else
{
{
IkReal j3array[1], cj3array[1], sj3array[1];
bool j3valid[1]={false};
_nj3 = 1;
IkReal x7150=((sj1)*(sj6));
IkReal x7151=((r20)*(sj5));
IkReal x7152=((IkReal(1.00000000000000))*(r21));
IkReal x7153=((cj5)*(cj6));
IkReal x7154=((r22)*(sj5));
IkReal x7155=((cj4)*(sj1));
IkReal x7156=((cj1)*(cj2));
IkReal x7157=((cj5)*(r20));
IkReal x7158=((cj4)*(x7156));
IkReal x7159=((IkReal(1.00000000000000))*(cj5)*(r22));
IkReal x7160=((cj6)*(r20)*(sj4));
IkReal x7161=((cj6)*(r21)*(sj5));
if( IKabs(((gconst4)*(((((cj4)*(x7150)*(x7157)))+(((r21)*(x7153)*(x7155)))+(((IkReal(-1.00000000000000))*(x7156)*(x7159)))+(((sj6)*(x7151)*(x7156)))+(((sj1)*(x7160)))+(((x7154)*(x7155)))+(((IkReal(-1.00000000000000))*(sj4)*(x7150)*(x7152)))+(((x7156)*(x7161))))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(((gconst4)*(((((IkReal(-1.00000000000000))*(x7152)*(x7153)*(x7158)))+(((x7150)*(x7151)))+(((IkReal(-1.00000000000000))*(sj1)*(x7159)))+(((IkReal(-1.00000000000000))*(x7156)*(x7160)))+(((IkReal(-1.00000000000000))*(sj6)*(x7157)*(x7158)))+(((IkReal(-1.00000000000000))*(x7154)*(x7158)))+(((sj1)*(x7161)))+(((r21)*(sj4)*(sj6)*(x7156))))))) < IKFAST_ATAN2_MAGTHRESH )
    continue;
j3array[0]=IKatan2(((gconst4)*(((((cj4)*(x7150)*(x7157)))+(((r21)*(x7153)*(x7155)))+(((IkReal(-1.00000000000000))*(x7156)*(x7159)))+(((sj6)*(x7151)*(x7156)))+(((sj1)*(x7160)))+(((x7154)*(x7155)))+(((IkReal(-1.00000000000000))*(sj4)*(x7150)*(x7152)))+(((x7156)*(x7161)))))), ((gconst4)*(((((IkReal(-1.00000000000000))*(x7152)*(x7153)*(x7158)))+(((x7150)*(x7151)))+(((IkReal(-1.00000000000000))*(sj1)*(x7159)))+(((IkReal(-1.00000000000000))*(x7156)*(x7160)))+(((IkReal(-1.00000000000000))*(sj6)*(x7157)*(x7158)))+(((IkReal(-1.00000000000000))*(x7154)*(x7158)))+(((sj1)*(x7161)))+(((r21)*(sj4)*(sj6)*(x7156)))))));
sj3array[0]=IKsin(j3array[0]);
cj3array[0]=IKcos(j3array[0]);
if( j3array[0] > IKPI )
{
    j3array[0]-=IK2PI;
}
else if( j3array[0] < -IKPI )
{    j3array[0]+=IK2PI;
}
j3valid[0] = true;
for(int ij3 = 0; ij3 < 1; ++ij3)
{
if( !j3valid[ij3] )
{
    continue;
}
_ij3[0] = ij3; _ij3[1] = -1;
for(int iij3 = ij3+1; iij3 < 1; ++iij3)
{
if( j3valid[iij3] && IKabs(cj3array[ij3]-cj3array[iij3]) < IKFAST_SOLUTION_THRESH && IKabs(sj3array[ij3]-sj3array[iij3]) < IKFAST_SOLUTION_THRESH )
{
    j3valid[iij3]=false; _ij3[1] = iij3; break; 
}
}
j3 = j3array[ij3]; cj3 = cj3array[ij3]; sj3 = sj3array[ij3];
{
IkReal evalcond[6];
IkReal x7162=IKcos(j3);
IkReal x7163=IKsin(j3);
IkReal x7164=((sj0)*(sj5));
IkReal x7165=((r00)*(sj6));
IkReal x7166=((IkReal(1.00000000000000))*(cj4));
IkReal x7167=((cj6)*(r01));
IkReal x7168=((cj0)*(cj5));
IkReal x7169=((cj5)*(sj0));
IkReal x7170=((cj6)*(r11));
IkReal x7171=((cj6)*(sj4));
IkReal x7172=((IkReal(1.00000000000000))*(cj1));
IkReal x7173=((cj4)*(cj5));
IkReal x7174=((cj6)*(r21));
IkReal x7175=((r20)*(sj6));
IkReal x7176=((r10)*(sj6));
IkReal x7177=((cj0)*(sj5));
IkReal x7178=((IkReal(1.00000000000000))*(cj0));
IkReal x7179=((IkReal(1.00000000000000))*(x7177));
IkReal x7180=((IkReal(1.00000000000000))*(x7163));
IkReal x7181=((cj0)*(sj4)*(sj6));
IkReal x7182=((cj2)*(x7163));
IkReal x7183=((sj0)*(sj4)*(sj6));
IkReal x7184=((IkReal(1.00000000000000))*(sj1)*(x7162));
evalcond[0]=((((IkReal(-1.00000000000000))*(x7184)))+(((IkReal(-1.00000000000000))*(cj5)*(r22)))+(((sj5)*(x7174)))+(((IkReal(-1.00000000000000))*(x7172)*(x7182)))+(((sj5)*(x7175))));
evalcond[1]=((((IkReal(-1.00000000000000))*(r21)*(sj4)*(sj6)))+(((cj1)*(cj2)*(x7162)))+(((x7173)*(x7175)))+(((cj4)*(r22)*(sj5)))+(((r20)*(x7171)))+(((x7173)*(x7174)))+(((IkReal(-1.00000000000000))*(sj1)*(x7180))));
evalcond[2]=((((x7164)*(x7167)))+(((x7164)*(x7165)))+(((IkReal(-1.00000000000000))*(x7176)*(x7179)))+(((IkReal(-1.00000000000000))*(sj2)*(x7180)))+(((r12)*(x7168)))+(((IkReal(-1.00000000000000))*(x7170)*(x7179)))+(((IkReal(-1.00000000000000))*(r02)*(x7169))));
evalcond[3]=((((IkReal(-1.00000000000000))*(x7165)*(x7179)))+(((r12)*(x7169)))+(((IkReal(-1.00000000000000))*(x7162)*(x7172)))+(((sj1)*(x7182)))+(((r02)*(x7168)))+(((IkReal(-1.00000000000000))*(x7164)*(x7170)))+(((IkReal(-1.00000000000000))*(x7164)*(x7176)))+(((IkReal(-1.00000000000000))*(x7167)*(x7179))));
evalcond[4]=((((cj4)*(r02)*(x7164)))+(((IkReal(-1.00000000000000))*(x7166)*(x7168)*(x7176)))+(((IkReal(-1.00000000000000))*(r12)*(x7166)*(x7177)))+(((r00)*(sj0)*(x7171)))+(((IkReal(-1.00000000000000))*(r10)*(x7171)*(x7178)))+(((sj2)*(x7162)))+(((cj4)*(x7167)*(x7169)))+(((IkReal(-1.00000000000000))*(x7166)*(x7168)*(x7170)))+(((IkReal(-1.00000000000000))*(r01)*(x7183)))+(((cj4)*(x7165)*(x7169)))+(((r11)*(x7181))));
evalcond[5]=((((IkReal(-1.00000000000000))*(r10)*(sj0)*(x7171)))+(((IkReal(-1.00000000000000))*(x7166)*(x7169)*(x7176)))+(((IkReal(-1.00000000000000))*(r02)*(x7166)*(x7177)))+(((IkReal(-1.00000000000000))*(r00)*(x7171)*(x7178)))+(((IkReal(-1.00000000000000))*(x7166)*(x7167)*(x7168)))+(((IkReal(-1.00000000000000))*(r12)*(x7164)*(x7166)))+(((IkReal(-1.00000000000000))*(x7165)*(x7166)*(x7168)))+(((r11)*(x7183)))+(((IkReal(-1.00000000000000))*(cj2)*(x7184)))+(((IkReal(-1.00000000000000))*(x7166)*(x7169)*(x7170)))+(((r01)*(x7181)))+(((IkReal(-1.00000000000000))*(x7163)*(x7172))));
if( IKabs(evalcond[0]) > 0.000001  || IKabs(evalcond[1]) > 0.000001  || IKabs(evalcond[2]) > 0.000001  || IKabs(evalcond[3]) > 0.000001  || IKabs(evalcond[4]) > 0.000001  || IKabs(evalcond[5]) > 0.000001  )
{
continue;
}
}

{
std::vector<IkSingleDOFSolutionBase<IkReal> > vinfos(7);
vinfos[0].jointtype = 1;
vinfos[0].foffset = j0;
vinfos[0].indices[0] = _ij0[0];
vinfos[0].indices[1] = _ij0[1];
vinfos[0].maxsolutions = _nj0;
vinfos[1].jointtype = 1;
vinfos[1].foffset = j1;
vinfos[1].indices[0] = _ij1[0];
vinfos[1].indices[1] = _ij1[1];
vinfos[1].maxsolutions = _nj1;
vinfos[2].jointtype = 1;
vinfos[2].foffset = j2;
vinfos[2].indices[0] = _ij2[0];
vinfos[2].indices[1] = _ij2[1];
vinfos[2].maxsolutions = _nj2;
vinfos[3].jointtype = 1;
vinfos[3].foffset = j3;
vinfos[3].indices[0] = _ij3[0];
vinfos[3].indices[1] = _ij3[1];
vinfos[3].maxsolutions = _nj3;
vinfos[4].jointtype = 1;
vinfos[4].foffset = j4;
vinfos[4].indices[0] = _ij4[0];
vinfos[4].indices[1] = _ij4[1];
vinfos[4].maxsolutions = _nj4;
vinfos[5].jointtype = 1;
vinfos[5].foffset = j5;
vinfos[5].indices[0] = _ij5[0];
vinfos[5].indices[1] = _ij5[1];
vinfos[5].maxsolutions = _nj5;
vinfos[6].jointtype = 1;
vinfos[6].foffset = j6;
vinfos[6].indices[0] = _ij6[0];
vinfos[6].indices[1] = _ij6[1];
vinfos[6].maxsolutions = _nj6;
std::vector<int> vfree(0);
solutions.AddSolution(vinfos,vfree);
}
}
}

}

}
}
}

}

}

} else
{
{
IkReal j4array[1], cj4array[1], sj4array[1];
bool j4valid[1]={false};
_nj4 = 1;
IkReal x7185=((cj5)*(sj0));
IkReal x7186=((cj2)*(sj6));
IkReal x7187=((IkReal(1.00000000000000))*(cj0));
IkReal x7188=((cj2)*(cj6));
IkReal x7189=((cj1)*(cj6)*(sj2));
IkReal x7190=((r10)*(x7187));
IkReal x7191=((cj1)*(sj2)*(sj6));
IkReal x7192=((cj1)*(sj2)*(sj5));
if( IKabs(((gconst0)*(((((r00)*(sj0)*(x7189)))+(((IkReal(-1.00000000000000))*(x7189)*(x7190)))+(((IkReal(-1.00000000000000))*(r01)*(sj0)*(x7191)))+(((r20)*(x7188)))+(((cj0)*(r11)*(x7191)))+(((IkReal(-1.00000000000000))*(r21)*(x7186))))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(((gconst0)*(((((IkReal(-1.00000000000000))*(cj5)*(x7190)*(x7191)))+(((cj2)*(r22)*(sj5)))+(((cj5)*(r20)*(x7186)))+(((cj5)*(r21)*(x7188)))+(((r02)*(sj0)*(x7192)))+(((IkReal(-1.00000000000000))*(cj5)*(r11)*(x7187)*(x7189)))+(((IkReal(-1.00000000000000))*(r12)*(x7187)*(x7192)))+(((r00)*(x7185)*(x7191)))+(((r01)*(x7185)*(x7189))))))) < IKFAST_ATAN2_MAGTHRESH )
    continue;
j4array[0]=IKatan2(((gconst0)*(((((r00)*(sj0)*(x7189)))+(((IkReal(-1.00000000000000))*(x7189)*(x7190)))+(((IkReal(-1.00000000000000))*(r01)*(sj0)*(x7191)))+(((r20)*(x7188)))+(((cj0)*(r11)*(x7191)))+(((IkReal(-1.00000000000000))*(r21)*(x7186)))))), ((gconst0)*(((((IkReal(-1.00000000000000))*(cj5)*(x7190)*(x7191)))+(((cj2)*(r22)*(sj5)))+(((cj5)*(r20)*(x7186)))+(((cj5)*(r21)*(x7188)))+(((r02)*(sj0)*(x7192)))+(((IkReal(-1.00000000000000))*(cj5)*(r11)*(x7187)*(x7189)))+(((IkReal(-1.00000000000000))*(r12)*(x7187)*(x7192)))+(((r00)*(x7185)*(x7191)))+(((r01)*(x7185)*(x7189)))))));
sj4array[0]=IKsin(j4array[0]);
cj4array[0]=IKcos(j4array[0]);
if( j4array[0] > IKPI )
{
    j4array[0]-=IK2PI;
}
else if( j4array[0] < -IKPI )
{    j4array[0]+=IK2PI;
}
j4valid[0] = true;
for(int ij4 = 0; ij4 < 1; ++ij4)
{
if( !j4valid[ij4] )
{
    continue;
}
_ij4[0] = ij4; _ij4[1] = -1;
for(int iij4 = ij4+1; iij4 < 1; ++iij4)
{
if( j4valid[iij4] && IKabs(cj4array[ij4]-cj4array[iij4]) < IKFAST_SOLUTION_THRESH && IKabs(sj4array[ij4]-sj4array[iij4]) < IKFAST_SOLUTION_THRESH )
{
    j4valid[iij4]=false; _ij4[1] = iij4; break; 
}
}
j4 = j4array[ij4]; cj4 = cj4array[ij4]; sj4 = sj4array[ij4];
{
IkReal evalcond[3];
IkReal x7193=IKsin(j4);
IkReal x7194=IKcos(j4);
IkReal x7195=((r00)*(sj6));
IkReal x7196=((cj6)*(r01));
IkReal x7197=((IkReal(1.00000000000000))*(cj0));
IkReal x7198=((IkReal(1.00000000000000))*(sj0));
IkReal x7199=((r10)*(sj6));
IkReal x7200=((sj5)*(x7193));
IkReal x7201=((IkReal(1.00000000000000))*(cj6)*(r11));
IkReal x7202=((cj5)*(x7193));
IkReal x7203=((cj6)*(x7194));
IkReal x7204=((sj0)*(x7202));
IkReal x7205=((r01)*(sj6)*(x7194));
IkReal x7206=((r11)*(sj6)*(x7194));
evalcond[0]=((((IkReal(-1.00000000000000))*(r20)*(x7203)))+(((IkReal(-1.00000000000000))*(cj1)*(sj2)))+(((cj6)*(r21)*(x7202)))+(((r21)*(sj6)*(x7194)))+(((r22)*(x7200)))+(((r20)*(sj6)*(x7202))));
evalcond[1]=((((IkReal(-1.00000000000000))*(x7197)*(x7199)*(x7202)))+(((sj0)*(x7205)))+(((IkReal(-1.00000000000000))*(x7197)*(x7206)))+(((IkReal(-1.00000000000000))*(r00)*(x7198)*(x7203)))+(((x7195)*(x7204)))+(((IkReal(-1.00000000000000))*(r12)*(x7197)*(x7200)))+(((IkReal(-1.00000000000000))*(cj6)*(r11)*(x7197)*(x7202)))+(((r02)*(sj0)*(x7200)))+(cj2)+(((x7196)*(x7204)))+(((cj0)*(r10)*(x7203))));
evalcond[2]=((((IkReal(-1.00000000000000))*(x7196)*(x7197)*(x7202)))+(((IkReal(-1.00000000000000))*(x7195)*(x7197)*(x7202)))+(((IkReal(-1.00000000000000))*(r12)*(x7198)*(x7200)))+(((IkReal(-1.00000000000000))*(x7198)*(x7199)*(x7202)))+(((IkReal(-1.00000000000000))*(cj6)*(r11)*(x7198)*(x7202)))+(((IkReal(-1.00000000000000))*(r02)*(x7197)*(x7200)))+(((cj0)*(r00)*(x7203)))+(((IkReal(-1.00000000000000))*(x7198)*(x7206)))+(((r10)*(sj0)*(x7203)))+(((sj1)*(sj2)))+(((IkReal(-1.00000000000000))*(x7197)*(x7205))));
if( IKabs(evalcond[0]) > 0.000001  || IKabs(evalcond[1]) > 0.000001  || IKabs(evalcond[2]) > 0.000001  )
{
continue;
}
}

{
IkReal dummyeval[1];
IkReal gconst4;
gconst4=IKsign((((sj1)*(sj1))+((((cj1)*(cj1))*((cj2)*(cj2))))));
dummyeval[0]=(((sj1)*(sj1))+((((cj1)*(cj1))*((cj2)*(cj2)))));
if( IKabs(dummyeval[0]) < 0.0000010000000000  )
{
{
IkReal dummyeval[2];
IkReal x7207=(cj1)*(cj1);
IkReal x7208=(sj1)*(sj1);
dummyeval[0]=((((cj2)*(x7207)))+(((cj2)*(x7208))));
dummyeval[1]=((x7208)+(x7207));
if( IKabs(dummyeval[0]) < 0.0000010000000000  || IKabs(dummyeval[1]) < 0.0000010000000000  )
{
{
IkReal dummyeval[2];
dummyeval[0]=sj2;
dummyeval[1]=sj1;
if( IKabs(dummyeval[0]) < 0.0000010000000000  || IKabs(dummyeval[1]) < 0.0000010000000000  )
{
{
IkReal evalcond[9];
IkReal x7209=((cj5)*(sj4));
IkReal x7210=((IkReal(1.00000000000000))*(sj6));
IkReal x7211=((r10)*(sj0));
IkReal x7212=((sj4)*(sj5));
IkReal x7213=((cj4)*(cj5));
IkReal x7214=((IkReal(1.00000000000000))*(r02));
IkReal x7215=((IkReal(0.374290000000000))*(cj0));
IkReal x7216=((cj5)*(r12));
IkReal x7217=((cj6)*(sj5));
IkReal x7218=((cj0)*(r11));
IkReal x7219=((cj5)*(sj0));
IkReal x7220=((r20)*(sj6));
IkReal x7221=((IkReal(1.00000000000000))*(sj0));
IkReal x7222=((IkReal(1.00000000000000))*(cj6));
IkReal x7223=((IkReal(0.0100000000000000))*(cj5));
IkReal x7224=((IkReal(0.0100000000000000))*(sj5));
IkReal x7225=((sj5)*(sj6));
IkReal x7226=((cj0)*(r10));
IkReal x7227=((cj4)*(cj6));
IkReal x7228=((cj0)*(r01));
IkReal x7229=((cj0)*(r00));
IkReal x7230=((cj6)*(r21));
IkReal x7231=((IkReal(0.374290000000000))*(sj0));
IkReal x7232=((IkReal(0.374290000000000))*(sj5));
IkReal x7233=((cj6)*(r11));
IkReal x7234=((sj0)*(sj4));
IkReal x7235=((cj4)*(sj5));
IkReal x7236=((cj4)*(sj6));
IkReal x7237=((IkReal(1.00000000000000))*(cj0));
IkReal x7238=((r02)*(sj0));
IkReal x7239=((r00)*(sj0)*(sj6));
IkReal x7240=((cj6)*(r01)*(sj0));
IkReal x7241=((r00)*(x7227));
IkReal x7242=((r12)*(x7237));
evalcond[0]=((IkReal(-3.14159265358979))+(IKfmod(((IkReal(3.14159265358979))+(j2)), IkReal(6.28318530717959))));
evalcond[1]=((((x7209)*(x7230)))+(((IkReal(-1.00000000000000))*(cj4)*(r20)*(x7222)))+(((r22)*(x7212)))+(((r21)*(x7236)))+(((x7209)*(x7220))));
evalcond[2]=((((IkReal(0.364420000000000))*(sj1)))+(((IkReal(0.374290000000000))*(r21)*(x7217)))+(((IkReal(-0.374290000000000))*(cj5)*(r22)))+(((x7220)*(x7232)))+(((IkReal(-1.00000000000000))*(x7223)*(x7230)))+(((IkReal(-1.00000000000000))*(x7220)*(x7223)))+(pz)+(((IkReal(-1.00000000000000))*(r22)*(x7224)))+(((IkReal(0.0690000000000000))*(cj1))));
evalcond[3]=((((r01)*(sj0)*(x7217)))+(((cj0)*(x7216)))+(((IkReal(-1.00000000000000))*(x7214)*(x7219)))+(((IkReal(-1.00000000000000))*(x7217)*(x7218)))+(((r00)*(sj0)*(x7225)))+(((IkReal(-1.00000000000000))*(sj5)*(x7210)*(x7226))));
evalcond[4]=((IkReal(1.00000000000000))+(((IkReal(-1.00000000000000))*(x7209)*(x7210)*(x7226)))+(((x7209)*(x7239)))+(((x7226)*(x7227)))+(((IkReal(-1.00000000000000))*(x7221)*(x7241)))+(((x7212)*(x7238)))+(((x7209)*(x7240)))+(((IkReal(-1.00000000000000))*(cj4)*(x7210)*(x7218)))+(((IkReal(-1.00000000000000))*(x7212)*(x7242)))+(((r01)*(sj0)*(x7236)))+(((IkReal(-1.00000000000000))*(x7209)*(x7218)*(x7222))));
evalcond[5]=((((x7235)*(x7238)))+(((IkReal(-1.00000000000000))*(x7210)*(x7213)*(x7226)))+(((x7213)*(x7239)))+(((IkReal(-1.00000000000000))*(r01)*(x7210)*(x7234)))+(((x7213)*(x7240)))+(((sj4)*(sj6)*(x7218)))+(((IkReal(-1.00000000000000))*(x7235)*(x7242)))+(((IkReal(-1.00000000000000))*(sj4)*(x7222)*(x7226)))+(((IkReal(-1.00000000000000))*(x7213)*(x7218)*(x7222)))+(((cj6)*(r00)*(x7234))));
evalcond[6]=((((IkReal(-1.00000000000000))*(x7209)*(x7210)*(x7211)))+(((IkReal(-1.00000000000000))*(cj4)*(r11)*(sj0)*(x7210)))+(((IkReal(-1.00000000000000))*(x7209)*(x7210)*(x7229)))+(((IkReal(-1.00000000000000))*(x7209)*(x7221)*(x7233)))+(((x7227)*(x7229)))+(((IkReal(-1.00000000000000))*(cj0)*(x7212)*(x7214)))+(((x7211)*(x7227)))+(((IkReal(-1.00000000000000))*(r12)*(x7212)*(x7221)))+(((IkReal(-1.00000000000000))*(cj4)*(x7210)*(x7228)))+(((IkReal(-1.00000000000000))*(x7209)*(x7222)*(x7228))));
evalcond[7]=((((IkReal(-0.0100000000000000))*(cj6)*(r01)*(x7219)))+(((IkReal(-1.00000000000000))*(x7224)*(x7238)))+(((IkReal(-1.00000000000000))*(py)*(x7237)))+(((cj0)*(r12)*(x7224)))+(((r01)*(x7217)*(x7231)))+(((IkReal(-0.374290000000000))*(r02)*(x7219)))+(((sj6)*(x7223)*(x7226)))+(((IkReal(-1.00000000000000))*(r11)*(x7215)*(x7217)))+(((cj6)*(x7218)*(x7223)))+(((r00)*(x7225)*(x7231)))+(((x7215)*(x7216)))+(((px)*(sj0)))+(((IkReal(-0.0100000000000000))*(r00)*(sj6)*(x7219)))+(((IkReal(-1.00000000000000))*(r10)*(x7215)*(x7225))));
evalcond[8]=((IkReal(0.0690000000000000))+(((IkReal(-0.0690000000000000))*(sj1)))+(((IkReal(-1.00000000000000))*(py)*(x7221)))+(((IkReal(-1.00000000000000))*(px)*(x7237)))+(((IkReal(-1.00000000000000))*(r11)*(x7217)*(x7231)))+(((cj5)*(r02)*(x7215)))+(((cj0)*(r02)*(x7224)))+(((sj6)*(x7211)*(x7223)))+(((IkReal(-0.374290000000000))*(x7211)*(x7225)))+(((IkReal(-1.00000000000000))*(r01)*(x7215)*(x7217)))+(((x7216)*(x7231)))+(((IkReal(0.0100000000000000))*(x7219)*(x7233)))+(((IkReal(-1.00000000000000))*(r00)*(x7215)*(x7225)))+(((r12)*(sj0)*(x7224)))+(((cj6)*(x7223)*(x7228)))+(((IkReal(0.364420000000000))*(cj1)))+(((sj6)*(x7223)*(x7229))));
if( IKabs(evalcond[0]) < 0.0000010000000000  && IKabs(evalcond[1]) < 0.0000010000000000  && IKabs(evalcond[2]) < 0.0000010000000000  && IKabs(evalcond[3]) < 0.0000010000000000  && IKabs(evalcond[4]) < 0.0000010000000000  && IKabs(evalcond[5]) < 0.0000010000000000  && IKabs(evalcond[6]) < 0.0000010000000000  && IKabs(evalcond[7]) < 0.0000010000000000  && IKabs(evalcond[8]) < 0.0000010000000000  )
{
{
IkReal dummyeval[1];
IkReal gconst5;
gconst5=IKsign((((cj1)*(cj1))+((sj1)*(sj1))));
dummyeval[0]=(((cj1)*(cj1))+((sj1)*(sj1)));
if( IKabs(dummyeval[0]) < 0.0000010000000000  )
{
{
IkReal dummyeval[1];
IkReal gconst6;
gconst6=IKsign((((cj1)*(cj1))+((sj1)*(sj1))));
dummyeval[0]=(((cj1)*(cj1))+((sj1)*(sj1)));
if( IKabs(dummyeval[0]) < 0.0000010000000000  )
{
continue;

} else
{
{
IkReal j3array[1], cj3array[1], sj3array[1];
bool j3valid[1]={false};
_nj3 = 1;
IkReal x7243=((sj5)*(sj6));
IkReal x7244=((IkReal(1.00000000000000))*(sj0));
IkReal x7245=((cj5)*(r12));
IkReal x7246=((cj0)*(r00));
IkReal x7247=((cj0)*(cj1));
IkReal x7248=((cj6)*(sj5));
IkReal x7249=((cj5)*(r02));
IkReal x7250=((IkReal(1.00000000000000))*(cj1));
IkReal x7251=((sj0)*(sj1));
IkReal x7252=((cj0)*(sj1));
IkReal x7253=((cj5)*(r22));
if( IKabs(((gconst6)*(((((cj1)*(r20)*(x7243)))+(((IkReal(-1.00000000000000))*(x7249)*(x7252)))+(((IkReal(-1.00000000000000))*(x7250)*(x7253)))+(((r11)*(x7248)*(x7251)))+(((sj1)*(x7243)*(x7246)))+(((r01)*(x7248)*(x7252)))+(((cj1)*(r21)*(x7248)))+(((r10)*(x7243)*(x7251)))+(((IkReal(-1.00000000000000))*(sj1)*(x7244)*(x7245))))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(((gconst6)*(((((IkReal(-1.00000000000000))*(sj1)*(x7253)))+(((r21)*(sj1)*(x7248)))+(((r20)*(sj1)*(x7243)))+(((x7247)*(x7249)))+(((IkReal(-1.00000000000000))*(r01)*(x7247)*(x7248)))+(((IkReal(-1.00000000000000))*(cj1)*(r11)*(x7244)*(x7248)))+(((cj1)*(sj0)*(x7245)))+(((IkReal(-1.00000000000000))*(cj1)*(r10)*(x7243)*(x7244)))+(((IkReal(-1.00000000000000))*(x7243)*(x7246)*(x7250))))))) < IKFAST_ATAN2_MAGTHRESH )
    continue;
j3array[0]=IKatan2(((gconst6)*(((((cj1)*(r20)*(x7243)))+(((IkReal(-1.00000000000000))*(x7249)*(x7252)))+(((IkReal(-1.00000000000000))*(x7250)*(x7253)))+(((r11)*(x7248)*(x7251)))+(((sj1)*(x7243)*(x7246)))+(((r01)*(x7248)*(x7252)))+(((cj1)*(r21)*(x7248)))+(((r10)*(x7243)*(x7251)))+(((IkReal(-1.00000000000000))*(sj1)*(x7244)*(x7245)))))), ((gconst6)*(((((IkReal(-1.00000000000000))*(sj1)*(x7253)))+(((r21)*(sj1)*(x7248)))+(((r20)*(sj1)*(x7243)))+(((x7247)*(x7249)))+(((IkReal(-1.00000000000000))*(r01)*(x7247)*(x7248)))+(((IkReal(-1.00000000000000))*(cj1)*(r11)*(x7244)*(x7248)))+(((cj1)*(sj0)*(x7245)))+(((IkReal(-1.00000000000000))*(cj1)*(r10)*(x7243)*(x7244)))+(((IkReal(-1.00000000000000))*(x7243)*(x7246)*(x7250)))))));
sj3array[0]=IKsin(j3array[0]);
cj3array[0]=IKcos(j3array[0]);
if( j3array[0] > IKPI )
{
    j3array[0]-=IK2PI;
}
else if( j3array[0] < -IKPI )
{    j3array[0]+=IK2PI;
}
j3valid[0] = true;
for(int ij3 = 0; ij3 < 1; ++ij3)
{
if( !j3valid[ij3] )
{
    continue;
}
_ij3[0] = ij3; _ij3[1] = -1;
for(int iij3 = ij3+1; iij3 < 1; ++iij3)
{
if( j3valid[iij3] && IKabs(cj3array[ij3]-cj3array[iij3]) < IKFAST_SOLUTION_THRESH && IKabs(sj3array[ij3]-sj3array[iij3]) < IKFAST_SOLUTION_THRESH )
{
    j3valid[iij3]=false; _ij3[1] = iij3; break; 
}
}
j3 = j3array[ij3]; cj3 = cj3array[ij3]; sj3 = sj3array[ij3];
{
IkReal evalcond[4];
IkReal x7254=IKcos(j3);
IkReal x7255=IKsin(j3);
IkReal x7256=((IkReal(1.00000000000000))*(cj4));
IkReal x7257=((sj0)*(sj5));
IkReal x7258=((cj0)*(cj5));
IkReal x7259=((cj6)*(r01));
IkReal x7260=((r00)*(sj6));
IkReal x7261=((cj6)*(r11));
IkReal x7262=((cj5)*(sj0));
IkReal x7263=((cj6)*(sj4));
IkReal x7264=((sj4)*(sj6));
IkReal x7265=((cj4)*(cj5));
IkReal x7266=((cj6)*(r21));
IkReal x7267=((r20)*(sj6));
IkReal x7268=((r10)*(sj6));
IkReal x7269=((cj1)*(x7254));
IkReal x7270=((IkReal(1.00000000000000))*(cj0)*(sj5));
IkReal x7271=((IkReal(1.00000000000000))*(x7255));
IkReal x7272=((IkReal(1.00000000000000))*(sj1)*(x7254));
IkReal x7273=((cj1)*(x7271));
IkReal x7274=((x7272)+(x7273));
evalcond[0]=((((sj5)*(x7267)))+(((sj5)*(x7266)))+(((IkReal(-1.00000000000000))*(x7274)))+(((IkReal(-1.00000000000000))*(cj5)*(r22))));
evalcond[1]=((((x7265)*(x7266)))+(((IkReal(-1.00000000000000))*(sj1)*(x7271)))+(((cj4)*(r22)*(sj5)))+(((r20)*(x7263)))+(x7269)+(((x7265)*(x7267)))+(((IkReal(-1.00000000000000))*(r21)*(x7264))));
evalcond[2]=((((IkReal(-1.00000000000000))*(x7269)))+(((sj1)*(x7255)))+(((r02)*(x7258)))+(((r12)*(x7262)))+(((IkReal(-1.00000000000000))*(x7259)*(x7270)))+(((IkReal(-1.00000000000000))*(x7260)*(x7270)))+(((IkReal(-1.00000000000000))*(x7257)*(x7268)))+(((IkReal(-1.00000000000000))*(x7257)*(x7261))));
evalcond[3]=((((IkReal(-1.00000000000000))*(cj0)*(r00)*(x7263)))+(((IkReal(-1.00000000000000))*(r10)*(sj0)*(x7263)))+(((IkReal(-1.00000000000000))*(x7256)*(x7261)*(x7262)))+(((IkReal(-1.00000000000000))*(x7256)*(x7258)*(x7259)))+(((IkReal(-1.00000000000000))*(x7256)*(x7262)*(x7268)))+(((IkReal(-1.00000000000000))*(x7274)))+(((cj0)*(r01)*(x7264)))+(((IkReal(-1.00000000000000))*(cj0)*(r02)*(sj5)*(x7256)))+(((IkReal(-1.00000000000000))*(x7256)*(x7258)*(x7260)))+(((IkReal(-1.00000000000000))*(r12)*(x7256)*(x7257)))+(((r11)*(sj0)*(x7264))));
if( IKabs(evalcond[0]) > 0.000001  || IKabs(evalcond[1]) > 0.000001  || IKabs(evalcond[2]) > 0.000001  || IKabs(evalcond[3]) > 0.000001  )
{
continue;
}
}

{
std::vector<IkSingleDOFSolutionBase<IkReal> > vinfos(7);
vinfos[0].jointtype = 1;
vinfos[0].foffset = j0;
vinfos[0].indices[0] = _ij0[0];
vinfos[0].indices[1] = _ij0[1];
vinfos[0].maxsolutions = _nj0;
vinfos[1].jointtype = 1;
vinfos[1].foffset = j1;
vinfos[1].indices[0] = _ij1[0];
vinfos[1].indices[1] = _ij1[1];
vinfos[1].maxsolutions = _nj1;
vinfos[2].jointtype = 1;
vinfos[2].foffset = j2;
vinfos[2].indices[0] = _ij2[0];
vinfos[2].indices[1] = _ij2[1];
vinfos[2].maxsolutions = _nj2;
vinfos[3].jointtype = 1;
vinfos[3].foffset = j3;
vinfos[3].indices[0] = _ij3[0];
vinfos[3].indices[1] = _ij3[1];
vinfos[3].maxsolutions = _nj3;
vinfos[4].jointtype = 1;
vinfos[4].foffset = j4;
vinfos[4].indices[0] = _ij4[0];
vinfos[4].indices[1] = _ij4[1];
vinfos[4].maxsolutions = _nj4;
vinfos[5].jointtype = 1;
vinfos[5].foffset = j5;
vinfos[5].indices[0] = _ij5[0];
vinfos[5].indices[1] = _ij5[1];
vinfos[5].maxsolutions = _nj5;
vinfos[6].jointtype = 1;
vinfos[6].foffset = j6;
vinfos[6].indices[0] = _ij6[0];
vinfos[6].indices[1] = _ij6[1];
vinfos[6].maxsolutions = _nj6;
std::vector<int> vfree(0);
solutions.AddSolution(vinfos,vfree);
}
}
}

}

}

} else
{
{
IkReal j3array[1], cj3array[1], sj3array[1];
bool j3valid[1]={false};
_nj3 = 1;
IkReal x7275=((sj1)*(sj5));
IkReal x7276=((r20)*(sj6));
IkReal x7277=((cj4)*(r22));
IkReal x7278=((IkReal(1.00000000000000))*(cj1));
IkReal x7279=((cj5)*(sj1));
IkReal x7280=((cj6)*(r21));
IkReal x7281=((cj1)*(sj5));
IkReal x7282=((cj4)*(cj5));
IkReal x7283=((cj6)*(r20)*(sj4));
IkReal x7284=((r21)*(sj4)*(sj6));
if( IKabs(((gconst5)*(((((x7276)*(x7281)))+(((x7280)*(x7281)))+(((x7275)*(x7277)))+(((sj1)*(x7283)))+(((IkReal(-1.00000000000000))*(cj5)*(r22)*(x7278)))+(((cj4)*(x7279)*(x7280)))+(((cj4)*(x7276)*(x7279)))+(((IkReal(-1.00000000000000))*(sj1)*(x7284))))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(((gconst5)*(((((IkReal(-1.00000000000000))*(r22)*(x7279)))+(((IkReal(-1.00000000000000))*(x7278)*(x7280)*(x7282)))+(((cj1)*(x7284)))+(((x7275)*(x7280)))+(((IkReal(-1.00000000000000))*(sj5)*(x7277)*(x7278)))+(((IkReal(-1.00000000000000))*(x7276)*(x7278)*(x7282)))+(((x7275)*(x7276)))+(((IkReal(-1.00000000000000))*(x7278)*(x7283))))))) < IKFAST_ATAN2_MAGTHRESH )
    continue;
j3array[0]=IKatan2(((gconst5)*(((((x7276)*(x7281)))+(((x7280)*(x7281)))+(((x7275)*(x7277)))+(((sj1)*(x7283)))+(((IkReal(-1.00000000000000))*(cj5)*(r22)*(x7278)))+(((cj4)*(x7279)*(x7280)))+(((cj4)*(x7276)*(x7279)))+(((IkReal(-1.00000000000000))*(sj1)*(x7284)))))), ((gconst5)*(((((IkReal(-1.00000000000000))*(r22)*(x7279)))+(((IkReal(-1.00000000000000))*(x7278)*(x7280)*(x7282)))+(((cj1)*(x7284)))+(((x7275)*(x7280)))+(((IkReal(-1.00000000000000))*(sj5)*(x7277)*(x7278)))+(((IkReal(-1.00000000000000))*(x7276)*(x7278)*(x7282)))+(((x7275)*(x7276)))+(((IkReal(-1.00000000000000))*(x7278)*(x7283)))))));
sj3array[0]=IKsin(j3array[0]);
cj3array[0]=IKcos(j3array[0]);
if( j3array[0] > IKPI )
{
    j3array[0]-=IK2PI;
}
else if( j3array[0] < -IKPI )
{    j3array[0]+=IK2PI;
}
j3valid[0] = true;
for(int ij3 = 0; ij3 < 1; ++ij3)
{
if( !j3valid[ij3] )
{
    continue;
}
_ij3[0] = ij3; _ij3[1] = -1;
for(int iij3 = ij3+1; iij3 < 1; ++iij3)
{
if( j3valid[iij3] && IKabs(cj3array[ij3]-cj3array[iij3]) < IKFAST_SOLUTION_THRESH && IKabs(sj3array[ij3]-sj3array[iij3]) < IKFAST_SOLUTION_THRESH )
{
    j3valid[iij3]=false; _ij3[1] = iij3; break; 
}
}
j3 = j3array[ij3]; cj3 = cj3array[ij3]; sj3 = sj3array[ij3];
{
IkReal evalcond[4];
IkReal x7285=IKcos(j3);
IkReal x7286=IKsin(j3);
IkReal x7287=((IkReal(1.00000000000000))*(cj4));
IkReal x7288=((sj0)*(sj5));
IkReal x7289=((cj0)*(cj5));
IkReal x7290=((cj6)*(r01));
IkReal x7291=((r00)*(sj6));
IkReal x7292=((cj6)*(r11));
IkReal x7293=((cj5)*(sj0));
IkReal x7294=((cj6)*(sj4));
IkReal x7295=((sj4)*(sj6));
IkReal x7296=((cj4)*(cj5));
IkReal x7297=((cj6)*(r21));
IkReal x7298=((r20)*(sj6));
IkReal x7299=((r10)*(sj6));
IkReal x7300=((cj1)*(x7285));
IkReal x7301=((IkReal(1.00000000000000))*(cj0)*(sj5));
IkReal x7302=((IkReal(1.00000000000000))*(x7286));
IkReal x7303=((IkReal(1.00000000000000))*(sj1)*(x7285));
IkReal x7304=((cj1)*(x7302));
IkReal x7305=((x7303)+(x7304));
evalcond[0]=((((sj5)*(x7298)))+(((sj5)*(x7297)))+(((IkReal(-1.00000000000000))*(cj5)*(r22)))+(((IkReal(-1.00000000000000))*(x7305))));
evalcond[1]=((((IkReal(-1.00000000000000))*(sj1)*(x7302)))+(((IkReal(-1.00000000000000))*(r21)*(x7295)))+(((cj4)*(r22)*(sj5)))+(x7300)+(((x7296)*(x7297)))+(((r20)*(x7294)))+(((x7296)*(x7298))));
evalcond[2]=((((sj1)*(x7286)))+(((IkReal(-1.00000000000000))*(x7288)*(x7292)))+(((IkReal(-1.00000000000000))*(x7290)*(x7301)))+(((r02)*(x7289)))+(((r12)*(x7293)))+(((IkReal(-1.00000000000000))*(x7300)))+(((IkReal(-1.00000000000000))*(x7291)*(x7301)))+(((IkReal(-1.00000000000000))*(x7288)*(x7299))));
evalcond[3]=((((IkReal(-1.00000000000000))*(x7287)*(x7292)*(x7293)))+(((IkReal(-1.00000000000000))*(x7287)*(x7293)*(x7299)))+(((IkReal(-1.00000000000000))*(cj0)*(r00)*(x7294)))+(((IkReal(-1.00000000000000))*(x7287)*(x7289)*(x7290)))+(((IkReal(-1.00000000000000))*(r12)*(x7287)*(x7288)))+(((IkReal(-1.00000000000000))*(r10)*(sj0)*(x7294)))+(((cj0)*(r01)*(x7295)))+(((r11)*(sj0)*(x7295)))+(((IkReal(-1.00000000000000))*(x7305)))+(((IkReal(-1.00000000000000))*(x7287)*(x7289)*(x7291)))+(((IkReal(-1.00000000000000))*(cj0)*(r02)*(sj5)*(x7287))));
if( IKabs(evalcond[0]) > 0.000001  || IKabs(evalcond[1]) > 0.000001  || IKabs(evalcond[2]) > 0.000001  || IKabs(evalcond[3]) > 0.000001  )
{
continue;
}
}

{
std::vector<IkSingleDOFSolutionBase<IkReal> > vinfos(7);
vinfos[0].jointtype = 1;
vinfos[0].foffset = j0;
vinfos[0].indices[0] = _ij0[0];
vinfos[0].indices[1] = _ij0[1];
vinfos[0].maxsolutions = _nj0;
vinfos[1].jointtype = 1;
vinfos[1].foffset = j1;
vinfos[1].indices[0] = _ij1[0];
vinfos[1].indices[1] = _ij1[1];
vinfos[1].maxsolutions = _nj1;
vinfos[2].jointtype = 1;
vinfos[2].foffset = j2;
vinfos[2].indices[0] = _ij2[0];
vinfos[2].indices[1] = _ij2[1];
vinfos[2].maxsolutions = _nj2;
vinfos[3].jointtype = 1;
vinfos[3].foffset = j3;
vinfos[3].indices[0] = _ij3[0];
vinfos[3].indices[1] = _ij3[1];
vinfos[3].maxsolutions = _nj3;
vinfos[4].jointtype = 1;
vinfos[4].foffset = j4;
vinfos[4].indices[0] = _ij4[0];
vinfos[4].indices[1] = _ij4[1];
vinfos[4].maxsolutions = _nj4;
vinfos[5].jointtype = 1;
vinfos[5].foffset = j5;
vinfos[5].indices[0] = _ij5[0];
vinfos[5].indices[1] = _ij5[1];
vinfos[5].maxsolutions = _nj5;
vinfos[6].jointtype = 1;
vinfos[6].foffset = j6;
vinfos[6].indices[0] = _ij6[0];
vinfos[6].indices[1] = _ij6[1];
vinfos[6].maxsolutions = _nj6;
std::vector<int> vfree(0);
solutions.AddSolution(vinfos,vfree);
}
}
}

}

}

} else
{
IkReal x7306=((cj5)*(sj4));
IkReal x7307=((IkReal(1.00000000000000))*(sj6));
IkReal x7308=((r10)*(sj0));
IkReal x7309=((sj4)*(sj5));
IkReal x7310=((cj4)*(cj5));
IkReal x7311=((IkReal(1.00000000000000))*(r02));
IkReal x7312=((IkReal(0.374290000000000))*(cj0));
IkReal x7313=((cj5)*(r12));
IkReal x7314=((cj6)*(sj5));
IkReal x7315=((cj0)*(r11));
IkReal x7316=((cj5)*(sj0));
IkReal x7317=((r20)*(sj6));
IkReal x7318=((IkReal(1.00000000000000))*(sj0));
IkReal x7319=((IkReal(1.00000000000000))*(cj6));
IkReal x7320=((IkReal(0.0100000000000000))*(cj5));
IkReal x7321=((IkReal(0.0100000000000000))*(sj5));
IkReal x7322=((sj5)*(sj6));
IkReal x7323=((cj0)*(r10));
IkReal x7324=((cj4)*(cj6));
IkReal x7325=((cj0)*(r01));
IkReal x7326=((cj0)*(r00));
IkReal x7327=((cj6)*(r21));
IkReal x7328=((IkReal(0.374290000000000))*(sj0));
IkReal x7329=((IkReal(0.374290000000000))*(sj5));
IkReal x7330=((cj6)*(r11));
IkReal x7331=((sj0)*(sj4));
IkReal x7332=((cj4)*(sj5));
IkReal x7333=((cj4)*(sj6));
IkReal x7334=((IkReal(1.00000000000000))*(cj0));
IkReal x7335=((r02)*(sj0));
IkReal x7336=((r00)*(sj0)*(sj6));
IkReal x7337=((cj6)*(r01)*(sj0));
IkReal x7338=((r00)*(x7324));
IkReal x7339=((r12)*(x7334));
evalcond[0]=((IkReal(-3.14159265358979))+(IKfmod(j2, IkReal(6.28318530717959))));
evalcond[1]=((((x7306)*(x7317)))+(((IkReal(-1.00000000000000))*(cj4)*(r20)*(x7319)))+(((x7306)*(x7327)))+(((r22)*(x7309)))+(((r21)*(x7333))));
evalcond[2]=((((IkReal(0.364420000000000))*(sj1)))+(((IkReal(-0.0690000000000000))*(cj1)))+(((IkReal(0.374290000000000))*(r21)*(x7314)))+(((IkReal(-1.00000000000000))*(x7317)*(x7320)))+(((IkReal(-0.374290000000000))*(cj5)*(r22)))+(((IkReal(-1.00000000000000))*(r22)*(x7321)))+(pz)+(((IkReal(-1.00000000000000))*(x7320)*(x7327)))+(((x7317)*(x7329))));
evalcond[3]=((((IkReal(-1.00000000000000))*(sj5)*(x7307)*(x7323)))+(((IkReal(-1.00000000000000))*(x7311)*(x7316)))+(((r00)*(sj0)*(x7322)))+(((r01)*(sj0)*(x7314)))+(((cj0)*(x7313)))+(((IkReal(-1.00000000000000))*(x7314)*(x7315))));
evalcond[4]=((IkReal(-1.00000000000000))+(((IkReal(-1.00000000000000))*(x7306)*(x7315)*(x7319)))+(((x7323)*(x7324)))+(((r01)*(sj0)*(x7333)))+(((x7306)*(x7337)))+(((IkReal(-1.00000000000000))*(cj4)*(x7307)*(x7315)))+(((x7309)*(x7335)))+(((IkReal(-1.00000000000000))*(x7309)*(x7339)))+(((x7306)*(x7336)))+(((IkReal(-1.00000000000000))*(x7318)*(x7338)))+(((IkReal(-1.00000000000000))*(x7306)*(x7307)*(x7323))));
evalcond[5]=((((IkReal(-1.00000000000000))*(x7307)*(x7310)*(x7323)))+(((sj4)*(sj6)*(x7315)))+(((x7310)*(x7337)))+(((cj6)*(r00)*(x7331)))+(((IkReal(-1.00000000000000))*(x7332)*(x7339)))+(((x7332)*(x7335)))+(((IkReal(-1.00000000000000))*(x7310)*(x7315)*(x7319)))+(((IkReal(-1.00000000000000))*(sj4)*(x7319)*(x7323)))+(((x7310)*(x7336)))+(((IkReal(-1.00000000000000))*(r01)*(x7307)*(x7331))));
evalcond[6]=((((IkReal(-1.00000000000000))*(cj4)*(x7307)*(x7325)))+(((x7324)*(x7326)))+(((x7308)*(x7324)))+(((IkReal(-1.00000000000000))*(x7306)*(x7307)*(x7326)))+(((IkReal(-1.00000000000000))*(r12)*(x7309)*(x7318)))+(((IkReal(-1.00000000000000))*(x7306)*(x7307)*(x7308)))+(((IkReal(-1.00000000000000))*(cj4)*(r11)*(sj0)*(x7307)))+(((IkReal(-1.00000000000000))*(x7306)*(x7318)*(x7330)))+(((IkReal(-1.00000000000000))*(cj0)*(x7309)*(x7311)))+(((IkReal(-1.00000000000000))*(x7306)*(x7319)*(x7325))));
evalcond[7]=((((sj6)*(x7320)*(x7323)))+(((IkReal(-1.00000000000000))*(x7321)*(x7335)))+(((IkReal(-1.00000000000000))*(r11)*(x7312)*(x7314)))+(((cj0)*(r12)*(x7321)))+(((r01)*(x7314)*(x7328)))+(((x7312)*(x7313)))+(((r00)*(x7322)*(x7328)))+(((IkReal(-1.00000000000000))*(r10)*(x7312)*(x7322)))+(((IkReal(-0.0100000000000000))*(cj6)*(r01)*(x7316)))+(((IkReal(-1.00000000000000))*(py)*(x7334)))+(((px)*(sj0)))+(((cj6)*(x7315)*(x7320)))+(((IkReal(-0.374290000000000))*(r02)*(x7316)))+(((IkReal(-0.0100000000000000))*(r00)*(sj6)*(x7316))));
evalcond[8]=((IkReal(0.0690000000000000))+(((IkReal(-0.374290000000000))*(x7308)*(x7322)))+(((cj5)*(r02)*(x7312)))+(((sj6)*(x7308)*(x7320)))+(((IkReal(0.0690000000000000))*(sj1)))+(((x7313)*(x7328)))+(((sj6)*(x7320)*(x7326)))+(((IkReal(-1.00000000000000))*(r11)*(x7314)*(x7328)))+(((r12)*(sj0)*(x7321)))+(((IkReal(-1.00000000000000))*(r00)*(x7312)*(x7322)))+(((IkReal(-1.00000000000000))*(py)*(x7318)))+(((IkReal(-1.00000000000000))*(px)*(x7334)))+(((cj0)*(r02)*(x7321)))+(((IkReal(-1.00000000000000))*(r01)*(x7312)*(x7314)))+(((IkReal(0.0100000000000000))*(x7316)*(x7330)))+(((cj6)*(x7320)*(x7325)))+(((IkReal(0.364420000000000))*(cj1))));
if( IKabs(evalcond[0]) < 0.0000010000000000  && IKabs(evalcond[1]) < 0.0000010000000000  && IKabs(evalcond[2]) < 0.0000010000000000  && IKabs(evalcond[3]) < 0.0000010000000000  && IKabs(evalcond[4]) < 0.0000010000000000  && IKabs(evalcond[5]) < 0.0000010000000000  && IKabs(evalcond[6]) < 0.0000010000000000  && IKabs(evalcond[7]) < 0.0000010000000000  && IKabs(evalcond[8]) < 0.0000010000000000  )
{
{
IkReal dummyeval[1];
IkReal gconst7;
gconst7=IKsign((((cj1)*(cj1))+((sj1)*(sj1))));
dummyeval[0]=(((cj1)*(cj1))+((sj1)*(sj1)));
if( IKabs(dummyeval[0]) < 0.0000010000000000  )
{
{
IkReal dummyeval[1];
IkReal gconst8;
gconst8=IKsign((((cj1)*(cj1))+((sj1)*(sj1))));
dummyeval[0]=(((cj1)*(cj1))+((sj1)*(sj1)));
if( IKabs(dummyeval[0]) < 0.0000010000000000  )
{
continue;

} else
{
{
IkReal j3array[1], cj3array[1], sj3array[1];
bool j3valid[1]={false};
_nj3 = 1;
IkReal x7340=((IkReal(1.00000000000000))*(sj0));
IkReal x7341=((cj6)*(r21));
IkReal x7342=((cj0)*(r00));
IkReal x7343=((cj5)*(sj1));
IkReal x7344=((r12)*(sj0));
IkReal x7345=((cj1)*(cj5));
IkReal x7346=((cj0)*(r02));
IkReal x7347=((sj1)*(sj5));
IkReal x7348=((cj6)*(r11));
IkReal x7349=((cj1)*(sj5));
IkReal x7350=((sj6)*(x7347));
IkReal x7351=((IkReal(1.00000000000000))*(x7349));
IkReal x7352=((cj0)*(cj6)*(r01));
if( IKabs(((gconst8)*(((((x7343)*(x7344)))+(((IkReal(-1.00000000000000))*(x7342)*(x7350)))+(((IkReal(-1.00000000000000))*(x7341)*(x7351)))+(((IkReal(-1.00000000000000))*(x7340)*(x7347)*(x7348)))+(((x7343)*(x7346)))+(((IkReal(-1.00000000000000))*(r20)*(sj6)*(x7351)))+(((r22)*(x7345)))+(((IkReal(-1.00000000000000))*(x7347)*(x7352)))+(((IkReal(-1.00000000000000))*(r10)*(x7340)*(x7350))))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(((gconst8)*(((((x7341)*(x7347)))+(((r20)*(x7350)))+(((x7344)*(x7345)))+(((IkReal(-1.00000000000000))*(sj6)*(x7342)*(x7351)))+(((IkReal(-1.00000000000000))*(x7340)*(x7348)*(x7349)))+(((x7345)*(x7346)))+(((IkReal(-1.00000000000000))*(r22)*(x7343)))+(((IkReal(-1.00000000000000))*(r10)*(sj6)*(x7340)*(x7349)))+(((IkReal(-1.00000000000000))*(x7351)*(x7352))))))) < IKFAST_ATAN2_MAGTHRESH )
    continue;
j3array[0]=IKatan2(((gconst8)*(((((x7343)*(x7344)))+(((IkReal(-1.00000000000000))*(x7342)*(x7350)))+(((IkReal(-1.00000000000000))*(x7341)*(x7351)))+(((IkReal(-1.00000000000000))*(x7340)*(x7347)*(x7348)))+(((x7343)*(x7346)))+(((IkReal(-1.00000000000000))*(r20)*(sj6)*(x7351)))+(((r22)*(x7345)))+(((IkReal(-1.00000000000000))*(x7347)*(x7352)))+(((IkReal(-1.00000000000000))*(r10)*(x7340)*(x7350)))))), ((gconst8)*(((((x7341)*(x7347)))+(((r20)*(x7350)))+(((x7344)*(x7345)))+(((IkReal(-1.00000000000000))*(sj6)*(x7342)*(x7351)))+(((IkReal(-1.00000000000000))*(x7340)*(x7348)*(x7349)))+(((x7345)*(x7346)))+(((IkReal(-1.00000000000000))*(r22)*(x7343)))+(((IkReal(-1.00000000000000))*(r10)*(sj6)*(x7340)*(x7349)))+(((IkReal(-1.00000000000000))*(x7351)*(x7352)))))));
sj3array[0]=IKsin(j3array[0]);
cj3array[0]=IKcos(j3array[0]);
if( j3array[0] > IKPI )
{
    j3array[0]-=IK2PI;
}
else if( j3array[0] < -IKPI )
{    j3array[0]+=IK2PI;
}
j3valid[0] = true;
for(int ij3 = 0; ij3 < 1; ++ij3)
{
if( !j3valid[ij3] )
{
    continue;
}
_ij3[0] = ij3; _ij3[1] = -1;
for(int iij3 = ij3+1; iij3 < 1; ++iij3)
{
if( j3valid[iij3] && IKabs(cj3array[ij3]-cj3array[iij3]) < IKFAST_SOLUTION_THRESH && IKabs(sj3array[ij3]-sj3array[iij3]) < IKFAST_SOLUTION_THRESH )
{
    j3valid[iij3]=false; _ij3[1] = iij3; break; 
}
}
j3 = j3array[ij3]; cj3 = cj3array[ij3]; sj3 = sj3array[ij3];
{
IkReal evalcond[4];
IkReal x7353=IKsin(j3);
IkReal x7354=IKcos(j3);
IkReal x7355=((IkReal(1.00000000000000))*(cj4));
IkReal x7356=((sj0)*(sj5));
IkReal x7357=((cj0)*(cj5));
IkReal x7358=((cj6)*(r01));
IkReal x7359=((r00)*(sj6));
IkReal x7360=((cj6)*(r11));
IkReal x7361=((cj5)*(sj0));
IkReal x7362=((cj6)*(sj4));
IkReal x7363=((sj4)*(sj6));
IkReal x7364=((cj4)*(cj5));
IkReal x7365=((cj6)*(r21));
IkReal x7366=((r20)*(sj6));
IkReal x7367=((r10)*(sj6));
IkReal x7368=((cj1)*(x7353));
IkReal x7369=((IkReal(1.00000000000000))*(cj0)*(sj5));
IkReal x7370=((IkReal(1.00000000000000))*(x7354));
IkReal x7371=((IkReal(1.00000000000000))*(sj1)*(x7353));
IkReal x7372=((cj1)*(x7370));
IkReal x7373=((x7372)+(x7371));
evalcond[0]=((((IkReal(-1.00000000000000))*(sj1)*(x7370)))+(((IkReal(-1.00000000000000))*(cj5)*(r22)))+(((sj5)*(x7365)))+(((sj5)*(x7366)))+(x7368));
evalcond[1]=((((IkReal(-1.00000000000000))*(x7373)))+(((cj4)*(r22)*(sj5)))+(((r20)*(x7362)))+(((x7364)*(x7365)))+(((IkReal(-1.00000000000000))*(r21)*(x7363)))+(((x7364)*(x7366))));
evalcond[2]=((((r12)*(x7361)))+(((IkReal(-1.00000000000000))*(x7356)*(x7367)))+(((IkReal(-1.00000000000000))*(x7373)))+(((IkReal(-1.00000000000000))*(x7359)*(x7369)))+(((IkReal(-1.00000000000000))*(x7358)*(x7369)))+(((r02)*(x7357)))+(((IkReal(-1.00000000000000))*(x7356)*(x7360))));
evalcond[3]=((((IkReal(-1.00000000000000))*(x7355)*(x7357)*(x7358)))+(((r11)*(sj0)*(x7363)))+(((IkReal(-1.00000000000000))*(x7355)*(x7357)*(x7359)))+(((IkReal(-1.00000000000000))*(r12)*(x7355)*(x7356)))+(((IkReal(-1.00000000000000))*(cj0)*(r02)*(sj5)*(x7355)))+(((IkReal(-1.00000000000000))*(x7355)*(x7360)*(x7361)))+(((cj0)*(r01)*(x7363)))+(((IkReal(-1.00000000000000))*(cj0)*(r00)*(x7362)))+(((IkReal(-1.00000000000000))*(x7355)*(x7361)*(x7367)))+(((sj1)*(x7354)))+(((IkReal(-1.00000000000000))*(x7368)))+(((IkReal(-1.00000000000000))*(r10)*(sj0)*(x7362))));
if( IKabs(evalcond[0]) > 0.000001  || IKabs(evalcond[1]) > 0.000001  || IKabs(evalcond[2]) > 0.000001  || IKabs(evalcond[3]) > 0.000001  )
{
continue;
}
}

{
std::vector<IkSingleDOFSolutionBase<IkReal> > vinfos(7);
vinfos[0].jointtype = 1;
vinfos[0].foffset = j0;
vinfos[0].indices[0] = _ij0[0];
vinfos[0].indices[1] = _ij0[1];
vinfos[0].maxsolutions = _nj0;
vinfos[1].jointtype = 1;
vinfos[1].foffset = j1;
vinfos[1].indices[0] = _ij1[0];
vinfos[1].indices[1] = _ij1[1];
vinfos[1].maxsolutions = _nj1;
vinfos[2].jointtype = 1;
vinfos[2].foffset = j2;
vinfos[2].indices[0] = _ij2[0];
vinfos[2].indices[1] = _ij2[1];
vinfos[2].maxsolutions = _nj2;
vinfos[3].jointtype = 1;
vinfos[3].foffset = j3;
vinfos[3].indices[0] = _ij3[0];
vinfos[3].indices[1] = _ij3[1];
vinfos[3].maxsolutions = _nj3;
vinfos[4].jointtype = 1;
vinfos[4].foffset = j4;
vinfos[4].indices[0] = _ij4[0];
vinfos[4].indices[1] = _ij4[1];
vinfos[4].maxsolutions = _nj4;
vinfos[5].jointtype = 1;
vinfos[5].foffset = j5;
vinfos[5].indices[0] = _ij5[0];
vinfos[5].indices[1] = _ij5[1];
vinfos[5].maxsolutions = _nj5;
vinfos[6].jointtype = 1;
vinfos[6].foffset = j6;
vinfos[6].indices[0] = _ij6[0];
vinfos[6].indices[1] = _ij6[1];
vinfos[6].maxsolutions = _nj6;
std::vector<int> vfree(0);
solutions.AddSolution(vinfos,vfree);
}
}
}

}

}

} else
{
{
IkReal j3array[1], cj3array[1], sj3array[1];
bool j3valid[1]={false};
_nj3 = 1;
IkReal x7374=((sj1)*(sj6));
IkReal x7375=((r20)*(sj5));
IkReal x7376=((IkReal(1.00000000000000))*(r21));
IkReal x7377=((cj1)*(cj6));
IkReal x7378=((r20)*(sj4));
IkReal x7379=((cj6)*(sj1));
IkReal x7380=((cj4)*(cj5));
IkReal x7381=((cj1)*(sj6));
IkReal x7382=((cj5)*(r22));
IkReal x7383=((cj4)*(r22)*(sj5));
if( IKabs(((gconst7)*(((((cj1)*(x7382)))+(((IkReal(-1.00000000000000))*(sj4)*(x7374)*(x7376)))+(((IkReal(-1.00000000000000))*(x7375)*(x7381)))+(((r20)*(x7374)*(x7380)))+(((x7378)*(x7379)))+(((sj1)*(x7383)))+(((r21)*(x7379)*(x7380)))+(((IkReal(-1.00000000000000))*(sj5)*(x7376)*(x7377))))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(((gconst7)*(((((r21)*(x7377)*(x7380)))+(((cj1)*(x7383)))+(((x7374)*(x7375)))+(((x7377)*(x7378)))+(((r20)*(x7380)*(x7381)))+(((r21)*(sj5)*(x7379)))+(((IkReal(-1.00000000000000))*(sj1)*(x7382)))+(((IkReal(-1.00000000000000))*(sj4)*(x7376)*(x7381))))))) < IKFAST_ATAN2_MAGTHRESH )
    continue;
j3array[0]=IKatan2(((gconst7)*(((((cj1)*(x7382)))+(((IkReal(-1.00000000000000))*(sj4)*(x7374)*(x7376)))+(((IkReal(-1.00000000000000))*(x7375)*(x7381)))+(((r20)*(x7374)*(x7380)))+(((x7378)*(x7379)))+(((sj1)*(x7383)))+(((r21)*(x7379)*(x7380)))+(((IkReal(-1.00000000000000))*(sj5)*(x7376)*(x7377)))))), ((gconst7)*(((((r21)*(x7377)*(x7380)))+(((cj1)*(x7383)))+(((x7374)*(x7375)))+(((x7377)*(x7378)))+(((r20)*(x7380)*(x7381)))+(((r21)*(sj5)*(x7379)))+(((IkReal(-1.00000000000000))*(sj1)*(x7382)))+(((IkReal(-1.00000000000000))*(sj4)*(x7376)*(x7381)))))));
sj3array[0]=IKsin(j3array[0]);
cj3array[0]=IKcos(j3array[0]);
if( j3array[0] > IKPI )
{
    j3array[0]-=IK2PI;
}
else if( j3array[0] < -IKPI )
{    j3array[0]+=IK2PI;
}
j3valid[0] = true;
for(int ij3 = 0; ij3 < 1; ++ij3)
{
if( !j3valid[ij3] )
{
    continue;
}
_ij3[0] = ij3; _ij3[1] = -1;
for(int iij3 = ij3+1; iij3 < 1; ++iij3)
{
if( j3valid[iij3] && IKabs(cj3array[ij3]-cj3array[iij3]) < IKFAST_SOLUTION_THRESH && IKabs(sj3array[ij3]-sj3array[iij3]) < IKFAST_SOLUTION_THRESH )
{
    j3valid[iij3]=false; _ij3[1] = iij3; break; 
}
}
j3 = j3array[ij3]; cj3 = cj3array[ij3]; sj3 = sj3array[ij3];
{
IkReal evalcond[4];
IkReal x7384=IKsin(j3);
IkReal x7385=IKcos(j3);
IkReal x7386=((IkReal(1.00000000000000))*(cj4));
IkReal x7387=((sj0)*(sj5));
IkReal x7388=((cj0)*(cj5));
IkReal x7389=((cj6)*(r01));
IkReal x7390=((r00)*(sj6));
IkReal x7391=((cj6)*(r11));
IkReal x7392=((cj5)*(sj0));
IkReal x7393=((cj6)*(sj4));
IkReal x7394=((sj4)*(sj6));
IkReal x7395=((cj4)*(cj5));
IkReal x7396=((cj6)*(r21));
IkReal x7397=((r20)*(sj6));
IkReal x7398=((r10)*(sj6));
IkReal x7399=((cj1)*(x7384));
IkReal x7400=((IkReal(1.00000000000000))*(cj0)*(sj5));
IkReal x7401=((IkReal(1.00000000000000))*(x7385));
IkReal x7402=((IkReal(1.00000000000000))*(sj1)*(x7384));
IkReal x7403=((cj1)*(x7401));
IkReal x7404=((x7403)+(x7402));
evalcond[0]=((((IkReal(-1.00000000000000))*(sj1)*(x7401)))+(((sj5)*(x7396)))+(((IkReal(-1.00000000000000))*(cj5)*(r22)))+(x7399)+(((sj5)*(x7397))));
evalcond[1]=((((IkReal(-1.00000000000000))*(r21)*(x7394)))+(((x7395)*(x7396)))+(((r20)*(x7393)))+(((IkReal(-1.00000000000000))*(x7404)))+(((cj4)*(r22)*(sj5)))+(((x7395)*(x7397))));
evalcond[2]=((((r02)*(x7388)))+(((IkReal(-1.00000000000000))*(x7404)))+(((r12)*(x7392)))+(((IkReal(-1.00000000000000))*(x7390)*(x7400)))+(((IkReal(-1.00000000000000))*(x7389)*(x7400)))+(((IkReal(-1.00000000000000))*(x7387)*(x7398)))+(((IkReal(-1.00000000000000))*(x7387)*(x7391))));
evalcond[3]=((((IkReal(-1.00000000000000))*(x7386)*(x7391)*(x7392)))+(((IkReal(-1.00000000000000))*(cj0)*(r00)*(x7393)))+(((IkReal(-1.00000000000000))*(x7386)*(x7388)*(x7389)))+(((IkReal(-1.00000000000000))*(x7386)*(x7388)*(x7390)))+(((sj1)*(x7385)))+(((IkReal(-1.00000000000000))*(cj0)*(r02)*(sj5)*(x7386)))+(((IkReal(-1.00000000000000))*(r10)*(sj0)*(x7393)))+(((cj0)*(r01)*(x7394)))+(((r11)*(sj0)*(x7394)))+(((IkReal(-1.00000000000000))*(x7386)*(x7392)*(x7398)))+(((IkReal(-1.00000000000000))*(x7399)))+(((IkReal(-1.00000000000000))*(r12)*(x7386)*(x7387))));
if( IKabs(evalcond[0]) > 0.000001  || IKabs(evalcond[1]) > 0.000001  || IKabs(evalcond[2]) > 0.000001  || IKabs(evalcond[3]) > 0.000001  )
{
continue;
}
}

{
std::vector<IkSingleDOFSolutionBase<IkReal> > vinfos(7);
vinfos[0].jointtype = 1;
vinfos[0].foffset = j0;
vinfos[0].indices[0] = _ij0[0];
vinfos[0].indices[1] = _ij0[1];
vinfos[0].maxsolutions = _nj0;
vinfos[1].jointtype = 1;
vinfos[1].foffset = j1;
vinfos[1].indices[0] = _ij1[0];
vinfos[1].indices[1] = _ij1[1];
vinfos[1].maxsolutions = _nj1;
vinfos[2].jointtype = 1;
vinfos[2].foffset = j2;
vinfos[2].indices[0] = _ij2[0];
vinfos[2].indices[1] = _ij2[1];
vinfos[2].maxsolutions = _nj2;
vinfos[3].jointtype = 1;
vinfos[3].foffset = j3;
vinfos[3].indices[0] = _ij3[0];
vinfos[3].indices[1] = _ij3[1];
vinfos[3].maxsolutions = _nj3;
vinfos[4].jointtype = 1;
vinfos[4].foffset = j4;
vinfos[4].indices[0] = _ij4[0];
vinfos[4].indices[1] = _ij4[1];
vinfos[4].maxsolutions = _nj4;
vinfos[5].jointtype = 1;
vinfos[5].foffset = j5;
vinfos[5].indices[0] = _ij5[0];
vinfos[5].indices[1] = _ij5[1];
vinfos[5].maxsolutions = _nj5;
vinfos[6].jointtype = 1;
vinfos[6].foffset = j6;
vinfos[6].indices[0] = _ij6[0];
vinfos[6].indices[1] = _ij6[1];
vinfos[6].maxsolutions = _nj6;
std::vector<int> vfree(0);
solutions.AddSolution(vinfos,vfree);
}
}
}

}

}

} else
{
IkReal x7405=((IkReal(1.00000000000000))*(cj0));
IkReal x7406=((cj4)*(sj6));
IkReal x7407=((sj0)*(sj4));
IkReal x7408=((cj5)*(sj6));
IkReal x7409=((sj4)*(sj5));
IkReal x7410=((r12)*(sj5));
IkReal x7411=((IkReal(0.374290000000000))*(cj5));
IkReal x7412=((r02)*(sj0));
IkReal x7413=((cj6)*(r21));
IkReal x7414=((IkReal(0.0100000000000000))*(cj5));
IkReal x7415=((IkReal(1.00000000000000))*(sj0));
IkReal x7416=((cj0)*(r10));
IkReal x7417=((cj4)*(cj6));
IkReal x7418=((r00)*(sj0));
IkReal x7419=((IkReal(0.374290000000000))*(sj5));
IkReal x7420=((cj0)*(r00));
IkReal x7421=((IkReal(0.0100000000000000))*(sj5));
IkReal x7422=((cj0)*(r02));
IkReal x7423=((cj5)*(sj4));
IkReal x7424=((cj6)*(r01));
IkReal x7425=((cj6)*(r11));
IkReal x7426=((r10)*(sj0));
IkReal x7427=((sj6)*(x7419));
IkReal x7428=((cj0)*(cj6)*(x7419));
evalcond[0]=((IkReal(-3.14159265358979))+(IKfmod(((IkReal(3.14159265358979))+(j1)), IkReal(6.28318530717959))));
evalcond[1]=((((IkReal(-1.00000000000000))*(sj2)))+(((x7413)*(x7423)))+(((r20)*(sj4)*(x7408)))+(((r21)*(x7406)))+(((r22)*(x7409)))+(((IkReal(-1.00000000000000))*(r20)*(x7417))));
evalcond[2]=((((IkReal(-1.00000000000000))*(r22)*(x7421)))+(((IkReal(-1.00000000000000))*(x7413)*(x7414)))+(pz)+(((r20)*(x7427)))+(((x7413)*(x7419)))+(((IkReal(0.0690000000000000))*(cj2)))+(((IkReal(-0.0100000000000000))*(r20)*(x7408)))+(((IkReal(-1.00000000000000))*(r22)*(x7411))));
evalcond[3]=((((r01)*(sj0)*(x7406)))+(((r00)*(x7407)*(x7408)))+(((cj5)*(x7407)*(x7424)))+(((x7416)*(x7417)))+(((IkReal(-1.00000000000000))*(r11)*(x7405)*(x7406)))+(cj2)+(((IkReal(-1.00000000000000))*(r10)*(sj4)*(x7405)*(x7408)))+(((IkReal(-1.00000000000000))*(r00)*(x7415)*(x7417)))+(((r02)*(sj5)*(x7407)))+(((IkReal(-1.00000000000000))*(r12)*(x7405)*(x7409)))+(((IkReal(-1.00000000000000))*(x7405)*(x7423)*(x7425))));
evalcond[4]=((((IkReal(-1.00000000000000))*(r11)*(x7406)*(x7415)))+(((IkReal(-1.00000000000000))*(r00)*(sj4)*(x7405)*(x7408)))+(((IkReal(-1.00000000000000))*(r02)*(x7405)*(x7409)))+(((x7417)*(x7420)))+(((IkReal(-1.00000000000000))*(r10)*(x7407)*(x7408)))+(((IkReal(-1.00000000000000))*(x7405)*(x7423)*(x7424)))+(((IkReal(-1.00000000000000))*(x7407)*(x7410)))+(((x7417)*(x7426)))+(((IkReal(-1.00000000000000))*(cj5)*(x7407)*(x7425)))+(((IkReal(-1.00000000000000))*(r01)*(x7405)*(x7406))));
evalcond[5]=((((IkReal(-0.0100000000000000))*(x7408)*(x7418)))+(((IkReal(0.0100000000000000))*(x7408)*(x7416)))+(((IkReal(0.0100000000000000))*(cj0)*(x7410)))+(((IkReal(0.0690000000000000))*(sj2)))+(((IkReal(-1.00000000000000))*(py)*(x7405)))+(((cj0)*(r12)*(x7411)))+(((IkReal(-1.00000000000000))*(cj0)*(x7419)*(x7425)))+(((IkReal(-1.00000000000000))*(x7412)*(x7421)))+(((sj0)*(x7419)*(x7424)))+(((x7418)*(x7427)))+(((IkReal(-1.00000000000000))*(sj0)*(x7414)*(x7424)))+(((IkReal(-1.00000000000000))*(x7416)*(x7427)))+(((px)*(sj0)))+(((IkReal(-1.00000000000000))*(x7411)*(x7412)))+(((cj0)*(x7414)*(x7425))));
evalcond[6]=((IkReal(0.433420000000000))+(((cj0)*(x7414)*(x7424)))+(((IkReal(0.0100000000000000))*(x7408)*(x7420)))+(((IkReal(0.0100000000000000))*(sj0)*(x7410)))+(((IkReal(-1.00000000000000))*(x7420)*(x7427)))+(((x7421)*(x7422)))+(((IkReal(-1.00000000000000))*(px)*(x7405)))+(((IkReal(-1.00000000000000))*(py)*(x7415)))+(((IkReal(-1.00000000000000))*(x7426)*(x7427)))+(((IkReal(-1.00000000000000))*(cj0)*(x7419)*(x7424)))+(((IkReal(-1.00000000000000))*(sj0)*(x7419)*(x7425)))+(((x7411)*(x7422)))+(((IkReal(0.0100000000000000))*(x7408)*(x7426)))+(((sj0)*(x7414)*(x7425)))+(((r12)*(sj0)*(x7411))));
if( IKabs(evalcond[0]) < 0.0000010000000000  && IKabs(evalcond[1]) < 0.0000010000000000  && IKabs(evalcond[2]) < 0.0000010000000000  && IKabs(evalcond[3]) < 0.0000010000000000  && IKabs(evalcond[4]) < 0.0000010000000000  && IKabs(evalcond[5]) < 0.0000010000000000  && IKabs(evalcond[6]) < 0.0000010000000000  )
{
{
IkReal dummyeval[1];
IkReal gconst9;
gconst9=IKsign(cj2);
dummyeval[0]=cj2;
if( IKabs(dummyeval[0]) < 0.0000010000000000  )
{
{
IkReal dummyeval[1];
dummyeval[0]=cj2;
if( IKabs(dummyeval[0]) < 0.0000010000000000  )
{
{
IkReal dummyeval[1];
dummyeval[0]=sj2;
if( IKabs(dummyeval[0]) < 0.0000010000000000  )
{
{
IkReal evalcond[9];
IkReal x7429=((cj5)*(sj4));
IkReal x7430=((IkReal(1.00000000000000))*(sj6));
IkReal x7431=((r10)*(sj0));
IkReal x7432=((sj4)*(sj5));
IkReal x7433=((cj5)*(cj6));
IkReal x7434=((r01)*(sj0));
IkReal x7435=((IkReal(1.00000000000000))*(r02));
IkReal x7436=((IkReal(0.374290000000000))*(cj0));
IkReal x7437=((cj5)*(r12));
IkReal x7438=((cj6)*(sj5));
IkReal x7439=((cj0)*(r11));
IkReal x7440=((cj5)*(sj0));
IkReal x7441=((r20)*(sj6));
IkReal x7442=((IkReal(1.00000000000000))*(sj0));
IkReal x7443=((cj4)*(cj5));
IkReal x7444=((IkReal(1.00000000000000))*(cj6));
IkReal x7445=((IkReal(0.0100000000000000))*(sj5));
IkReal x7446=((sj5)*(sj6));
IkReal x7447=((cj0)*(r10));
IkReal x7448=((cj4)*(cj6));
IkReal x7449=((cj0)*(r01));
IkReal x7450=((IkReal(1.00000000000000))*(cj4));
IkReal x7451=((cj0)*(r00));
IkReal x7452=((IkReal(0.374290000000000))*(sj0));
IkReal x7453=((cj0)*(r12));
IkReal x7454=((IkReal(0.374290000000000))*(sj5));
IkReal x7455=((cj4)*(sj6));
IkReal x7456=((IkReal(1.00000000000000))*(cj0));
IkReal x7457=((r02)*(sj0));
IkReal x7458=((IkReal(0.0100000000000000))*(cj5));
IkReal x7459=((r11)*(sj0));
IkReal x7460=((r00)*(sj0)*(sj6));
IkReal x7461=((r00)*(x7448));
IkReal x7462=((sj6)*(x7458));
evalcond[0]=((IkReal(-3.14159265358979))+(IKfmod(((IkReal(3.14159265358979))+(j2)), IkReal(6.28318530717959))));
evalcond[1]=((((x7429)*(x7441)))+(((r21)*(x7455)))+(((IkReal(-1.00000000000000))*(cj4)*(r20)*(x7444)))+(((r22)*(x7432)))+(((cj6)*(r21)*(x7429))));
evalcond[2]=((IkReal(0.0690000000000000))+(((IkReal(0.374290000000000))*(r21)*(x7438)))+(((IkReal(-1.00000000000000))*(x7441)*(x7458)))+(((IkReal(-0.0100000000000000))*(r21)*(x7433)))+(((x7441)*(x7454)))+(((IkReal(-0.374290000000000))*(cj5)*(r22)))+(pz)+(((IkReal(-1.00000000000000))*(r22)*(x7445))));
evalcond[3]=((((r00)*(sj0)*(x7446)))+(((IkReal(-1.00000000000000))*(x7438)*(x7439)))+(((x7434)*(x7438)))+(((IkReal(-1.00000000000000))*(sj5)*(x7430)*(x7447)))+(((cj0)*(x7437)))+(((IkReal(-1.00000000000000))*(x7435)*(x7440))));
evalcond[4]=((IkReal(1.00000000000000))+(((x7447)*(x7448)))+(((IkReal(-1.00000000000000))*(x7429)*(x7430)*(x7447)))+(((x7434)*(x7455)))+(((IkReal(-1.00000000000000))*(x7442)*(x7461)))+(((IkReal(-1.00000000000000))*(x7432)*(x7453)))+(((cj6)*(x7429)*(x7434)))+(((x7432)*(x7457)))+(((IkReal(-1.00000000000000))*(cj4)*(x7430)*(x7439)))+(((IkReal(-1.00000000000000))*(x7429)*(x7439)*(x7444)))+(((x7429)*(x7460))));
evalcond[5]=((((cj4)*(sj5)*(x7457)))+(((cj4)*(x7433)*(x7434)))+(((IkReal(-1.00000000000000))*(sj5)*(x7450)*(x7453)))+(((r00)*(x7440)*(x7455)))+(((IkReal(-1.00000000000000))*(sj4)*(x7430)*(x7434)))+(((IkReal(-1.00000000000000))*(x7430)*(x7443)*(x7447)))+(((IkReal(-1.00000000000000))*(sj4)*(x7444)*(x7447)))+(((cj6)*(r00)*(sj0)*(sj4)))+(((IkReal(-1.00000000000000))*(x7433)*(x7439)*(x7450)))+(((sj4)*(sj6)*(x7439))));
evalcond[6]=((((x7431)*(x7448)))+(((IkReal(-1.00000000000000))*(x7429)*(x7430)*(x7451)))+(((IkReal(-1.00000000000000))*(cj6)*(r11)*(x7429)*(x7442)))+(((IkReal(-1.00000000000000))*(r12)*(x7432)*(x7442)))+(((IkReal(-1.00000000000000))*(cj4)*(x7430)*(x7459)))+(((IkReal(-1.00000000000000))*(x7429)*(x7444)*(x7449)))+(((x7448)*(x7451)))+(((IkReal(-1.00000000000000))*(cj0)*(x7432)*(x7435)))+(((IkReal(-1.00000000000000))*(x7429)*(x7430)*(x7431)))+(((IkReal(-1.00000000000000))*(cj4)*(x7430)*(x7449))));
evalcond[7]=((((IkReal(-1.00000000000000))*(py)*(x7456)))+(((IkReal(-1.00000000000000))*(r11)*(x7436)*(x7438)))+(((IkReal(-0.374290000000000))*(r02)*(x7440)))+(((IkReal(0.0100000000000000))*(x7433)*(x7439)))+(((IkReal(-0.0100000000000000))*(r00)*(sj6)*(x7440)))+(((IkReal(-0.0100000000000000))*(x7433)*(x7434)))+(((x7436)*(x7437)))+(((r00)*(x7446)*(x7452)))+(((x7447)*(x7462)))+(((px)*(sj0)))+(((IkReal(0.374290000000000))*(x7434)*(x7438)))+(((IkReal(-1.00000000000000))*(x7445)*(x7457)))+(((IkReal(-1.00000000000000))*(r10)*(x7436)*(x7446)))+(((x7445)*(x7453))));
evalcond[8]=((IkReal(0.433420000000000))+(((cj5)*(r02)*(x7436)))+(((IkReal(-1.00000000000000))*(py)*(x7442)))+(((IkReal(-0.374290000000000))*(x7431)*(x7446)))+(((x7431)*(x7462)))+(((x7451)*(x7462)))+(((IkReal(-1.00000000000000))*(r01)*(x7436)*(x7438)))+(((IkReal(-1.00000000000000))*(r00)*(x7436)*(x7446)))+(((IkReal(0.0100000000000000))*(x7433)*(x7449)))+(((IkReal(0.0100000000000000))*(x7433)*(x7459)))+(((IkReal(-1.00000000000000))*(r11)*(x7438)*(x7452)))+(((x7437)*(x7452)))+(((cj0)*(r02)*(x7445)))+(((IkReal(-1.00000000000000))*(px)*(x7456)))+(((r12)*(sj0)*(x7445))));
if( IKabs(evalcond[0]) < 0.0000010000000000  && IKabs(evalcond[1]) < 0.0000010000000000  && IKabs(evalcond[2]) < 0.0000010000000000  && IKabs(evalcond[3]) < 0.0000010000000000  && IKabs(evalcond[4]) < 0.0000010000000000  && IKabs(evalcond[5]) < 0.0000010000000000  && IKabs(evalcond[6]) < 0.0000010000000000  && IKabs(evalcond[7]) < 0.0000010000000000  && IKabs(evalcond[8]) < 0.0000010000000000  )
{
{
IkReal j3array[1], cj3array[1], sj3array[1];
bool j3valid[1]={false};
_nj3 = 1;
IkReal x7463=((IkReal(1.00000000000000))*(cj4));
IkReal x7464=((cj6)*(r21));
IkReal x7465=((r20)*(sj6));
if( IKabs(((((sj5)*(x7465)))+(((IkReal(-1.00000000000000))*(cj5)*(r22)))+(((sj5)*(x7464))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(((((IkReal(-1.00000000000000))*(cj5)*(x7463)*(x7464)))+(((IkReal(-1.00000000000000))*(cj5)*(x7463)*(x7465)))+(((IkReal(-1.00000000000000))*(r22)*(sj5)*(x7463)))+(((r21)*(sj4)*(sj6)))+(((IkReal(-1.00000000000000))*(cj6)*(r20)*(sj4))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(IKsqr(((((sj5)*(x7465)))+(((IkReal(-1.00000000000000))*(cj5)*(r22)))+(((sj5)*(x7464)))))+IKsqr(((((IkReal(-1.00000000000000))*(cj5)*(x7463)*(x7464)))+(((IkReal(-1.00000000000000))*(cj5)*(x7463)*(x7465)))+(((IkReal(-1.00000000000000))*(r22)*(sj5)*(x7463)))+(((r21)*(sj4)*(sj6)))+(((IkReal(-1.00000000000000))*(cj6)*(r20)*(sj4)))))-1) <= IKFAST_SINCOS_THRESH )
    continue;
j3array[0]=IKatan2(((((sj5)*(x7465)))+(((IkReal(-1.00000000000000))*(cj5)*(r22)))+(((sj5)*(x7464)))), ((((IkReal(-1.00000000000000))*(cj5)*(x7463)*(x7464)))+(((IkReal(-1.00000000000000))*(cj5)*(x7463)*(x7465)))+(((IkReal(-1.00000000000000))*(r22)*(sj5)*(x7463)))+(((r21)*(sj4)*(sj6)))+(((IkReal(-1.00000000000000))*(cj6)*(r20)*(sj4)))));
sj3array[0]=IKsin(j3array[0]);
cj3array[0]=IKcos(j3array[0]);
if( j3array[0] > IKPI )
{
    j3array[0]-=IK2PI;
}
else if( j3array[0] < -IKPI )
{    j3array[0]+=IK2PI;
}
j3valid[0] = true;
for(int ij3 = 0; ij3 < 1; ++ij3)
{
if( !j3valid[ij3] )
{
    continue;
}
_ij3[0] = ij3; _ij3[1] = -1;
for(int iij3 = ij3+1; iij3 < 1; ++iij3)
{
if( j3valid[iij3] && IKabs(cj3array[ij3]-cj3array[iij3]) < IKFAST_SOLUTION_THRESH && IKabs(sj3array[ij3]-sj3array[iij3]) < IKFAST_SOLUTION_THRESH )
{
    j3valid[iij3]=false; _ij3[1] = iij3; break; 
}
}
j3 = j3array[ij3]; cj3 = cj3array[ij3]; sj3 = sj3array[ij3];
{
IkReal evalcond[4];
IkReal x7466=IKcos(j3);
IkReal x7467=((IkReal(1.00000000000000))*(cj4));
IkReal x7468=((sj0)*(sj5));
IkReal x7469=((cj0)*(cj5));
IkReal x7470=((cj6)*(r01));
IkReal x7471=((r00)*(sj6));
IkReal x7472=((cj6)*(r11));
IkReal x7473=((cj5)*(sj0));
IkReal x7474=((cj6)*(sj4));
IkReal x7475=((sj4)*(sj6));
IkReal x7476=((cj4)*(cj5));
IkReal x7477=((cj6)*(r21));
IkReal x7478=((r20)*(sj6));
IkReal x7479=((r10)*(sj6));
IkReal x7480=((IkReal(1.00000000000000))*(IKsin(j3)));
IkReal x7481=((IkReal(1.00000000000000))*(cj0)*(sj5));
evalcond[0]=((((sj5)*(x7477)))+(((IkReal(-1.00000000000000))*(cj5)*(r22)))+(((sj5)*(x7478)))+(((IkReal(-1.00000000000000))*(x7480))));
evalcond[1]=((((x7476)*(x7477)))+(((x7476)*(x7478)))+(((IkReal(-1.00000000000000))*(r21)*(x7475)))+(((cj4)*(r22)*(sj5)))+(((r20)*(x7474)))+(x7466));
evalcond[2]=((((IkReal(-1.00000000000000))*(x7471)*(x7481)))+(((IkReal(-1.00000000000000))*(x7468)*(x7472)))+(((IkReal(-1.00000000000000))*(x7468)*(x7479)))+(((IkReal(-1.00000000000000))*(x7470)*(x7481)))+(((IkReal(-1.00000000000000))*(x7466)))+(((r12)*(x7473)))+(((r02)*(x7469))));
evalcond[3]=((((IkReal(-1.00000000000000))*(r12)*(x7467)*(x7468)))+(((IkReal(-1.00000000000000))*(cj0)*(r02)*(sj5)*(x7467)))+(((IkReal(-1.00000000000000))*(r10)*(sj0)*(x7474)))+(((IkReal(-1.00000000000000))*(x7467)*(x7469)*(x7470)))+(((r11)*(sj0)*(x7475)))+(((IkReal(-1.00000000000000))*(x7467)*(x7472)*(x7473)))+(((IkReal(-1.00000000000000))*(cj0)*(r00)*(x7474)))+(((IkReal(-1.00000000000000))*(x7480)))+(((cj0)*(r01)*(x7475)))+(((IkReal(-1.00000000000000))*(x7467)*(x7473)*(x7479)))+(((IkReal(-1.00000000000000))*(x7467)*(x7469)*(x7471))));
if( IKabs(evalcond[0]) > 0.000001  || IKabs(evalcond[1]) > 0.000001  || IKabs(evalcond[2]) > 0.000001  || IKabs(evalcond[3]) > 0.000001  )
{
continue;
}
}

{
std::vector<IkSingleDOFSolutionBase<IkReal> > vinfos(7);
vinfos[0].jointtype = 1;
vinfos[0].foffset = j0;
vinfos[0].indices[0] = _ij0[0];
vinfos[0].indices[1] = _ij0[1];
vinfos[0].maxsolutions = _nj0;
vinfos[1].jointtype = 1;
vinfos[1].foffset = j1;
vinfos[1].indices[0] = _ij1[0];
vinfos[1].indices[1] = _ij1[1];
vinfos[1].maxsolutions = _nj1;
vinfos[2].jointtype = 1;
vinfos[2].foffset = j2;
vinfos[2].indices[0] = _ij2[0];
vinfos[2].indices[1] = _ij2[1];
vinfos[2].maxsolutions = _nj2;
vinfos[3].jointtype = 1;
vinfos[3].foffset = j3;
vinfos[3].indices[0] = _ij3[0];
vinfos[3].indices[1] = _ij3[1];
vinfos[3].maxsolutions = _nj3;
vinfos[4].jointtype = 1;
vinfos[4].foffset = j4;
vinfos[4].indices[0] = _ij4[0];
vinfos[4].indices[1] = _ij4[1];
vinfos[4].maxsolutions = _nj4;
vinfos[5].jointtype = 1;
vinfos[5].foffset = j5;
vinfos[5].indices[0] = _ij5[0];
vinfos[5].indices[1] = _ij5[1];
vinfos[5].maxsolutions = _nj5;
vinfos[6].jointtype = 1;
vinfos[6].foffset = j6;
vinfos[6].indices[0] = _ij6[0];
vinfos[6].indices[1] = _ij6[1];
vinfos[6].maxsolutions = _nj6;
std::vector<int> vfree(0);
solutions.AddSolution(vinfos,vfree);
}
}
}

} else
{
IkReal x7482=((cj5)*(sj4));
IkReal x7483=((IkReal(1.00000000000000))*(sj6));
IkReal x7484=((r10)*(sj0));
IkReal x7485=((sj4)*(sj5));
IkReal x7486=((cj5)*(cj6));
IkReal x7487=((r01)*(sj0));
IkReal x7488=((IkReal(1.00000000000000))*(r02));
IkReal x7489=((IkReal(0.374290000000000))*(cj0));
IkReal x7490=((cj5)*(r12));
IkReal x7491=((cj6)*(sj5));
IkReal x7492=((cj0)*(r11));
IkReal x7493=((cj5)*(sj0));
IkReal x7494=((r20)*(sj6));
IkReal x7495=((IkReal(1.00000000000000))*(sj0));
IkReal x7496=((cj4)*(cj5));
IkReal x7497=((IkReal(1.00000000000000))*(cj6));
IkReal x7498=((IkReal(0.0100000000000000))*(sj5));
IkReal x7499=((sj5)*(sj6));
IkReal x7500=((cj0)*(r10));
IkReal x7501=((cj4)*(cj6));
IkReal x7502=((cj0)*(r01));
IkReal x7503=((IkReal(1.00000000000000))*(cj4));
IkReal x7504=((cj0)*(r00));
IkReal x7505=((IkReal(0.374290000000000))*(sj0));
IkReal x7506=((cj0)*(r12));
IkReal x7507=((IkReal(0.374290000000000))*(sj5));
IkReal x7508=((cj4)*(sj6));
IkReal x7509=((IkReal(1.00000000000000))*(cj0));
IkReal x7510=((r02)*(sj0));
IkReal x7511=((IkReal(0.0100000000000000))*(cj5));
IkReal x7512=((r11)*(sj0));
IkReal x7513=((r00)*(sj0)*(sj6));
IkReal x7514=((r00)*(x7501));
IkReal x7515=((sj6)*(x7511));
evalcond[0]=((IkReal(-3.14159265358979))+(IKfmod(j2, IkReal(6.28318530717959))));
evalcond[1]=((((r21)*(x7508)))+(((r22)*(x7485)))+(((x7482)*(x7494)))+(((cj6)*(r21)*(x7482)))+(((IkReal(-1.00000000000000))*(cj4)*(r20)*(x7497))));
evalcond[2]=((IkReal(-0.0690000000000000))+(((x7494)*(x7507)))+(((IkReal(0.374290000000000))*(r21)*(x7491)))+(((IkReal(-0.374290000000000))*(cj5)*(r22)))+(((IkReal(-1.00000000000000))*(r22)*(x7498)))+(pz)+(((IkReal(-1.00000000000000))*(x7494)*(x7511)))+(((IkReal(-0.0100000000000000))*(r21)*(x7486))));
evalcond[3]=((((IkReal(-1.00000000000000))*(x7491)*(x7492)))+(((x7487)*(x7491)))+(((IkReal(-1.00000000000000))*(x7488)*(x7493)))+(((r00)*(sj0)*(x7499)))+(((cj0)*(x7490)))+(((IkReal(-1.00000000000000))*(sj5)*(x7483)*(x7500))));
evalcond[4]=((IkReal(-1.00000000000000))+(((IkReal(-1.00000000000000))*(x7482)*(x7492)*(x7497)))+(((x7485)*(x7510)))+(((IkReal(-1.00000000000000))*(cj4)*(x7483)*(x7492)))+(((cj6)*(x7482)*(x7487)))+(((x7500)*(x7501)))+(((x7482)*(x7513)))+(((IkReal(-1.00000000000000))*(x7485)*(x7506)))+(((IkReal(-1.00000000000000))*(x7482)*(x7483)*(x7500)))+(((IkReal(-1.00000000000000))*(x7495)*(x7514)))+(((x7487)*(x7508))));
evalcond[5]=((((IkReal(-1.00000000000000))*(x7483)*(x7496)*(x7500)))+(((r00)*(x7493)*(x7508)))+(((cj4)*(sj5)*(x7510)))+(((cj4)*(x7486)*(x7487)))+(((cj6)*(r00)*(sj0)*(sj4)))+(((sj4)*(sj6)*(x7492)))+(((IkReal(-1.00000000000000))*(sj4)*(x7497)*(x7500)))+(((IkReal(-1.00000000000000))*(x7486)*(x7492)*(x7503)))+(((IkReal(-1.00000000000000))*(sj5)*(x7503)*(x7506)))+(((IkReal(-1.00000000000000))*(sj4)*(x7483)*(x7487))));
evalcond[6]=((((IkReal(-1.00000000000000))*(cj4)*(x7483)*(x7512)))+(((x7484)*(x7501)))+(((IkReal(-1.00000000000000))*(cj4)*(x7483)*(x7502)))+(((IkReal(-1.00000000000000))*(x7482)*(x7483)*(x7504)))+(((x7501)*(x7504)))+(((IkReal(-1.00000000000000))*(x7482)*(x7483)*(x7484)))+(((IkReal(-1.00000000000000))*(r12)*(x7485)*(x7495)))+(((IkReal(-1.00000000000000))*(cj0)*(x7485)*(x7488)))+(((IkReal(-1.00000000000000))*(x7482)*(x7497)*(x7502)))+(((IkReal(-1.00000000000000))*(cj6)*(r11)*(x7482)*(x7495))));
evalcond[7]=((((IkReal(-1.00000000000000))*(x7498)*(x7510)))+(((IkReal(-1.00000000000000))*(r10)*(x7489)*(x7499)))+(((x7489)*(x7490)))+(((IkReal(-0.374290000000000))*(r02)*(x7493)))+(((IkReal(-1.00000000000000))*(py)*(x7509)))+(((x7500)*(x7515)))+(((IkReal(-0.0100000000000000))*(x7486)*(x7487)))+(((IkReal(-1.00000000000000))*(r11)*(x7489)*(x7491)))+(((IkReal(0.374290000000000))*(x7487)*(x7491)))+(((px)*(sj0)))+(((IkReal(-0.0100000000000000))*(r00)*(sj6)*(x7493)))+(((x7498)*(x7506)))+(((r00)*(x7499)*(x7505)))+(((IkReal(0.0100000000000000))*(x7486)*(x7492))));
evalcond[8]=((IkReal(0.433420000000000))+(((x7490)*(x7505)))+(((r12)*(sj0)*(x7498)))+(((x7504)*(x7515)))+(((IkReal(-1.00000000000000))*(r11)*(x7491)*(x7505)))+(((cj0)*(r02)*(x7498)))+(((IkReal(-1.00000000000000))*(r00)*(x7489)*(x7499)))+(((IkReal(-1.00000000000000))*(py)*(x7495)))+(((IkReal(-1.00000000000000))*(r01)*(x7489)*(x7491)))+(((IkReal(-0.374290000000000))*(x7484)*(x7499)))+(((x7484)*(x7515)))+(((cj5)*(r02)*(x7489)))+(((IkReal(0.0100000000000000))*(x7486)*(x7502)))+(((IkReal(0.0100000000000000))*(x7486)*(x7512)))+(((IkReal(-1.00000000000000))*(px)*(x7509))));
if( IKabs(evalcond[0]) < 0.0000010000000000  && IKabs(evalcond[1]) < 0.0000010000000000  && IKabs(evalcond[2]) < 0.0000010000000000  && IKabs(evalcond[3]) < 0.0000010000000000  && IKabs(evalcond[4]) < 0.0000010000000000  && IKabs(evalcond[5]) < 0.0000010000000000  && IKabs(evalcond[6]) < 0.0000010000000000  && IKabs(evalcond[7]) < 0.0000010000000000  && IKabs(evalcond[8]) < 0.0000010000000000  )
{
{
IkReal j3array[1], cj3array[1], sj3array[1];
bool j3valid[1]={false};
_nj3 = 1;
IkReal x7516=((IkReal(1.00000000000000))*(r21));
IkReal x7517=((cj4)*(cj5));
IkReal x7518=((r20)*(sj6));
if( IKabs(((((IkReal(-1.00000000000000))*(cj6)*(sj5)*(x7516)))+(((cj5)*(r22)))+(((IkReal(-1.00000000000000))*(sj5)*(x7518))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(((((cj6)*(r21)*(x7517)))+(((x7517)*(x7518)))+(((cj6)*(r20)*(sj4)))+(((cj4)*(r22)*(sj5)))+(((IkReal(-1.00000000000000))*(sj4)*(sj6)*(x7516))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(IKsqr(((((IkReal(-1.00000000000000))*(cj6)*(sj5)*(x7516)))+(((cj5)*(r22)))+(((IkReal(-1.00000000000000))*(sj5)*(x7518)))))+IKsqr(((((cj6)*(r21)*(x7517)))+(((x7517)*(x7518)))+(((cj6)*(r20)*(sj4)))+(((cj4)*(r22)*(sj5)))+(((IkReal(-1.00000000000000))*(sj4)*(sj6)*(x7516)))))-1) <= IKFAST_SINCOS_THRESH )
    continue;
j3array[0]=IKatan2(((((IkReal(-1.00000000000000))*(cj6)*(sj5)*(x7516)))+(((cj5)*(r22)))+(((IkReal(-1.00000000000000))*(sj5)*(x7518)))), ((((cj6)*(r21)*(x7517)))+(((x7517)*(x7518)))+(((cj6)*(r20)*(sj4)))+(((cj4)*(r22)*(sj5)))+(((IkReal(-1.00000000000000))*(sj4)*(sj6)*(x7516)))));
sj3array[0]=IKsin(j3array[0]);
cj3array[0]=IKcos(j3array[0]);
if( j3array[0] > IKPI )
{
    j3array[0]-=IK2PI;
}
else if( j3array[0] < -IKPI )
{    j3array[0]+=IK2PI;
}
j3valid[0] = true;
for(int ij3 = 0; ij3 < 1; ++ij3)
{
if( !j3valid[ij3] )
{
    continue;
}
_ij3[0] = ij3; _ij3[1] = -1;
for(int iij3 = ij3+1; iij3 < 1; ++iij3)
{
if( j3valid[iij3] && IKabs(cj3array[ij3]-cj3array[iij3]) < IKFAST_SOLUTION_THRESH && IKabs(sj3array[ij3]-sj3array[iij3]) < IKFAST_SOLUTION_THRESH )
{
    j3valid[iij3]=false; _ij3[1] = iij3; break; 
}
}
j3 = j3array[ij3]; cj3 = cj3array[ij3]; sj3 = sj3array[ij3];
{
IkReal evalcond[4];
IkReal x7519=IKsin(j3);
IkReal x7520=((IkReal(1.00000000000000))*(cj4));
IkReal x7521=((sj0)*(sj5));
IkReal x7522=((cj0)*(cj5));
IkReal x7523=((cj6)*(r01));
IkReal x7524=((r00)*(sj6));
IkReal x7525=((cj6)*(r11));
IkReal x7526=((cj5)*(sj0));
IkReal x7527=((cj6)*(sj4));
IkReal x7528=((sj4)*(sj6));
IkReal x7529=((cj4)*(cj5));
IkReal x7530=((cj6)*(r21));
IkReal x7531=((r20)*(sj6));
IkReal x7532=((r10)*(sj6));
IkReal x7533=((IkReal(1.00000000000000))*(IKcos(j3)));
IkReal x7534=((IkReal(1.00000000000000))*(cj0)*(sj5));
evalcond[0]=((x7519)+(((sj5)*(x7530)))+(((IkReal(-1.00000000000000))*(cj5)*(r22)))+(((sj5)*(x7531))));
evalcond[1]=((((r20)*(x7527)))+(((x7529)*(x7531)))+(((cj4)*(r22)*(sj5)))+(((IkReal(-1.00000000000000))*(r21)*(x7528)))+(((x7529)*(x7530)))+(((IkReal(-1.00000000000000))*(x7533))));
evalcond[2]=((((IkReal(-1.00000000000000))*(x7521)*(x7532)))+(((IkReal(-1.00000000000000))*(x7524)*(x7534)))+(((r02)*(x7522)))+(((IkReal(-1.00000000000000))*(x7521)*(x7525)))+(((IkReal(-1.00000000000000))*(x7523)*(x7534)))+(((r12)*(x7526)))+(((IkReal(-1.00000000000000))*(x7533))));
evalcond[3]=((((IkReal(-1.00000000000000))*(r12)*(x7520)*(x7521)))+(((IkReal(-1.00000000000000))*(x7520)*(x7526)*(x7532)))+(((IkReal(-1.00000000000000))*(x7519)))+(((IkReal(-1.00000000000000))*(x7520)*(x7522)*(x7523)))+(((IkReal(-1.00000000000000))*(cj0)*(r00)*(x7527)))+(((IkReal(-1.00000000000000))*(r10)*(sj0)*(x7527)))+(((r11)*(sj0)*(x7528)))+(((IkReal(-1.00000000000000))*(x7520)*(x7525)*(x7526)))+(((IkReal(-1.00000000000000))*(x7520)*(x7522)*(x7524)))+(((IkReal(-1.00000000000000))*(cj0)*(r02)*(sj5)*(x7520)))+(((cj0)*(r01)*(x7528))));
if( IKabs(evalcond[0]) > 0.000001  || IKabs(evalcond[1]) > 0.000001  || IKabs(evalcond[2]) > 0.000001  || IKabs(evalcond[3]) > 0.000001  )
{
continue;
}
}

{
std::vector<IkSingleDOFSolutionBase<IkReal> > vinfos(7);
vinfos[0].jointtype = 1;
vinfos[0].foffset = j0;
vinfos[0].indices[0] = _ij0[0];
vinfos[0].indices[1] = _ij0[1];
vinfos[0].maxsolutions = _nj0;
vinfos[1].jointtype = 1;
vinfos[1].foffset = j1;
vinfos[1].indices[0] = _ij1[0];
vinfos[1].indices[1] = _ij1[1];
vinfos[1].maxsolutions = _nj1;
vinfos[2].jointtype = 1;
vinfos[2].foffset = j2;
vinfos[2].indices[0] = _ij2[0];
vinfos[2].indices[1] = _ij2[1];
vinfos[2].maxsolutions = _nj2;
vinfos[3].jointtype = 1;
vinfos[3].foffset = j3;
vinfos[3].indices[0] = _ij3[0];
vinfos[3].indices[1] = _ij3[1];
vinfos[3].maxsolutions = _nj3;
vinfos[4].jointtype = 1;
vinfos[4].foffset = j4;
vinfos[4].indices[0] = _ij4[0];
vinfos[4].indices[1] = _ij4[1];
vinfos[4].maxsolutions = _nj4;
vinfos[5].jointtype = 1;
vinfos[5].foffset = j5;
vinfos[5].indices[0] = _ij5[0];
vinfos[5].indices[1] = _ij5[1];
vinfos[5].maxsolutions = _nj5;
vinfos[6].jointtype = 1;
vinfos[6].foffset = j6;
vinfos[6].indices[0] = _ij6[0];
vinfos[6].indices[1] = _ij6[1];
vinfos[6].maxsolutions = _nj6;
std::vector<int> vfree(0);
solutions.AddSolution(vinfos,vfree);
}
}
}

} else
{
IkReal x7535=((IkReal(1.00000000000000))*(cj0));
IkReal x7536=((cj4)*(sj6));
IkReal x7537=((sj0)*(sj4));
IkReal x7538=((cj5)*(sj6));
IkReal x7539=((sj4)*(sj5));
IkReal x7540=((r12)*(sj5));
IkReal x7541=((IkReal(0.374290000000000))*(cj5));
IkReal x7542=((r02)*(sj0));
IkReal x7543=((r20)*(sj4));
IkReal x7544=((IkReal(1.00000000000000))*(sj0));
IkReal x7545=((IkReal(1.00000000000000))*(cj5));
IkReal x7546=((cj0)*(r10));
IkReal x7547=((cj4)*(cj6));
IkReal x7548=((r00)*(sj0));
IkReal x7549=((cj6)*(r21));
IkReal x7550=((IkReal(0.374290000000000))*(sj5));
IkReal x7551=((cj0)*(r00));
IkReal x7552=((IkReal(0.0100000000000000))*(sj5));
IkReal x7553=((cj0)*(r02));
IkReal x7554=((cj5)*(sj4));
IkReal x7555=((cj6)*(r01));
IkReal x7556=((cj6)*(r11));
IkReal x7557=((r01)*(sj0));
IkReal x7558=((r10)*(sj0));
IkReal x7559=((IkReal(0.0100000000000000))*(cj5)*(cj6));
IkReal x7560=((sj6)*(x7550));
IkReal x7561=((cj0)*(cj6)*(x7550));
evalcond[0]=((IkReal(-3.14159265358979))+(IKfmod(((IkReal(1.57079632679490))+(j2)), IkReal(6.28318530717959))));
evalcond[1]=((((IkReal(-1.00000000000000))*(r22)*(x7545)))+(((r20)*(sj5)*(sj6)))+(((sj5)*(x7549))));
evalcond[2]=((IkReal(-1.00000000000000))+(((x7549)*(x7554)))+(((r22)*(x7539)))+(((r21)*(x7536)))+(((x7538)*(x7543)))+(((IkReal(-1.00000000000000))*(r20)*(x7547))));
evalcond[3]=((((IkReal(-0.0100000000000000))*(r20)*(x7538)))+(((IkReal(-0.0100000000000000))*(cj5)*(x7549)))+(((x7549)*(x7550)))+(((IkReal(-1.00000000000000))*(r22)*(x7552)))+(((IkReal(-1.00000000000000))*(r22)*(x7541)))+(pz)+(((r20)*(x7560))));
evalcond[4]=((((IkReal(-1.00000000000000))*(r21)*(sj4)*(sj6)))+(((cj5)*(r21)*(x7547)))+(((cj4)*(r22)*(sj5)))+(((cj5)*(r20)*(x7536)))+(((cj6)*(x7543))));
evalcond[5]=((((r00)*(x7537)*(x7538)))+(((IkReal(-1.00000000000000))*(x7535)*(x7554)*(x7556)))+(((IkReal(-1.00000000000000))*(r10)*(sj4)*(x7535)*(x7538)))+(((cj5)*(x7537)*(x7555)))+(((IkReal(-1.00000000000000))*(r12)*(x7535)*(x7539)))+(((IkReal(-1.00000000000000))*(r11)*(x7535)*(x7536)))+(((x7546)*(x7547)))+(((IkReal(-1.00000000000000))*(r00)*(x7544)*(x7547)))+(((r02)*(sj5)*(x7537)))+(((x7536)*(x7557))));
evalcond[6]=((((IkReal(-1.00000000000000))*(r10)*(x7537)*(x7538)))+(((IkReal(-1.00000000000000))*(r01)*(x7535)*(x7536)))+(((IkReal(-1.00000000000000))*(x7535)*(x7554)*(x7555)))+(((x7547)*(x7551)))+(((IkReal(-1.00000000000000))*(x7537)*(x7540)))+(((x7547)*(x7558)))+(((IkReal(-1.00000000000000))*(r00)*(sj4)*(x7535)*(x7538)))+(((IkReal(-1.00000000000000))*(r02)*(x7535)*(x7539)))+(((IkReal(-1.00000000000000))*(x7537)*(x7545)*(x7556)))+(((IkReal(-1.00000000000000))*(r11)*(x7536)*(x7544))));
evalcond[7]=((IkReal(0.0690000000000000))+(((IkReal(-1.00000000000000))*(x7546)*(x7560)))+(((cj0)*(r12)*(x7541)))+(((IkReal(-0.0100000000000000))*(x7538)*(x7548)))+(((IkReal(0.0100000000000000))*(cj0)*(cj5)*(x7556)))+(((IkReal(-1.00000000000000))*(py)*(x7535)))+(((sj0)*(x7550)*(x7555)))+(((IkReal(-1.00000000000000))*(x7541)*(x7542)))+(((IkReal(-0.0100000000000000))*(cj5)*(sj0)*(x7555)))+(((x7548)*(x7560)))+(((IkReal(0.0100000000000000))*(x7538)*(x7546)))+(((IkReal(0.0100000000000000))*(cj0)*(x7540)))+(((IkReal(-1.00000000000000))*(x7542)*(x7552)))+(((px)*(sj0)))+(((IkReal(-1.00000000000000))*(cj0)*(x7550)*(x7556))));
evalcond[8]=((IkReal(0.433420000000000))+(((x7541)*(x7553)))+(((IkReal(0.0100000000000000))*(cj0)*(cj5)*(x7555)))+(((IkReal(-1.00000000000000))*(x7551)*(x7560)))+(((IkReal(0.0100000000000000))*(sj0)*(x7540)))+(((r12)*(sj0)*(x7541)))+(((IkReal(0.0100000000000000))*(x7538)*(x7558)))+(((IkReal(-1.00000000000000))*(cj0)*(x7550)*(x7555)))+(((x7552)*(x7553)))+(((IkReal(-1.00000000000000))*(py)*(x7544)))+(((IkReal(-1.00000000000000))*(x7558)*(x7560)))+(((IkReal(-1.00000000000000))*(sj0)*(x7550)*(x7556)))+(((IkReal(0.0100000000000000))*(cj5)*(sj0)*(x7556)))+(((IkReal(-1.00000000000000))*(px)*(x7535)))+(((IkReal(0.0100000000000000))*(x7538)*(x7551))));
if( IKabs(evalcond[0]) < 0.0000010000000000  && IKabs(evalcond[1]) < 0.0000010000000000  && IKabs(evalcond[2]) < 0.0000010000000000  && IKabs(evalcond[3]) < 0.0000010000000000  && IKabs(evalcond[4]) < 0.0000010000000000  && IKabs(evalcond[5]) < 0.0000010000000000  && IKabs(evalcond[6]) < 0.0000010000000000  && IKabs(evalcond[7]) < 0.0000010000000000  && IKabs(evalcond[8]) < 0.0000010000000000  )
{
{
IkReal j3array[1], cj3array[1], sj3array[1];
bool j3valid[1]={false};
_nj3 = 1;
IkReal x7562=((cj0)*(cj5));
IkReal x7563=((IkReal(1.00000000000000))*(cj0));
IkReal x7564=((cj6)*(r11));
IkReal x7565=((r10)*(sj6));
IkReal x7566=((cj5)*(sj0));
IkReal x7567=((r00)*(sj5)*(sj6));
IkReal x7568=((cj6)*(r01)*(sj5));
IkReal x7569=((IkReal(1.00000000000000))*(sj0)*(sj5));
if( IKabs(((((IkReal(-1.00000000000000))*(sj5)*(x7563)*(x7565)))+(((r12)*(x7562)))+(((sj0)*(x7567)))+(((sj0)*(x7568)))+(((IkReal(-1.00000000000000))*(sj5)*(x7563)*(x7564)))+(((IkReal(-1.00000000000000))*(r02)*(x7566))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(((((IkReal(-1.00000000000000))*(x7563)*(x7567)))+(((IkReal(-1.00000000000000))*(x7564)*(x7569)))+(((r12)*(x7566)))+(((r02)*(x7562)))+(((IkReal(-1.00000000000000))*(x7565)*(x7569)))+(((IkReal(-1.00000000000000))*(x7563)*(x7568))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(IKsqr(((((IkReal(-1.00000000000000))*(sj5)*(x7563)*(x7565)))+(((r12)*(x7562)))+(((sj0)*(x7567)))+(((sj0)*(x7568)))+(((IkReal(-1.00000000000000))*(sj5)*(x7563)*(x7564)))+(((IkReal(-1.00000000000000))*(r02)*(x7566)))))+IKsqr(((((IkReal(-1.00000000000000))*(x7563)*(x7567)))+(((IkReal(-1.00000000000000))*(x7564)*(x7569)))+(((r12)*(x7566)))+(((r02)*(x7562)))+(((IkReal(-1.00000000000000))*(x7565)*(x7569)))+(((IkReal(-1.00000000000000))*(x7563)*(x7568)))))-1) <= IKFAST_SINCOS_THRESH )
    continue;
j3array[0]=IKatan2(((((IkReal(-1.00000000000000))*(sj5)*(x7563)*(x7565)))+(((r12)*(x7562)))+(((sj0)*(x7567)))+(((sj0)*(x7568)))+(((IkReal(-1.00000000000000))*(sj5)*(x7563)*(x7564)))+(((IkReal(-1.00000000000000))*(r02)*(x7566)))), ((((IkReal(-1.00000000000000))*(x7563)*(x7567)))+(((IkReal(-1.00000000000000))*(x7564)*(x7569)))+(((r12)*(x7566)))+(((r02)*(x7562)))+(((IkReal(-1.00000000000000))*(x7565)*(x7569)))+(((IkReal(-1.00000000000000))*(x7563)*(x7568)))));
sj3array[0]=IKsin(j3array[0]);
cj3array[0]=IKcos(j3array[0]);
if( j3array[0] > IKPI )
{
    j3array[0]-=IK2PI;
}
else if( j3array[0] < -IKPI )
{    j3array[0]+=IK2PI;
}
j3valid[0] = true;
for(int ij3 = 0; ij3 < 1; ++ij3)
{
if( !j3valid[ij3] )
{
    continue;
}
_ij3[0] = ij3; _ij3[1] = -1;
for(int iij3 = ij3+1; iij3 < 1; ++iij3)
{
if( j3valid[iij3] && IKabs(cj3array[ij3]-cj3array[iij3]) < IKFAST_SOLUTION_THRESH && IKabs(sj3array[ij3]-sj3array[iij3]) < IKFAST_SOLUTION_THRESH )
{
    j3valid[iij3]=false; _ij3[1] = iij3; break; 
}
}
j3 = j3array[ij3]; cj3 = cj3array[ij3]; sj3 = sj3array[ij3];
{
IkReal evalcond[4];
IkReal x7570=IKcos(j3);
IkReal x7571=((sj0)*(sj5));
IkReal x7572=((r00)*(sj6));
IkReal x7573=((cj6)*(sj0));
IkReal x7574=((IkReal(1.00000000000000))*(cj4));
IkReal x7575=((r00)*(sj4));
IkReal x7576=((cj0)*(cj5));
IkReal x7577=((cj5)*(sj0));
IkReal x7578=((cj6)*(r11));
IkReal x7579=((r10)*(sj6));
IkReal x7580=((cj0)*(sj5));
IkReal x7581=((r10)*(sj4));
IkReal x7582=((IkReal(1.00000000000000))*(IKsin(j3)));
IkReal x7583=((cj4)*(cj5)*(r01));
IkReal x7584=((IkReal(1.00000000000000))*(cj0)*(cj6));
IkReal x7585=((cj0)*(sj4)*(sj6));
IkReal x7586=((sj0)*(sj4)*(sj6));
evalcond[0]=((((IkReal(-1.00000000000000))*(x7582)))+(((IkReal(-1.00000000000000))*(r02)*(x7577)))+(((IkReal(-1.00000000000000))*(x7578)*(x7580)))+(((cj6)*(r01)*(x7571)))+(((IkReal(-1.00000000000000))*(x7579)*(x7580)))+(((x7571)*(x7572)))+(((r12)*(x7576))));
evalcond[1]=((((IkReal(-1.00000000000000))*(cj6)*(r01)*(x7580)))+(((IkReal(-1.00000000000000))*(x7571)*(x7578)))+(((IkReal(-1.00000000000000))*(x7571)*(x7579)))+(((IkReal(-1.00000000000000))*(x7570)))+(((r12)*(x7577)))+(((r02)*(x7576)))+(((IkReal(-1.00000000000000))*(x7572)*(x7580))));
evalcond[2]=((((cj4)*(r02)*(x7571)))+(((IkReal(-1.00000000000000))*(x7574)*(x7576)*(x7579)))+(((r11)*(x7585)))+(((IkReal(-1.00000000000000))*(x7581)*(x7584)))+(((IkReal(-1.00000000000000))*(x7574)*(x7576)*(x7578)))+(((IkReal(-1.00000000000000))*(r01)*(x7586)))+(((x7573)*(x7575)))+(((IkReal(-1.00000000000000))*(r12)*(x7574)*(x7580)))+(((x7573)*(x7583)))+(((cj4)*(x7572)*(x7577)))+(x7570));
evalcond[3]=((((IkReal(-1.00000000000000))*(r12)*(x7571)*(x7574)))+(((IkReal(-1.00000000000000))*(x7582)))+(((IkReal(-1.00000000000000))*(r02)*(x7574)*(x7580)))+(((IkReal(-1.00000000000000))*(x7574)*(x7577)*(x7579)))+(((IkReal(-1.00000000000000))*(x7572)*(x7574)*(x7576)))+(((r11)*(x7586)))+(((r01)*(x7585)))+(((IkReal(-1.00000000000000))*(x7573)*(x7581)))+(((IkReal(-1.00000000000000))*(x7575)*(x7584)))+(((IkReal(-1.00000000000000))*(cj6)*(r01)*(x7574)*(x7576)))+(((IkReal(-1.00000000000000))*(cj5)*(r11)*(x7573)*(x7574))));
if( IKabs(evalcond[0]) > 0.000001  || IKabs(evalcond[1]) > 0.000001  || IKabs(evalcond[2]) > 0.000001  || IKabs(evalcond[3]) > 0.000001  )
{
continue;
}
}

{
std::vector<IkSingleDOFSolutionBase<IkReal> > vinfos(7);
vinfos[0].jointtype = 1;
vinfos[0].foffset = j0;
vinfos[0].indices[0] = _ij0[0];
vinfos[0].indices[1] = _ij0[1];
vinfos[0].maxsolutions = _nj0;
vinfos[1].jointtype = 1;
vinfos[1].foffset = j1;
vinfos[1].indices[0] = _ij1[0];
vinfos[1].indices[1] = _ij1[1];
vinfos[1].maxsolutions = _nj1;
vinfos[2].jointtype = 1;
vinfos[2].foffset = j2;
vinfos[2].indices[0] = _ij2[0];
vinfos[2].indices[1] = _ij2[1];
vinfos[2].maxsolutions = _nj2;
vinfos[3].jointtype = 1;
vinfos[3].foffset = j3;
vinfos[3].indices[0] = _ij3[0];
vinfos[3].indices[1] = _ij3[1];
vinfos[3].maxsolutions = _nj3;
vinfos[4].jointtype = 1;
vinfos[4].foffset = j4;
vinfos[4].indices[0] = _ij4[0];
vinfos[4].indices[1] = _ij4[1];
vinfos[4].maxsolutions = _nj4;
vinfos[5].jointtype = 1;
vinfos[5].foffset = j5;
vinfos[5].indices[0] = _ij5[0];
vinfos[5].indices[1] = _ij5[1];
vinfos[5].maxsolutions = _nj5;
vinfos[6].jointtype = 1;
vinfos[6].foffset = j6;
vinfos[6].indices[0] = _ij6[0];
vinfos[6].indices[1] = _ij6[1];
vinfos[6].maxsolutions = _nj6;
std::vector<int> vfree(0);
solutions.AddSolution(vinfos,vfree);
}
}
}

} else
{
IkReal x7587=((IkReal(1.00000000000000))*(cj0));
IkReal x7588=((cj4)*(sj6));
IkReal x7589=((sj0)*(sj4));
IkReal x7590=((cj5)*(sj6));
IkReal x7591=((sj4)*(sj5));
IkReal x7592=((r12)*(sj5));
IkReal x7593=((IkReal(0.374290000000000))*(cj5));
IkReal x7594=((r02)*(sj0));
IkReal x7595=((r20)*(sj4));
IkReal x7596=((IkReal(1.00000000000000))*(sj0));
IkReal x7597=((IkReal(1.00000000000000))*(cj5));
IkReal x7598=((cj0)*(r10));
IkReal x7599=((cj4)*(cj6));
IkReal x7600=((r00)*(sj0));
IkReal x7601=((cj6)*(r21));
IkReal x7602=((IkReal(0.374290000000000))*(sj5));
IkReal x7603=((cj0)*(r00));
IkReal x7604=((IkReal(0.0100000000000000))*(sj5));
IkReal x7605=((cj0)*(r02));
IkReal x7606=((cj5)*(sj4));
IkReal x7607=((cj6)*(r01));
IkReal x7608=((cj6)*(r11));
IkReal x7609=((r01)*(sj0));
IkReal x7610=((r10)*(sj0));
IkReal x7611=((IkReal(0.0100000000000000))*(cj5)*(cj6));
IkReal x7612=((sj6)*(x7602));
IkReal x7613=((cj0)*(cj6)*(x7602));
evalcond[0]=((IkReal(-3.14159265358979))+(IKfmod(((IkReal(4.71238898038469))+(j2)), IkReal(6.28318530717959))));
evalcond[1]=((((sj5)*(x7601)))+(((IkReal(-1.00000000000000))*(r22)*(x7597)))+(((r20)*(sj5)*(sj6))));
evalcond[2]=((IkReal(1.00000000000000))+(((IkReal(-1.00000000000000))*(r20)*(x7599)))+(((x7601)*(x7606)))+(((r21)*(x7588)))+(((r22)*(x7591)))+(((x7590)*(x7595))));
evalcond[3]=((((IkReal(-0.0100000000000000))*(cj5)*(x7601)))+(((x7601)*(x7602)))+(((IkReal(-0.0100000000000000))*(r20)*(x7590)))+(((IkReal(-1.00000000000000))*(r22)*(x7604)))+(pz)+(((r20)*(x7612)))+(((IkReal(-1.00000000000000))*(r22)*(x7593))));
evalcond[4]=((((IkReal(-1.00000000000000))*(r21)*(sj4)*(sj6)))+(((cj5)*(r21)*(x7599)))+(((cj4)*(r22)*(sj5)))+(((cj6)*(x7595)))+(((cj5)*(r20)*(x7588))));
evalcond[5]=((((cj5)*(x7589)*(x7607)))+(((IkReal(-1.00000000000000))*(r11)*(x7587)*(x7588)))+(((IkReal(-1.00000000000000))*(r10)*(sj4)*(x7587)*(x7590)))+(((IkReal(-1.00000000000000))*(r12)*(x7587)*(x7591)))+(((r02)*(sj5)*(x7589)))+(((x7588)*(x7609)))+(((IkReal(-1.00000000000000))*(x7587)*(x7606)*(x7608)))+(((x7598)*(x7599)))+(((r00)*(x7589)*(x7590)))+(((IkReal(-1.00000000000000))*(r00)*(x7596)*(x7599))));
evalcond[6]=((((x7599)*(x7603)))+(((IkReal(-1.00000000000000))*(r01)*(x7587)*(x7588)))+(((IkReal(-1.00000000000000))*(r10)*(x7589)*(x7590)))+(((IkReal(-1.00000000000000))*(x7587)*(x7606)*(x7607)))+(((IkReal(-1.00000000000000))*(x7589)*(x7592)))+(((x7599)*(x7610)))+(((IkReal(-1.00000000000000))*(r00)*(sj4)*(x7587)*(x7590)))+(((IkReal(-1.00000000000000))*(r11)*(x7588)*(x7596)))+(((IkReal(-1.00000000000000))*(r02)*(x7587)*(x7591)))+(((IkReal(-1.00000000000000))*(x7589)*(x7597)*(x7608))));
evalcond[7]=((IkReal(-0.0690000000000000))+(((sj0)*(x7602)*(x7607)))+(((IkReal(-0.0100000000000000))*(x7590)*(x7600)))+(((IkReal(-1.00000000000000))*(py)*(x7587)))+(((IkReal(-1.00000000000000))*(x7594)*(x7604)))+(((IkReal(0.0100000000000000))*(cj0)*(x7592)))+(((IkReal(-0.0100000000000000))*(cj5)*(sj0)*(x7607)))+(((x7600)*(x7612)))+(((IkReal(0.0100000000000000))*(x7590)*(x7598)))+(((cj0)*(r12)*(x7593)))+(((px)*(sj0)))+(((IkReal(0.0100000000000000))*(cj0)*(cj5)*(x7608)))+(((IkReal(-1.00000000000000))*(cj0)*(x7602)*(x7608)))+(((IkReal(-1.00000000000000))*(x7598)*(x7612)))+(((IkReal(-1.00000000000000))*(x7593)*(x7594))));
evalcond[8]=((IkReal(0.433420000000000))+(((IkReal(-1.00000000000000))*(x7610)*(x7612)))+(((x7593)*(x7605)))+(((IkReal(-1.00000000000000))*(cj0)*(x7602)*(x7607)))+(((IkReal(0.0100000000000000))*(sj0)*(x7592)))+(((IkReal(-1.00000000000000))*(px)*(x7587)))+(((r12)*(sj0)*(x7593)))+(((IkReal(-1.00000000000000))*(x7603)*(x7612)))+(((IkReal(-1.00000000000000))*(sj0)*(x7602)*(x7608)))+(((IkReal(0.0100000000000000))*(x7590)*(x7603)))+(((IkReal(-1.00000000000000))*(py)*(x7596)))+(((IkReal(0.0100000000000000))*(cj0)*(cj5)*(x7607)))+(((IkReal(0.0100000000000000))*(x7590)*(x7610)))+(((x7604)*(x7605)))+(((IkReal(0.0100000000000000))*(cj5)*(sj0)*(x7608))));
if( IKabs(evalcond[0]) < 0.0000010000000000  && IKabs(evalcond[1]) < 0.0000010000000000  && IKabs(evalcond[2]) < 0.0000010000000000  && IKabs(evalcond[3]) < 0.0000010000000000  && IKabs(evalcond[4]) < 0.0000010000000000  && IKabs(evalcond[5]) < 0.0000010000000000  && IKabs(evalcond[6]) < 0.0000010000000000  && IKabs(evalcond[7]) < 0.0000010000000000  && IKabs(evalcond[8]) < 0.0000010000000000  )
{
{
IkReal j3array[1], cj3array[1], sj3array[1];
bool j3valid[1]={false};
_nj3 = 1;
IkReal x7614=((cj5)*(r02));
IkReal x7615=((cj0)*(sj5));
IkReal x7616=((r10)*(sj6));
IkReal x7617=((IkReal(1.00000000000000))*(cj6));
IkReal x7618=((sj0)*(sj5));
IkReal x7619=((cj5)*(r12));
IkReal x7620=((IkReal(1.00000000000000))*(r00)*(sj6));
if( IKabs(((((IkReal(-1.00000000000000))*(r01)*(x7617)*(x7618)))+(((sj0)*(x7614)))+(((IkReal(-1.00000000000000))*(x7618)*(x7620)))+(((x7615)*(x7616)))+(((IkReal(-1.00000000000000))*(cj0)*(x7619)))+(((cj6)*(r11)*(x7615))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(((((IkReal(-1.00000000000000))*(r01)*(x7615)*(x7617)))+(((IkReal(-1.00000000000000))*(x7615)*(x7620)))+(((sj0)*(x7619)))+(((cj0)*(x7614)))+(((IkReal(-1.00000000000000))*(x7616)*(x7618)))+(((IkReal(-1.00000000000000))*(r11)*(x7617)*(x7618))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(IKsqr(((((IkReal(-1.00000000000000))*(r01)*(x7617)*(x7618)))+(((sj0)*(x7614)))+(((IkReal(-1.00000000000000))*(x7618)*(x7620)))+(((x7615)*(x7616)))+(((IkReal(-1.00000000000000))*(cj0)*(x7619)))+(((cj6)*(r11)*(x7615)))))+IKsqr(((((IkReal(-1.00000000000000))*(r01)*(x7615)*(x7617)))+(((IkReal(-1.00000000000000))*(x7615)*(x7620)))+(((sj0)*(x7619)))+(((cj0)*(x7614)))+(((IkReal(-1.00000000000000))*(x7616)*(x7618)))+(((IkReal(-1.00000000000000))*(r11)*(x7617)*(x7618)))))-1) <= IKFAST_SINCOS_THRESH )
    continue;
j3array[0]=IKatan2(((((IkReal(-1.00000000000000))*(r01)*(x7617)*(x7618)))+(((sj0)*(x7614)))+(((IkReal(-1.00000000000000))*(x7618)*(x7620)))+(((x7615)*(x7616)))+(((IkReal(-1.00000000000000))*(cj0)*(x7619)))+(((cj6)*(r11)*(x7615)))), ((((IkReal(-1.00000000000000))*(r01)*(x7615)*(x7617)))+(((IkReal(-1.00000000000000))*(x7615)*(x7620)))+(((sj0)*(x7619)))+(((cj0)*(x7614)))+(((IkReal(-1.00000000000000))*(x7616)*(x7618)))+(((IkReal(-1.00000000000000))*(r11)*(x7617)*(x7618)))));
sj3array[0]=IKsin(j3array[0]);
cj3array[0]=IKcos(j3array[0]);
if( j3array[0] > IKPI )
{
    j3array[0]-=IK2PI;
}
else if( j3array[0] < -IKPI )
{    j3array[0]+=IK2PI;
}
j3valid[0] = true;
for(int ij3 = 0; ij3 < 1; ++ij3)
{
if( !j3valid[ij3] )
{
    continue;
}
_ij3[0] = ij3; _ij3[1] = -1;
for(int iij3 = ij3+1; iij3 < 1; ++iij3)
{
if( j3valid[iij3] && IKabs(cj3array[ij3]-cj3array[iij3]) < IKFAST_SOLUTION_THRESH && IKabs(sj3array[ij3]-sj3array[iij3]) < IKFAST_SOLUTION_THRESH )
{
    j3valid[iij3]=false; _ij3[1] = iij3; break; 
}
}
j3 = j3array[ij3]; cj3 = cj3array[ij3]; sj3 = sj3array[ij3];
{
IkReal evalcond[4];
IkReal x7621=IKsin(j3);
IkReal x7622=((sj0)*(sj5));
IkReal x7623=((r00)*(sj6));
IkReal x7624=((IkReal(1.00000000000000))*(cj4));
IkReal x7625=((cj6)*(sj0));
IkReal x7626=((r00)*(sj4));
IkReal x7627=((cj0)*(cj5));
IkReal x7628=((cj6)*(r01));
IkReal x7629=((cj5)*(sj0));
IkReal x7630=((cj0)*(sj5));
IkReal x7631=((cj6)*(r11));
IkReal x7632=((r10)*(sj6));
IkReal x7633=((r10)*(sj4));
IkReal x7634=((IkReal(1.00000000000000))*(IKcos(j3)));
IkReal x7635=((cj0)*(sj4)*(sj6));
IkReal x7636=((sj0)*(sj4)*(sj6));
IkReal x7637=((IkReal(1.00000000000000))*(cj0)*(cj6));
evalcond[0]=((((IkReal(-1.00000000000000))*(r02)*(x7629)))+(((x7622)*(x7628)))+(((r12)*(x7627)))+(((x7622)*(x7623)))+(x7621)+(((IkReal(-1.00000000000000))*(x7630)*(x7631)))+(((IkReal(-1.00000000000000))*(x7630)*(x7632))));
evalcond[1]=((((IkReal(-1.00000000000000))*(x7628)*(x7630)))+(((IkReal(-1.00000000000000))*(x7634)))+(((IkReal(-1.00000000000000))*(x7622)*(x7632)))+(((IkReal(-1.00000000000000))*(x7623)*(x7630)))+(((r12)*(x7629)))+(((IkReal(-1.00000000000000))*(x7622)*(x7631)))+(((r02)*(x7627))));
evalcond[2]=((((IkReal(-1.00000000000000))*(x7624)*(x7627)*(x7632)))+(((IkReal(-1.00000000000000))*(x7624)*(x7627)*(x7631)))+(((cj4)*(r02)*(x7622)))+(((x7625)*(x7626)))+(((IkReal(-1.00000000000000))*(x7634)))+(((cj4)*(x7623)*(x7629)))+(((r11)*(x7635)))+(((IkReal(-1.00000000000000))*(r01)*(x7636)))+(((IkReal(-1.00000000000000))*(x7633)*(x7637)))+(((IkReal(-1.00000000000000))*(r12)*(x7624)*(x7630)))+(((cj4)*(cj5)*(r01)*(x7625))));
evalcond[3]=((((r11)*(x7636)))+(((IkReal(-1.00000000000000))*(x7626)*(x7637)))+(((IkReal(-1.00000000000000))*(x7624)*(x7627)*(x7628)))+(((IkReal(-1.00000000000000))*(r02)*(x7624)*(x7630)))+(((IkReal(-1.00000000000000))*(x7625)*(x7633)))+(((r01)*(x7635)))+(((IkReal(-1.00000000000000))*(r12)*(x7622)*(x7624)))+(((IkReal(-1.00000000000000))*(x7624)*(x7629)*(x7632)))+(((IkReal(-1.00000000000000))*(x7621)))+(((IkReal(-1.00000000000000))*(x7623)*(x7624)*(x7627)))+(((IkReal(-1.00000000000000))*(cj5)*(r11)*(x7624)*(x7625))));
if( IKabs(evalcond[0]) > 0.000001  || IKabs(evalcond[1]) > 0.000001  || IKabs(evalcond[2]) > 0.000001  || IKabs(evalcond[3]) > 0.000001  )
{
continue;
}
}

{
std::vector<IkSingleDOFSolutionBase<IkReal> > vinfos(7);
vinfos[0].jointtype = 1;
vinfos[0].foffset = j0;
vinfos[0].indices[0] = _ij0[0];
vinfos[0].indices[1] = _ij0[1];
vinfos[0].maxsolutions = _nj0;
vinfos[1].jointtype = 1;
vinfos[1].foffset = j1;
vinfos[1].indices[0] = _ij1[0];
vinfos[1].indices[1] = _ij1[1];
vinfos[1].maxsolutions = _nj1;
vinfos[2].jointtype = 1;
vinfos[2].foffset = j2;
vinfos[2].indices[0] = _ij2[0];
vinfos[2].indices[1] = _ij2[1];
vinfos[2].maxsolutions = _nj2;
vinfos[3].jointtype = 1;
vinfos[3].foffset = j3;
vinfos[3].indices[0] = _ij3[0];
vinfos[3].indices[1] = _ij3[1];
vinfos[3].maxsolutions = _nj3;
vinfos[4].jointtype = 1;
vinfos[4].foffset = j4;
vinfos[4].indices[0] = _ij4[0];
vinfos[4].indices[1] = _ij4[1];
vinfos[4].maxsolutions = _nj4;
vinfos[5].jointtype = 1;
vinfos[5].foffset = j5;
vinfos[5].indices[0] = _ij5[0];
vinfos[5].indices[1] = _ij5[1];
vinfos[5].maxsolutions = _nj5;
vinfos[6].jointtype = 1;
vinfos[6].foffset = j6;
vinfos[6].indices[0] = _ij6[0];
vinfos[6].indices[1] = _ij6[1];
vinfos[6].maxsolutions = _nj6;
std::vector<int> vfree(0);
solutions.AddSolution(vinfos,vfree);
}
}
}

} else
{
if( 1 )
{
continue;

} else
{
}
}
}
}
}
}

} else
{
{
IkReal j3array[1], cj3array[1], sj3array[1];
bool j3valid[1]={false};
_nj3 = 1;
IkReal x7638=((cj0)*(cj5));
IkReal x7639=((IkReal(1.00000000000000))*(cj0));
IkReal x7640=((cj6)*(r11));
IkReal x7641=((r10)*(sj6));
IkReal x7642=((cj5)*(sj0));
IkReal x7643=((r00)*(sj5)*(sj6));
IkReal x7644=((cj6)*(r01)*(sj5));
IkReal x7645=((IkReal(1.00000000000000))*(sj0)*(sj5));
if( IKabs(((((IKabs(sj2) != 0)?((IkReal)1/(sj2)):(IkReal)1.0e30))*(((((IkReal(-1.00000000000000))*(r02)*(x7642)))+(((sj0)*(x7644)))+(((IkReal(-1.00000000000000))*(sj5)*(x7639)*(x7640)))+(((IkReal(-1.00000000000000))*(sj5)*(x7639)*(x7641)))+(((r12)*(x7638)))+(((sj0)*(x7643))))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(((((r02)*(x7638)))+(((IkReal(-1.00000000000000))*(x7640)*(x7645)))+(((r12)*(x7642)))+(((IkReal(-1.00000000000000))*(x7639)*(x7643)))+(((IkReal(-1.00000000000000))*(x7639)*(x7644)))+(((IkReal(-1.00000000000000))*(x7641)*(x7645))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(IKsqr(((((IKabs(sj2) != 0)?((IkReal)1/(sj2)):(IkReal)1.0e30))*(((((IkReal(-1.00000000000000))*(r02)*(x7642)))+(((sj0)*(x7644)))+(((IkReal(-1.00000000000000))*(sj5)*(x7639)*(x7640)))+(((IkReal(-1.00000000000000))*(sj5)*(x7639)*(x7641)))+(((r12)*(x7638)))+(((sj0)*(x7643)))))))+IKsqr(((((r02)*(x7638)))+(((IkReal(-1.00000000000000))*(x7640)*(x7645)))+(((r12)*(x7642)))+(((IkReal(-1.00000000000000))*(x7639)*(x7643)))+(((IkReal(-1.00000000000000))*(x7639)*(x7644)))+(((IkReal(-1.00000000000000))*(x7641)*(x7645)))))-1) <= IKFAST_SINCOS_THRESH )
    continue;
j3array[0]=IKatan2(((((IKabs(sj2) != 0)?((IkReal)1/(sj2)):(IkReal)1.0e30))*(((((IkReal(-1.00000000000000))*(r02)*(x7642)))+(((sj0)*(x7644)))+(((IkReal(-1.00000000000000))*(sj5)*(x7639)*(x7640)))+(((IkReal(-1.00000000000000))*(sj5)*(x7639)*(x7641)))+(((r12)*(x7638)))+(((sj0)*(x7643)))))), ((((r02)*(x7638)))+(((IkReal(-1.00000000000000))*(x7640)*(x7645)))+(((r12)*(x7642)))+(((IkReal(-1.00000000000000))*(x7639)*(x7643)))+(((IkReal(-1.00000000000000))*(x7639)*(x7644)))+(((IkReal(-1.00000000000000))*(x7641)*(x7645)))));
sj3array[0]=IKsin(j3array[0]);
cj3array[0]=IKcos(j3array[0]);
if( j3array[0] > IKPI )
{
    j3array[0]-=IK2PI;
}
else if( j3array[0] < -IKPI )
{    j3array[0]+=IK2PI;
}
j3valid[0] = true;
for(int ij3 = 0; ij3 < 1; ++ij3)
{
if( !j3valid[ij3] )
{
    continue;
}
_ij3[0] = ij3; _ij3[1] = -1;
for(int iij3 = ij3+1; iij3 < 1; ++iij3)
{
if( j3valid[iij3] && IKabs(cj3array[ij3]-cj3array[iij3]) < IKFAST_SOLUTION_THRESH && IKabs(sj3array[ij3]-sj3array[iij3]) < IKFAST_SOLUTION_THRESH )
{
    j3valid[iij3]=false; _ij3[1] = iij3; break; 
}
}
j3 = j3array[ij3]; cj3 = cj3array[ij3]; sj3 = sj3array[ij3];
{
IkReal evalcond[6];
IkReal x7646=IKsin(j3);
IkReal x7647=IKcos(j3);
IkReal x7648=((sj0)*(sj5));
IkReal x7649=((r00)*(sj6));
IkReal x7650=((IkReal(1.00000000000000))*(cj4));
IkReal x7651=((cj6)*(r01));
IkReal x7652=((cj0)*(cj5));
IkReal x7653=((cj5)*(sj0));
IkReal x7654=((cj6)*(r11));
IkReal x7655=((cj0)*(sj5));
IkReal x7656=((cj6)*(sj4));
IkReal x7657=((cj4)*(cj5));
IkReal x7658=((cj6)*(r21));
IkReal x7659=((r20)*(sj6));
IkReal x7660=((r10)*(sj6));
IkReal x7661=((IkReal(1.00000000000000))*(cj0));
IkReal x7662=((IkReal(1.00000000000000))*(x7646));
IkReal x7663=((cj0)*(sj4)*(sj6));
IkReal x7664=((sj0)*(sj4)*(sj6));
evalcond[0]=((((IkReal(-1.00000000000000))*(cj2)*(x7662)))+(((sj5)*(x7659)))+(((IkReal(-1.00000000000000))*(cj5)*(r22)))+(((sj5)*(x7658))));
evalcond[1]=((((x7657)*(x7658)))+(((IkReal(-1.00000000000000))*(r21)*(sj4)*(sj6)))+(((x7657)*(x7659)))+(((r20)*(x7656)))+(((cj4)*(r22)*(sj5)))+(((cj2)*(x7647))));
evalcond[2]=((((x7648)*(x7649)))+(((IkReal(-1.00000000000000))*(x7655)*(x7660)))+(((x7648)*(x7651)))+(((IkReal(-1.00000000000000))*(r02)*(x7653)))+(((r12)*(x7652)))+(((IkReal(-1.00000000000000))*(sj2)*(x7662)))+(((IkReal(-1.00000000000000))*(x7654)*(x7655))));
evalcond[3]=((((IkReal(-1.00000000000000))*(x7647)))+(((IkReal(-1.00000000000000))*(x7648)*(x7654)))+(((IkReal(-1.00000000000000))*(x7648)*(x7660)))+(((r12)*(x7653)))+(((IkReal(-1.00000000000000))*(x7651)*(x7655)))+(((IkReal(-1.00000000000000))*(x7649)*(x7655)))+(((r02)*(x7652))));
evalcond[4]=((((IkReal(-1.00000000000000))*(r12)*(x7650)*(x7655)))+(((r00)*(sj0)*(x7656)))+(((IkReal(-1.00000000000000))*(x7650)*(x7652)*(x7660)))+(((IkReal(-1.00000000000000))*(r01)*(x7664)))+(((cj4)*(r02)*(x7648)))+(((sj2)*(x7647)))+(((IkReal(-1.00000000000000))*(x7650)*(x7652)*(x7654)))+(((cj4)*(x7649)*(x7653)))+(((cj4)*(x7651)*(x7653)))+(((IkReal(-1.00000000000000))*(r10)*(x7656)*(x7661)))+(((r11)*(x7663))));
evalcond[5]=((((r11)*(x7664)))+(((IkReal(-1.00000000000000))*(x7650)*(x7653)*(x7660)))+(((IkReal(-1.00000000000000))*(x7650)*(x7651)*(x7652)))+(((IkReal(-1.00000000000000))*(x7650)*(x7653)*(x7654)))+(((IkReal(-1.00000000000000))*(r12)*(x7648)*(x7650)))+(((r01)*(x7663)))+(((IkReal(-1.00000000000000))*(x7649)*(x7650)*(x7652)))+(((IkReal(-1.00000000000000))*(r02)*(x7650)*(x7655)))+(((IkReal(-1.00000000000000))*(x7662)))+(((IkReal(-1.00000000000000))*(r10)*(sj0)*(x7656)))+(((IkReal(-1.00000000000000))*(r00)*(x7656)*(x7661))));
if( IKabs(evalcond[0]) > 0.000001  || IKabs(evalcond[1]) > 0.000001  || IKabs(evalcond[2]) > 0.000001  || IKabs(evalcond[3]) > 0.000001  || IKabs(evalcond[4]) > 0.000001  || IKabs(evalcond[5]) > 0.000001  )
{
continue;
}
}

{
std::vector<IkSingleDOFSolutionBase<IkReal> > vinfos(7);
vinfos[0].jointtype = 1;
vinfos[0].foffset = j0;
vinfos[0].indices[0] = _ij0[0];
vinfos[0].indices[1] = _ij0[1];
vinfos[0].maxsolutions = _nj0;
vinfos[1].jointtype = 1;
vinfos[1].foffset = j1;
vinfos[1].indices[0] = _ij1[0];
vinfos[1].indices[1] = _ij1[1];
vinfos[1].maxsolutions = _nj1;
vinfos[2].jointtype = 1;
vinfos[2].foffset = j2;
vinfos[2].indices[0] = _ij2[0];
vinfos[2].indices[1] = _ij2[1];
vinfos[2].maxsolutions = _nj2;
vinfos[3].jointtype = 1;
vinfos[3].foffset = j3;
vinfos[3].indices[0] = _ij3[0];
vinfos[3].indices[1] = _ij3[1];
vinfos[3].maxsolutions = _nj3;
vinfos[4].jointtype = 1;
vinfos[4].foffset = j4;
vinfos[4].indices[0] = _ij4[0];
vinfos[4].indices[1] = _ij4[1];
vinfos[4].maxsolutions = _nj4;
vinfos[5].jointtype = 1;
vinfos[5].foffset = j5;
vinfos[5].indices[0] = _ij5[0];
vinfos[5].indices[1] = _ij5[1];
vinfos[5].maxsolutions = _nj5;
vinfos[6].jointtype = 1;
vinfos[6].foffset = j6;
vinfos[6].indices[0] = _ij6[0];
vinfos[6].indices[1] = _ij6[1];
vinfos[6].maxsolutions = _nj6;
std::vector<int> vfree(0);
solutions.AddSolution(vinfos,vfree);
}
}
}

}

}

} else
{
{
IkReal j3array[1], cj3array[1], sj3array[1];
bool j3valid[1]={false};
_nj3 = 1;
IkReal x7665=((sj5)*(sj6));
IkReal x7666=((IkReal(1.00000000000000))*(cj6)*(sj5));
if( IKabs(((((IKabs(cj2) != 0)?((IkReal)1/(cj2)):(IkReal)1.0e30))*(((((cj6)*(r21)*(sj5)))+(((IkReal(-1.00000000000000))*(cj5)*(r22)))+(((r20)*(x7665))))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(((((cj0)*(cj5)*(r02)))+(((cj5)*(r12)*(sj0)))+(((IkReal(-1.00000000000000))*(r11)*(sj0)*(x7666)))+(((IkReal(-1.00000000000000))*(cj0)*(r00)*(x7665)))+(((IkReal(-1.00000000000000))*(r10)*(sj0)*(x7665)))+(((IkReal(-1.00000000000000))*(cj0)*(r01)*(x7666))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(IKsqr(((((IKabs(cj2) != 0)?((IkReal)1/(cj2)):(IkReal)1.0e30))*(((((cj6)*(r21)*(sj5)))+(((IkReal(-1.00000000000000))*(cj5)*(r22)))+(((r20)*(x7665)))))))+IKsqr(((((cj0)*(cj5)*(r02)))+(((cj5)*(r12)*(sj0)))+(((IkReal(-1.00000000000000))*(r11)*(sj0)*(x7666)))+(((IkReal(-1.00000000000000))*(cj0)*(r00)*(x7665)))+(((IkReal(-1.00000000000000))*(r10)*(sj0)*(x7665)))+(((IkReal(-1.00000000000000))*(cj0)*(r01)*(x7666)))))-1) <= IKFAST_SINCOS_THRESH )
    continue;
j3array[0]=IKatan2(((((IKabs(cj2) != 0)?((IkReal)1/(cj2)):(IkReal)1.0e30))*(((((cj6)*(r21)*(sj5)))+(((IkReal(-1.00000000000000))*(cj5)*(r22)))+(((r20)*(x7665)))))), ((((cj0)*(cj5)*(r02)))+(((cj5)*(r12)*(sj0)))+(((IkReal(-1.00000000000000))*(r11)*(sj0)*(x7666)))+(((IkReal(-1.00000000000000))*(cj0)*(r00)*(x7665)))+(((IkReal(-1.00000000000000))*(r10)*(sj0)*(x7665)))+(((IkReal(-1.00000000000000))*(cj0)*(r01)*(x7666)))));
sj3array[0]=IKsin(j3array[0]);
cj3array[0]=IKcos(j3array[0]);
if( j3array[0] > IKPI )
{
    j3array[0]-=IK2PI;
}
else if( j3array[0] < -IKPI )
{    j3array[0]+=IK2PI;
}
j3valid[0] = true;
for(int ij3 = 0; ij3 < 1; ++ij3)
{
if( !j3valid[ij3] )
{
    continue;
}
_ij3[0] = ij3; _ij3[1] = -1;
for(int iij3 = ij3+1; iij3 < 1; ++iij3)
{
if( j3valid[iij3] && IKabs(cj3array[ij3]-cj3array[iij3]) < IKFAST_SOLUTION_THRESH && IKabs(sj3array[ij3]-sj3array[iij3]) < IKFAST_SOLUTION_THRESH )
{
    j3valid[iij3]=false; _ij3[1] = iij3; break; 
}
}
j3 = j3array[ij3]; cj3 = cj3array[ij3]; sj3 = sj3array[ij3];
{
IkReal evalcond[6];
IkReal x7667=IKsin(j3);
IkReal x7668=IKcos(j3);
IkReal x7669=((sj0)*(sj5));
IkReal x7670=((r00)*(sj6));
IkReal x7671=((IkReal(1.00000000000000))*(cj4));
IkReal x7672=((cj6)*(r01));
IkReal x7673=((cj0)*(cj5));
IkReal x7674=((cj5)*(sj0));
IkReal x7675=((cj6)*(r11));
IkReal x7676=((cj0)*(sj5));
IkReal x7677=((cj6)*(sj4));
IkReal x7678=((cj4)*(cj5));
IkReal x7679=((cj6)*(r21));
IkReal x7680=((r20)*(sj6));
IkReal x7681=((r10)*(sj6));
IkReal x7682=((IkReal(1.00000000000000))*(cj0));
IkReal x7683=((IkReal(1.00000000000000))*(x7667));
IkReal x7684=((cj0)*(sj4)*(sj6));
IkReal x7685=((sj0)*(sj4)*(sj6));
evalcond[0]=((((sj5)*(x7679)))+(((IkReal(-1.00000000000000))*(cj5)*(r22)))+(((IkReal(-1.00000000000000))*(cj2)*(x7683)))+(((sj5)*(x7680))));
evalcond[1]=((((r20)*(x7677)))+(((IkReal(-1.00000000000000))*(r21)*(sj4)*(sj6)))+(((cj2)*(x7668)))+(((cj4)*(r22)*(sj5)))+(((x7678)*(x7680)))+(((x7678)*(x7679))));
evalcond[2]=((((x7669)*(x7672)))+(((IkReal(-1.00000000000000))*(x7675)*(x7676)))+(((IkReal(-1.00000000000000))*(r02)*(x7674)))+(((IkReal(-1.00000000000000))*(sj2)*(x7683)))+(((x7669)*(x7670)))+(((r12)*(x7673)))+(((IkReal(-1.00000000000000))*(x7676)*(x7681))));
evalcond[3]=((((IkReal(-1.00000000000000))*(x7672)*(x7676)))+(((r12)*(x7674)))+(((IkReal(-1.00000000000000))*(x7670)*(x7676)))+(((IkReal(-1.00000000000000))*(x7669)*(x7681)))+(((IkReal(-1.00000000000000))*(x7669)*(x7675)))+(((IkReal(-1.00000000000000))*(x7668)))+(((r02)*(x7673))));
evalcond[4]=((((IkReal(-1.00000000000000))*(x7671)*(x7673)*(x7681)))+(((IkReal(-1.00000000000000))*(r12)*(x7671)*(x7676)))+(((sj2)*(x7668)))+(((cj4)*(x7670)*(x7674)))+(((cj4)*(x7672)*(x7674)))+(((r00)*(sj0)*(x7677)))+(((IkReal(-1.00000000000000))*(r01)*(x7685)))+(((cj4)*(r02)*(x7669)))+(((r11)*(x7684)))+(((IkReal(-1.00000000000000))*(r10)*(x7677)*(x7682)))+(((IkReal(-1.00000000000000))*(x7671)*(x7673)*(x7675))));
evalcond[5]=((((IkReal(-1.00000000000000))*(x7671)*(x7672)*(x7673)))+(((IkReal(-1.00000000000000))*(r10)*(sj0)*(x7677)))+(((IkReal(-1.00000000000000))*(x7683)))+(((IkReal(-1.00000000000000))*(x7671)*(x7674)*(x7681)))+(((IkReal(-1.00000000000000))*(r02)*(x7671)*(x7676)))+(((IkReal(-1.00000000000000))*(x7671)*(x7674)*(x7675)))+(((IkReal(-1.00000000000000))*(x7670)*(x7671)*(x7673)))+(((IkReal(-1.00000000000000))*(r12)*(x7669)*(x7671)))+(((r01)*(x7684)))+(((IkReal(-1.00000000000000))*(r00)*(x7677)*(x7682)))+(((r11)*(x7685))));
if( IKabs(evalcond[0]) > 0.000001  || IKabs(evalcond[1]) > 0.000001  || IKabs(evalcond[2]) > 0.000001  || IKabs(evalcond[3]) > 0.000001  || IKabs(evalcond[4]) > 0.000001  || IKabs(evalcond[5]) > 0.000001  )
{
continue;
}
}

{
std::vector<IkSingleDOFSolutionBase<IkReal> > vinfos(7);
vinfos[0].jointtype = 1;
vinfos[0].foffset = j0;
vinfos[0].indices[0] = _ij0[0];
vinfos[0].indices[1] = _ij0[1];
vinfos[0].maxsolutions = _nj0;
vinfos[1].jointtype = 1;
vinfos[1].foffset = j1;
vinfos[1].indices[0] = _ij1[0];
vinfos[1].indices[1] = _ij1[1];
vinfos[1].maxsolutions = _nj1;
vinfos[2].jointtype = 1;
vinfos[2].foffset = j2;
vinfos[2].indices[0] = _ij2[0];
vinfos[2].indices[1] = _ij2[1];
vinfos[2].maxsolutions = _nj2;
vinfos[3].jointtype = 1;
vinfos[3].foffset = j3;
vinfos[3].indices[0] = _ij3[0];
vinfos[3].indices[1] = _ij3[1];
vinfos[3].maxsolutions = _nj3;
vinfos[4].jointtype = 1;
vinfos[4].foffset = j4;
vinfos[4].indices[0] = _ij4[0];
vinfos[4].indices[1] = _ij4[1];
vinfos[4].maxsolutions = _nj4;
vinfos[5].jointtype = 1;
vinfos[5].foffset = j5;
vinfos[5].indices[0] = _ij5[0];
vinfos[5].indices[1] = _ij5[1];
vinfos[5].maxsolutions = _nj5;
vinfos[6].jointtype = 1;
vinfos[6].foffset = j6;
vinfos[6].indices[0] = _ij6[0];
vinfos[6].indices[1] = _ij6[1];
vinfos[6].maxsolutions = _nj6;
std::vector<int> vfree(0);
solutions.AddSolution(vinfos,vfree);
}
}
}

}

}

} else
{
{
IkReal j3array[1], cj3array[1], sj3array[1];
bool j3valid[1]={false};
_nj3 = 1;
IkReal x7686=((IkReal(1.00000000000000))*(cj4));
IkReal x7687=((cj6)*(r21));
IkReal x7688=((r20)*(sj6));
if( IKabs(((gconst9)*(((((sj5)*(x7687)))+(((sj5)*(x7688)))+(((IkReal(-1.00000000000000))*(cj5)*(r22))))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(((gconst9)*(((((IkReal(-1.00000000000000))*(r22)*(sj5)*(x7686)))+(((r21)*(sj4)*(sj6)))+(((IkReal(-1.00000000000000))*(cj5)*(x7686)*(x7688)))+(((IkReal(-1.00000000000000))*(cj5)*(x7686)*(x7687)))+(((IkReal(-1.00000000000000))*(cj6)*(r20)*(sj4))))))) < IKFAST_ATAN2_MAGTHRESH )
    continue;
j3array[0]=IKatan2(((gconst9)*(((((sj5)*(x7687)))+(((sj5)*(x7688)))+(((IkReal(-1.00000000000000))*(cj5)*(r22)))))), ((gconst9)*(((((IkReal(-1.00000000000000))*(r22)*(sj5)*(x7686)))+(((r21)*(sj4)*(sj6)))+(((IkReal(-1.00000000000000))*(cj5)*(x7686)*(x7688)))+(((IkReal(-1.00000000000000))*(cj5)*(x7686)*(x7687)))+(((IkReal(-1.00000000000000))*(cj6)*(r20)*(sj4)))))));
sj3array[0]=IKsin(j3array[0]);
cj3array[0]=IKcos(j3array[0]);
if( j3array[0] > IKPI )
{
    j3array[0]-=IK2PI;
}
else if( j3array[0] < -IKPI )
{    j3array[0]+=IK2PI;
}
j3valid[0] = true;
for(int ij3 = 0; ij3 < 1; ++ij3)
{
if( !j3valid[ij3] )
{
    continue;
}
_ij3[0] = ij3; _ij3[1] = -1;
for(int iij3 = ij3+1; iij3 < 1; ++iij3)
{
if( j3valid[iij3] && IKabs(cj3array[ij3]-cj3array[iij3]) < IKFAST_SOLUTION_THRESH && IKabs(sj3array[ij3]-sj3array[iij3]) < IKFAST_SOLUTION_THRESH )
{
    j3valid[iij3]=false; _ij3[1] = iij3; break; 
}
}
j3 = j3array[ij3]; cj3 = cj3array[ij3]; sj3 = sj3array[ij3];
{
IkReal evalcond[6];
IkReal x7689=IKsin(j3);
IkReal x7690=IKcos(j3);
IkReal x7691=((sj0)*(sj5));
IkReal x7692=((r00)*(sj6));
IkReal x7693=((IkReal(1.00000000000000))*(cj4));
IkReal x7694=((cj6)*(r01));
IkReal x7695=((cj0)*(cj5));
IkReal x7696=((cj5)*(sj0));
IkReal x7697=((cj6)*(r11));
IkReal x7698=((cj0)*(sj5));
IkReal x7699=((cj6)*(sj4));
IkReal x7700=((cj4)*(cj5));
IkReal x7701=((cj6)*(r21));
IkReal x7702=((r20)*(sj6));
IkReal x7703=((r10)*(sj6));
IkReal x7704=((IkReal(1.00000000000000))*(cj0));
IkReal x7705=((IkReal(1.00000000000000))*(x7689));
IkReal x7706=((cj0)*(sj4)*(sj6));
IkReal x7707=((sj0)*(sj4)*(sj6));
evalcond[0]=((((sj5)*(x7702)))+(((IkReal(-1.00000000000000))*(cj5)*(r22)))+(((IkReal(-1.00000000000000))*(cj2)*(x7705)))+(((sj5)*(x7701))));
evalcond[1]=((((IkReal(-1.00000000000000))*(r21)*(sj4)*(sj6)))+(((cj2)*(x7690)))+(((x7700)*(x7701)))+(((r20)*(x7699)))+(((cj4)*(r22)*(sj5)))+(((x7700)*(x7702))));
evalcond[2]=((((IkReal(-1.00000000000000))*(sj2)*(x7705)))+(((x7691)*(x7694)))+(((IkReal(-1.00000000000000))*(x7698)*(x7703)))+(((x7691)*(x7692)))+(((r12)*(x7695)))+(((IkReal(-1.00000000000000))*(r02)*(x7696)))+(((IkReal(-1.00000000000000))*(x7697)*(x7698))));
evalcond[3]=((((IkReal(-1.00000000000000))*(x7694)*(x7698)))+(((r12)*(x7696)))+(((IkReal(-1.00000000000000))*(x7691)*(x7703)))+(((IkReal(-1.00000000000000))*(x7690)))+(((r02)*(x7695)))+(((IkReal(-1.00000000000000))*(x7691)*(x7697)))+(((IkReal(-1.00000000000000))*(x7692)*(x7698))));
evalcond[4]=((((IkReal(-1.00000000000000))*(r01)*(x7707)))+(((IkReal(-1.00000000000000))*(x7693)*(x7695)*(x7703)))+(((r00)*(sj0)*(x7699)))+(((IkReal(-1.00000000000000))*(r10)*(x7699)*(x7704)))+(((IkReal(-1.00000000000000))*(r12)*(x7693)*(x7698)))+(((sj2)*(x7690)))+(((cj4)*(x7694)*(x7696)))+(((r11)*(x7706)))+(((IkReal(-1.00000000000000))*(x7693)*(x7695)*(x7697)))+(((cj4)*(x7692)*(x7696)))+(((cj4)*(r02)*(x7691))));
evalcond[5]=((((r01)*(x7706)))+(((r11)*(x7707)))+(((IkReal(-1.00000000000000))*(x7705)))+(((IkReal(-1.00000000000000))*(x7693)*(x7696)*(x7703)))+(((IkReal(-1.00000000000000))*(r00)*(x7699)*(x7704)))+(((IkReal(-1.00000000000000))*(r10)*(sj0)*(x7699)))+(((IkReal(-1.00000000000000))*(r02)*(x7693)*(x7698)))+(((IkReal(-1.00000000000000))*(x7693)*(x7696)*(x7697)))+(((IkReal(-1.00000000000000))*(r12)*(x7691)*(x7693)))+(((IkReal(-1.00000000000000))*(x7693)*(x7694)*(x7695)))+(((IkReal(-1.00000000000000))*(x7692)*(x7693)*(x7695))));
if( IKabs(evalcond[0]) > 0.000001  || IKabs(evalcond[1]) > 0.000001  || IKabs(evalcond[2]) > 0.000001  || IKabs(evalcond[3]) > 0.000001  || IKabs(evalcond[4]) > 0.000001  || IKabs(evalcond[5]) > 0.000001  )
{
continue;
}
}

{
std::vector<IkSingleDOFSolutionBase<IkReal> > vinfos(7);
vinfos[0].jointtype = 1;
vinfos[0].foffset = j0;
vinfos[0].indices[0] = _ij0[0];
vinfos[0].indices[1] = _ij0[1];
vinfos[0].maxsolutions = _nj0;
vinfos[1].jointtype = 1;
vinfos[1].foffset = j1;
vinfos[1].indices[0] = _ij1[0];
vinfos[1].indices[1] = _ij1[1];
vinfos[1].maxsolutions = _nj1;
vinfos[2].jointtype = 1;
vinfos[2].foffset = j2;
vinfos[2].indices[0] = _ij2[0];
vinfos[2].indices[1] = _ij2[1];
vinfos[2].maxsolutions = _nj2;
vinfos[3].jointtype = 1;
vinfos[3].foffset = j3;
vinfos[3].indices[0] = _ij3[0];
vinfos[3].indices[1] = _ij3[1];
vinfos[3].maxsolutions = _nj3;
vinfos[4].jointtype = 1;
vinfos[4].foffset = j4;
vinfos[4].indices[0] = _ij4[0];
vinfos[4].indices[1] = _ij4[1];
vinfos[4].maxsolutions = _nj4;
vinfos[5].jointtype = 1;
vinfos[5].foffset = j5;
vinfos[5].indices[0] = _ij5[0];
vinfos[5].indices[1] = _ij5[1];
vinfos[5].maxsolutions = _nj5;
vinfos[6].jointtype = 1;
vinfos[6].foffset = j6;
vinfos[6].indices[0] = _ij6[0];
vinfos[6].indices[1] = _ij6[1];
vinfos[6].maxsolutions = _nj6;
std::vector<int> vfree(0);
solutions.AddSolution(vinfos,vfree);
}
}
}

}

}

} else
{
IkReal x7708=((IkReal(1.00000000000000))*(cj0));
IkReal x7709=((cj4)*(sj6));
IkReal x7710=((sj0)*(sj4));
IkReal x7711=((cj5)*(sj6));
IkReal x7712=((sj4)*(sj5));
IkReal x7713=((r12)*(sj5));
IkReal x7714=((IkReal(0.374290000000000))*(cj5));
IkReal x7715=((r02)*(sj0));
IkReal x7716=((IkReal(1.00000000000000))*(sj0));
IkReal x7717=((cj0)*(r10));
IkReal x7718=((cj4)*(cj6));
IkReal x7719=((r00)*(sj0));
IkReal x7720=((cj6)*(r21));
IkReal x7721=((IkReal(0.374290000000000))*(sj5));
IkReal x7722=((cj0)*(r00));
IkReal x7723=((IkReal(0.0100000000000000))*(sj5));
IkReal x7724=((cj0)*(r02));
IkReal x7725=((cj5)*(sj4));
IkReal x7726=((cj6)*(r01));
IkReal x7727=((cj6)*(r11));
IkReal x7728=((r01)*(sj0));
IkReal x7729=((r10)*(sj0));
IkReal x7730=((IkReal(0.0100000000000000))*(cj5)*(cj6));
IkReal x7731=((sj6)*(x7721));
IkReal x7732=((cj0)*(cj6)*(x7721));
evalcond[0]=((IkReal(-3.14159265358979))+(IKfmod(j1, IkReal(6.28318530717959))));
evalcond[1]=((sj2)+(((x7720)*(x7725)))+(((r20)*(sj4)*(x7711)))+(((IkReal(-1.00000000000000))*(r20)*(x7718)))+(((r22)*(x7712)))+(((r21)*(x7709))));
evalcond[2]=((((IkReal(-0.0100000000000000))*(r20)*(x7711)))+(((IkReal(-0.0690000000000000))*(cj2)))+(((x7720)*(x7721)))+(((IkReal(-0.0100000000000000))*(cj5)*(x7720)))+(pz)+(((IkReal(-1.00000000000000))*(r22)*(x7723)))+(((r20)*(x7731)))+(((IkReal(-1.00000000000000))*(r22)*(x7714))));
evalcond[3]=((((x7709)*(x7728)))+(((IkReal(-1.00000000000000))*(r12)*(x7708)*(x7712)))+(((IkReal(-1.00000000000000))*(x7708)*(x7725)*(x7727)))+(cj2)+(((cj5)*(x7710)*(x7726)))+(((r00)*(x7710)*(x7711)))+(((IkReal(-1.00000000000000))*(r10)*(sj4)*(x7708)*(x7711)))+(((x7717)*(x7718)))+(((r02)*(sj5)*(x7710)))+(((IkReal(-1.00000000000000))*(r11)*(x7708)*(x7709)))+(((IkReal(-1.00000000000000))*(r00)*(x7716)*(x7718))));
evalcond[4]=((((IkReal(-1.00000000000000))*(x7708)*(x7725)*(x7726)))+(((IkReal(-1.00000000000000))*(r10)*(x7710)*(x7711)))+(((IkReal(-1.00000000000000))*(r00)*(sj4)*(x7708)*(x7711)))+(((x7718)*(x7729)))+(((IkReal(-1.00000000000000))*(r02)*(x7708)*(x7712)))+(((IkReal(-1.00000000000000))*(r11)*(x7709)*(x7716)))+(((IkReal(-1.00000000000000))*(r01)*(x7708)*(x7709)))+(((x7718)*(x7722)))+(((IkReal(-1.00000000000000))*(x7710)*(x7713)))+(((IkReal(-1.00000000000000))*(cj5)*(x7710)*(x7727))));
evalcond[5]=((((IkReal(0.0100000000000000))*(cj0)*(x7713)))+(((IkReal(-1.00000000000000))*(x7714)*(x7715)))+(((IkReal(-0.0100000000000000))*(cj5)*(sj0)*(x7726)))+(((IkReal(0.0100000000000000))*(x7711)*(x7717)))+(((IkReal(-1.00000000000000))*(x7717)*(x7731)))+(((IkReal(0.0100000000000000))*(cj0)*(cj5)*(x7727)))+(((x7719)*(x7731)))+(((IkReal(0.0690000000000000))*(sj2)))+(((IkReal(-1.00000000000000))*(py)*(x7708)))+(((IkReal(-1.00000000000000))*(x7715)*(x7723)))+(((IkReal(-1.00000000000000))*(cj0)*(x7721)*(x7727)))+(((cj0)*(r12)*(x7714)))+(((IkReal(-0.0100000000000000))*(x7711)*(x7719)))+(((px)*(sj0)))+(((sj0)*(x7721)*(x7726))));
evalcond[6]=((IkReal(-0.295420000000000))+(((IkReal(-1.00000000000000))*(x7722)*(x7731)))+(((IkReal(0.0100000000000000))*(x7711)*(x7729)))+(((IkReal(-1.00000000000000))*(py)*(x7716)))+(((IkReal(0.0100000000000000))*(x7711)*(x7722)))+(((IkReal(0.0100000000000000))*(sj0)*(x7713)))+(((IkReal(0.0100000000000000))*(cj5)*(sj0)*(x7727)))+(((IkReal(-1.00000000000000))*(px)*(x7708)))+(((r12)*(sj0)*(x7714)))+(((IkReal(-1.00000000000000))*(cj0)*(x7721)*(x7726)))+(((IkReal(-1.00000000000000))*(sj0)*(x7721)*(x7727)))+(((x7723)*(x7724)))+(((IkReal(0.0100000000000000))*(cj0)*(cj5)*(x7726)))+(((IkReal(-1.00000000000000))*(x7729)*(x7731)))+(((x7714)*(x7724))));
if( IKabs(evalcond[0]) < 0.0000010000000000  && IKabs(evalcond[1]) < 0.0000010000000000  && IKabs(evalcond[2]) < 0.0000010000000000  && IKabs(evalcond[3]) < 0.0000010000000000  && IKabs(evalcond[4]) < 0.0000010000000000  && IKabs(evalcond[5]) < 0.0000010000000000  && IKabs(evalcond[6]) < 0.0000010000000000  )
{
{
IkReal dummyeval[1];
IkReal gconst10;
gconst10=IKsign(cj2);
dummyeval[0]=cj2;
if( IKabs(dummyeval[0]) < 0.0000010000000000  )
{
{
IkReal dummyeval[1];
dummyeval[0]=cj2;
if( IKabs(dummyeval[0]) < 0.0000010000000000  )
{
{
IkReal dummyeval[1];
dummyeval[0]=sj2;
if( IKabs(dummyeval[0]) < 0.0000010000000000  )
{
{
IkReal evalcond[9];
IkReal x7733=((cj5)*(sj4));
IkReal x7734=((IkReal(1.00000000000000))*(sj6));
IkReal x7735=((r10)*(sj0));
IkReal x7736=((sj4)*(sj5));
IkReal x7737=((cj5)*(cj6));
IkReal x7738=((r01)*(sj0));
IkReal x7739=((IkReal(1.00000000000000))*(r02));
IkReal x7740=((IkReal(0.374290000000000))*(cj0));
IkReal x7741=((cj5)*(r12));
IkReal x7742=((cj6)*(sj5));
IkReal x7743=((cj0)*(r11));
IkReal x7744=((cj5)*(sj0));
IkReal x7745=((r20)*(sj6));
IkReal x7746=((IkReal(1.00000000000000))*(sj0));
IkReal x7747=((cj4)*(cj5));
IkReal x7748=((IkReal(1.00000000000000))*(cj6));
IkReal x7749=((IkReal(0.0100000000000000))*(sj5));
IkReal x7750=((sj5)*(sj6));
IkReal x7751=((cj0)*(r10));
IkReal x7752=((cj4)*(cj6));
IkReal x7753=((cj0)*(r01));
IkReal x7754=((IkReal(1.00000000000000))*(cj4));
IkReal x7755=((cj0)*(r00));
IkReal x7756=((IkReal(0.374290000000000))*(sj0));
IkReal x7757=((cj0)*(r12));
IkReal x7758=((IkReal(0.374290000000000))*(sj5));
IkReal x7759=((cj4)*(sj6));
IkReal x7760=((IkReal(1.00000000000000))*(cj0));
IkReal x7761=((r02)*(sj0));
IkReal x7762=((IkReal(0.0100000000000000))*(cj5));
IkReal x7763=((r11)*(sj0));
IkReal x7764=((r00)*(sj0)*(sj6));
IkReal x7765=((r00)*(x7752));
IkReal x7766=((sj6)*(x7762));
evalcond[0]=((IkReal(-3.14159265358979))+(IKfmod(((IkReal(3.14159265358979))+(j2)), IkReal(6.28318530717959))));
evalcond[1]=((((r22)*(x7736)))+(((x7733)*(x7745)))+(((IkReal(-1.00000000000000))*(cj4)*(r20)*(x7748)))+(((cj6)*(r21)*(x7733)))+(((r21)*(x7759))));
evalcond[2]=((IkReal(-0.0690000000000000))+(((IkReal(-0.374290000000000))*(cj5)*(r22)))+(((IkReal(-0.0100000000000000))*(r21)*(x7737)))+(((x7745)*(x7758)))+(pz)+(((IkReal(-1.00000000000000))*(r22)*(x7749)))+(((IkReal(0.374290000000000))*(r21)*(x7742)))+(((IkReal(-1.00000000000000))*(x7745)*(x7762))));
evalcond[3]=((((IkReal(-1.00000000000000))*(x7742)*(x7743)))+(((IkReal(-1.00000000000000))*(sj5)*(x7734)*(x7751)))+(((IkReal(-1.00000000000000))*(x7739)*(x7744)))+(((x7738)*(x7742)))+(((cj0)*(x7741)))+(((r00)*(sj0)*(x7750))));
evalcond[4]=((IkReal(1.00000000000000))+(((x7736)*(x7761)))+(((IkReal(-1.00000000000000))*(x7733)*(x7734)*(x7751)))+(((IkReal(-1.00000000000000))*(x7736)*(x7757)))+(((x7733)*(x7764)))+(((x7751)*(x7752)))+(((cj6)*(x7733)*(x7738)))+(((IkReal(-1.00000000000000))*(x7733)*(x7743)*(x7748)))+(((IkReal(-1.00000000000000))*(cj4)*(x7734)*(x7743)))+(((x7738)*(x7759)))+(((IkReal(-1.00000000000000))*(x7746)*(x7765))));
evalcond[5]=((((IkReal(-1.00000000000000))*(x7734)*(x7747)*(x7751)))+(((IkReal(-1.00000000000000))*(x7737)*(x7743)*(x7754)))+(((IkReal(-1.00000000000000))*(sj4)*(x7734)*(x7738)))+(((cj6)*(r00)*(sj0)*(sj4)))+(((cj4)*(sj5)*(x7761)))+(((r00)*(x7744)*(x7759)))+(((IkReal(-1.00000000000000))*(sj5)*(x7754)*(x7757)))+(((sj4)*(sj6)*(x7743)))+(((IkReal(-1.00000000000000))*(sj4)*(x7748)*(x7751)))+(((cj4)*(x7737)*(x7738))));
evalcond[6]=((((x7735)*(x7752)))+(((x7752)*(x7755)))+(((IkReal(-1.00000000000000))*(cj6)*(r11)*(x7733)*(x7746)))+(((IkReal(-1.00000000000000))*(r12)*(x7736)*(x7746)))+(((IkReal(-1.00000000000000))*(x7733)*(x7734)*(x7755)))+(((IkReal(-1.00000000000000))*(cj4)*(x7734)*(x7753)))+(((IkReal(-1.00000000000000))*(cj4)*(x7734)*(x7763)))+(((IkReal(-1.00000000000000))*(cj0)*(x7736)*(x7739)))+(((IkReal(-1.00000000000000))*(x7733)*(x7734)*(x7735)))+(((IkReal(-1.00000000000000))*(x7733)*(x7748)*(x7753))));
evalcond[7]=((((IkReal(-1.00000000000000))*(r11)*(x7740)*(x7742)))+(((IkReal(-0.374290000000000))*(r02)*(x7744)))+(((x7740)*(x7741)))+(((IkReal(0.0100000000000000))*(x7737)*(x7743)))+(((IkReal(-1.00000000000000))*(py)*(x7760)))+(((IkReal(-1.00000000000000))*(x7749)*(x7761)))+(((IkReal(0.374290000000000))*(x7738)*(x7742)))+(((IkReal(-1.00000000000000))*(r10)*(x7740)*(x7750)))+(((IkReal(-0.0100000000000000))*(r00)*(sj6)*(x7744)))+(((x7751)*(x7766)))+(((px)*(sj0)))+(((r00)*(x7750)*(x7756)))+(((x7749)*(x7757)))+(((IkReal(-0.0100000000000000))*(x7737)*(x7738))));
evalcond[8]=((IkReal(-0.295420000000000))+(((r12)*(sj0)*(x7749)))+(((x7735)*(x7766)))+(((IkReal(0.0100000000000000))*(x7737)*(x7763)))+(((IkReal(-1.00000000000000))*(r11)*(x7742)*(x7756)))+(((x7741)*(x7756)))+(((IkReal(-1.00000000000000))*(r00)*(x7740)*(x7750)))+(((IkReal(-1.00000000000000))*(py)*(x7746)))+(((cj0)*(r02)*(x7749)))+(((IkReal(0.0100000000000000))*(x7737)*(x7753)))+(((IkReal(-0.374290000000000))*(x7735)*(x7750)))+(((IkReal(-1.00000000000000))*(px)*(x7760)))+(((x7755)*(x7766)))+(((cj5)*(r02)*(x7740)))+(((IkReal(-1.00000000000000))*(r01)*(x7740)*(x7742))));
if( IKabs(evalcond[0]) < 0.0000010000000000  && IKabs(evalcond[1]) < 0.0000010000000000  && IKabs(evalcond[2]) < 0.0000010000000000  && IKabs(evalcond[3]) < 0.0000010000000000  && IKabs(evalcond[4]) < 0.0000010000000000  && IKabs(evalcond[5]) < 0.0000010000000000  && IKabs(evalcond[6]) < 0.0000010000000000  && IKabs(evalcond[7]) < 0.0000010000000000  && IKabs(evalcond[8]) < 0.0000010000000000  )
{
{
IkReal j3array[1], cj3array[1], sj3array[1];
bool j3valid[1]={false};
_nj3 = 1;
IkReal x7767=((IkReal(1.00000000000000))*(r21));
IkReal x7768=((cj4)*(cj5));
IkReal x7769=((r20)*(sj6));
if( IKabs(((((IkReal(-1.00000000000000))*(cj6)*(sj5)*(x7767)))+(((IkReal(-1.00000000000000))*(sj5)*(x7769)))+(((cj5)*(r22))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(((((IkReal(-1.00000000000000))*(sj4)*(sj6)*(x7767)))+(((x7768)*(x7769)))+(((cj6)*(r20)*(sj4)))+(((cj4)*(r22)*(sj5)))+(((cj6)*(r21)*(x7768))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(IKsqr(((((IkReal(-1.00000000000000))*(cj6)*(sj5)*(x7767)))+(((IkReal(-1.00000000000000))*(sj5)*(x7769)))+(((cj5)*(r22)))))+IKsqr(((((IkReal(-1.00000000000000))*(sj4)*(sj6)*(x7767)))+(((x7768)*(x7769)))+(((cj6)*(r20)*(sj4)))+(((cj4)*(r22)*(sj5)))+(((cj6)*(r21)*(x7768)))))-1) <= IKFAST_SINCOS_THRESH )
    continue;
j3array[0]=IKatan2(((((IkReal(-1.00000000000000))*(cj6)*(sj5)*(x7767)))+(((IkReal(-1.00000000000000))*(sj5)*(x7769)))+(((cj5)*(r22)))), ((((IkReal(-1.00000000000000))*(sj4)*(sj6)*(x7767)))+(((x7768)*(x7769)))+(((cj6)*(r20)*(sj4)))+(((cj4)*(r22)*(sj5)))+(((cj6)*(r21)*(x7768)))));
sj3array[0]=IKsin(j3array[0]);
cj3array[0]=IKcos(j3array[0]);
if( j3array[0] > IKPI )
{
    j3array[0]-=IK2PI;
}
else if( j3array[0] < -IKPI )
{    j3array[0]+=IK2PI;
}
j3valid[0] = true;
for(int ij3 = 0; ij3 < 1; ++ij3)
{
if( !j3valid[ij3] )
{
    continue;
}
_ij3[0] = ij3; _ij3[1] = -1;
for(int iij3 = ij3+1; iij3 < 1; ++iij3)
{
if( j3valid[iij3] && IKabs(cj3array[ij3]-cj3array[iij3]) < IKFAST_SOLUTION_THRESH && IKabs(sj3array[ij3]-sj3array[iij3]) < IKFAST_SOLUTION_THRESH )
{
    j3valid[iij3]=false; _ij3[1] = iij3; break; 
}
}
j3 = j3array[ij3]; cj3 = cj3array[ij3]; sj3 = sj3array[ij3];
{
IkReal evalcond[4];
IkReal x7770=IKcos(j3);
IkReal x7771=IKsin(j3);
IkReal x7772=((IkReal(1.00000000000000))*(cj4));
IkReal x7773=((sj0)*(sj5));
IkReal x7774=((cj0)*(cj5));
IkReal x7775=((cj6)*(r01));
IkReal x7776=((r00)*(sj6));
IkReal x7777=((cj6)*(r11));
IkReal x7778=((cj5)*(sj0));
IkReal x7779=((cj6)*(sj4));
IkReal x7780=((sj4)*(sj6));
IkReal x7781=((cj4)*(cj5));
IkReal x7782=((cj6)*(r21));
IkReal x7783=((r20)*(sj6));
IkReal x7784=((r10)*(sj6));
IkReal x7785=((IkReal(1.00000000000000))*(cj0)*(sj5));
evalcond[0]=((((IkReal(-1.00000000000000))*(cj5)*(r22)))+(x7771)+(((sj5)*(x7782)))+(((sj5)*(x7783))));
evalcond[1]=((((IkReal(-1.00000000000000))*(r21)*(x7780)))+(((x7781)*(x7782)))+(((cj4)*(r22)*(sj5)))+(((r20)*(x7779)))+(((IkReal(-1.00000000000000))*(x7770)))+(((x7781)*(x7783))));
evalcond[2]=((((IkReal(-1.00000000000000))*(x7773)*(x7777)))+(((IkReal(-1.00000000000000))*(x7773)*(x7784)))+(((IkReal(-1.00000000000000))*(x7776)*(x7785)))+(((IkReal(-1.00000000000000))*(x7775)*(x7785)))+(x7770)+(((r12)*(x7778)))+(((r02)*(x7774))));
evalcond[3]=((((IkReal(-1.00000000000000))*(x7772)*(x7778)*(x7784)))+(((IkReal(-1.00000000000000))*(x7772)*(x7774)*(x7776)))+(((IkReal(-1.00000000000000))*(r10)*(sj0)*(x7779)))+(((IkReal(-1.00000000000000))*(x7772)*(x7774)*(x7775)))+(((r11)*(sj0)*(x7780)))+(x7771)+(((IkReal(-1.00000000000000))*(cj0)*(r00)*(x7779)))+(((cj0)*(r01)*(x7780)))+(((IkReal(-1.00000000000000))*(cj0)*(r02)*(sj5)*(x7772)))+(((IkReal(-1.00000000000000))*(r12)*(x7772)*(x7773)))+(((IkReal(-1.00000000000000))*(x7772)*(x7777)*(x7778))));
if( IKabs(evalcond[0]) > 0.000001  || IKabs(evalcond[1]) > 0.000001  || IKabs(evalcond[2]) > 0.000001  || IKabs(evalcond[3]) > 0.000001  )
{
continue;
}
}

{
std::vector<IkSingleDOFSolutionBase<IkReal> > vinfos(7);
vinfos[0].jointtype = 1;
vinfos[0].foffset = j0;
vinfos[0].indices[0] = _ij0[0];
vinfos[0].indices[1] = _ij0[1];
vinfos[0].maxsolutions = _nj0;
vinfos[1].jointtype = 1;
vinfos[1].foffset = j1;
vinfos[1].indices[0] = _ij1[0];
vinfos[1].indices[1] = _ij1[1];
vinfos[1].maxsolutions = _nj1;
vinfos[2].jointtype = 1;
vinfos[2].foffset = j2;
vinfos[2].indices[0] = _ij2[0];
vinfos[2].indices[1] = _ij2[1];
vinfos[2].maxsolutions = _nj2;
vinfos[3].jointtype = 1;
vinfos[3].foffset = j3;
vinfos[3].indices[0] = _ij3[0];
vinfos[3].indices[1] = _ij3[1];
vinfos[3].maxsolutions = _nj3;
vinfos[4].jointtype = 1;
vinfos[4].foffset = j4;
vinfos[4].indices[0] = _ij4[0];
vinfos[4].indices[1] = _ij4[1];
vinfos[4].maxsolutions = _nj4;
vinfos[5].jointtype = 1;
vinfos[5].foffset = j5;
vinfos[5].indices[0] = _ij5[0];
vinfos[5].indices[1] = _ij5[1];
vinfos[5].maxsolutions = _nj5;
vinfos[6].jointtype = 1;
vinfos[6].foffset = j6;
vinfos[6].indices[0] = _ij6[0];
vinfos[6].indices[1] = _ij6[1];
vinfos[6].maxsolutions = _nj6;
std::vector<int> vfree(0);
solutions.AddSolution(vinfos,vfree);
}
}
}

} else
{
IkReal x7786=((cj5)*(sj4));
IkReal x7787=((IkReal(1.00000000000000))*(sj6));
IkReal x7788=((r10)*(sj0));
IkReal x7789=((sj4)*(sj5));
IkReal x7790=((cj5)*(cj6));
IkReal x7791=((r01)*(sj0));
IkReal x7792=((IkReal(1.00000000000000))*(r02));
IkReal x7793=((IkReal(0.374290000000000))*(cj0));
IkReal x7794=((cj5)*(r12));
IkReal x7795=((cj6)*(sj5));
IkReal x7796=((cj0)*(r11));
IkReal x7797=((cj5)*(sj0));
IkReal x7798=((r20)*(sj6));
IkReal x7799=((IkReal(1.00000000000000))*(sj0));
IkReal x7800=((cj4)*(cj5));
IkReal x7801=((IkReal(1.00000000000000))*(cj6));
IkReal x7802=((IkReal(0.0100000000000000))*(sj5));
IkReal x7803=((sj5)*(sj6));
IkReal x7804=((cj0)*(r10));
IkReal x7805=((cj4)*(cj6));
IkReal x7806=((cj0)*(r01));
IkReal x7807=((IkReal(1.00000000000000))*(cj4));
IkReal x7808=((cj0)*(r00));
IkReal x7809=((IkReal(0.374290000000000))*(sj0));
IkReal x7810=((cj0)*(r12));
IkReal x7811=((IkReal(0.374290000000000))*(sj5));
IkReal x7812=((cj4)*(sj6));
IkReal x7813=((IkReal(1.00000000000000))*(cj0));
IkReal x7814=((r02)*(sj0));
IkReal x7815=((IkReal(0.0100000000000000))*(cj5));
IkReal x7816=((r11)*(sj0));
IkReal x7817=((r00)*(sj0)*(sj6));
IkReal x7818=((r00)*(x7805));
IkReal x7819=((sj6)*(x7815));
evalcond[0]=((IkReal(-3.14159265358979))+(IKfmod(j2, IkReal(6.28318530717959))));
evalcond[1]=((((r21)*(x7812)))+(((x7786)*(x7798)))+(((cj6)*(r21)*(x7786)))+(((IkReal(-1.00000000000000))*(cj4)*(r20)*(x7801)))+(((r22)*(x7789))));
evalcond[2]=((IkReal(0.0690000000000000))+(((IkReal(-1.00000000000000))*(r22)*(x7802)))+(((IkReal(0.374290000000000))*(r21)*(x7795)))+(((IkReal(-0.374290000000000))*(cj5)*(r22)))+(((x7798)*(x7811)))+(pz)+(((IkReal(-0.0100000000000000))*(r21)*(x7790)))+(((IkReal(-1.00000000000000))*(x7798)*(x7815))));
evalcond[3]=((((r00)*(sj0)*(x7803)))+(((x7791)*(x7795)))+(((cj0)*(x7794)))+(((IkReal(-1.00000000000000))*(x7792)*(x7797)))+(((IkReal(-1.00000000000000))*(x7795)*(x7796)))+(((IkReal(-1.00000000000000))*(sj5)*(x7787)*(x7804))));
evalcond[4]=((IkReal(-1.00000000000000))+(((IkReal(-1.00000000000000))*(x7789)*(x7810)))+(((x7786)*(x7817)))+(((cj6)*(x7786)*(x7791)))+(((IkReal(-1.00000000000000))*(x7786)*(x7787)*(x7804)))+(((x7789)*(x7814)))+(((x7791)*(x7812)))+(((IkReal(-1.00000000000000))*(x7799)*(x7818)))+(((IkReal(-1.00000000000000))*(x7786)*(x7796)*(x7801)))+(((x7804)*(x7805)))+(((IkReal(-1.00000000000000))*(cj4)*(x7787)*(x7796))));
evalcond[5]=((((IkReal(-1.00000000000000))*(x7790)*(x7796)*(x7807)))+(((r00)*(x7797)*(x7812)))+(((sj4)*(sj6)*(x7796)))+(((cj6)*(r00)*(sj0)*(sj4)))+(((IkReal(-1.00000000000000))*(x7787)*(x7800)*(x7804)))+(((IkReal(-1.00000000000000))*(sj5)*(x7807)*(x7810)))+(((IkReal(-1.00000000000000))*(sj4)*(x7787)*(x7791)))+(((cj4)*(x7790)*(x7791)))+(((IkReal(-1.00000000000000))*(sj4)*(x7801)*(x7804)))+(((cj4)*(sj5)*(x7814))));
evalcond[6]=((((IkReal(-1.00000000000000))*(cj4)*(x7787)*(x7806)))+(((IkReal(-1.00000000000000))*(cj4)*(x7787)*(x7816)))+(((x7805)*(x7808)))+(((IkReal(-1.00000000000000))*(cj6)*(r11)*(x7786)*(x7799)))+(((IkReal(-1.00000000000000))*(x7786)*(x7787)*(x7788)))+(((x7788)*(x7805)))+(((IkReal(-1.00000000000000))*(cj0)*(x7789)*(x7792)))+(((IkReal(-1.00000000000000))*(x7786)*(x7787)*(x7808)))+(((IkReal(-1.00000000000000))*(x7786)*(x7801)*(x7806)))+(((IkReal(-1.00000000000000))*(r12)*(x7789)*(x7799))));
evalcond[7]=((((r00)*(x7803)*(x7809)))+(((IkReal(-0.0100000000000000))*(x7790)*(x7791)))+(((IkReal(-1.00000000000000))*(x7802)*(x7814)))+(((x7793)*(x7794)))+(((IkReal(-1.00000000000000))*(py)*(x7813)))+(((x7804)*(x7819)))+(((IkReal(-0.374290000000000))*(r02)*(x7797)))+(((IkReal(-0.0100000000000000))*(r00)*(sj6)*(x7797)))+(((IkReal(0.0100000000000000))*(x7790)*(x7796)))+(((IkReal(0.374290000000000))*(x7791)*(x7795)))+(((IkReal(-1.00000000000000))*(r10)*(x7793)*(x7803)))+(((x7802)*(x7810)))+(((px)*(sj0)))+(((IkReal(-1.00000000000000))*(r11)*(x7793)*(x7795))));
evalcond[8]=((IkReal(-0.295420000000000))+(((IkReal(-1.00000000000000))*(py)*(x7799)))+(((cj5)*(r02)*(x7793)))+(((cj0)*(r02)*(x7802)))+(((r12)*(sj0)*(x7802)))+(((x7788)*(x7819)))+(((x7794)*(x7809)))+(((IkReal(-1.00000000000000))*(r11)*(x7795)*(x7809)))+(((IkReal(-0.374290000000000))*(x7788)*(x7803)))+(((x7808)*(x7819)))+(((IkReal(-1.00000000000000))*(px)*(x7813)))+(((IkReal(-1.00000000000000))*(r01)*(x7793)*(x7795)))+(((IkReal(0.0100000000000000))*(x7790)*(x7806)))+(((IkReal(0.0100000000000000))*(x7790)*(x7816)))+(((IkReal(-1.00000000000000))*(r00)*(x7793)*(x7803))));
if( IKabs(evalcond[0]) < 0.0000010000000000  && IKabs(evalcond[1]) < 0.0000010000000000  && IKabs(evalcond[2]) < 0.0000010000000000  && IKabs(evalcond[3]) < 0.0000010000000000  && IKabs(evalcond[4]) < 0.0000010000000000  && IKabs(evalcond[5]) < 0.0000010000000000  && IKabs(evalcond[6]) < 0.0000010000000000  && IKabs(evalcond[7]) < 0.0000010000000000  && IKabs(evalcond[8]) < 0.0000010000000000  )
{
{
IkReal j3array[1], cj3array[1], sj3array[1];
bool j3valid[1]={false};
_nj3 = 1;
IkReal x7820=((IkReal(1.00000000000000))*(cj4));
IkReal x7821=((cj6)*(r21));
IkReal x7822=((r20)*(sj6));
if( IKabs(((((sj5)*(x7821)))+(((sj5)*(x7822)))+(((IkReal(-1.00000000000000))*(cj5)*(r22))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(((((IkReal(-1.00000000000000))*(cj5)*(x7820)*(x7822)))+(((r21)*(sj4)*(sj6)))+(((IkReal(-1.00000000000000))*(r22)*(sj5)*(x7820)))+(((IkReal(-1.00000000000000))*(cj5)*(x7820)*(x7821)))+(((IkReal(-1.00000000000000))*(cj6)*(r20)*(sj4))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(IKsqr(((((sj5)*(x7821)))+(((sj5)*(x7822)))+(((IkReal(-1.00000000000000))*(cj5)*(r22)))))+IKsqr(((((IkReal(-1.00000000000000))*(cj5)*(x7820)*(x7822)))+(((r21)*(sj4)*(sj6)))+(((IkReal(-1.00000000000000))*(r22)*(sj5)*(x7820)))+(((IkReal(-1.00000000000000))*(cj5)*(x7820)*(x7821)))+(((IkReal(-1.00000000000000))*(cj6)*(r20)*(sj4)))))-1) <= IKFAST_SINCOS_THRESH )
    continue;
j3array[0]=IKatan2(((((sj5)*(x7821)))+(((sj5)*(x7822)))+(((IkReal(-1.00000000000000))*(cj5)*(r22)))), ((((IkReal(-1.00000000000000))*(cj5)*(x7820)*(x7822)))+(((r21)*(sj4)*(sj6)))+(((IkReal(-1.00000000000000))*(r22)*(sj5)*(x7820)))+(((IkReal(-1.00000000000000))*(cj5)*(x7820)*(x7821)))+(((IkReal(-1.00000000000000))*(cj6)*(r20)*(sj4)))));
sj3array[0]=IKsin(j3array[0]);
cj3array[0]=IKcos(j3array[0]);
if( j3array[0] > IKPI )
{
    j3array[0]-=IK2PI;
}
else if( j3array[0] < -IKPI )
{    j3array[0]+=IK2PI;
}
j3valid[0] = true;
for(int ij3 = 0; ij3 < 1; ++ij3)
{
if( !j3valid[ij3] )
{
    continue;
}
_ij3[0] = ij3; _ij3[1] = -1;
for(int iij3 = ij3+1; iij3 < 1; ++iij3)
{
if( j3valid[iij3] && IKabs(cj3array[ij3]-cj3array[iij3]) < IKFAST_SOLUTION_THRESH && IKabs(sj3array[ij3]-sj3array[iij3]) < IKFAST_SOLUTION_THRESH )
{
    j3valid[iij3]=false; _ij3[1] = iij3; break; 
}
}
j3 = j3array[ij3]; cj3 = cj3array[ij3]; sj3 = sj3array[ij3];
{
IkReal evalcond[4];
IkReal x7823=IKcos(j3);
IkReal x7824=IKsin(j3);
IkReal x7825=((IkReal(1.00000000000000))*(cj4));
IkReal x7826=((sj0)*(sj5));
IkReal x7827=((cj0)*(cj5));
IkReal x7828=((cj6)*(r01));
IkReal x7829=((r00)*(sj6));
IkReal x7830=((cj6)*(r11));
IkReal x7831=((cj5)*(sj0));
IkReal x7832=((cj6)*(sj4));
IkReal x7833=((sj4)*(sj6));
IkReal x7834=((cj4)*(cj5));
IkReal x7835=((cj6)*(r21));
IkReal x7836=((r20)*(sj6));
IkReal x7837=((r10)*(sj6));
IkReal x7838=((IkReal(1.00000000000000))*(cj0)*(sj5));
evalcond[0]=((((sj5)*(x7836)))+(((sj5)*(x7835)))+(((IkReal(-1.00000000000000))*(cj5)*(r22)))+(((IkReal(-1.00000000000000))*(x7824))));
evalcond[1]=((x7823)+(((cj4)*(r22)*(sj5)))+(((IkReal(-1.00000000000000))*(r21)*(x7833)))+(((x7834)*(x7836)))+(((x7834)*(x7835)))+(((r20)*(x7832))));
evalcond[2]=((((IkReal(-1.00000000000000))*(x7829)*(x7838)))+(((IkReal(-1.00000000000000))*(x7828)*(x7838)))+(((IkReal(-1.00000000000000))*(x7826)*(x7830)))+(x7823)+(((IkReal(-1.00000000000000))*(x7826)*(x7837)))+(((r12)*(x7831)))+(((r02)*(x7827))));
evalcond[3]=((((IkReal(-1.00000000000000))*(cj0)*(r00)*(x7832)))+(((IkReal(-1.00000000000000))*(r12)*(x7825)*(x7826)))+(x7824)+(((r11)*(sj0)*(x7833)))+(((IkReal(-1.00000000000000))*(x7825)*(x7827)*(x7829)))+(((IkReal(-1.00000000000000))*(cj0)*(r02)*(sj5)*(x7825)))+(((IkReal(-1.00000000000000))*(x7825)*(x7831)*(x7837)))+(((IkReal(-1.00000000000000))*(x7825)*(x7827)*(x7828)))+(((cj0)*(r01)*(x7833)))+(((IkReal(-1.00000000000000))*(x7825)*(x7830)*(x7831)))+(((IkReal(-1.00000000000000))*(r10)*(sj0)*(x7832))));
if( IKabs(evalcond[0]) > 0.000001  || IKabs(evalcond[1]) > 0.000001  || IKabs(evalcond[2]) > 0.000001  || IKabs(evalcond[3]) > 0.000001  )
{
continue;
}
}

{
std::vector<IkSingleDOFSolutionBase<IkReal> > vinfos(7);
vinfos[0].jointtype = 1;
vinfos[0].foffset = j0;
vinfos[0].indices[0] = _ij0[0];
vinfos[0].indices[1] = _ij0[1];
vinfos[0].maxsolutions = _nj0;
vinfos[1].jointtype = 1;
vinfos[1].foffset = j1;
vinfos[1].indices[0] = _ij1[0];
vinfos[1].indices[1] = _ij1[1];
vinfos[1].maxsolutions = _nj1;
vinfos[2].jointtype = 1;
vinfos[2].foffset = j2;
vinfos[2].indices[0] = _ij2[0];
vinfos[2].indices[1] = _ij2[1];
vinfos[2].maxsolutions = _nj2;
vinfos[3].jointtype = 1;
vinfos[3].foffset = j3;
vinfos[3].indices[0] = _ij3[0];
vinfos[3].indices[1] = _ij3[1];
vinfos[3].maxsolutions = _nj3;
vinfos[4].jointtype = 1;
vinfos[4].foffset = j4;
vinfos[4].indices[0] = _ij4[0];
vinfos[4].indices[1] = _ij4[1];
vinfos[4].maxsolutions = _nj4;
vinfos[5].jointtype = 1;
vinfos[5].foffset = j5;
vinfos[5].indices[0] = _ij5[0];
vinfos[5].indices[1] = _ij5[1];
vinfos[5].maxsolutions = _nj5;
vinfos[6].jointtype = 1;
vinfos[6].foffset = j6;
vinfos[6].indices[0] = _ij6[0];
vinfos[6].indices[1] = _ij6[1];
vinfos[6].maxsolutions = _nj6;
std::vector<int> vfree(0);
solutions.AddSolution(vinfos,vfree);
}
}
}

} else
{
IkReal x7839=((IkReal(1.00000000000000))*(cj0));
IkReal x7840=((cj4)*(sj6));
IkReal x7841=((sj0)*(sj4));
IkReal x7842=((cj5)*(sj6));
IkReal x7843=((sj4)*(sj5));
IkReal x7844=((r12)*(sj5));
IkReal x7845=((IkReal(0.374290000000000))*(cj5));
IkReal x7846=((r02)*(sj0));
IkReal x7847=((r20)*(sj4));
IkReal x7848=((IkReal(1.00000000000000))*(sj0));
IkReal x7849=((IkReal(1.00000000000000))*(cj5));
IkReal x7850=((cj0)*(r10));
IkReal x7851=((cj4)*(cj6));
IkReal x7852=((r00)*(sj0));
IkReal x7853=((cj6)*(r21));
IkReal x7854=((IkReal(0.374290000000000))*(sj5));
IkReal x7855=((cj0)*(r00));
IkReal x7856=((IkReal(0.0100000000000000))*(sj5));
IkReal x7857=((cj0)*(r02));
IkReal x7858=((cj5)*(sj4));
IkReal x7859=((cj6)*(r01));
IkReal x7860=((cj6)*(r11));
IkReal x7861=((r01)*(sj0));
IkReal x7862=((r10)*(sj0));
IkReal x7863=((IkReal(0.0100000000000000))*(cj5)*(cj6));
IkReal x7864=((sj6)*(x7854));
IkReal x7865=((cj0)*(cj6)*(x7854));
evalcond[0]=((IkReal(-3.14159265358979))+(IKfmod(((IkReal(1.57079632679490))+(j2)), IkReal(6.28318530717959))));
evalcond[1]=((((IkReal(-1.00000000000000))*(r22)*(x7849)))+(((sj5)*(x7853)))+(((r20)*(sj5)*(sj6))));
evalcond[2]=((IkReal(1.00000000000000))+(((IkReal(-1.00000000000000))*(r20)*(x7851)))+(((x7842)*(x7847)))+(((r22)*(x7843)))+(((r21)*(x7840)))+(((x7853)*(x7858))));
evalcond[3]=((((IkReal(-1.00000000000000))*(r22)*(x7845)))+(((IkReal(-0.0100000000000000))*(cj5)*(x7853)))+(((IkReal(-0.0100000000000000))*(r20)*(x7842)))+(((r20)*(x7864)))+(((x7853)*(x7854)))+(pz)+(((IkReal(-1.00000000000000))*(r22)*(x7856))));
evalcond[4]=((((IkReal(-1.00000000000000))*(r21)*(sj4)*(sj6)))+(((cj6)*(x7847)))+(((cj4)*(r22)*(sj5)))+(((cj5)*(r20)*(x7840)))+(((cj5)*(r21)*(x7851))));
evalcond[5]=((((r02)*(sj5)*(x7841)))+(((IkReal(-1.00000000000000))*(r00)*(x7848)*(x7851)))+(((IkReal(-1.00000000000000))*(r11)*(x7839)*(x7840)))+(((IkReal(-1.00000000000000))*(r12)*(x7839)*(x7843)))+(((IkReal(-1.00000000000000))*(r10)*(sj4)*(x7839)*(x7842)))+(((IkReal(-1.00000000000000))*(x7839)*(x7858)*(x7860)))+(((cj5)*(x7841)*(x7859)))+(((r00)*(x7841)*(x7842)))+(((x7840)*(x7861)))+(((x7850)*(x7851))));
evalcond[6]=((((x7851)*(x7862)))+(((IkReal(-1.00000000000000))*(x7841)*(x7849)*(x7860)))+(((IkReal(-1.00000000000000))*(x7841)*(x7844)))+(((IkReal(-1.00000000000000))*(r10)*(x7841)*(x7842)))+(((IkReal(-1.00000000000000))*(r00)*(sj4)*(x7839)*(x7842)))+(((IkReal(-1.00000000000000))*(r02)*(x7839)*(x7843)))+(((IkReal(-1.00000000000000))*(r11)*(x7840)*(x7848)))+(((IkReal(-1.00000000000000))*(x7839)*(x7858)*(x7859)))+(((x7851)*(x7855)))+(((IkReal(-1.00000000000000))*(r01)*(x7839)*(x7840))));
evalcond[7]=((IkReal(0.0690000000000000))+(((IkReal(0.0100000000000000))*(x7842)*(x7850)))+(((x7852)*(x7864)))+(((IkReal(-1.00000000000000))*(py)*(x7839)))+(((IkReal(0.0100000000000000))*(cj0)*(x7844)))+(((IkReal(-1.00000000000000))*(x7850)*(x7864)))+(((sj0)*(x7854)*(x7859)))+(((cj0)*(r12)*(x7845)))+(((IkReal(-0.0100000000000000))*(x7842)*(x7852)))+(((IkReal(0.0100000000000000))*(cj0)*(cj5)*(x7860)))+(((IkReal(-1.00000000000000))*(x7845)*(x7846)))+(((IkReal(-1.00000000000000))*(cj0)*(x7854)*(x7860)))+(((px)*(sj0)))+(((IkReal(-1.00000000000000))*(x7846)*(x7856)))+(((IkReal(-0.0100000000000000))*(cj5)*(sj0)*(x7859))));
evalcond[8]=((IkReal(-0.295420000000000))+(((IkReal(-1.00000000000000))*(sj0)*(x7854)*(x7860)))+(((IkReal(0.0100000000000000))*(sj0)*(x7844)))+(((IkReal(-1.00000000000000))*(x7862)*(x7864)))+(((x7845)*(x7857)))+(((IkReal(-1.00000000000000))*(px)*(x7839)))+(((IkReal(-1.00000000000000))*(py)*(x7848)))+(((IkReal(-1.00000000000000))*(cj0)*(x7854)*(x7859)))+(((r12)*(sj0)*(x7845)))+(((x7856)*(x7857)))+(((IkReal(-1.00000000000000))*(x7855)*(x7864)))+(((IkReal(0.0100000000000000))*(x7842)*(x7862)))+(((IkReal(0.0100000000000000))*(cj5)*(sj0)*(x7860)))+(((IkReal(0.0100000000000000))*(cj0)*(cj5)*(x7859)))+(((IkReal(0.0100000000000000))*(x7842)*(x7855))));
if( IKabs(evalcond[0]) < 0.0000010000000000  && IKabs(evalcond[1]) < 0.0000010000000000  && IKabs(evalcond[2]) < 0.0000010000000000  && IKabs(evalcond[3]) < 0.0000010000000000  && IKabs(evalcond[4]) < 0.0000010000000000  && IKabs(evalcond[5]) < 0.0000010000000000  && IKabs(evalcond[6]) < 0.0000010000000000  && IKabs(evalcond[7]) < 0.0000010000000000  && IKabs(evalcond[8]) < 0.0000010000000000  )
{
{
IkReal j3array[1], cj3array[1], sj3array[1];
bool j3valid[1]={false};
_nj3 = 1;
IkReal x7866=((sj0)*(sj5));
IkReal x7867=((r00)*(sj6));
IkReal x7868=((IkReal(1.00000000000000))*(cj5));
IkReal x7869=((cj6)*(r11));
IkReal x7870=((cj6)*(r01));
IkReal x7871=((r10)*(sj6));
IkReal x7872=((cj0)*(sj5));
if( IKabs(((((IkReal(-1.00000000000000))*(r02)*(sj0)*(x7868)))+(((x7866)*(x7867)))+(((x7866)*(x7870)))+(((cj0)*(cj5)*(r12)))+(((IkReal(-1.00000000000000))*(x7869)*(x7872)))+(((IkReal(-1.00000000000000))*(x7871)*(x7872))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(((((x7867)*(x7872)))+(((IkReal(-1.00000000000000))*(cj0)*(r02)*(x7868)))+(((x7866)*(x7871)))+(((x7866)*(x7869)))+(((x7870)*(x7872)))+(((IkReal(-1.00000000000000))*(r12)*(sj0)*(x7868))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(IKsqr(((((IkReal(-1.00000000000000))*(r02)*(sj0)*(x7868)))+(((x7866)*(x7867)))+(((x7866)*(x7870)))+(((cj0)*(cj5)*(r12)))+(((IkReal(-1.00000000000000))*(x7869)*(x7872)))+(((IkReal(-1.00000000000000))*(x7871)*(x7872)))))+IKsqr(((((x7867)*(x7872)))+(((IkReal(-1.00000000000000))*(cj0)*(r02)*(x7868)))+(((x7866)*(x7871)))+(((x7866)*(x7869)))+(((x7870)*(x7872)))+(((IkReal(-1.00000000000000))*(r12)*(sj0)*(x7868)))))-1) <= IKFAST_SINCOS_THRESH )
    continue;
j3array[0]=IKatan2(((((IkReal(-1.00000000000000))*(r02)*(sj0)*(x7868)))+(((x7866)*(x7867)))+(((x7866)*(x7870)))+(((cj0)*(cj5)*(r12)))+(((IkReal(-1.00000000000000))*(x7869)*(x7872)))+(((IkReal(-1.00000000000000))*(x7871)*(x7872)))), ((((x7867)*(x7872)))+(((IkReal(-1.00000000000000))*(cj0)*(r02)*(x7868)))+(((x7866)*(x7871)))+(((x7866)*(x7869)))+(((x7870)*(x7872)))+(((IkReal(-1.00000000000000))*(r12)*(sj0)*(x7868)))));
sj3array[0]=IKsin(j3array[0]);
cj3array[0]=IKcos(j3array[0]);
if( j3array[0] > IKPI )
{
    j3array[0]-=IK2PI;
}
else if( j3array[0] < -IKPI )
{    j3array[0]+=IK2PI;
}
j3valid[0] = true;
for(int ij3 = 0; ij3 < 1; ++ij3)
{
if( !j3valid[ij3] )
{
    continue;
}
_ij3[0] = ij3; _ij3[1] = -1;
for(int iij3 = ij3+1; iij3 < 1; ++iij3)
{
if( j3valid[iij3] && IKabs(cj3array[ij3]-cj3array[iij3]) < IKFAST_SOLUTION_THRESH && IKabs(sj3array[ij3]-sj3array[iij3]) < IKFAST_SOLUTION_THRESH )
{
    j3valid[iij3]=false; _ij3[1] = iij3; break; 
}
}
j3 = j3array[ij3]; cj3 = cj3array[ij3]; sj3 = sj3array[ij3];
{
IkReal evalcond[4];
IkReal x7873=IKcos(j3);
IkReal x7874=IKsin(j3);
IkReal x7875=((sj0)*(sj5));
IkReal x7876=((r00)*(sj6));
IkReal x7877=((cj6)*(sj0));
IkReal x7878=((IkReal(1.00000000000000))*(cj4));
IkReal x7879=((r00)*(sj4));
IkReal x7880=((cj0)*(cj5));
IkReal x7881=((cj5)*(sj0));
IkReal x7882=((cj6)*(r11));
IkReal x7883=((r10)*(sj6));
IkReal x7884=((cj0)*(sj5));
IkReal x7885=((r10)*(sj4));
IkReal x7886=((cj4)*(cj5)*(r01));
IkReal x7887=((IkReal(1.00000000000000))*(cj0)*(cj6));
IkReal x7888=((cj0)*(sj4)*(sj6));
IkReal x7889=((sj0)*(sj4)*(sj6));
evalcond[0]=((((x7875)*(x7876)))+(((r12)*(x7880)))+(((cj6)*(r01)*(x7875)))+(((IkReal(-1.00000000000000))*(r02)*(x7881)))+(((IkReal(-1.00000000000000))*(x7883)*(x7884)))+(((IkReal(-1.00000000000000))*(x7874)))+(((IkReal(-1.00000000000000))*(x7882)*(x7884))));
evalcond[1]=((((IkReal(-1.00000000000000))*(x7875)*(x7883)))+(((IkReal(-1.00000000000000))*(x7876)*(x7884)))+(((r02)*(x7880)))+(((r12)*(x7881)))+(((IkReal(-1.00000000000000))*(x7875)*(x7882)))+(x7873)+(((IkReal(-1.00000000000000))*(cj6)*(r01)*(x7884))));
evalcond[2]=((((cj4)*(r02)*(x7875)))+(((IkReal(-1.00000000000000))*(x7885)*(x7887)))+(((r11)*(x7888)))+(((IkReal(-1.00000000000000))*(r01)*(x7889)))+(((IkReal(-1.00000000000000))*(r12)*(x7878)*(x7884)))+(((IkReal(-1.00000000000000))*(x7878)*(x7880)*(x7883)))+(x7873)+(((cj4)*(x7876)*(x7881)))+(((IkReal(-1.00000000000000))*(x7878)*(x7880)*(x7882)))+(((x7877)*(x7879)))+(((x7877)*(x7886))));
evalcond[3]=((((IkReal(-1.00000000000000))*(x7877)*(x7885)))+(((r11)*(x7889)))+(((IkReal(-1.00000000000000))*(x7879)*(x7887)))+(((IkReal(-1.00000000000000))*(r12)*(x7875)*(x7878)))+(((IkReal(-1.00000000000000))*(cj6)*(r01)*(x7878)*(x7880)))+(x7874)+(((IkReal(-1.00000000000000))*(r02)*(x7878)*(x7884)))+(((IkReal(-1.00000000000000))*(cj5)*(r11)*(x7877)*(x7878)))+(((IkReal(-1.00000000000000))*(x7878)*(x7881)*(x7883)))+(((IkReal(-1.00000000000000))*(x7876)*(x7878)*(x7880)))+(((r01)*(x7888))));
if( IKabs(evalcond[0]) > 0.000001  || IKabs(evalcond[1]) > 0.000001  || IKabs(evalcond[2]) > 0.000001  || IKabs(evalcond[3]) > 0.000001  )
{
continue;
}
}

{
std::vector<IkSingleDOFSolutionBase<IkReal> > vinfos(7);
vinfos[0].jointtype = 1;
vinfos[0].foffset = j0;
vinfos[0].indices[0] = _ij0[0];
vinfos[0].indices[1] = _ij0[1];
vinfos[0].maxsolutions = _nj0;
vinfos[1].jointtype = 1;
vinfos[1].foffset = j1;
vinfos[1].indices[0] = _ij1[0];
vinfos[1].indices[1] = _ij1[1];
vinfos[1].maxsolutions = _nj1;
vinfos[2].jointtype = 1;
vinfos[2].foffset = j2;
vinfos[2].indices[0] = _ij2[0];
vinfos[2].indices[1] = _ij2[1];
vinfos[2].maxsolutions = _nj2;
vinfos[3].jointtype = 1;
vinfos[3].foffset = j3;
vinfos[3].indices[0] = _ij3[0];
vinfos[3].indices[1] = _ij3[1];
vinfos[3].maxsolutions = _nj3;
vinfos[4].jointtype = 1;
vinfos[4].foffset = j4;
vinfos[4].indices[0] = _ij4[0];
vinfos[4].indices[1] = _ij4[1];
vinfos[4].maxsolutions = _nj4;
vinfos[5].jointtype = 1;
vinfos[5].foffset = j5;
vinfos[5].indices[0] = _ij5[0];
vinfos[5].indices[1] = _ij5[1];
vinfos[5].maxsolutions = _nj5;
vinfos[6].jointtype = 1;
vinfos[6].foffset = j6;
vinfos[6].indices[0] = _ij6[0];
vinfos[6].indices[1] = _ij6[1];
vinfos[6].maxsolutions = _nj6;
std::vector<int> vfree(0);
solutions.AddSolution(vinfos,vfree);
}
}
}

} else
{
IkReal x7890=((IkReal(1.00000000000000))*(cj0));
IkReal x7891=((cj4)*(sj6));
IkReal x7892=((sj0)*(sj4));
IkReal x7893=((cj5)*(sj6));
IkReal x7894=((sj4)*(sj5));
IkReal x7895=((r12)*(sj5));
IkReal x7896=((IkReal(0.374290000000000))*(cj5));
IkReal x7897=((r02)*(sj0));
IkReal x7898=((r20)*(sj4));
IkReal x7899=((IkReal(1.00000000000000))*(sj0));
IkReal x7900=((IkReal(1.00000000000000))*(cj5));
IkReal x7901=((cj0)*(r10));
IkReal x7902=((cj4)*(cj6));
IkReal x7903=((r00)*(sj0));
IkReal x7904=((cj6)*(r21));
IkReal x7905=((IkReal(0.374290000000000))*(sj5));
IkReal x7906=((cj0)*(r00));
IkReal x7907=((IkReal(0.0100000000000000))*(sj5));
IkReal x7908=((cj0)*(r02));
IkReal x7909=((cj5)*(sj4));
IkReal x7910=((cj6)*(r01));
IkReal x7911=((cj6)*(r11));
IkReal x7912=((r01)*(sj0));
IkReal x7913=((r10)*(sj0));
IkReal x7914=((IkReal(0.0100000000000000))*(cj5)*(cj6));
IkReal x7915=((sj6)*(x7905));
IkReal x7916=((cj0)*(cj6)*(x7905));
evalcond[0]=((IkReal(-3.14159265358979))+(IKfmod(((IkReal(4.71238898038469))+(j2)), IkReal(6.28318530717959))));
evalcond[1]=((((sj5)*(x7904)))+(((IkReal(-1.00000000000000))*(r22)*(x7900)))+(((r20)*(sj5)*(sj6))));
evalcond[2]=((IkReal(-1.00000000000000))+(((r21)*(x7891)))+(((x7904)*(x7909)))+(((x7893)*(x7898)))+(((r22)*(x7894)))+(((IkReal(-1.00000000000000))*(r20)*(x7902))));
evalcond[3]=((((x7904)*(x7905)))+(((IkReal(-0.0100000000000000))*(cj5)*(x7904)))+(((IkReal(-1.00000000000000))*(r22)*(x7896)))+(pz)+(((IkReal(-0.0100000000000000))*(r20)*(x7893)))+(((r20)*(x7915)))+(((IkReal(-1.00000000000000))*(r22)*(x7907))));
evalcond[4]=((((cj5)*(r20)*(x7891)))+(((IkReal(-1.00000000000000))*(r21)*(sj4)*(sj6)))+(((cj4)*(r22)*(sj5)))+(((cj5)*(r21)*(x7902)))+(((cj6)*(x7898))));
evalcond[5]=((((IkReal(-1.00000000000000))*(r12)*(x7890)*(x7894)))+(((cj5)*(x7892)*(x7910)))+(((r02)*(sj5)*(x7892)))+(((IkReal(-1.00000000000000))*(r00)*(x7899)*(x7902)))+(((IkReal(-1.00000000000000))*(r11)*(x7890)*(x7891)))+(((x7901)*(x7902)))+(((r00)*(x7892)*(x7893)))+(((IkReal(-1.00000000000000))*(x7890)*(x7909)*(x7911)))+(((x7891)*(x7912)))+(((IkReal(-1.00000000000000))*(r10)*(sj4)*(x7890)*(x7893))));
evalcond[6]=((((IkReal(-1.00000000000000))*(r01)*(x7890)*(x7891)))+(((IkReal(-1.00000000000000))*(x7892)*(x7900)*(x7911)))+(((IkReal(-1.00000000000000))*(r10)*(x7892)*(x7893)))+(((IkReal(-1.00000000000000))*(r11)*(x7891)*(x7899)))+(((IkReal(-1.00000000000000))*(r00)*(sj4)*(x7890)*(x7893)))+(((IkReal(-1.00000000000000))*(x7890)*(x7909)*(x7910)))+(((IkReal(-1.00000000000000))*(r02)*(x7890)*(x7894)))+(((x7902)*(x7906)))+(((x7902)*(x7913)))+(((IkReal(-1.00000000000000))*(x7892)*(x7895))));
evalcond[7]=((IkReal(-0.0690000000000000))+(((IkReal(-0.0100000000000000))*(x7893)*(x7903)))+(((IkReal(-1.00000000000000))*(x7897)*(x7907)))+(((IkReal(-1.00000000000000))*(x7896)*(x7897)))+(((cj0)*(r12)*(x7896)))+(((IkReal(-0.0100000000000000))*(cj5)*(sj0)*(x7910)))+(((IkReal(0.0100000000000000))*(x7893)*(x7901)))+(((IkReal(-1.00000000000000))*(py)*(x7890)))+(((IkReal(-1.00000000000000))*(x7901)*(x7915)))+(((IkReal(-1.00000000000000))*(cj0)*(x7905)*(x7911)))+(((sj0)*(x7905)*(x7910)))+(((IkReal(0.0100000000000000))*(cj0)*(cj5)*(x7911)))+(((px)*(sj0)))+(((IkReal(0.0100000000000000))*(cj0)*(x7895)))+(((x7903)*(x7915))));
evalcond[8]=((IkReal(-0.295420000000000))+(((IkReal(-1.00000000000000))*(sj0)*(x7905)*(x7911)))+(((IkReal(-1.00000000000000))*(py)*(x7899)))+(((IkReal(-1.00000000000000))*(x7906)*(x7915)))+(((IkReal(-1.00000000000000))*(cj0)*(x7905)*(x7910)))+(((IkReal(-1.00000000000000))*(x7913)*(x7915)))+(((x7907)*(x7908)))+(((IkReal(0.0100000000000000))*(cj0)*(cj5)*(x7910)))+(((IkReal(-1.00000000000000))*(px)*(x7890)))+(((x7896)*(x7908)))+(((IkReal(0.0100000000000000))*(x7893)*(x7913)))+(((IkReal(0.0100000000000000))*(x7893)*(x7906)))+(((IkReal(0.0100000000000000))*(sj0)*(x7895)))+(((r12)*(sj0)*(x7896)))+(((IkReal(0.0100000000000000))*(cj5)*(sj0)*(x7911))));
if( IKabs(evalcond[0]) < 0.0000010000000000  && IKabs(evalcond[1]) < 0.0000010000000000  && IKabs(evalcond[2]) < 0.0000010000000000  && IKabs(evalcond[3]) < 0.0000010000000000  && IKabs(evalcond[4]) < 0.0000010000000000  && IKabs(evalcond[5]) < 0.0000010000000000  && IKabs(evalcond[6]) < 0.0000010000000000  && IKabs(evalcond[7]) < 0.0000010000000000  && IKabs(evalcond[8]) < 0.0000010000000000  )
{
{
IkReal j3array[1], cj3array[1], sj3array[1];
bool j3valid[1]={false};
_nj3 = 1;
IkReal x7917=((IkReal(1.00000000000000))*(cj5));
IkReal x7918=((r10)*(sj5)*(sj6));
IkReal x7919=((cj6)*(sj0)*(sj5));
IkReal x7920=((r00)*(sj5)*(sj6));
IkReal x7921=((cj0)*(cj6)*(sj5));
if( IKabs(((((IkReal(-1.00000000000000))*(sj0)*(x7920)))+(((r11)*(x7921)))+(((cj0)*(x7918)))+(((IkReal(-1.00000000000000))*(r01)*(x7919)))+(((cj5)*(r02)*(sj0)))+(((IkReal(-1.00000000000000))*(cj0)*(r12)*(x7917))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(((((cj0)*(x7920)))+(((IkReal(-1.00000000000000))*(r12)*(sj0)*(x7917)))+(((r01)*(x7921)))+(((r11)*(x7919)))+(((sj0)*(x7918)))+(((IkReal(-1.00000000000000))*(cj0)*(r02)*(x7917))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(IKsqr(((((IkReal(-1.00000000000000))*(sj0)*(x7920)))+(((r11)*(x7921)))+(((cj0)*(x7918)))+(((IkReal(-1.00000000000000))*(r01)*(x7919)))+(((cj5)*(r02)*(sj0)))+(((IkReal(-1.00000000000000))*(cj0)*(r12)*(x7917)))))+IKsqr(((((cj0)*(x7920)))+(((IkReal(-1.00000000000000))*(r12)*(sj0)*(x7917)))+(((r01)*(x7921)))+(((r11)*(x7919)))+(((sj0)*(x7918)))+(((IkReal(-1.00000000000000))*(cj0)*(r02)*(x7917)))))-1) <= IKFAST_SINCOS_THRESH )
    continue;
j3array[0]=IKatan2(((((IkReal(-1.00000000000000))*(sj0)*(x7920)))+(((r11)*(x7921)))+(((cj0)*(x7918)))+(((IkReal(-1.00000000000000))*(r01)*(x7919)))+(((cj5)*(r02)*(sj0)))+(((IkReal(-1.00000000000000))*(cj0)*(r12)*(x7917)))), ((((cj0)*(x7920)))+(((IkReal(-1.00000000000000))*(r12)*(sj0)*(x7917)))+(((r01)*(x7921)))+(((r11)*(x7919)))+(((sj0)*(x7918)))+(((IkReal(-1.00000000000000))*(cj0)*(r02)*(x7917)))));
sj3array[0]=IKsin(j3array[0]);
cj3array[0]=IKcos(j3array[0]);
if( j3array[0] > IKPI )
{
    j3array[0]-=IK2PI;
}
else if( j3array[0] < -IKPI )
{    j3array[0]+=IK2PI;
}
j3valid[0] = true;
for(int ij3 = 0; ij3 < 1; ++ij3)
{
if( !j3valid[ij3] )
{
    continue;
}
_ij3[0] = ij3; _ij3[1] = -1;
for(int iij3 = ij3+1; iij3 < 1; ++iij3)
{
if( j3valid[iij3] && IKabs(cj3array[ij3]-cj3array[iij3]) < IKFAST_SOLUTION_THRESH && IKabs(sj3array[ij3]-sj3array[iij3]) < IKFAST_SOLUTION_THRESH )
{
    j3valid[iij3]=false; _ij3[1] = iij3; break; 
}
}
j3 = j3array[ij3]; cj3 = cj3array[ij3]; sj3 = sj3array[ij3];
{
IkReal evalcond[4];
IkReal x7922=IKcos(j3);
IkReal x7923=IKsin(j3);
IkReal x7924=((sj0)*(sj5));
IkReal x7925=((r00)*(sj6));
IkReal x7926=((IkReal(1.00000000000000))*(cj4));
IkReal x7927=((cj6)*(sj0));
IkReal x7928=((r00)*(sj4));
IkReal x7929=((cj0)*(cj5));
IkReal x7930=((cj6)*(r01));
IkReal x7931=((cj5)*(sj0));
IkReal x7932=((cj0)*(sj5));
IkReal x7933=((cj6)*(r11));
IkReal x7934=((r10)*(sj6));
IkReal x7935=((r10)*(sj4));
IkReal x7936=((cj0)*(sj4)*(sj6));
IkReal x7937=((sj0)*(sj4)*(sj6));
IkReal x7938=((IkReal(1.00000000000000))*(cj0)*(cj6));
evalcond[0]=((((IkReal(-1.00000000000000))*(r02)*(x7931)))+(((x7924)*(x7930)))+(((IkReal(-1.00000000000000))*(x7932)*(x7934)))+(((r12)*(x7929)))+(((x7924)*(x7925)))+(x7923)+(((IkReal(-1.00000000000000))*(x7932)*(x7933))));
evalcond[1]=((((IkReal(-1.00000000000000))*(x7924)*(x7934)))+(((r02)*(x7929)))+(((r12)*(x7931)))+(((IkReal(-1.00000000000000))*(x7925)*(x7932)))+(((IkReal(-1.00000000000000))*(x7924)*(x7933)))+(((IkReal(-1.00000000000000))*(x7930)*(x7932)))+(x7922));
evalcond[2]=((((IkReal(-1.00000000000000))*(r12)*(x7926)*(x7932)))+(((IkReal(-1.00000000000000))*(x7926)*(x7929)*(x7933)))+(((cj4)*(r02)*(x7924)))+(((IkReal(-1.00000000000000))*(x7935)*(x7938)))+(((x7927)*(x7928)))+(((IkReal(-1.00000000000000))*(r01)*(x7937)))+(((cj4)*(x7925)*(x7931)))+(((IkReal(-1.00000000000000))*(x7922)))+(((r11)*(x7936)))+(((cj4)*(cj5)*(r01)*(x7927)))+(((IkReal(-1.00000000000000))*(x7926)*(x7929)*(x7934))));
evalcond[3]=((((IkReal(-1.00000000000000))*(x7927)*(x7935)))+(((IkReal(-1.00000000000000))*(r12)*(x7924)*(x7926)))+(((r11)*(x7937)))+(((IkReal(-1.00000000000000))*(x7926)*(x7929)*(x7930)))+(((r01)*(x7936)))+(((IkReal(-1.00000000000000))*(r02)*(x7926)*(x7932)))+(((IkReal(-1.00000000000000))*(x7925)*(x7926)*(x7929)))+(x7923)+(((IkReal(-1.00000000000000))*(x7928)*(x7938)))+(((IkReal(-1.00000000000000))*(x7926)*(x7931)*(x7934)))+(((IkReal(-1.00000000000000))*(cj5)*(r11)*(x7926)*(x7927))));
if( IKabs(evalcond[0]) > 0.000001  || IKabs(evalcond[1]) > 0.000001  || IKabs(evalcond[2]) > 0.000001  || IKabs(evalcond[3]) > 0.000001  )
{
continue;
}
}

{
std::vector<IkSingleDOFSolutionBase<IkReal> > vinfos(7);
vinfos[0].jointtype = 1;
vinfos[0].foffset = j0;
vinfos[0].indices[0] = _ij0[0];
vinfos[0].indices[1] = _ij0[1];
vinfos[0].maxsolutions = _nj0;
vinfos[1].jointtype = 1;
vinfos[1].foffset = j1;
vinfos[1].indices[0] = _ij1[0];
vinfos[1].indices[1] = _ij1[1];
vinfos[1].maxsolutions = _nj1;
vinfos[2].jointtype = 1;
vinfos[2].foffset = j2;
vinfos[2].indices[0] = _ij2[0];
vinfos[2].indices[1] = _ij2[1];
vinfos[2].maxsolutions = _nj2;
vinfos[3].jointtype = 1;
vinfos[3].foffset = j3;
vinfos[3].indices[0] = _ij3[0];
vinfos[3].indices[1] = _ij3[1];
vinfos[3].maxsolutions = _nj3;
vinfos[4].jointtype = 1;
vinfos[4].foffset = j4;
vinfos[4].indices[0] = _ij4[0];
vinfos[4].indices[1] = _ij4[1];
vinfos[4].maxsolutions = _nj4;
vinfos[5].jointtype = 1;
vinfos[5].foffset = j5;
vinfos[5].indices[0] = _ij5[0];
vinfos[5].indices[1] = _ij5[1];
vinfos[5].maxsolutions = _nj5;
vinfos[6].jointtype = 1;
vinfos[6].foffset = j6;
vinfos[6].indices[0] = _ij6[0];
vinfos[6].indices[1] = _ij6[1];
vinfos[6].maxsolutions = _nj6;
std::vector<int> vfree(0);
solutions.AddSolution(vinfos,vfree);
}
}
}

} else
{
if( 1 )
{
continue;

} else
{
}
}
}
}
}
}

} else
{
{
IkReal j3array[1], cj3array[1], sj3array[1];
bool j3valid[1]={false};
_nj3 = 1;
IkReal x7939=((sj0)*(sj5));
IkReal x7940=((r00)*(sj6));
IkReal x7941=((IkReal(1.00000000000000))*(cj5));
IkReal x7942=((cj6)*(r11));
IkReal x7943=((cj6)*(r01));
IkReal x7944=((cj0)*(sj5));
IkReal x7945=((r10)*(sj6));
if( IKabs(((((IKabs(sj2) != 0)?((IkReal)1/(sj2)):(IkReal)1.0e30))*(((((IkReal(-1.00000000000000))*(x7942)*(x7944)))+(((x7939)*(x7943)))+(((cj0)*(cj5)*(r12)))+(((x7939)*(x7940)))+(((IkReal(-1.00000000000000))*(r02)*(sj0)*(x7941)))+(((IkReal(-1.00000000000000))*(x7944)*(x7945))))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(((((IkReal(-1.00000000000000))*(r12)*(sj0)*(x7941)))+(((x7939)*(x7942)))+(((x7943)*(x7944)))+(((IkReal(-1.00000000000000))*(cj0)*(r02)*(x7941)))+(((x7940)*(x7944)))+(((x7939)*(x7945))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(IKsqr(((((IKabs(sj2) != 0)?((IkReal)1/(sj2)):(IkReal)1.0e30))*(((((IkReal(-1.00000000000000))*(x7942)*(x7944)))+(((x7939)*(x7943)))+(((cj0)*(cj5)*(r12)))+(((x7939)*(x7940)))+(((IkReal(-1.00000000000000))*(r02)*(sj0)*(x7941)))+(((IkReal(-1.00000000000000))*(x7944)*(x7945)))))))+IKsqr(((((IkReal(-1.00000000000000))*(r12)*(sj0)*(x7941)))+(((x7939)*(x7942)))+(((x7943)*(x7944)))+(((IkReal(-1.00000000000000))*(cj0)*(r02)*(x7941)))+(((x7940)*(x7944)))+(((x7939)*(x7945)))))-1) <= IKFAST_SINCOS_THRESH )
    continue;
j3array[0]=IKatan2(((((IKabs(sj2) != 0)?((IkReal)1/(sj2)):(IkReal)1.0e30))*(((((IkReal(-1.00000000000000))*(x7942)*(x7944)))+(((x7939)*(x7943)))+(((cj0)*(cj5)*(r12)))+(((x7939)*(x7940)))+(((IkReal(-1.00000000000000))*(r02)*(sj0)*(x7941)))+(((IkReal(-1.00000000000000))*(x7944)*(x7945)))))), ((((IkReal(-1.00000000000000))*(r12)*(sj0)*(x7941)))+(((x7939)*(x7942)))+(((x7943)*(x7944)))+(((IkReal(-1.00000000000000))*(cj0)*(r02)*(x7941)))+(((x7940)*(x7944)))+(((x7939)*(x7945)))));
sj3array[0]=IKsin(j3array[0]);
cj3array[0]=IKcos(j3array[0]);
if( j3array[0] > IKPI )
{
    j3array[0]-=IK2PI;
}
else if( j3array[0] < -IKPI )
{    j3array[0]+=IK2PI;
}
j3valid[0] = true;
for(int ij3 = 0; ij3 < 1; ++ij3)
{
if( !j3valid[ij3] )
{
    continue;
}
_ij3[0] = ij3; _ij3[1] = -1;
for(int iij3 = ij3+1; iij3 < 1; ++iij3)
{
if( j3valid[iij3] && IKabs(cj3array[ij3]-cj3array[iij3]) < IKFAST_SOLUTION_THRESH && IKabs(sj3array[ij3]-sj3array[iij3]) < IKFAST_SOLUTION_THRESH )
{
    j3valid[iij3]=false; _ij3[1] = iij3; break; 
}
}
j3 = j3array[ij3]; cj3 = cj3array[ij3]; sj3 = sj3array[ij3];
{
IkReal evalcond[6];
IkReal x7946=IKsin(j3);
IkReal x7947=IKcos(j3);
IkReal x7948=((sj0)*(sj5));
IkReal x7949=((r00)*(sj6));
IkReal x7950=((IkReal(1.00000000000000))*(cj4));
IkReal x7951=((cj6)*(r01));
IkReal x7952=((cj0)*(cj5));
IkReal x7953=((cj5)*(sj0));
IkReal x7954=((cj6)*(r11));
IkReal x7955=((cj6)*(sj4));
IkReal x7956=((cj0)*(sj5));
IkReal x7957=((cj4)*(cj5));
IkReal x7958=((cj6)*(r21));
IkReal x7959=((r20)*(sj6));
IkReal x7960=((r10)*(sj6));
IkReal x7961=((IkReal(1.00000000000000))*(cj0));
IkReal x7962=((cj0)*(sj4)*(sj6));
IkReal x7963=((sj0)*(sj4)*(sj6));
evalcond[0]=((((IkReal(-1.00000000000000))*(cj5)*(r22)))+(((sj5)*(x7959)))+(((cj2)*(x7946)))+(((sj5)*(x7958))));
evalcond[1]=((((r20)*(x7955)))+(((IkReal(-1.00000000000000))*(r21)*(sj4)*(sj6)))+(((cj4)*(r22)*(sj5)))+(((IkReal(-1.00000000000000))*(cj2)*(x7947)))+(((x7957)*(x7959)))+(((x7957)*(x7958))));
evalcond[2]=((((IkReal(-1.00000000000000))*(x7956)*(x7960)))+(((x7948)*(x7951)))+(((IkReal(-1.00000000000000))*(x7954)*(x7956)))+(((IkReal(-1.00000000000000))*(sj2)*(x7946)))+(((r12)*(x7952)))+(((x7948)*(x7949)))+(((IkReal(-1.00000000000000))*(r02)*(x7953))));
evalcond[3]=((((r12)*(x7953)))+(x7947)+(((IkReal(-1.00000000000000))*(x7951)*(x7956)))+(((IkReal(-1.00000000000000))*(x7949)*(x7956)))+(((r02)*(x7952)))+(((IkReal(-1.00000000000000))*(x7948)*(x7960)))+(((IkReal(-1.00000000000000))*(x7948)*(x7954))));
evalcond[4]=((((cj4)*(r02)*(x7948)))+(((IkReal(-1.00000000000000))*(x7950)*(x7952)*(x7954)))+(((r00)*(sj0)*(x7955)))+(((IkReal(-1.00000000000000))*(r10)*(x7955)*(x7961)))+(((r11)*(x7962)))+(((sj2)*(x7947)))+(((IkReal(-1.00000000000000))*(r12)*(x7950)*(x7956)))+(((IkReal(-1.00000000000000))*(x7950)*(x7952)*(x7960)))+(((cj4)*(x7951)*(x7953)))+(((IkReal(-1.00000000000000))*(r01)*(x7963)))+(((cj4)*(x7949)*(x7953))));
evalcond[5]=((((IkReal(-1.00000000000000))*(r00)*(x7955)*(x7961)))+(((r01)*(x7962)))+(x7946)+(((IkReal(-1.00000000000000))*(x7950)*(x7953)*(x7954)))+(((IkReal(-1.00000000000000))*(r02)*(x7950)*(x7956)))+(((IkReal(-1.00000000000000))*(x7950)*(x7953)*(x7960)))+(((IkReal(-1.00000000000000))*(r10)*(sj0)*(x7955)))+(((r11)*(x7963)))+(((IkReal(-1.00000000000000))*(x7949)*(x7950)*(x7952)))+(((IkReal(-1.00000000000000))*(r12)*(x7948)*(x7950)))+(((IkReal(-1.00000000000000))*(x7950)*(x7951)*(x7952))));
if( IKabs(evalcond[0]) > 0.000001  || IKabs(evalcond[1]) > 0.000001  || IKabs(evalcond[2]) > 0.000001  || IKabs(evalcond[3]) > 0.000001  || IKabs(evalcond[4]) > 0.000001  || IKabs(evalcond[5]) > 0.000001  )
{
continue;
}
}

{
std::vector<IkSingleDOFSolutionBase<IkReal> > vinfos(7);
vinfos[0].jointtype = 1;
vinfos[0].foffset = j0;
vinfos[0].indices[0] = _ij0[0];
vinfos[0].indices[1] = _ij0[1];
vinfos[0].maxsolutions = _nj0;
vinfos[1].jointtype = 1;
vinfos[1].foffset = j1;
vinfos[1].indices[0] = _ij1[0];
vinfos[1].indices[1] = _ij1[1];
vinfos[1].maxsolutions = _nj1;
vinfos[2].jointtype = 1;
vinfos[2].foffset = j2;
vinfos[2].indices[0] = _ij2[0];
vinfos[2].indices[1] = _ij2[1];
vinfos[2].maxsolutions = _nj2;
vinfos[3].jointtype = 1;
vinfos[3].foffset = j3;
vinfos[3].indices[0] = _ij3[0];
vinfos[3].indices[1] = _ij3[1];
vinfos[3].maxsolutions = _nj3;
vinfos[4].jointtype = 1;
vinfos[4].foffset = j4;
vinfos[4].indices[0] = _ij4[0];
vinfos[4].indices[1] = _ij4[1];
vinfos[4].maxsolutions = _nj4;
vinfos[5].jointtype = 1;
vinfos[5].foffset = j5;
vinfos[5].indices[0] = _ij5[0];
vinfos[5].indices[1] = _ij5[1];
vinfos[5].maxsolutions = _nj5;
vinfos[6].jointtype = 1;
vinfos[6].foffset = j6;
vinfos[6].indices[0] = _ij6[0];
vinfos[6].indices[1] = _ij6[1];
vinfos[6].maxsolutions = _nj6;
std::vector<int> vfree(0);
solutions.AddSolution(vinfos,vfree);
}
}
}

}

}

} else
{
{
IkReal j3array[1], cj3array[1], sj3array[1];
bool j3valid[1]={false};
_nj3 = 1;
IkReal x7964=((cj6)*(sj5));
IkReal x7965=((IkReal(1.00000000000000))*(cj5));
IkReal x7966=((sj5)*(sj6));
if( IKabs(((((IKabs(cj2) != 0)?((IkReal)1/(cj2)):(IkReal)1.0e30))*(((((IkReal(-1.00000000000000))*(r20)*(x7966)))+(((IkReal(-1.00000000000000))*(r21)*(x7964)))+(((cj5)*(r22))))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(((((IkReal(-1.00000000000000))*(r12)*(sj0)*(x7965)))+(((r11)*(sj0)*(x7964)))+(((cj0)*(r01)*(x7964)))+(((cj0)*(r00)*(x7966)))+(((IkReal(-1.00000000000000))*(cj0)*(r02)*(x7965)))+(((r10)*(sj0)*(x7966))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(IKsqr(((((IKabs(cj2) != 0)?((IkReal)1/(cj2)):(IkReal)1.0e30))*(((((IkReal(-1.00000000000000))*(r20)*(x7966)))+(((IkReal(-1.00000000000000))*(r21)*(x7964)))+(((cj5)*(r22)))))))+IKsqr(((((IkReal(-1.00000000000000))*(r12)*(sj0)*(x7965)))+(((r11)*(sj0)*(x7964)))+(((cj0)*(r01)*(x7964)))+(((cj0)*(r00)*(x7966)))+(((IkReal(-1.00000000000000))*(cj0)*(r02)*(x7965)))+(((r10)*(sj0)*(x7966)))))-1) <= IKFAST_SINCOS_THRESH )
    continue;
j3array[0]=IKatan2(((((IKabs(cj2) != 0)?((IkReal)1/(cj2)):(IkReal)1.0e30))*(((((IkReal(-1.00000000000000))*(r20)*(x7966)))+(((IkReal(-1.00000000000000))*(r21)*(x7964)))+(((cj5)*(r22)))))), ((((IkReal(-1.00000000000000))*(r12)*(sj0)*(x7965)))+(((r11)*(sj0)*(x7964)))+(((cj0)*(r01)*(x7964)))+(((cj0)*(r00)*(x7966)))+(((IkReal(-1.00000000000000))*(cj0)*(r02)*(x7965)))+(((r10)*(sj0)*(x7966)))));
sj3array[0]=IKsin(j3array[0]);
cj3array[0]=IKcos(j3array[0]);
if( j3array[0] > IKPI )
{
    j3array[0]-=IK2PI;
}
else if( j3array[0] < -IKPI )
{    j3array[0]+=IK2PI;
}
j3valid[0] = true;
for(int ij3 = 0; ij3 < 1; ++ij3)
{
if( !j3valid[ij3] )
{
    continue;
}
_ij3[0] = ij3; _ij3[1] = -1;
for(int iij3 = ij3+1; iij3 < 1; ++iij3)
{
if( j3valid[iij3] && IKabs(cj3array[ij3]-cj3array[iij3]) < IKFAST_SOLUTION_THRESH && IKabs(sj3array[ij3]-sj3array[iij3]) < IKFAST_SOLUTION_THRESH )
{
    j3valid[iij3]=false; _ij3[1] = iij3; break; 
}
}
j3 = j3array[ij3]; cj3 = cj3array[ij3]; sj3 = sj3array[ij3];
{
IkReal evalcond[6];
IkReal x7967=IKsin(j3);
IkReal x7968=IKcos(j3);
IkReal x7969=((sj0)*(sj5));
IkReal x7970=((r00)*(sj6));
IkReal x7971=((IkReal(1.00000000000000))*(cj4));
IkReal x7972=((cj6)*(r01));
IkReal x7973=((cj0)*(cj5));
IkReal x7974=((cj5)*(sj0));
IkReal x7975=((cj6)*(r11));
IkReal x7976=((cj6)*(sj4));
IkReal x7977=((cj0)*(sj5));
IkReal x7978=((cj4)*(cj5));
IkReal x7979=((cj6)*(r21));
IkReal x7980=((r20)*(sj6));
IkReal x7981=((r10)*(sj6));
IkReal x7982=((IkReal(1.00000000000000))*(cj0));
IkReal x7983=((cj0)*(sj4)*(sj6));
IkReal x7984=((sj0)*(sj4)*(sj6));
evalcond[0]=((((sj5)*(x7979)))+(((cj2)*(x7967)))+(((IkReal(-1.00000000000000))*(cj5)*(r22)))+(((sj5)*(x7980))));
evalcond[1]=((((r20)*(x7976)))+(((IkReal(-1.00000000000000))*(r21)*(sj4)*(sj6)))+(((cj4)*(r22)*(sj5)))+(((x7978)*(x7979)))+(((IkReal(-1.00000000000000))*(cj2)*(x7968)))+(((x7978)*(x7980))));
evalcond[2]=((((x7969)*(x7970)))+(((x7969)*(x7972)))+(((r12)*(x7973)))+(((IkReal(-1.00000000000000))*(x7975)*(x7977)))+(((IkReal(-1.00000000000000))*(r02)*(x7974)))+(((IkReal(-1.00000000000000))*(x7977)*(x7981)))+(((IkReal(-1.00000000000000))*(sj2)*(x7967))));
evalcond[3]=((x7968)+(((r02)*(x7973)))+(((IkReal(-1.00000000000000))*(x7970)*(x7977)))+(((IkReal(-1.00000000000000))*(x7969)*(x7981)))+(((r12)*(x7974)))+(((IkReal(-1.00000000000000))*(x7972)*(x7977)))+(((IkReal(-1.00000000000000))*(x7969)*(x7975))));
evalcond[4]=((((cj4)*(r02)*(x7969)))+(((r00)*(sj0)*(x7976)))+(((cj4)*(x7970)*(x7974)))+(((sj2)*(x7968)))+(((IkReal(-1.00000000000000))*(r12)*(x7971)*(x7977)))+(((IkReal(-1.00000000000000))*(r10)*(x7976)*(x7982)))+(((IkReal(-1.00000000000000))*(r01)*(x7984)))+(((IkReal(-1.00000000000000))*(x7971)*(x7973)*(x7975)))+(((IkReal(-1.00000000000000))*(x7971)*(x7973)*(x7981)))+(((cj4)*(x7972)*(x7974)))+(((r11)*(x7983))));
evalcond[5]=((((IkReal(-1.00000000000000))*(r02)*(x7971)*(x7977)))+(x7967)+(((r01)*(x7983)))+(((r11)*(x7984)))+(((IkReal(-1.00000000000000))*(x7970)*(x7971)*(x7973)))+(((IkReal(-1.00000000000000))*(x7971)*(x7974)*(x7981)))+(((IkReal(-1.00000000000000))*(r00)*(x7976)*(x7982)))+(((IkReal(-1.00000000000000))*(x7971)*(x7974)*(x7975)))+(((IkReal(-1.00000000000000))*(x7971)*(x7972)*(x7973)))+(((IkReal(-1.00000000000000))*(r12)*(x7969)*(x7971)))+(((IkReal(-1.00000000000000))*(r10)*(sj0)*(x7976))));
if( IKabs(evalcond[0]) > 0.000001  || IKabs(evalcond[1]) > 0.000001  || IKabs(evalcond[2]) > 0.000001  || IKabs(evalcond[3]) > 0.000001  || IKabs(evalcond[4]) > 0.000001  || IKabs(evalcond[5]) > 0.000001  )
{
continue;
}
}

{
std::vector<IkSingleDOFSolutionBase<IkReal> > vinfos(7);
vinfos[0].jointtype = 1;
vinfos[0].foffset = j0;
vinfos[0].indices[0] = _ij0[0];
vinfos[0].indices[1] = _ij0[1];
vinfos[0].maxsolutions = _nj0;
vinfos[1].jointtype = 1;
vinfos[1].foffset = j1;
vinfos[1].indices[0] = _ij1[0];
vinfos[1].indices[1] = _ij1[1];
vinfos[1].maxsolutions = _nj1;
vinfos[2].jointtype = 1;
vinfos[2].foffset = j2;
vinfos[2].indices[0] = _ij2[0];
vinfos[2].indices[1] = _ij2[1];
vinfos[2].maxsolutions = _nj2;
vinfos[3].jointtype = 1;
vinfos[3].foffset = j3;
vinfos[3].indices[0] = _ij3[0];
vinfos[3].indices[1] = _ij3[1];
vinfos[3].maxsolutions = _nj3;
vinfos[4].jointtype = 1;
vinfos[4].foffset = j4;
vinfos[4].indices[0] = _ij4[0];
vinfos[4].indices[1] = _ij4[1];
vinfos[4].maxsolutions = _nj4;
vinfos[5].jointtype = 1;
vinfos[5].foffset = j5;
vinfos[5].indices[0] = _ij5[0];
vinfos[5].indices[1] = _ij5[1];
vinfos[5].maxsolutions = _nj5;
vinfos[6].jointtype = 1;
vinfos[6].foffset = j6;
vinfos[6].indices[0] = _ij6[0];
vinfos[6].indices[1] = _ij6[1];
vinfos[6].maxsolutions = _nj6;
std::vector<int> vfree(0);
solutions.AddSolution(vinfos,vfree);
}
}
}

}

}

} else
{
{
IkReal j3array[1], cj3array[1], sj3array[1];
bool j3valid[1]={false};
_nj3 = 1;
IkReal x7985=((IkReal(1.00000000000000))*(r21));
IkReal x7986=((cj4)*(cj5));
IkReal x7987=((r20)*(sj6));
if( IKabs(((gconst10)*(((((IkReal(-1.00000000000000))*(cj6)*(sj5)*(x7985)))+(((IkReal(-1.00000000000000))*(sj5)*(x7987)))+(((cj5)*(r22))))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(((gconst10)*(((((IkReal(-1.00000000000000))*(sj4)*(sj6)*(x7985)))+(((cj6)*(r20)*(sj4)))+(((cj4)*(r22)*(sj5)))+(((x7986)*(x7987)))+(((cj6)*(r21)*(x7986))))))) < IKFAST_ATAN2_MAGTHRESH )
    continue;
j3array[0]=IKatan2(((gconst10)*(((((IkReal(-1.00000000000000))*(cj6)*(sj5)*(x7985)))+(((IkReal(-1.00000000000000))*(sj5)*(x7987)))+(((cj5)*(r22)))))), ((gconst10)*(((((IkReal(-1.00000000000000))*(sj4)*(sj6)*(x7985)))+(((cj6)*(r20)*(sj4)))+(((cj4)*(r22)*(sj5)))+(((x7986)*(x7987)))+(((cj6)*(r21)*(x7986)))))));
sj3array[0]=IKsin(j3array[0]);
cj3array[0]=IKcos(j3array[0]);
if( j3array[0] > IKPI )
{
    j3array[0]-=IK2PI;
}
else if( j3array[0] < -IKPI )
{    j3array[0]+=IK2PI;
}
j3valid[0] = true;
for(int ij3 = 0; ij3 < 1; ++ij3)
{
if( !j3valid[ij3] )
{
    continue;
}
_ij3[0] = ij3; _ij3[1] = -1;
for(int iij3 = ij3+1; iij3 < 1; ++iij3)
{
if( j3valid[iij3] && IKabs(cj3array[ij3]-cj3array[iij3]) < IKFAST_SOLUTION_THRESH && IKabs(sj3array[ij3]-sj3array[iij3]) < IKFAST_SOLUTION_THRESH )
{
    j3valid[iij3]=false; _ij3[1] = iij3; break; 
}
}
j3 = j3array[ij3]; cj3 = cj3array[ij3]; sj3 = sj3array[ij3];
{
IkReal evalcond[6];
IkReal x7988=IKsin(j3);
IkReal x7989=IKcos(j3);
IkReal x7990=((sj0)*(sj5));
IkReal x7991=((r00)*(sj6));
IkReal x7992=((IkReal(1.00000000000000))*(cj4));
IkReal x7993=((cj6)*(r01));
IkReal x7994=((cj0)*(cj5));
IkReal x7995=((cj5)*(sj0));
IkReal x7996=((cj6)*(r11));
IkReal x7997=((cj6)*(sj4));
IkReal x7998=((cj0)*(sj5));
IkReal x7999=((cj4)*(cj5));
IkReal x8000=((cj6)*(r21));
IkReal x8001=((r20)*(sj6));
IkReal x8002=((r10)*(sj6));
IkReal x8003=((IkReal(1.00000000000000))*(cj0));
IkReal x8004=((cj0)*(sj4)*(sj6));
IkReal x8005=((sj0)*(sj4)*(sj6));
evalcond[0]=((((cj2)*(x7988)))+(((IkReal(-1.00000000000000))*(cj5)*(r22)))+(((sj5)*(x8001)))+(((sj5)*(x8000))));
evalcond[1]=((((IkReal(-1.00000000000000))*(r21)*(sj4)*(sj6)))+(((cj4)*(r22)*(sj5)))+(((x7999)*(x8001)))+(((IkReal(-1.00000000000000))*(cj2)*(x7989)))+(((x7999)*(x8000)))+(((r20)*(x7997))));
evalcond[2]=((((IkReal(-1.00000000000000))*(x7998)*(x8002)))+(((IkReal(-1.00000000000000))*(sj2)*(x7988)))+(((IkReal(-1.00000000000000))*(r02)*(x7995)))+(((IkReal(-1.00000000000000))*(x7996)*(x7998)))+(((x7990)*(x7993)))+(((x7990)*(x7991)))+(((r12)*(x7994))));
evalcond[3]=((((IkReal(-1.00000000000000))*(x7991)*(x7998)))+(((IkReal(-1.00000000000000))*(x7990)*(x8002)))+(x7989)+(((IkReal(-1.00000000000000))*(x7990)*(x7996)))+(((IkReal(-1.00000000000000))*(x7993)*(x7998)))+(((r12)*(x7995)))+(((r02)*(x7994))));
evalcond[4]=((((IkReal(-1.00000000000000))*(x7992)*(x7994)*(x7996)))+(((sj2)*(x7989)))+(((IkReal(-1.00000000000000))*(r10)*(x7997)*(x8003)))+(((IkReal(-1.00000000000000))*(x7992)*(x7994)*(x8002)))+(((r11)*(x8004)))+(((IkReal(-1.00000000000000))*(r01)*(x8005)))+(((cj4)*(r02)*(x7990)))+(((IkReal(-1.00000000000000))*(r12)*(x7992)*(x7998)))+(((cj4)*(x7991)*(x7995)))+(((r00)*(sj0)*(x7997)))+(((cj4)*(x7993)*(x7995))));
evalcond[5]=((((r11)*(x8005)))+(((IkReal(-1.00000000000000))*(x7992)*(x7995)*(x7996)))+(((IkReal(-1.00000000000000))*(x7991)*(x7992)*(x7994)))+(x7988)+(((IkReal(-1.00000000000000))*(r00)*(x7997)*(x8003)))+(((IkReal(-1.00000000000000))*(x7992)*(x7995)*(x8002)))+(((IkReal(-1.00000000000000))*(x7992)*(x7993)*(x7994)))+(((IkReal(-1.00000000000000))*(r10)*(sj0)*(x7997)))+(((r01)*(x8004)))+(((IkReal(-1.00000000000000))*(r12)*(x7990)*(x7992)))+(((IkReal(-1.00000000000000))*(r02)*(x7992)*(x7998))));
if( IKabs(evalcond[0]) > 0.000001  || IKabs(evalcond[1]) > 0.000001  || IKabs(evalcond[2]) > 0.000001  || IKabs(evalcond[3]) > 0.000001  || IKabs(evalcond[4]) > 0.000001  || IKabs(evalcond[5]) > 0.000001  )
{
continue;
}
}

{
std::vector<IkSingleDOFSolutionBase<IkReal> > vinfos(7);
vinfos[0].jointtype = 1;
vinfos[0].foffset = j0;
vinfos[0].indices[0] = _ij0[0];
vinfos[0].indices[1] = _ij0[1];
vinfos[0].maxsolutions = _nj0;
vinfos[1].jointtype = 1;
vinfos[1].foffset = j1;
vinfos[1].indices[0] = _ij1[0];
vinfos[1].indices[1] = _ij1[1];
vinfos[1].maxsolutions = _nj1;
vinfos[2].jointtype = 1;
vinfos[2].foffset = j2;
vinfos[2].indices[0] = _ij2[0];
vinfos[2].indices[1] = _ij2[1];
vinfos[2].maxsolutions = _nj2;
vinfos[3].jointtype = 1;
vinfos[3].foffset = j3;
vinfos[3].indices[0] = _ij3[0];
vinfos[3].indices[1] = _ij3[1];
vinfos[3].maxsolutions = _nj3;
vinfos[4].jointtype = 1;
vinfos[4].foffset = j4;
vinfos[4].indices[0] = _ij4[0];
vinfos[4].indices[1] = _ij4[1];
vinfos[4].maxsolutions = _nj4;
vinfos[5].jointtype = 1;
vinfos[5].foffset = j5;
vinfos[5].indices[0] = _ij5[0];
vinfos[5].indices[1] = _ij5[1];
vinfos[5].maxsolutions = _nj5;
vinfos[6].jointtype = 1;
vinfos[6].foffset = j6;
vinfos[6].indices[0] = _ij6[0];
vinfos[6].indices[1] = _ij6[1];
vinfos[6].maxsolutions = _nj6;
std::vector<int> vfree(0);
solutions.AddSolution(vinfos,vfree);
}
}
}

}

}

} else
{
IkReal x8006=((IkReal(1.00000000000000))*(cj0));
IkReal x8007=((cj4)*(sj6));
IkReal x8008=((sj0)*(sj4));
IkReal x8009=((cj5)*(sj6));
IkReal x8010=((sj4)*(sj5));
IkReal x8011=((r12)*(sj5));
IkReal x8012=((IkReal(0.374290000000000))*(cj5));
IkReal x8013=((r02)*(sj0));
IkReal x8014=((IkReal(1.00000000000000))*(sj0));
IkReal x8015=((cj0)*(r10));
IkReal x8016=((cj4)*(cj6));
IkReal x8017=((r00)*(sj0));
IkReal x8018=((cj6)*(r21));
IkReal x8019=((IkReal(0.374290000000000))*(sj5));
IkReal x8020=((IkReal(0.0100000000000000))*(sj5));
IkReal x8021=((cj0)*(r02));
IkReal x8022=((cj5)*(sj4));
IkReal x8023=((cj6)*(r01));
IkReal x8024=((cj0)*(r00));
IkReal x8025=((cj6)*(r11));
IkReal x8026=((r01)*(sj0));
IkReal x8027=((r10)*(sj0));
IkReal x8028=((IkReal(0.0100000000000000))*(cj5)*(cj6));
IkReal x8029=((sj6)*(x8019));
IkReal x8030=((cj0)*(cj6)*(x8019));
evalcond[0]=((IkReal(-3.14159265358979))+(IKfmod(((IkReal(1.57079632679490))+(j2)), IkReal(6.28318530717959))));
evalcond[1]=((((IkReal(-1.00000000000000))*(r20)*(x8016)))+(((r21)*(x8007)))+(((x8018)*(x8022)))+(((IkReal(-1.00000000000000))*(cj1)))+(((r20)*(sj4)*(x8009)))+(((r22)*(x8010))));
evalcond[2]=((((x8018)*(x8019)))+(((IkReal(0.364420000000000))*(sj1)))+(((IkReal(-1.00000000000000))*(r22)*(x8012)))+(((IkReal(-0.0100000000000000))*(r20)*(x8009)))+(((IkReal(-1.00000000000000))*(r22)*(x8020)))+(((r20)*(x8029)))+(((IkReal(-0.0100000000000000))*(cj5)*(x8018)))+(pz));
evalcond[3]=((((IkReal(-1.00000000000000))*(r11)*(x8006)*(x8007)))+(((x8015)*(x8016)))+(((IkReal(-1.00000000000000))*(r00)*(x8014)*(x8016)))+(((IkReal(-1.00000000000000))*(r12)*(x8006)*(x8010)))+(((IkReal(-1.00000000000000))*(r10)*(sj4)*(x8006)*(x8009)))+(((r02)*(sj5)*(x8008)))+(((x8007)*(x8026)))+(((IkReal(-1.00000000000000))*(x8006)*(x8022)*(x8025)))+(((r00)*(x8008)*(x8009)))+(((cj5)*(x8008)*(x8023))));
evalcond[4]=((((IkReal(-1.00000000000000))*(x8008)*(x8011)))+(((IkReal(-1.00000000000000))*(r01)*(x8006)*(x8007)))+(((IkReal(-1.00000000000000))*(cj5)*(x8008)*(x8025)))+(sj1)+(((IkReal(-1.00000000000000))*(x8006)*(x8022)*(x8023)))+(((x8016)*(x8024)))+(((IkReal(-1.00000000000000))*(r11)*(x8007)*(x8014)))+(((x8016)*(x8027)))+(((IkReal(-1.00000000000000))*(r00)*(sj4)*(x8006)*(x8009)))+(((IkReal(-1.00000000000000))*(r10)*(x8008)*(x8009)))+(((IkReal(-1.00000000000000))*(r02)*(x8006)*(x8010))));
evalcond[5]=((IkReal(0.0690000000000000))+(((IkReal(0.0100000000000000))*(cj0)*(cj5)*(x8025)))+(((x8017)*(x8029)))+(((IkReal(0.0100000000000000))*(cj0)*(x8011)))+(((IkReal(0.0100000000000000))*(x8009)*(x8015)))+(((IkReal(-1.00000000000000))*(x8015)*(x8029)))+(((IkReal(-1.00000000000000))*(x8013)*(x8020)))+(((IkReal(-0.0100000000000000))*(x8009)*(x8017)))+(((IkReal(-0.0100000000000000))*(cj5)*(sj0)*(x8023)))+(((IkReal(-1.00000000000000))*(py)*(x8006)))+(((sj0)*(x8019)*(x8023)))+(((IkReal(-1.00000000000000))*(cj0)*(x8019)*(x8025)))+(((px)*(sj0)))+(((IkReal(-1.00000000000000))*(x8012)*(x8013)))+(((cj0)*(r12)*(x8012))));
evalcond[6]=((IkReal(0.0690000000000000))+(((x8012)*(x8021)))+(((IkReal(0.0100000000000000))*(cj5)*(sj0)*(x8025)))+(((IkReal(-1.00000000000000))*(px)*(x8006)))+(((r12)*(sj0)*(x8012)))+(((IkReal(-1.00000000000000))*(sj0)*(x8019)*(x8025)))+(((IkReal(0.0100000000000000))*(cj0)*(cj5)*(x8023)))+(((IkReal(0.0100000000000000))*(x8009)*(x8027)))+(((IkReal(-1.00000000000000))*(py)*(x8014)))+(((IkReal(0.0100000000000000))*(x8009)*(x8024)))+(((IkReal(0.0100000000000000))*(sj0)*(x8011)))+(((IkReal(-1.00000000000000))*(x8027)*(x8029)))+(((IkReal(-1.00000000000000))*(cj0)*(x8019)*(x8023)))+(((IkReal(-1.00000000000000))*(x8024)*(x8029)))+(((IkReal(0.364420000000000))*(cj1)))+(((x8020)*(x8021))));
if( IKabs(evalcond[0]) < 0.0000010000000000  && IKabs(evalcond[1]) < 0.0000010000000000  && IKabs(evalcond[2]) < 0.0000010000000000  && IKabs(evalcond[3]) < 0.0000010000000000  && IKabs(evalcond[4]) < 0.0000010000000000  && IKabs(evalcond[5]) < 0.0000010000000000  && IKabs(evalcond[6]) < 0.0000010000000000  )
{
{
IkReal dummyeval[1];
IkReal gconst11;
gconst11=IKsign(sj1);
dummyeval[0]=sj1;
if( IKabs(dummyeval[0]) < 0.0000010000000000  )
{
{
IkReal dummyeval[1];
dummyeval[0]=sj1;
if( IKabs(dummyeval[0]) < 0.0000010000000000  )
{
{
IkReal dummyeval[1];
dummyeval[0]=cj1;
if( IKabs(dummyeval[0]) < 0.0000010000000000  )
{
{
IkReal evalcond[9];
IkReal x8031=((IkReal(1.00000000000000))*(cj0));
IkReal x8032=((cj4)*(sj6));
IkReal x8033=((sj0)*(sj6));
IkReal x8034=((cj5)*(sj4));
IkReal x8035=((IkReal(0.374290000000000))*(sj5));
IkReal x8036=((sj4)*(sj5));
IkReal x8037=((cj0)*(cj6));
IkReal x8038=((IkReal(0.0100000000000000))*(cj5));
IkReal x8039=((cj4)*(sj5));
IkReal x8040=((cj5)*(sj0));
IkReal x8041=((IkReal(0.374290000000000))*(r02));
IkReal x8042=((r20)*(sj6));
IkReal x8043=((cj6)*(r21));
IkReal x8044=((IkReal(1.00000000000000))*(sj0));
IkReal x8045=((cj0)*(sj6));
IkReal x8046=((cj4)*(cj6));
IkReal x8047=((IkReal(0.374290000000000))*(r12));
IkReal x8048=((cj0)*(cj5));
IkReal x8049=((cj6)*(sj5));
IkReal x8050=((cj6)*(r01));
IkReal x8051=((r00)*(sj6));
IkReal x8052=((IkReal(0.0100000000000000))*(sj5));
IkReal x8053=((cj6)*(r11));
IkReal x8054=((IkReal(1.00000000000000))*(r10));
IkReal x8055=((r02)*(sj0));
IkReal x8056=((cj6)*(sj4));
IkReal x8057=((r12)*(x8044));
evalcond[0]=((IkReal(-3.14159265358979))+(IKfmod(((IkReal(1.57079632679490))+(j1)), IkReal(6.28318530717959))));
evalcond[1]=((((r21)*(x8032)))+(((x8034)*(x8043)))+(((IkReal(-1.00000000000000))*(r20)*(x8046)))+(((r22)*(x8036)))+(((x8034)*(x8042))));
evalcond[2]=((IkReal(0.364420000000000))+(((IkReal(-0.374290000000000))*(cj5)*(r22)))+(((x8035)*(x8042)))+(pz)+(((IkReal(-1.00000000000000))*(x8038)*(x8043)))+(((IkReal(-1.00000000000000))*(r22)*(x8052)))+(((x8035)*(x8043)))+(((IkReal(-1.00000000000000))*(x8038)*(x8042))));
evalcond[3]=((((IkReal(-1.00000000000000))*(r01)*(x8031)*(x8049)))+(((IkReal(-1.00000000000000))*(sj5)*(x8033)*(x8054)))+(((r12)*(x8040)))+(((IkReal(-1.00000000000000))*(r11)*(x8044)*(x8049)))+(((IkReal(-1.00000000000000))*(sj5)*(x8031)*(x8051)))+(((r02)*(x8048))));
evalcond[4]=((((IkReal(-1.00000000000000))*(r00)*(x8044)*(x8046)))+(((r01)*(sj0)*(x8032)))+(((IkReal(-1.00000000000000))*(x8031)*(x8034)*(x8053)))+(((sj0)*(x8034)*(x8050)))+(((IkReal(-1.00000000000000))*(r10)*(sj6)*(x8031)*(x8034)))+(((cj4)*(r10)*(x8037)))+(((r00)*(x8033)*(x8034)))+(((IkReal(-1.00000000000000))*(r11)*(x8031)*(x8032)))+(((IkReal(-1.00000000000000))*(r12)*(x8031)*(x8036)))+(((x8036)*(x8055))));
evalcond[5]=((IkReal(1.00000000000000))+(((IkReal(-1.00000000000000))*(x8036)*(x8057)))+(((IkReal(-1.00000000000000))*(x8031)*(x8034)*(x8051)))+(((cj4)*(r00)*(x8037)))+(((IkReal(-1.00000000000000))*(r02)*(x8031)*(x8036)))+(((IkReal(-1.00000000000000))*(x8033)*(x8034)*(x8054)))+(((r10)*(sj0)*(x8046)))+(((IkReal(-1.00000000000000))*(r01)*(x8031)*(x8032)))+(((IkReal(-1.00000000000000))*(x8031)*(x8034)*(x8050)))+(((IkReal(-1.00000000000000))*(x8034)*(x8044)*(x8053)))+(((IkReal(-1.00000000000000))*(r11)*(x8032)*(x8044))));
evalcond[6]=((IkReal(0.0690000000000000))+(((IkReal(-1.00000000000000))*(r11)*(x8035)*(x8037)))+(((cj0)*(r12)*(x8052)))+(((IkReal(-1.00000000000000))*(sj0)*(x8038)*(x8050)))+(((r00)*(x8033)*(x8035)))+(((IkReal(-1.00000000000000))*(r00)*(x8033)*(x8038)))+(((IkReal(-1.00000000000000))*(r10)*(x8035)*(x8045)))+(((IkReal(-1.00000000000000))*(x8052)*(x8055)))+(((IkReal(-1.00000000000000))*(x8040)*(x8041)))+(((IkReal(-1.00000000000000))*(py)*(x8031)))+(((sj0)*(x8035)*(x8050)))+(((px)*(sj0)))+(((x8047)*(x8048)))+(((r11)*(x8037)*(x8038)))+(((r10)*(x8038)*(x8045))));
evalcond[7]=((((IkReal(-1.00000000000000))*(r11)*(x8040)*(x8046)))+(((IkReal(-1.00000000000000))*(r10)*(x8044)*(x8056)))+(((IkReal(-1.00000000000000))*(x8032)*(x8040)*(x8054)))+(((r01)*(sj4)*(x8045)))+(((r11)*(sj4)*(x8033)))+(((IkReal(-1.00000000000000))*(r00)*(x8031)*(x8056)))+(((IkReal(-1.00000000000000))*(cj5)*(r00)*(x8031)*(x8032)))+(((IkReal(-1.00000000000000))*(r02)*(x8031)*(x8039)))+(((IkReal(-1.00000000000000))*(cj5)*(r01)*(x8031)*(x8046)))+(((IkReal(-1.00000000000000))*(x8039)*(x8057))));
evalcond[8]=((IkReal(0.0690000000000000))+(((r12)*(sj0)*(x8052)))+(((r00)*(x8038)*(x8045)))+(((r01)*(x8037)*(x8038)))+(((IkReal(-1.00000000000000))*(px)*(x8031)))+(((IkReal(-1.00000000000000))*(r01)*(x8035)*(x8037)))+(((x8040)*(x8047)))+(((IkReal(-1.00000000000000))*(sj0)*(x8035)*(x8053)))+(((cj0)*(r02)*(x8052)))+(((IkReal(-1.00000000000000))*(r10)*(x8033)*(x8035)))+(((IkReal(-1.00000000000000))*(py)*(x8044)))+(((sj0)*(x8038)*(x8053)))+(((IkReal(-1.00000000000000))*(r00)*(x8035)*(x8045)))+(((x8041)*(x8048)))+(((r10)*(x8033)*(x8038))));
if( IKabs(evalcond[0]) < 0.0000010000000000  && IKabs(evalcond[1]) < 0.0000010000000000  && IKabs(evalcond[2]) < 0.0000010000000000  && IKabs(evalcond[3]) < 0.0000010000000000  && IKabs(evalcond[4]) < 0.0000010000000000  && IKabs(evalcond[5]) < 0.0000010000000000  && IKabs(evalcond[6]) < 0.0000010000000000  && IKabs(evalcond[7]) < 0.0000010000000000  && IKabs(evalcond[8]) < 0.0000010000000000  )
{
{
IkReal j3array[1], cj3array[1], sj3array[1];
bool j3valid[1]={false};
_nj3 = 1;
IkReal x8058=((r20)*(sj6));
IkReal x8059=((cj4)*(cj5));
IkReal x8060=((cj6)*(r21));
if( IKabs(((((IkReal(-1.00000000000000))*(r21)*(sj4)*(sj6)))+(((x8059)*(x8060)))+(((cj6)*(r20)*(sj4)))+(((cj4)*(r22)*(sj5)))+(((x8058)*(x8059))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(((((sj5)*(x8058)))+(((IkReal(-1.00000000000000))*(cj5)*(r22)))+(((sj5)*(x8060))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(IKsqr(((((IkReal(-1.00000000000000))*(r21)*(sj4)*(sj6)))+(((x8059)*(x8060)))+(((cj6)*(r20)*(sj4)))+(((cj4)*(r22)*(sj5)))+(((x8058)*(x8059)))))+IKsqr(((((sj5)*(x8058)))+(((IkReal(-1.00000000000000))*(cj5)*(r22)))+(((sj5)*(x8060)))))-1) <= IKFAST_SINCOS_THRESH )
    continue;
j3array[0]=IKatan2(((((IkReal(-1.00000000000000))*(r21)*(sj4)*(sj6)))+(((x8059)*(x8060)))+(((cj6)*(r20)*(sj4)))+(((cj4)*(r22)*(sj5)))+(((x8058)*(x8059)))), ((((sj5)*(x8058)))+(((IkReal(-1.00000000000000))*(cj5)*(r22)))+(((sj5)*(x8060)))));
sj3array[0]=IKsin(j3array[0]);
cj3array[0]=IKcos(j3array[0]);
if( j3array[0] > IKPI )
{
    j3array[0]-=IK2PI;
}
else if( j3array[0] < -IKPI )
{    j3array[0]+=IK2PI;
}
j3valid[0] = true;
for(int ij3 = 0; ij3 < 1; ++ij3)
{
if( !j3valid[ij3] )
{
    continue;
}
_ij3[0] = ij3; _ij3[1] = -1;
for(int iij3 = ij3+1; iij3 < 1; ++iij3)
{
if( j3valid[iij3] && IKabs(cj3array[ij3]-cj3array[iij3]) < IKFAST_SOLUTION_THRESH && IKabs(sj3array[ij3]-sj3array[iij3]) < IKFAST_SOLUTION_THRESH )
{
    j3valid[iij3]=false; _ij3[1] = iij3; break; 
}
}
j3 = j3array[ij3]; cj3 = cj3array[ij3]; sj3 = sj3array[ij3];
{
IkReal evalcond[4];
IkReal x8061=IKcos(j3);
IkReal x8062=((sj0)*(sj5));
IkReal x8063=((r00)*(sj6));
IkReal x8064=((cj6)*(r01));
IkReal x8065=((cj5)*(sj0));
IkReal x8066=((cj0)*(cj5));
IkReal x8067=((cj6)*(sj4));
IkReal x8068=((sj4)*(sj6));
IkReal x8069=((cj0)*(r11));
IkReal x8070=((cj4)*(cj6));
IkReal x8071=((cj4)*(sj6));
IkReal x8072=((IkReal(1.00000000000000))*(cj0));
IkReal x8073=((cj4)*(sj5));
IkReal x8074=((sj5)*(sj6));
IkReal x8075=((cj6)*(sj5));
IkReal x8076=((IkReal(1.00000000000000))*(IKsin(j3)));
evalcond[0]=((((IkReal(-1.00000000000000))*(cj5)*(r22)))+(((r21)*(x8075)))+(((r20)*(x8074)))+(((IkReal(-1.00000000000000))*(x8061))));
evalcond[1]=((((cj5)*(r21)*(x8070)))+(((r20)*(x8067)))+(((IkReal(-1.00000000000000))*(x8076)))+(((cj5)*(r20)*(x8071)))+(((IkReal(-1.00000000000000))*(r21)*(x8068)))+(((r22)*(x8073))));
evalcond[2]=((((IkReal(-1.00000000000000))*(r02)*(x8065)))+(((IkReal(-1.00000000000000))*(x8069)*(x8075)))+(((x8062)*(x8064)))+(((IkReal(-1.00000000000000))*(x8076)))+(((r12)*(x8066)))+(((IkReal(-1.00000000000000))*(r10)*(x8072)*(x8074)))+(((x8062)*(x8063))));
evalcond[3]=((((x8068)*(x8069)))+(((IkReal(-1.00000000000000))*(r11)*(x8066)*(x8070)))+(((IkReal(-1.00000000000000))*(r12)*(x8072)*(x8073)))+(((cj4)*(x8063)*(x8065)))+(((cj4)*(x8064)*(x8065)))+(x8061)+(((cj4)*(r02)*(x8062)))+(((IkReal(-1.00000000000000))*(r01)*(sj0)*(x8068)))+(((IkReal(-1.00000000000000))*(r10)*(x8066)*(x8071)))+(((r00)*(sj0)*(x8067)))+(((IkReal(-1.00000000000000))*(r10)*(x8067)*(x8072))));
if( IKabs(evalcond[0]) > 0.000001  || IKabs(evalcond[1]) > 0.000001  || IKabs(evalcond[2]) > 0.000001  || IKabs(evalcond[3]) > 0.000001  )
{
continue;
}
}

{
std::vector<IkSingleDOFSolutionBase<IkReal> > vinfos(7);
vinfos[0].jointtype = 1;
vinfos[0].foffset = j0;
vinfos[0].indices[0] = _ij0[0];
vinfos[0].indices[1] = _ij0[1];
vinfos[0].maxsolutions = _nj0;
vinfos[1].jointtype = 1;
vinfos[1].foffset = j1;
vinfos[1].indices[0] = _ij1[0];
vinfos[1].indices[1] = _ij1[1];
vinfos[1].maxsolutions = _nj1;
vinfos[2].jointtype = 1;
vinfos[2].foffset = j2;
vinfos[2].indices[0] = _ij2[0];
vinfos[2].indices[1] = _ij2[1];
vinfos[2].maxsolutions = _nj2;
vinfos[3].jointtype = 1;
vinfos[3].foffset = j3;
vinfos[3].indices[0] = _ij3[0];
vinfos[3].indices[1] = _ij3[1];
vinfos[3].maxsolutions = _nj3;
vinfos[4].jointtype = 1;
vinfos[4].foffset = j4;
vinfos[4].indices[0] = _ij4[0];
vinfos[4].indices[1] = _ij4[1];
vinfos[4].maxsolutions = _nj4;
vinfos[5].jointtype = 1;
vinfos[5].foffset = j5;
vinfos[5].indices[0] = _ij5[0];
vinfos[5].indices[1] = _ij5[1];
vinfos[5].maxsolutions = _nj5;
vinfos[6].jointtype = 1;
vinfos[6].foffset = j6;
vinfos[6].indices[0] = _ij6[0];
vinfos[6].indices[1] = _ij6[1];
vinfos[6].maxsolutions = _nj6;
std::vector<int> vfree(0);
solutions.AddSolution(vinfos,vfree);
}
}
}

} else
{
IkReal x8077=((IkReal(1.00000000000000))*(cj0));
IkReal x8078=((cj4)*(sj6));
IkReal x8079=((sj0)*(sj6));
IkReal x8080=((cj5)*(sj4));
IkReal x8081=((IkReal(0.374290000000000))*(sj5));
IkReal x8082=((sj4)*(sj5));
IkReal x8083=((cj0)*(cj6));
IkReal x8084=((IkReal(0.0100000000000000))*(cj5));
IkReal x8085=((cj4)*(sj5));
IkReal x8086=((cj5)*(sj0));
IkReal x8087=((IkReal(0.374290000000000))*(r02));
IkReal x8088=((r20)*(sj6));
IkReal x8089=((cj6)*(r21));
IkReal x8090=((IkReal(1.00000000000000))*(sj0));
IkReal x8091=((cj0)*(sj6));
IkReal x8092=((cj4)*(cj6));
IkReal x8093=((IkReal(0.374290000000000))*(r12));
IkReal x8094=((cj0)*(cj5));
IkReal x8095=((cj6)*(sj5));
IkReal x8096=((cj6)*(r01));
IkReal x8097=((r00)*(sj6));
IkReal x8098=((IkReal(0.0100000000000000))*(sj5));
IkReal x8099=((cj6)*(r11));
IkReal x8100=((IkReal(1.00000000000000))*(r10));
IkReal x8101=((r02)*(sj0));
IkReal x8102=((cj6)*(sj4));
IkReal x8103=((r12)*(x8090));
evalcond[0]=((IkReal(-3.14159265358979))+(IKfmod(((IkReal(4.71238898038469))+(j1)), IkReal(6.28318530717959))));
evalcond[1]=((((x8080)*(x8089)))+(((r21)*(x8078)))+(((x8080)*(x8088)))+(((r22)*(x8082)))+(((IkReal(-1.00000000000000))*(r20)*(x8092))));
evalcond[2]=((IkReal(-0.364420000000000))+(((IkReal(-1.00000000000000))*(x8084)*(x8089)))+(((IkReal(-0.374290000000000))*(cj5)*(r22)))+(((x8081)*(x8088)))+(pz)+(((IkReal(-1.00000000000000))*(x8084)*(x8088)))+(((IkReal(-1.00000000000000))*(r22)*(x8098)))+(((x8081)*(x8089))));
evalcond[3]=((((IkReal(-1.00000000000000))*(sj5)*(x8077)*(x8097)))+(((IkReal(-1.00000000000000))*(r11)*(x8090)*(x8095)))+(((r02)*(x8094)))+(((IkReal(-1.00000000000000))*(sj5)*(x8079)*(x8100)))+(((r12)*(x8086)))+(((IkReal(-1.00000000000000))*(r01)*(x8077)*(x8095))));
evalcond[4]=((((IkReal(-1.00000000000000))*(r12)*(x8077)*(x8082)))+(((r00)*(x8079)*(x8080)))+(((IkReal(-1.00000000000000))*(r11)*(x8077)*(x8078)))+(((IkReal(-1.00000000000000))*(x8077)*(x8080)*(x8099)))+(((IkReal(-1.00000000000000))*(r00)*(x8090)*(x8092)))+(((x8082)*(x8101)))+(((cj4)*(r10)*(x8083)))+(((r01)*(sj0)*(x8078)))+(((sj0)*(x8080)*(x8096)))+(((IkReal(-1.00000000000000))*(r10)*(sj6)*(x8077)*(x8080))));
evalcond[5]=((IkReal(-1.00000000000000))+(((r10)*(sj0)*(x8092)))+(((IkReal(-1.00000000000000))*(x8077)*(x8080)*(x8097)))+(((IkReal(-1.00000000000000))*(r02)*(x8077)*(x8082)))+(((IkReal(-1.00000000000000))*(x8077)*(x8080)*(x8096)))+(((IkReal(-1.00000000000000))*(x8079)*(x8080)*(x8100)))+(((IkReal(-1.00000000000000))*(r11)*(x8078)*(x8090)))+(((IkReal(-1.00000000000000))*(x8082)*(x8103)))+(((IkReal(-1.00000000000000))*(r01)*(x8077)*(x8078)))+(((IkReal(-1.00000000000000))*(x8080)*(x8090)*(x8099)))+(((cj4)*(r00)*(x8083))));
evalcond[6]=((IkReal(0.0690000000000000))+(((IkReal(-1.00000000000000))*(r00)*(x8079)*(x8084)))+(((IkReal(-1.00000000000000))*(sj0)*(x8084)*(x8096)))+(((cj0)*(r12)*(x8098)))+(((IkReal(-1.00000000000000))*(r10)*(x8081)*(x8091)))+(((sj0)*(x8081)*(x8096)))+(((r10)*(x8084)*(x8091)))+(((r00)*(x8079)*(x8081)))+(((IkReal(-1.00000000000000))*(x8086)*(x8087)))+(((r11)*(x8083)*(x8084)))+(((IkReal(-1.00000000000000))*(py)*(x8077)))+(((px)*(sj0)))+(((IkReal(-1.00000000000000))*(r11)*(x8081)*(x8083)))+(((x8093)*(x8094)))+(((IkReal(-1.00000000000000))*(x8098)*(x8101))));
evalcond[7]=((((IkReal(-1.00000000000000))*(cj5)*(r00)*(x8077)*(x8078)))+(((r01)*(sj4)*(x8091)))+(((IkReal(-1.00000000000000))*(r10)*(x8090)*(x8102)))+(((IkReal(-1.00000000000000))*(r00)*(x8077)*(x8102)))+(((r11)*(sj4)*(x8079)))+(((IkReal(-1.00000000000000))*(r11)*(x8086)*(x8092)))+(((IkReal(-1.00000000000000))*(cj5)*(r01)*(x8077)*(x8092)))+(((IkReal(-1.00000000000000))*(r02)*(x8077)*(x8085)))+(((IkReal(-1.00000000000000))*(x8085)*(x8103)))+(((IkReal(-1.00000000000000))*(x8078)*(x8086)*(x8100))));
evalcond[8]=((IkReal(0.0690000000000000))+(((cj0)*(r02)*(x8098)))+(((IkReal(-1.00000000000000))*(r10)*(x8079)*(x8081)))+(((IkReal(-1.00000000000000))*(py)*(x8090)))+(((r12)*(sj0)*(x8098)))+(((r00)*(x8084)*(x8091)))+(((x8086)*(x8093)))+(((IkReal(-1.00000000000000))*(r00)*(x8081)*(x8091)))+(((IkReal(-1.00000000000000))*(px)*(x8077)))+(((r10)*(x8079)*(x8084)))+(((sj0)*(x8084)*(x8099)))+(((IkReal(-1.00000000000000))*(sj0)*(x8081)*(x8099)))+(((IkReal(-1.00000000000000))*(r01)*(x8081)*(x8083)))+(((r01)*(x8083)*(x8084)))+(((x8087)*(x8094))));
if( IKabs(evalcond[0]) < 0.0000010000000000  && IKabs(evalcond[1]) < 0.0000010000000000  && IKabs(evalcond[2]) < 0.0000010000000000  && IKabs(evalcond[3]) < 0.0000010000000000  && IKabs(evalcond[4]) < 0.0000010000000000  && IKabs(evalcond[5]) < 0.0000010000000000  && IKabs(evalcond[6]) < 0.0000010000000000  && IKabs(evalcond[7]) < 0.0000010000000000  && IKabs(evalcond[8]) < 0.0000010000000000  )
{
{
IkReal j3array[1], cj3array[1], sj3array[1];
bool j3valid[1]={false};
_nj3 = 1;
IkReal x8104=((IkReal(1.00000000000000))*(sj5));
IkReal x8105=((cj6)*(r21));
IkReal x8106=((r20)*(sj6));
IkReal x8107=((IkReal(1.00000000000000))*(cj4)*(cj5));
if( IKabs(((((IkReal(-1.00000000000000))*(x8105)*(x8107)))+(((IkReal(-1.00000000000000))*(cj4)*(r22)*(x8104)))+(((r21)*(sj4)*(sj6)))+(((IkReal(-1.00000000000000))*(x8106)*(x8107)))+(((IkReal(-1.00000000000000))*(cj6)*(r20)*(sj4))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(((((IkReal(-1.00000000000000))*(x8104)*(x8105)))+(((IkReal(-1.00000000000000))*(x8104)*(x8106)))+(((cj5)*(r22))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(IKsqr(((((IkReal(-1.00000000000000))*(x8105)*(x8107)))+(((IkReal(-1.00000000000000))*(cj4)*(r22)*(x8104)))+(((r21)*(sj4)*(sj6)))+(((IkReal(-1.00000000000000))*(x8106)*(x8107)))+(((IkReal(-1.00000000000000))*(cj6)*(r20)*(sj4)))))+IKsqr(((((IkReal(-1.00000000000000))*(x8104)*(x8105)))+(((IkReal(-1.00000000000000))*(x8104)*(x8106)))+(((cj5)*(r22)))))-1) <= IKFAST_SINCOS_THRESH )
    continue;
j3array[0]=IKatan2(((((IkReal(-1.00000000000000))*(x8105)*(x8107)))+(((IkReal(-1.00000000000000))*(cj4)*(r22)*(x8104)))+(((r21)*(sj4)*(sj6)))+(((IkReal(-1.00000000000000))*(x8106)*(x8107)))+(((IkReal(-1.00000000000000))*(cj6)*(r20)*(sj4)))), ((((IkReal(-1.00000000000000))*(x8104)*(x8105)))+(((IkReal(-1.00000000000000))*(x8104)*(x8106)))+(((cj5)*(r22)))));
sj3array[0]=IKsin(j3array[0]);
cj3array[0]=IKcos(j3array[0]);
if( j3array[0] > IKPI )
{
    j3array[0]-=IK2PI;
}
else if( j3array[0] < -IKPI )
{    j3array[0]+=IK2PI;
}
j3valid[0] = true;
for(int ij3 = 0; ij3 < 1; ++ij3)
{
if( !j3valid[ij3] )
{
    continue;
}
_ij3[0] = ij3; _ij3[1] = -1;
for(int iij3 = ij3+1; iij3 < 1; ++iij3)
{
if( j3valid[iij3] && IKabs(cj3array[ij3]-cj3array[iij3]) < IKFAST_SOLUTION_THRESH && IKabs(sj3array[ij3]-sj3array[iij3]) < IKFAST_SOLUTION_THRESH )
{
    j3valid[iij3]=false; _ij3[1] = iij3; break; 
}
}
j3 = j3array[ij3]; cj3 = cj3array[ij3]; sj3 = sj3array[ij3];
{
IkReal evalcond[4];
IkReal x8108=IKsin(j3);
IkReal x8109=IKcos(j3);
IkReal x8110=((sj0)*(sj5));
IkReal x8111=((r00)*(sj6));
IkReal x8112=((cj6)*(r01));
IkReal x8113=((cj5)*(sj0));
IkReal x8114=((cj0)*(cj5));
IkReal x8115=((cj6)*(sj4));
IkReal x8116=((sj4)*(sj6));
IkReal x8117=((cj0)*(r11));
IkReal x8118=((cj4)*(cj6));
IkReal x8119=((cj4)*(sj6));
IkReal x8120=((IkReal(1.00000000000000))*(cj0));
IkReal x8121=((cj4)*(sj5));
IkReal x8122=((sj5)*(sj6));
IkReal x8123=((cj6)*(sj5));
evalcond[0]=((x8109)+(((r21)*(x8123)))+(((IkReal(-1.00000000000000))*(cj5)*(r22)))+(((r20)*(x8122))));
evalcond[1]=((((IkReal(-1.00000000000000))*(r21)*(x8116)))+(((cj5)*(r20)*(x8119)))+(x8108)+(((r20)*(x8115)))+(((r22)*(x8121)))+(((cj5)*(r21)*(x8118))));
evalcond[2]=((((IkReal(-1.00000000000000))*(x8108)))+(((r12)*(x8114)))+(((IkReal(-1.00000000000000))*(r10)*(x8120)*(x8122)))+(((x8110)*(x8111)))+(((x8110)*(x8112)))+(((IkReal(-1.00000000000000))*(r02)*(x8113)))+(((IkReal(-1.00000000000000))*(x8117)*(x8123))));
evalcond[3]=((((IkReal(-1.00000000000000))*(r11)*(x8114)*(x8118)))+(((cj4)*(x8111)*(x8113)))+(((IkReal(-1.00000000000000))*(r10)*(x8115)*(x8120)))+(x8109)+(((IkReal(-1.00000000000000))*(r01)*(sj0)*(x8116)))+(((x8116)*(x8117)))+(((cj4)*(x8112)*(x8113)))+(((IkReal(-1.00000000000000))*(r10)*(x8114)*(x8119)))+(((cj4)*(r02)*(x8110)))+(((r00)*(sj0)*(x8115)))+(((IkReal(-1.00000000000000))*(r12)*(x8120)*(x8121))));
if( IKabs(evalcond[0]) > 0.000001  || IKabs(evalcond[1]) > 0.000001  || IKabs(evalcond[2]) > 0.000001  || IKabs(evalcond[3]) > 0.000001  )
{
continue;
}
}

{
std::vector<IkSingleDOFSolutionBase<IkReal> > vinfos(7);
vinfos[0].jointtype = 1;
vinfos[0].foffset = j0;
vinfos[0].indices[0] = _ij0[0];
vinfos[0].indices[1] = _ij0[1];
vinfos[0].maxsolutions = _nj0;
vinfos[1].jointtype = 1;
vinfos[1].foffset = j1;
vinfos[1].indices[0] = _ij1[0];
vinfos[1].indices[1] = _ij1[1];
vinfos[1].maxsolutions = _nj1;
vinfos[2].jointtype = 1;
vinfos[2].foffset = j2;
vinfos[2].indices[0] = _ij2[0];
vinfos[2].indices[1] = _ij2[1];
vinfos[2].maxsolutions = _nj2;
vinfos[3].jointtype = 1;
vinfos[3].foffset = j3;
vinfos[3].indices[0] = _ij3[0];
vinfos[3].indices[1] = _ij3[1];
vinfos[3].maxsolutions = _nj3;
vinfos[4].jointtype = 1;
vinfos[4].foffset = j4;
vinfos[4].indices[0] = _ij4[0];
vinfos[4].indices[1] = _ij4[1];
vinfos[4].maxsolutions = _nj4;
vinfos[5].jointtype = 1;
vinfos[5].foffset = j5;
vinfos[5].indices[0] = _ij5[0];
vinfos[5].indices[1] = _ij5[1];
vinfos[5].maxsolutions = _nj5;
vinfos[6].jointtype = 1;
vinfos[6].foffset = j6;
vinfos[6].indices[0] = _ij6[0];
vinfos[6].indices[1] = _ij6[1];
vinfos[6].maxsolutions = _nj6;
std::vector<int> vfree(0);
solutions.AddSolution(vinfos,vfree);
}
}
}

} else
{
if( 1 )
{
continue;

} else
{
}
}
}
}

} else
{
{
IkReal j3array[1], cj3array[1], sj3array[1];
bool j3valid[1]={false};
_nj3 = 1;
IkReal x8124=((cj0)*(cj5));
IkReal x8125=((IkReal(1.00000000000000))*(cj0));
IkReal x8126=((cj6)*(r11));
IkReal x8127=((r10)*(sj6));
IkReal x8128=((cj5)*(sj0));
IkReal x8129=((r00)*(sj5)*(sj6));
IkReal x8130=((cj6)*(r01)*(sj5));
IkReal x8131=((IkReal(1.00000000000000))*(sj0)*(sj5));
if( IKabs(((((r12)*(x8124)))+(((IkReal(-1.00000000000000))*(r02)*(x8128)))+(((sj0)*(x8129)))+(((sj0)*(x8130)))+(((IkReal(-1.00000000000000))*(sj5)*(x8125)*(x8127)))+(((IkReal(-1.00000000000000))*(sj5)*(x8125)*(x8126))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(((((IKabs(cj1) != 0)?((IkReal)1/(cj1)):(IkReal)1.0e30))*(((((IkReal(-1.00000000000000))*(x8125)*(x8130)))+(((IkReal(-1.00000000000000))*(x8125)*(x8129)))+(((r12)*(x8128)))+(((IkReal(-1.00000000000000))*(x8127)*(x8131)))+(((IkReal(-1.00000000000000))*(x8126)*(x8131)))+(((r02)*(x8124))))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(IKsqr(((((r12)*(x8124)))+(((IkReal(-1.00000000000000))*(r02)*(x8128)))+(((sj0)*(x8129)))+(((sj0)*(x8130)))+(((IkReal(-1.00000000000000))*(sj5)*(x8125)*(x8127)))+(((IkReal(-1.00000000000000))*(sj5)*(x8125)*(x8126)))))+IKsqr(((((IKabs(cj1) != 0)?((IkReal)1/(cj1)):(IkReal)1.0e30))*(((((IkReal(-1.00000000000000))*(x8125)*(x8130)))+(((IkReal(-1.00000000000000))*(x8125)*(x8129)))+(((r12)*(x8128)))+(((IkReal(-1.00000000000000))*(x8127)*(x8131)))+(((IkReal(-1.00000000000000))*(x8126)*(x8131)))+(((r02)*(x8124)))))))-1) <= IKFAST_SINCOS_THRESH )
    continue;
j3array[0]=IKatan2(((((r12)*(x8124)))+(((IkReal(-1.00000000000000))*(r02)*(x8128)))+(((sj0)*(x8129)))+(((sj0)*(x8130)))+(((IkReal(-1.00000000000000))*(sj5)*(x8125)*(x8127)))+(((IkReal(-1.00000000000000))*(sj5)*(x8125)*(x8126)))), ((((IKabs(cj1) != 0)?((IkReal)1/(cj1)):(IkReal)1.0e30))*(((((IkReal(-1.00000000000000))*(x8125)*(x8130)))+(((IkReal(-1.00000000000000))*(x8125)*(x8129)))+(((r12)*(x8128)))+(((IkReal(-1.00000000000000))*(x8127)*(x8131)))+(((IkReal(-1.00000000000000))*(x8126)*(x8131)))+(((r02)*(x8124)))))));
sj3array[0]=IKsin(j3array[0]);
cj3array[0]=IKcos(j3array[0]);
if( j3array[0] > IKPI )
{
    j3array[0]-=IK2PI;
}
else if( j3array[0] < -IKPI )
{    j3array[0]+=IK2PI;
}
j3valid[0] = true;
for(int ij3 = 0; ij3 < 1; ++ij3)
{
if( !j3valid[ij3] )
{
    continue;
}
_ij3[0] = ij3; _ij3[1] = -1;
for(int iij3 = ij3+1; iij3 < 1; ++iij3)
{
if( j3valid[iij3] && IKabs(cj3array[ij3]-cj3array[iij3]) < IKFAST_SOLUTION_THRESH && IKabs(sj3array[ij3]-sj3array[iij3]) < IKFAST_SOLUTION_THRESH )
{
    j3valid[iij3]=false; _ij3[1] = iij3; break; 
}
}
j3 = j3array[ij3]; cj3 = cj3array[ij3]; sj3 = sj3array[ij3];
{
IkReal evalcond[6];
IkReal x8132=IKsin(j3);
IkReal x8133=IKcos(j3);
IkReal x8134=((sj0)*(sj5));
IkReal x8135=((r00)*(sj6));
IkReal x8136=((cj6)*(r01));
IkReal x8137=((cj4)*(cj5));
IkReal x8138=((IkReal(1.00000000000000))*(cj0));
IkReal x8139=((cj5)*(r12));
IkReal x8140=((IkReal(1.00000000000000))*(sj0));
IkReal x8141=((cj6)*(r11));
IkReal x8142=((cj5)*(r02));
IkReal x8143=((IkReal(1.00000000000000))*(cj1));
IkReal x8144=((cj6)*(sj4));
IkReal x8145=((cj6)*(r21));
IkReal x8146=((r20)*(sj6));
IkReal x8147=((r10)*(sj6));
IkReal x8148=((sj4)*(sj6));
IkReal x8149=((cj4)*(r02));
IkReal x8150=((IkReal(1.00000000000000))*(cj4)*(r12));
IkReal x8151=((IkReal(1.00000000000000))*(x8132));
IkReal x8152=((cj0)*(x8148));
evalcond[0]=((((sj5)*(x8146)))+(((IkReal(-1.00000000000000))*(sj1)*(x8133)))+(((IkReal(-1.00000000000000))*(cj5)*(r22)))+(((sj5)*(x8145))));
evalcond[1]=((((r20)*(x8144)))+(((IkReal(-1.00000000000000))*(r21)*(x8148)))+(((cj4)*(r22)*(sj5)))+(((IkReal(-1.00000000000000))*(sj1)*(x8151)))+(((x8137)*(x8146)))+(((x8137)*(x8145))));
evalcond[2]=((((IkReal(-1.00000000000000))*(sj5)*(x8138)*(x8147)))+(((IkReal(-1.00000000000000))*(x8151)))+(((IkReal(-1.00000000000000))*(x8140)*(x8142)))+(((x8134)*(x8136)))+(((IkReal(-1.00000000000000))*(sj5)*(x8138)*(x8141)))+(((cj0)*(x8139)))+(((x8134)*(x8135))));
evalcond[3]=((((IkReal(-1.00000000000000))*(x8134)*(x8147)))+(((IkReal(-1.00000000000000))*(sj5)*(x8135)*(x8138)))+(((IkReal(-1.00000000000000))*(sj5)*(x8136)*(x8138)))+(((cj0)*(x8142)))+(((IkReal(-1.00000000000000))*(x8134)*(x8141)))+(((sj0)*(x8139)))+(((IkReal(-1.00000000000000))*(x8133)*(x8143))));
evalcond[4]=((((x8134)*(x8149)))+(x8133)+(((IkReal(-1.00000000000000))*(r10)*(x8138)*(x8144)))+(((r11)*(x8152)))+(((IkReal(-1.00000000000000))*(cj4)*(r12)*(sj5)*(x8138)))+(((r00)*(sj0)*(x8144)))+(((IkReal(-1.00000000000000))*(x8137)*(x8138)*(x8141)))+(((sj0)*(x8135)*(x8137)))+(((sj0)*(x8136)*(x8137)))+(((IkReal(-1.00000000000000))*(x8137)*(x8138)*(x8147)))+(((IkReal(-1.00000000000000))*(r01)*(x8140)*(x8148))));
evalcond[5]=((((IkReal(-1.00000000000000))*(r00)*(x8138)*(x8144)))+(((IkReal(-1.00000000000000))*(x8137)*(x8140)*(x8141)))+(((IkReal(-1.00000000000000))*(sj5)*(x8138)*(x8149)))+(((IkReal(-1.00000000000000))*(r10)*(x8140)*(x8144)))+(((IkReal(-1.00000000000000))*(x8137)*(x8140)*(x8147)))+(((r11)*(sj0)*(x8148)))+(((IkReal(-1.00000000000000))*(x8134)*(x8150)))+(((r01)*(x8152)))+(((IkReal(-1.00000000000000))*(x8136)*(x8137)*(x8138)))+(((IkReal(-1.00000000000000))*(x8135)*(x8137)*(x8138)))+(((IkReal(-1.00000000000000))*(x8132)*(x8143))));
if( IKabs(evalcond[0]) > 0.000001  || IKabs(evalcond[1]) > 0.000001  || IKabs(evalcond[2]) > 0.000001  || IKabs(evalcond[3]) > 0.000001  || IKabs(evalcond[4]) > 0.000001  || IKabs(evalcond[5]) > 0.000001  )
{
continue;
}
}

{
std::vector<IkSingleDOFSolutionBase<IkReal> > vinfos(7);
vinfos[0].jointtype = 1;
vinfos[0].foffset = j0;
vinfos[0].indices[0] = _ij0[0];
vinfos[0].indices[1] = _ij0[1];
vinfos[0].maxsolutions = _nj0;
vinfos[1].jointtype = 1;
vinfos[1].foffset = j1;
vinfos[1].indices[0] = _ij1[0];
vinfos[1].indices[1] = _ij1[1];
vinfos[1].maxsolutions = _nj1;
vinfos[2].jointtype = 1;
vinfos[2].foffset = j2;
vinfos[2].indices[0] = _ij2[0];
vinfos[2].indices[1] = _ij2[1];
vinfos[2].maxsolutions = _nj2;
vinfos[3].jointtype = 1;
vinfos[3].foffset = j3;
vinfos[3].indices[0] = _ij3[0];
vinfos[3].indices[1] = _ij3[1];
vinfos[3].maxsolutions = _nj3;
vinfos[4].jointtype = 1;
vinfos[4].foffset = j4;
vinfos[4].indices[0] = _ij4[0];
vinfos[4].indices[1] = _ij4[1];
vinfos[4].maxsolutions = _nj4;
vinfos[5].jointtype = 1;
vinfos[5].foffset = j5;
vinfos[5].indices[0] = _ij5[0];
vinfos[5].indices[1] = _ij5[1];
vinfos[5].maxsolutions = _nj5;
vinfos[6].jointtype = 1;
vinfos[6].foffset = j6;
vinfos[6].indices[0] = _ij6[0];
vinfos[6].indices[1] = _ij6[1];
vinfos[6].maxsolutions = _nj6;
std::vector<int> vfree(0);
solutions.AddSolution(vinfos,vfree);
}
}
}

}

}

} else
{
{
IkReal j3array[1], cj3array[1], sj3array[1];
bool j3valid[1]={false};
_nj3 = 1;
IkReal x8153=((sj5)*(sj6));
IkReal x8154=((cj6)*(sj5));
IkReal x8155=((IkReal(1.00000000000000))*(cj0));
IkReal x8156=((IkReal(1.00000000000000))*(cj5));
if( IKabs(((((IkReal(-1.00000000000000))*(r02)*(sj0)*(x8156)))+(((r01)*(sj0)*(x8154)))+(((cj0)*(cj5)*(r12)))+(((IkReal(-1.00000000000000))*(r10)*(x8153)*(x8155)))+(((r00)*(sj0)*(x8153)))+(((IkReal(-1.00000000000000))*(r11)*(x8154)*(x8155))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(((((IKabs(sj1) != 0)?((IkReal)1/(sj1)):(IkReal)1.0e30))*(((((r20)*(x8153)))+(((r21)*(x8154)))+(((IkReal(-1.00000000000000))*(r22)*(x8156))))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(IKsqr(((((IkReal(-1.00000000000000))*(r02)*(sj0)*(x8156)))+(((r01)*(sj0)*(x8154)))+(((cj0)*(cj5)*(r12)))+(((IkReal(-1.00000000000000))*(r10)*(x8153)*(x8155)))+(((r00)*(sj0)*(x8153)))+(((IkReal(-1.00000000000000))*(r11)*(x8154)*(x8155)))))+IKsqr(((((IKabs(sj1) != 0)?((IkReal)1/(sj1)):(IkReal)1.0e30))*(((((r20)*(x8153)))+(((r21)*(x8154)))+(((IkReal(-1.00000000000000))*(r22)*(x8156)))))))-1) <= IKFAST_SINCOS_THRESH )
    continue;
j3array[0]=IKatan2(((((IkReal(-1.00000000000000))*(r02)*(sj0)*(x8156)))+(((r01)*(sj0)*(x8154)))+(((cj0)*(cj5)*(r12)))+(((IkReal(-1.00000000000000))*(r10)*(x8153)*(x8155)))+(((r00)*(sj0)*(x8153)))+(((IkReal(-1.00000000000000))*(r11)*(x8154)*(x8155)))), ((((IKabs(sj1) != 0)?((IkReal)1/(sj1)):(IkReal)1.0e30))*(((((r20)*(x8153)))+(((r21)*(x8154)))+(((IkReal(-1.00000000000000))*(r22)*(x8156)))))));
sj3array[0]=IKsin(j3array[0]);
cj3array[0]=IKcos(j3array[0]);
if( j3array[0] > IKPI )
{
    j3array[0]-=IK2PI;
}
else if( j3array[0] < -IKPI )
{    j3array[0]+=IK2PI;
}
j3valid[0] = true;
for(int ij3 = 0; ij3 < 1; ++ij3)
{
if( !j3valid[ij3] )
{
    continue;
}
_ij3[0] = ij3; _ij3[1] = -1;
for(int iij3 = ij3+1; iij3 < 1; ++iij3)
{
if( j3valid[iij3] && IKabs(cj3array[ij3]-cj3array[iij3]) < IKFAST_SOLUTION_THRESH && IKabs(sj3array[ij3]-sj3array[iij3]) < IKFAST_SOLUTION_THRESH )
{
    j3valid[iij3]=false; _ij3[1] = iij3; break; 
}
}
j3 = j3array[ij3]; cj3 = cj3array[ij3]; sj3 = sj3array[ij3];
{
IkReal evalcond[6];
IkReal x8157=IKsin(j3);
IkReal x8158=IKcos(j3);
IkReal x8159=((sj0)*(sj5));
IkReal x8160=((r00)*(sj6));
IkReal x8161=((cj6)*(r01));
IkReal x8162=((cj4)*(cj5));
IkReal x8163=((IkReal(1.00000000000000))*(cj0));
IkReal x8164=((cj5)*(r12));
IkReal x8165=((IkReal(1.00000000000000))*(sj0));
IkReal x8166=((cj6)*(r11));
IkReal x8167=((cj5)*(r02));
IkReal x8168=((IkReal(1.00000000000000))*(cj1));
IkReal x8169=((cj6)*(sj4));
IkReal x8170=((cj6)*(r21));
IkReal x8171=((r20)*(sj6));
IkReal x8172=((r10)*(sj6));
IkReal x8173=((sj4)*(sj6));
IkReal x8174=((cj4)*(r02));
IkReal x8175=((IkReal(1.00000000000000))*(cj4)*(r12));
IkReal x8176=((IkReal(1.00000000000000))*(x8157));
IkReal x8177=((cj0)*(x8173));
evalcond[0]=((((sj5)*(x8171)))+(((IkReal(-1.00000000000000))*(sj1)*(x8158)))+(((IkReal(-1.00000000000000))*(cj5)*(r22)))+(((sj5)*(x8170))));
evalcond[1]=((((IkReal(-1.00000000000000))*(sj1)*(x8176)))+(((cj4)*(r22)*(sj5)))+(((r20)*(x8169)))+(((x8162)*(x8171)))+(((x8162)*(x8170)))+(((IkReal(-1.00000000000000))*(r21)*(x8173))));
evalcond[2]=((((IkReal(-1.00000000000000))*(x8176)))+(((x8159)*(x8160)))+(((IkReal(-1.00000000000000))*(sj5)*(x8163)*(x8172)))+(((IkReal(-1.00000000000000))*(sj5)*(x8163)*(x8166)))+(((cj0)*(x8164)))+(((x8159)*(x8161)))+(((IkReal(-1.00000000000000))*(x8165)*(x8167))));
evalcond[3]=((((IkReal(-1.00000000000000))*(x8158)*(x8168)))+(((IkReal(-1.00000000000000))*(sj5)*(x8161)*(x8163)))+(((sj0)*(x8164)))+(((IkReal(-1.00000000000000))*(x8159)*(x8172)))+(((IkReal(-1.00000000000000))*(x8159)*(x8166)))+(((cj0)*(x8167)))+(((IkReal(-1.00000000000000))*(sj5)*(x8160)*(x8163))));
evalcond[4]=((x8158)+(((IkReal(-1.00000000000000))*(x8162)*(x8163)*(x8166)))+(((x8159)*(x8174)))+(((sj0)*(x8161)*(x8162)))+(((r11)*(x8177)))+(((IkReal(-1.00000000000000))*(r01)*(x8165)*(x8173)))+(((IkReal(-1.00000000000000))*(x8162)*(x8163)*(x8172)))+(((IkReal(-1.00000000000000))*(cj4)*(r12)*(sj5)*(x8163)))+(((r00)*(sj0)*(x8169)))+(((sj0)*(x8160)*(x8162)))+(((IkReal(-1.00000000000000))*(r10)*(x8163)*(x8169))));
evalcond[5]=((((IkReal(-1.00000000000000))*(x8162)*(x8165)*(x8172)))+(((IkReal(-1.00000000000000))*(r10)*(x8165)*(x8169)))+(((IkReal(-1.00000000000000))*(x8157)*(x8168)))+(((r11)*(sj0)*(x8173)))+(((IkReal(-1.00000000000000))*(x8161)*(x8162)*(x8163)))+(((IkReal(-1.00000000000000))*(sj5)*(x8163)*(x8174)))+(((IkReal(-1.00000000000000))*(x8162)*(x8165)*(x8166)))+(((IkReal(-1.00000000000000))*(x8160)*(x8162)*(x8163)))+(((r01)*(x8177)))+(((IkReal(-1.00000000000000))*(x8159)*(x8175)))+(((IkReal(-1.00000000000000))*(r00)*(x8163)*(x8169))));
if( IKabs(evalcond[0]) > 0.000001  || IKabs(evalcond[1]) > 0.000001  || IKabs(evalcond[2]) > 0.000001  || IKabs(evalcond[3]) > 0.000001  || IKabs(evalcond[4]) > 0.000001  || IKabs(evalcond[5]) > 0.000001  )
{
continue;
}
}

{
std::vector<IkSingleDOFSolutionBase<IkReal> > vinfos(7);
vinfos[0].jointtype = 1;
vinfos[0].foffset = j0;
vinfos[0].indices[0] = _ij0[0];
vinfos[0].indices[1] = _ij0[1];
vinfos[0].maxsolutions = _nj0;
vinfos[1].jointtype = 1;
vinfos[1].foffset = j1;
vinfos[1].indices[0] = _ij1[0];
vinfos[1].indices[1] = _ij1[1];
vinfos[1].maxsolutions = _nj1;
vinfos[2].jointtype = 1;
vinfos[2].foffset = j2;
vinfos[2].indices[0] = _ij2[0];
vinfos[2].indices[1] = _ij2[1];
vinfos[2].maxsolutions = _nj2;
vinfos[3].jointtype = 1;
vinfos[3].foffset = j3;
vinfos[3].indices[0] = _ij3[0];
vinfos[3].indices[1] = _ij3[1];
vinfos[3].maxsolutions = _nj3;
vinfos[4].jointtype = 1;
vinfos[4].foffset = j4;
vinfos[4].indices[0] = _ij4[0];
vinfos[4].indices[1] = _ij4[1];
vinfos[4].maxsolutions = _nj4;
vinfos[5].jointtype = 1;
vinfos[5].foffset = j5;
vinfos[5].indices[0] = _ij5[0];
vinfos[5].indices[1] = _ij5[1];
vinfos[5].maxsolutions = _nj5;
vinfos[6].jointtype = 1;
vinfos[6].foffset = j6;
vinfos[6].indices[0] = _ij6[0];
vinfos[6].indices[1] = _ij6[1];
vinfos[6].maxsolutions = _nj6;
std::vector<int> vfree(0);
solutions.AddSolution(vinfos,vfree);
}
}
}

}

}

} else
{
{
IkReal j3array[1], cj3array[1], sj3array[1];
bool j3valid[1]={false};
_nj3 = 1;
IkReal x8178=((r20)*(sj6));
IkReal x8179=((cj4)*(cj5));
IkReal x8180=((cj6)*(r21));
if( IKabs(((gconst11)*(((((IkReal(-1.00000000000000))*(r21)*(sj4)*(sj6)))+(((cj6)*(r20)*(sj4)))+(((cj4)*(r22)*(sj5)))+(((x8178)*(x8179)))+(((x8179)*(x8180))))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(((gconst11)*(((((sj5)*(x8180)))+(((sj5)*(x8178)))+(((IkReal(-1.00000000000000))*(cj5)*(r22))))))) < IKFAST_ATAN2_MAGTHRESH )
    continue;
j3array[0]=IKatan2(((gconst11)*(((((IkReal(-1.00000000000000))*(r21)*(sj4)*(sj6)))+(((cj6)*(r20)*(sj4)))+(((cj4)*(r22)*(sj5)))+(((x8178)*(x8179)))+(((x8179)*(x8180)))))), ((gconst11)*(((((sj5)*(x8180)))+(((sj5)*(x8178)))+(((IkReal(-1.00000000000000))*(cj5)*(r22)))))));
sj3array[0]=IKsin(j3array[0]);
cj3array[0]=IKcos(j3array[0]);
if( j3array[0] > IKPI )
{
    j3array[0]-=IK2PI;
}
else if( j3array[0] < -IKPI )
{    j3array[0]+=IK2PI;
}
j3valid[0] = true;
for(int ij3 = 0; ij3 < 1; ++ij3)
{
if( !j3valid[ij3] )
{
    continue;
}
_ij3[0] = ij3; _ij3[1] = -1;
for(int iij3 = ij3+1; iij3 < 1; ++iij3)
{
if( j3valid[iij3] && IKabs(cj3array[ij3]-cj3array[iij3]) < IKFAST_SOLUTION_THRESH && IKabs(sj3array[ij3]-sj3array[iij3]) < IKFAST_SOLUTION_THRESH )
{
    j3valid[iij3]=false; _ij3[1] = iij3; break; 
}
}
j3 = j3array[ij3]; cj3 = cj3array[ij3]; sj3 = sj3array[ij3];
{
IkReal evalcond[6];
IkReal x8181=IKsin(j3);
IkReal x8182=IKcos(j3);
IkReal x8183=((sj0)*(sj5));
IkReal x8184=((r00)*(sj6));
IkReal x8185=((cj6)*(r01));
IkReal x8186=((cj4)*(cj5));
IkReal x8187=((IkReal(1.00000000000000))*(cj0));
IkReal x8188=((cj5)*(r12));
IkReal x8189=((IkReal(1.00000000000000))*(sj0));
IkReal x8190=((cj6)*(r11));
IkReal x8191=((cj5)*(r02));
IkReal x8192=((IkReal(1.00000000000000))*(cj1));
IkReal x8193=((cj6)*(sj4));
IkReal x8194=((cj6)*(r21));
IkReal x8195=((r20)*(sj6));
IkReal x8196=((r10)*(sj6));
IkReal x8197=((sj4)*(sj6));
IkReal x8198=((cj4)*(r02));
IkReal x8199=((IkReal(1.00000000000000))*(cj4)*(r12));
IkReal x8200=((IkReal(1.00000000000000))*(x8181));
IkReal x8201=((cj0)*(x8197));
evalcond[0]=((((sj5)*(x8194)))+(((sj5)*(x8195)))+(((IkReal(-1.00000000000000))*(cj5)*(r22)))+(((IkReal(-1.00000000000000))*(sj1)*(x8182))));
evalcond[1]=((((IkReal(-1.00000000000000))*(r21)*(x8197)))+(((IkReal(-1.00000000000000))*(sj1)*(x8200)))+(((cj4)*(r22)*(sj5)))+(((x8186)*(x8195)))+(((r20)*(x8193)))+(((x8186)*(x8194))));
evalcond[2]=((((IkReal(-1.00000000000000))*(x8200)))+(((cj0)*(x8188)))+(((x8183)*(x8185)))+(((IkReal(-1.00000000000000))*(x8189)*(x8191)))+(((x8183)*(x8184)))+(((IkReal(-1.00000000000000))*(sj5)*(x8187)*(x8196)))+(((IkReal(-1.00000000000000))*(sj5)*(x8187)*(x8190))));
evalcond[3]=((((IkReal(-1.00000000000000))*(sj5)*(x8185)*(x8187)))+(((IkReal(-1.00000000000000))*(x8183)*(x8190)))+(((IkReal(-1.00000000000000))*(x8183)*(x8196)))+(((IkReal(-1.00000000000000))*(sj5)*(x8184)*(x8187)))+(((IkReal(-1.00000000000000))*(x8182)*(x8192)))+(((sj0)*(x8188)))+(((cj0)*(x8191))));
evalcond[4]=((((IkReal(-1.00000000000000))*(x8186)*(x8187)*(x8190)))+(((IkReal(-1.00000000000000))*(r01)*(x8189)*(x8197)))+(((IkReal(-1.00000000000000))*(x8186)*(x8187)*(x8196)))+(x8182)+(((sj0)*(x8185)*(x8186)))+(((IkReal(-1.00000000000000))*(r10)*(x8187)*(x8193)))+(((r11)*(x8201)))+(((sj0)*(x8184)*(x8186)))+(((x8183)*(x8198)))+(((IkReal(-1.00000000000000))*(cj4)*(r12)*(sj5)*(x8187)))+(((r00)*(sj0)*(x8193))));
evalcond[5]=((((IkReal(-1.00000000000000))*(r10)*(x8189)*(x8193)))+(((IkReal(-1.00000000000000))*(x8185)*(x8186)*(x8187)))+(((IkReal(-1.00000000000000))*(x8186)*(x8189)*(x8196)))+(((IkReal(-1.00000000000000))*(x8183)*(x8199)))+(((r01)*(x8201)))+(((IkReal(-1.00000000000000))*(sj5)*(x8187)*(x8198)))+(((IkReal(-1.00000000000000))*(x8181)*(x8192)))+(((IkReal(-1.00000000000000))*(x8184)*(x8186)*(x8187)))+(((r11)*(sj0)*(x8197)))+(((IkReal(-1.00000000000000))*(x8186)*(x8189)*(x8190)))+(((IkReal(-1.00000000000000))*(r00)*(x8187)*(x8193))));
if( IKabs(evalcond[0]) > 0.000001  || IKabs(evalcond[1]) > 0.000001  || IKabs(evalcond[2]) > 0.000001  || IKabs(evalcond[3]) > 0.000001  || IKabs(evalcond[4]) > 0.000001  || IKabs(evalcond[5]) > 0.000001  )
{
continue;
}
}

{
std::vector<IkSingleDOFSolutionBase<IkReal> > vinfos(7);
vinfos[0].jointtype = 1;
vinfos[0].foffset = j0;
vinfos[0].indices[0] = _ij0[0];
vinfos[0].indices[1] = _ij0[1];
vinfos[0].maxsolutions = _nj0;
vinfos[1].jointtype = 1;
vinfos[1].foffset = j1;
vinfos[1].indices[0] = _ij1[0];
vinfos[1].indices[1] = _ij1[1];
vinfos[1].maxsolutions = _nj1;
vinfos[2].jointtype = 1;
vinfos[2].foffset = j2;
vinfos[2].indices[0] = _ij2[0];
vinfos[2].indices[1] = _ij2[1];
vinfos[2].maxsolutions = _nj2;
vinfos[3].jointtype = 1;
vinfos[3].foffset = j3;
vinfos[3].indices[0] = _ij3[0];
vinfos[3].indices[1] = _ij3[1];
vinfos[3].maxsolutions = _nj3;
vinfos[4].jointtype = 1;
vinfos[4].foffset = j4;
vinfos[4].indices[0] = _ij4[0];
vinfos[4].indices[1] = _ij4[1];
vinfos[4].maxsolutions = _nj4;
vinfos[5].jointtype = 1;
vinfos[5].foffset = j5;
vinfos[5].indices[0] = _ij5[0];
vinfos[5].indices[1] = _ij5[1];
vinfos[5].maxsolutions = _nj5;
vinfos[6].jointtype = 1;
vinfos[6].foffset = j6;
vinfos[6].indices[0] = _ij6[0];
vinfos[6].indices[1] = _ij6[1];
vinfos[6].maxsolutions = _nj6;
std::vector<int> vfree(0);
solutions.AddSolution(vinfos,vfree);
}
}
}

}

}

} else
{
IkReal x8202=((IkReal(1.00000000000000))*(cj0));
IkReal x8203=((cj4)*(sj6));
IkReal x8204=((sj0)*(sj4));
IkReal x8205=((cj5)*(sj6));
IkReal x8206=((sj4)*(sj5));
IkReal x8207=((r12)*(sj5));
IkReal x8208=((IkReal(0.374290000000000))*(cj5));
IkReal x8209=((r02)*(sj0));
IkReal x8210=((IkReal(1.00000000000000))*(sj0));
IkReal x8211=((cj0)*(r10));
IkReal x8212=((cj4)*(cj6));
IkReal x8213=((r00)*(sj0));
IkReal x8214=((cj6)*(r21));
IkReal x8215=((IkReal(0.374290000000000))*(sj5));
IkReal x8216=((cj0)*(r00));
IkReal x8217=((IkReal(0.0100000000000000))*(sj5));
IkReal x8218=((cj0)*(r02));
IkReal x8219=((cj5)*(sj4));
IkReal x8220=((cj6)*(r01));
IkReal x8221=((cj6)*(r11));
IkReal x8222=((r01)*(sj0));
IkReal x8223=((r10)*(sj0));
IkReal x8224=((IkReal(0.0100000000000000))*(cj5)*(cj6));
IkReal x8225=((sj6)*(x8215));
IkReal x8226=((cj0)*(cj6)*(x8215));
evalcond[0]=((IkReal(-3.14159265358979))+(IKfmod(((IkReal(4.71238898038469))+(j2)), IkReal(6.28318530717959))));
evalcond[1]=((((r21)*(x8203)))+(((r22)*(x8206)))+(((x8214)*(x8219)))+(cj1)+(((IkReal(-1.00000000000000))*(r20)*(x8212)))+(((r20)*(sj4)*(x8205))));
evalcond[2]=((((r20)*(x8225)))+(((IkReal(-0.0100000000000000))*(cj5)*(x8214)))+(((IkReal(0.364420000000000))*(sj1)))+(((IkReal(-1.00000000000000))*(r22)*(x8217)))+(((IkReal(-1.00000000000000))*(r22)*(x8208)))+(pz)+(((x8214)*(x8215)))+(((IkReal(-0.0100000000000000))*(r20)*(x8205))));
evalcond[3]=((((IkReal(-1.00000000000000))*(x8202)*(x8219)*(x8221)))+(((IkReal(-1.00000000000000))*(r11)*(x8202)*(x8203)))+(((x8211)*(x8212)))+(((r02)*(sj5)*(x8204)))+(((IkReal(-1.00000000000000))*(r12)*(x8202)*(x8206)))+(((r00)*(x8204)*(x8205)))+(((cj5)*(x8204)*(x8220)))+(((IkReal(-1.00000000000000))*(r00)*(x8210)*(x8212)))+(((IkReal(-1.00000000000000))*(r10)*(sj4)*(x8202)*(x8205)))+(((x8203)*(x8222))));
evalcond[4]=((((IkReal(-1.00000000000000))*(cj5)*(x8204)*(x8221)))+(((IkReal(-1.00000000000000))*(r02)*(x8202)*(x8206)))+(((IkReal(-1.00000000000000))*(r01)*(x8202)*(x8203)))+(((IkReal(-1.00000000000000))*(r00)*(sj4)*(x8202)*(x8205)))+(((IkReal(-1.00000000000000))*(sj1)))+(((IkReal(-1.00000000000000))*(r11)*(x8203)*(x8210)))+(((IkReal(-1.00000000000000))*(x8202)*(x8219)*(x8220)))+(((IkReal(-1.00000000000000))*(r10)*(x8204)*(x8205)))+(((x8212)*(x8223)))+(((IkReal(-1.00000000000000))*(x8204)*(x8207)))+(((x8212)*(x8216))));
evalcond[5]=((IkReal(-0.0690000000000000))+(((IkReal(-1.00000000000000))*(py)*(x8202)))+(((IkReal(-1.00000000000000))*(x8211)*(x8225)))+(((IkReal(-0.0100000000000000))*(x8205)*(x8213)))+(((IkReal(-1.00000000000000))*(x8208)*(x8209)))+(((IkReal(0.0100000000000000))*(cj0)*(cj5)*(x8221)))+(((IkReal(-1.00000000000000))*(cj0)*(x8215)*(x8221)))+(((IkReal(0.0100000000000000))*(x8205)*(x8211)))+(((IkReal(-1.00000000000000))*(x8209)*(x8217)))+(((sj0)*(x8215)*(x8220)))+(((x8213)*(x8225)))+(((cj0)*(r12)*(x8208)))+(((px)*(sj0)))+(((IkReal(-0.0100000000000000))*(cj5)*(sj0)*(x8220)))+(((IkReal(0.0100000000000000))*(cj0)*(x8207))));
evalcond[6]=((IkReal(0.0690000000000000))+(((x8208)*(x8218)))+(((IkReal(0.0100000000000000))*(sj0)*(x8207)))+(((r12)*(sj0)*(x8208)))+(((IkReal(-1.00000000000000))*(x8223)*(x8225)))+(((IkReal(0.0100000000000000))*(cj5)*(sj0)*(x8221)))+(((IkReal(-1.00000000000000))*(cj0)*(x8215)*(x8220)))+(((IkReal(-1.00000000000000))*(sj0)*(x8215)*(x8221)))+(((IkReal(-1.00000000000000))*(x8216)*(x8225)))+(((IkReal(0.0100000000000000))*(cj0)*(cj5)*(x8220)))+(((IkReal(0.0100000000000000))*(x8205)*(x8223)))+(((IkReal(-1.00000000000000))*(px)*(x8202)))+(((x8217)*(x8218)))+(((IkReal(0.364420000000000))*(cj1)))+(((IkReal(0.0100000000000000))*(x8205)*(x8216)))+(((IkReal(-1.00000000000000))*(py)*(x8210))));
if( IKabs(evalcond[0]) < 0.0000010000000000  && IKabs(evalcond[1]) < 0.0000010000000000  && IKabs(evalcond[2]) < 0.0000010000000000  && IKabs(evalcond[3]) < 0.0000010000000000  && IKabs(evalcond[4]) < 0.0000010000000000  && IKabs(evalcond[5]) < 0.0000010000000000  && IKabs(evalcond[6]) < 0.0000010000000000  )
{
{
IkReal dummyeval[1];
IkReal gconst12;
gconst12=IKsign(sj1);
dummyeval[0]=sj1;
if( IKabs(dummyeval[0]) < 0.0000010000000000  )
{
{
IkReal dummyeval[1];
dummyeval[0]=sj1;
if( IKabs(dummyeval[0]) < 0.0000010000000000  )
{
{
IkReal dummyeval[1];
dummyeval[0]=cj1;
if( IKabs(dummyeval[0]) < 0.0000010000000000  )
{
{
IkReal evalcond[9];
IkReal x8227=((IkReal(1.00000000000000))*(cj0));
IkReal x8228=((cj4)*(sj6));
IkReal x8229=((sj0)*(sj6));
IkReal x8230=((cj5)*(sj4));
IkReal x8231=((IkReal(0.374290000000000))*(sj5));
IkReal x8232=((sj4)*(sj5));
IkReal x8233=((cj0)*(cj6));
IkReal x8234=((IkReal(0.0100000000000000))*(cj5));
IkReal x8235=((cj4)*(sj5));
IkReal x8236=((cj5)*(sj0));
IkReal x8237=((IkReal(0.374290000000000))*(r02));
IkReal x8238=((r20)*(sj6));
IkReal x8239=((cj6)*(r21));
IkReal x8240=((IkReal(1.00000000000000))*(sj0));
IkReal x8241=((cj0)*(sj6));
IkReal x8242=((cj4)*(cj6));
IkReal x8243=((IkReal(0.374290000000000))*(r12));
IkReal x8244=((cj0)*(cj5));
IkReal x8245=((cj6)*(sj5));
IkReal x8246=((cj6)*(r01));
IkReal x8247=((r00)*(sj6));
IkReal x8248=((IkReal(0.0100000000000000))*(sj5));
IkReal x8249=((cj6)*(r11));
IkReal x8250=((IkReal(1.00000000000000))*(r10));
IkReal x8251=((r02)*(sj0));
IkReal x8252=((cj6)*(sj4));
IkReal x8253=((r12)*(x8240));
evalcond[0]=((IkReal(-3.14159265358979))+(IKfmod(((IkReal(1.57079632679490))+(j1)), IkReal(6.28318530717959))));
evalcond[1]=((((IkReal(-1.00000000000000))*(r20)*(x8242)))+(((x8230)*(x8239)))+(((x8230)*(x8238)))+(((r21)*(x8228)))+(((r22)*(x8232))));
evalcond[2]=((IkReal(0.364420000000000))+(((IkReal(-1.00000000000000))*(x8234)*(x8238)))+(((IkReal(-1.00000000000000))*(x8234)*(x8239)))+(((IkReal(-0.374290000000000))*(cj5)*(r22)))+(((x8231)*(x8239)))+(((x8231)*(x8238)))+(((IkReal(-1.00000000000000))*(r22)*(x8248)))+(pz));
evalcond[3]=((((IkReal(-1.00000000000000))*(r11)*(x8240)*(x8245)))+(((IkReal(-1.00000000000000))*(r01)*(x8227)*(x8245)))+(((IkReal(-1.00000000000000))*(sj5)*(x8229)*(x8250)))+(((IkReal(-1.00000000000000))*(sj5)*(x8227)*(x8247)))+(((r02)*(x8244)))+(((r12)*(x8236))));
evalcond[4]=((((sj0)*(x8230)*(x8246)))+(((IkReal(-1.00000000000000))*(r10)*(sj6)*(x8227)*(x8230)))+(((IkReal(-1.00000000000000))*(r00)*(x8240)*(x8242)))+(((r00)*(x8229)*(x8230)))+(((IkReal(-1.00000000000000))*(r11)*(x8227)*(x8228)))+(((x8232)*(x8251)))+(((IkReal(-1.00000000000000))*(r12)*(x8227)*(x8232)))+(((IkReal(-1.00000000000000))*(x8227)*(x8230)*(x8249)))+(((r01)*(sj0)*(x8228)))+(((cj4)*(r10)*(x8233))));
evalcond[5]=((IkReal(-1.00000000000000))+(((cj4)*(r00)*(x8233)))+(((IkReal(-1.00000000000000))*(r11)*(x8228)*(x8240)))+(((IkReal(-1.00000000000000))*(r01)*(x8227)*(x8228)))+(((IkReal(-1.00000000000000))*(r02)*(x8227)*(x8232)))+(((r10)*(sj0)*(x8242)))+(((IkReal(-1.00000000000000))*(x8230)*(x8240)*(x8249)))+(((IkReal(-1.00000000000000))*(x8227)*(x8230)*(x8247)))+(((IkReal(-1.00000000000000))*(x8229)*(x8230)*(x8250)))+(((IkReal(-1.00000000000000))*(x8227)*(x8230)*(x8246)))+(((IkReal(-1.00000000000000))*(x8232)*(x8253))));
evalcond[6]=((IkReal(-0.0690000000000000))+(((r10)*(x8234)*(x8241)))+(((IkReal(-1.00000000000000))*(py)*(x8227)))+(((IkReal(-1.00000000000000))*(r00)*(x8229)*(x8234)))+(((IkReal(-1.00000000000000))*(x8248)*(x8251)))+(((r11)*(x8233)*(x8234)))+(((r00)*(x8229)*(x8231)))+(((IkReal(-1.00000000000000))*(r10)*(x8231)*(x8241)))+(((IkReal(-1.00000000000000))*(r11)*(x8231)*(x8233)))+(((sj0)*(x8231)*(x8246)))+(((IkReal(-1.00000000000000))*(sj0)*(x8234)*(x8246)))+(((x8243)*(x8244)))+(((cj0)*(r12)*(x8248)))+(((px)*(sj0)))+(((IkReal(-1.00000000000000))*(x8236)*(x8237))));
evalcond[7]=((((IkReal(-1.00000000000000))*(r02)*(x8227)*(x8235)))+(((IkReal(-1.00000000000000))*(x8228)*(x8236)*(x8250)))+(((IkReal(-1.00000000000000))*(r10)*(x8240)*(x8252)))+(((r01)*(sj4)*(x8241)))+(((IkReal(-1.00000000000000))*(r11)*(x8236)*(x8242)))+(((IkReal(-1.00000000000000))*(cj5)*(r01)*(x8227)*(x8242)))+(((IkReal(-1.00000000000000))*(x8235)*(x8253)))+(((IkReal(-1.00000000000000))*(r00)*(x8227)*(x8252)))+(((IkReal(-1.00000000000000))*(cj5)*(r00)*(x8227)*(x8228)))+(((r11)*(sj4)*(x8229))));
evalcond[8]=((IkReal(0.0690000000000000))+(((cj0)*(r02)*(x8248)))+(((IkReal(-1.00000000000000))*(px)*(x8227)))+(((x8237)*(x8244)))+(((sj0)*(x8234)*(x8249)))+(((r12)*(sj0)*(x8248)))+(((IkReal(-1.00000000000000))*(r01)*(x8231)*(x8233)))+(((IkReal(-1.00000000000000))*(r10)*(x8229)*(x8231)))+(((IkReal(-1.00000000000000))*(sj0)*(x8231)*(x8249)))+(((IkReal(-1.00000000000000))*(r00)*(x8231)*(x8241)))+(((r01)*(x8233)*(x8234)))+(((x8236)*(x8243)))+(((r10)*(x8229)*(x8234)))+(((IkReal(-1.00000000000000))*(py)*(x8240)))+(((r00)*(x8234)*(x8241))));
if( IKabs(evalcond[0]) < 0.0000010000000000  && IKabs(evalcond[1]) < 0.0000010000000000  && IKabs(evalcond[2]) < 0.0000010000000000  && IKabs(evalcond[3]) < 0.0000010000000000  && IKabs(evalcond[4]) < 0.0000010000000000  && IKabs(evalcond[5]) < 0.0000010000000000  && IKabs(evalcond[6]) < 0.0000010000000000  && IKabs(evalcond[7]) < 0.0000010000000000  && IKabs(evalcond[8]) < 0.0000010000000000  )
{
{
IkReal j3array[1], cj3array[1], sj3array[1];
bool j3valid[1]={false};
_nj3 = 1;
IkReal x8254=((r20)*(sj6));
IkReal x8255=((cj4)*(cj5));
IkReal x8256=((cj6)*(r21));
if( IKabs(((((IkReal(-1.00000000000000))*(r21)*(sj4)*(sj6)))+(((cj6)*(r20)*(sj4)))+(((cj4)*(r22)*(sj5)))+(((x8254)*(x8255)))+(((x8255)*(x8256))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(((((sj5)*(x8256)))+(((IkReal(-1.00000000000000))*(cj5)*(r22)))+(((sj5)*(x8254))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(IKsqr(((((IkReal(-1.00000000000000))*(r21)*(sj4)*(sj6)))+(((cj6)*(r20)*(sj4)))+(((cj4)*(r22)*(sj5)))+(((x8254)*(x8255)))+(((x8255)*(x8256)))))+IKsqr(((((sj5)*(x8256)))+(((IkReal(-1.00000000000000))*(cj5)*(r22)))+(((sj5)*(x8254)))))-1) <= IKFAST_SINCOS_THRESH )
    continue;
j3array[0]=IKatan2(((((IkReal(-1.00000000000000))*(r21)*(sj4)*(sj6)))+(((cj6)*(r20)*(sj4)))+(((cj4)*(r22)*(sj5)))+(((x8254)*(x8255)))+(((x8255)*(x8256)))), ((((sj5)*(x8256)))+(((IkReal(-1.00000000000000))*(cj5)*(r22)))+(((sj5)*(x8254)))));
sj3array[0]=IKsin(j3array[0]);
cj3array[0]=IKcos(j3array[0]);
if( j3array[0] > IKPI )
{
    j3array[0]-=IK2PI;
}
else if( j3array[0] < -IKPI )
{    j3array[0]+=IK2PI;
}
j3valid[0] = true;
for(int ij3 = 0; ij3 < 1; ++ij3)
{
if( !j3valid[ij3] )
{
    continue;
}
_ij3[0] = ij3; _ij3[1] = -1;
for(int iij3 = ij3+1; iij3 < 1; ++iij3)
{
if( j3valid[iij3] && IKabs(cj3array[ij3]-cj3array[iij3]) < IKFAST_SOLUTION_THRESH && IKabs(sj3array[ij3]-sj3array[iij3]) < IKFAST_SOLUTION_THRESH )
{
    j3valid[iij3]=false; _ij3[1] = iij3; break; 
}
}
j3 = j3array[ij3]; cj3 = cj3array[ij3]; sj3 = sj3array[ij3];
{
IkReal evalcond[4];
IkReal x8257=IKsin(j3);
IkReal x8258=((sj0)*(sj5));
IkReal x8259=((r00)*(sj6));
IkReal x8260=((cj6)*(r01));
IkReal x8261=((cj5)*(sj0));
IkReal x8262=((cj0)*(cj5));
IkReal x8263=((cj6)*(sj4));
IkReal x8264=((sj4)*(sj6));
IkReal x8265=((cj0)*(r11));
IkReal x8266=((cj4)*(cj6));
IkReal x8267=((cj4)*(sj6));
IkReal x8268=((IkReal(1.00000000000000))*(cj0));
IkReal x8269=((cj4)*(sj5));
IkReal x8270=((sj5)*(sj6));
IkReal x8271=((cj6)*(sj5));
IkReal x8272=((IkReal(1.00000000000000))*(IKcos(j3)));
evalcond[0]=((((IkReal(-1.00000000000000))*(cj5)*(r22)))+(((IkReal(-1.00000000000000))*(x8272)))+(((r20)*(x8270)))+(((r21)*(x8271))));
evalcond[1]=((((cj5)*(r20)*(x8267)))+(((r22)*(x8269)))+(((IkReal(-1.00000000000000))*(r21)*(x8264)))+(((cj5)*(r21)*(x8266)))+(((r20)*(x8263)))+(((IkReal(-1.00000000000000))*(x8257))));
evalcond[2]=((((r12)*(x8262)))+(((IkReal(-1.00000000000000))*(x8265)*(x8271)))+(((x8258)*(x8260)))+(((IkReal(-1.00000000000000))*(r10)*(x8268)*(x8270)))+(((x8258)*(x8259)))+(x8257)+(((IkReal(-1.00000000000000))*(r02)*(x8261))));
evalcond[3]=((((IkReal(-1.00000000000000))*(r10)*(x8262)*(x8267)))+(((cj4)*(x8259)*(x8261)))+(((r00)*(sj0)*(x8263)))+(((x8264)*(x8265)))+(((IkReal(-1.00000000000000))*(x8272)))+(((IkReal(-1.00000000000000))*(r10)*(x8263)*(x8268)))+(((IkReal(-1.00000000000000))*(r01)*(sj0)*(x8264)))+(((IkReal(-1.00000000000000))*(r12)*(x8268)*(x8269)))+(((cj4)*(r02)*(x8258)))+(((cj4)*(x8260)*(x8261)))+(((IkReal(-1.00000000000000))*(r11)*(x8262)*(x8266))));
if( IKabs(evalcond[0]) > 0.000001  || IKabs(evalcond[1]) > 0.000001  || IKabs(evalcond[2]) > 0.000001  || IKabs(evalcond[3]) > 0.000001  )
{
continue;
}
}

{
std::vector<IkSingleDOFSolutionBase<IkReal> > vinfos(7);
vinfos[0].jointtype = 1;
vinfos[0].foffset = j0;
vinfos[0].indices[0] = _ij0[0];
vinfos[0].indices[1] = _ij0[1];
vinfos[0].maxsolutions = _nj0;
vinfos[1].jointtype = 1;
vinfos[1].foffset = j1;
vinfos[1].indices[0] = _ij1[0];
vinfos[1].indices[1] = _ij1[1];
vinfos[1].maxsolutions = _nj1;
vinfos[2].jointtype = 1;
vinfos[2].foffset = j2;
vinfos[2].indices[0] = _ij2[0];
vinfos[2].indices[1] = _ij2[1];
vinfos[2].maxsolutions = _nj2;
vinfos[3].jointtype = 1;
vinfos[3].foffset = j3;
vinfos[3].indices[0] = _ij3[0];
vinfos[3].indices[1] = _ij3[1];
vinfos[3].maxsolutions = _nj3;
vinfos[4].jointtype = 1;
vinfos[4].foffset = j4;
vinfos[4].indices[0] = _ij4[0];
vinfos[4].indices[1] = _ij4[1];
vinfos[4].maxsolutions = _nj4;
vinfos[5].jointtype = 1;
vinfos[5].foffset = j5;
vinfos[5].indices[0] = _ij5[0];
vinfos[5].indices[1] = _ij5[1];
vinfos[5].maxsolutions = _nj5;
vinfos[6].jointtype = 1;
vinfos[6].foffset = j6;
vinfos[6].indices[0] = _ij6[0];
vinfos[6].indices[1] = _ij6[1];
vinfos[6].maxsolutions = _nj6;
std::vector<int> vfree(0);
solutions.AddSolution(vinfos,vfree);
}
}
}

} else
{
IkReal x8273=((IkReal(1.00000000000000))*(cj0));
IkReal x8274=((cj4)*(sj6));
IkReal x8275=((sj0)*(sj6));
IkReal x8276=((cj5)*(sj4));
IkReal x8277=((IkReal(0.374290000000000))*(sj5));
IkReal x8278=((sj4)*(sj5));
IkReal x8279=((cj0)*(cj6));
IkReal x8280=((IkReal(0.0100000000000000))*(cj5));
IkReal x8281=((cj4)*(sj5));
IkReal x8282=((cj5)*(sj0));
IkReal x8283=((IkReal(0.374290000000000))*(r02));
IkReal x8284=((r20)*(sj6));
IkReal x8285=((cj6)*(r21));
IkReal x8286=((IkReal(1.00000000000000))*(sj0));
IkReal x8287=((cj0)*(sj6));
IkReal x8288=((cj4)*(cj6));
IkReal x8289=((IkReal(0.374290000000000))*(r12));
IkReal x8290=((cj0)*(cj5));
IkReal x8291=((cj6)*(sj5));
IkReal x8292=((cj6)*(r01));
IkReal x8293=((r00)*(sj6));
IkReal x8294=((IkReal(0.0100000000000000))*(sj5));
IkReal x8295=((cj6)*(r11));
IkReal x8296=((IkReal(1.00000000000000))*(r10));
IkReal x8297=((r02)*(sj0));
IkReal x8298=((cj6)*(sj4));
IkReal x8299=((r12)*(x8286));
evalcond[0]=((IkReal(-3.14159265358979))+(IKfmod(((IkReal(4.71238898038469))+(j1)), IkReal(6.28318530717959))));
evalcond[1]=((((x8276)*(x8285)))+(((r22)*(x8278)))+(((x8276)*(x8284)))+(((IkReal(-1.00000000000000))*(r20)*(x8288)))+(((r21)*(x8274))));
evalcond[2]=((IkReal(-0.364420000000000))+(((IkReal(-1.00000000000000))*(r22)*(x8294)))+(((IkReal(-1.00000000000000))*(x8280)*(x8284)))+(((IkReal(-1.00000000000000))*(x8280)*(x8285)))+(((IkReal(-0.374290000000000))*(cj5)*(r22)))+(pz)+(((x8277)*(x8284)))+(((x8277)*(x8285))));
evalcond[3]=((((IkReal(-1.00000000000000))*(sj5)*(x8275)*(x8296)))+(((r12)*(x8282)))+(((r02)*(x8290)))+(((IkReal(-1.00000000000000))*(r11)*(x8286)*(x8291)))+(((IkReal(-1.00000000000000))*(r01)*(x8273)*(x8291)))+(((IkReal(-1.00000000000000))*(sj5)*(x8273)*(x8293))));
evalcond[4]=((((x8278)*(x8297)))+(((IkReal(-1.00000000000000))*(r10)*(sj6)*(x8273)*(x8276)))+(((r00)*(x8275)*(x8276)))+(((IkReal(-1.00000000000000))*(r12)*(x8273)*(x8278)))+(((IkReal(-1.00000000000000))*(r11)*(x8273)*(x8274)))+(((r01)*(sj0)*(x8274)))+(((IkReal(-1.00000000000000))*(x8273)*(x8276)*(x8295)))+(((IkReal(-1.00000000000000))*(r00)*(x8286)*(x8288)))+(((cj4)*(r10)*(x8279)))+(((sj0)*(x8276)*(x8292))));
evalcond[5]=((IkReal(1.00000000000000))+(((r10)*(sj0)*(x8288)))+(((cj4)*(r00)*(x8279)))+(((IkReal(-1.00000000000000))*(r01)*(x8273)*(x8274)))+(((IkReal(-1.00000000000000))*(r11)*(x8274)*(x8286)))+(((IkReal(-1.00000000000000))*(x8273)*(x8276)*(x8292)))+(((IkReal(-1.00000000000000))*(x8276)*(x8286)*(x8295)))+(((IkReal(-1.00000000000000))*(r02)*(x8273)*(x8278)))+(((IkReal(-1.00000000000000))*(x8278)*(x8299)))+(((IkReal(-1.00000000000000))*(x8275)*(x8276)*(x8296)))+(((IkReal(-1.00000000000000))*(x8273)*(x8276)*(x8293))));
evalcond[6]=((IkReal(-0.0690000000000000))+(((x8289)*(x8290)))+(((r11)*(x8279)*(x8280)))+(((IkReal(-1.00000000000000))*(r11)*(x8277)*(x8279)))+(((cj0)*(r12)*(x8294)))+(((IkReal(-1.00000000000000))*(r00)*(x8275)*(x8280)))+(((IkReal(-1.00000000000000))*(r10)*(x8277)*(x8287)))+(((IkReal(-1.00000000000000))*(sj0)*(x8280)*(x8292)))+(((IkReal(-1.00000000000000))*(x8282)*(x8283)))+(((IkReal(-1.00000000000000))*(py)*(x8273)))+(((sj0)*(x8277)*(x8292)))+(((px)*(sj0)))+(((r10)*(x8280)*(x8287)))+(((r00)*(x8275)*(x8277)))+(((IkReal(-1.00000000000000))*(x8294)*(x8297))));
evalcond[7]=((((IkReal(-1.00000000000000))*(r10)*(x8286)*(x8298)))+(((IkReal(-1.00000000000000))*(x8281)*(x8299)))+(((IkReal(-1.00000000000000))*(r00)*(x8273)*(x8298)))+(((IkReal(-1.00000000000000))*(r02)*(x8273)*(x8281)))+(((IkReal(-1.00000000000000))*(x8274)*(x8282)*(x8296)))+(((IkReal(-1.00000000000000))*(cj5)*(r01)*(x8273)*(x8288)))+(((r11)*(sj4)*(x8275)))+(((r01)*(sj4)*(x8287)))+(((IkReal(-1.00000000000000))*(r11)*(x8282)*(x8288)))+(((IkReal(-1.00000000000000))*(cj5)*(r00)*(x8273)*(x8274))));
evalcond[8]=((IkReal(0.0690000000000000))+(((IkReal(-1.00000000000000))*(px)*(x8273)))+(((IkReal(-1.00000000000000))*(py)*(x8286)))+(((r12)*(sj0)*(x8294)))+(((x8283)*(x8290)))+(((r10)*(x8275)*(x8280)))+(((r01)*(x8279)*(x8280)))+(((IkReal(-1.00000000000000))*(r00)*(x8277)*(x8287)))+(((IkReal(-1.00000000000000))*(sj0)*(x8277)*(x8295)))+(((cj0)*(r02)*(x8294)))+(((sj0)*(x8280)*(x8295)))+(((IkReal(-1.00000000000000))*(r10)*(x8275)*(x8277)))+(((IkReal(-1.00000000000000))*(r01)*(x8277)*(x8279)))+(((x8282)*(x8289)))+(((r00)*(x8280)*(x8287))));
if( IKabs(evalcond[0]) < 0.0000010000000000  && IKabs(evalcond[1]) < 0.0000010000000000  && IKabs(evalcond[2]) < 0.0000010000000000  && IKabs(evalcond[3]) < 0.0000010000000000  && IKabs(evalcond[4]) < 0.0000010000000000  && IKabs(evalcond[5]) < 0.0000010000000000  && IKabs(evalcond[6]) < 0.0000010000000000  && IKabs(evalcond[7]) < 0.0000010000000000  && IKabs(evalcond[8]) < 0.0000010000000000  )
{
{
IkReal j3array[1], cj3array[1], sj3array[1];
bool j3valid[1]={false};
_nj3 = 1;
IkReal x8300=((IkReal(1.00000000000000))*(sj5));
IkReal x8301=((cj6)*(r21));
IkReal x8302=((r20)*(sj6));
IkReal x8303=((IkReal(1.00000000000000))*(cj4)*(cj5));
if( IKabs(((((IkReal(-1.00000000000000))*(x8302)*(x8303)))+(((IkReal(-1.00000000000000))*(cj4)*(r22)*(x8300)))+(((r21)*(sj4)*(sj6)))+(((IkReal(-1.00000000000000))*(x8301)*(x8303)))+(((IkReal(-1.00000000000000))*(cj6)*(r20)*(sj4))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(((((IkReal(-1.00000000000000))*(x8300)*(x8301)))+(((IkReal(-1.00000000000000))*(x8300)*(x8302)))+(((cj5)*(r22))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(IKsqr(((((IkReal(-1.00000000000000))*(x8302)*(x8303)))+(((IkReal(-1.00000000000000))*(cj4)*(r22)*(x8300)))+(((r21)*(sj4)*(sj6)))+(((IkReal(-1.00000000000000))*(x8301)*(x8303)))+(((IkReal(-1.00000000000000))*(cj6)*(r20)*(sj4)))))+IKsqr(((((IkReal(-1.00000000000000))*(x8300)*(x8301)))+(((IkReal(-1.00000000000000))*(x8300)*(x8302)))+(((cj5)*(r22)))))-1) <= IKFAST_SINCOS_THRESH )
    continue;
j3array[0]=IKatan2(((((IkReal(-1.00000000000000))*(x8302)*(x8303)))+(((IkReal(-1.00000000000000))*(cj4)*(r22)*(x8300)))+(((r21)*(sj4)*(sj6)))+(((IkReal(-1.00000000000000))*(x8301)*(x8303)))+(((IkReal(-1.00000000000000))*(cj6)*(r20)*(sj4)))), ((((IkReal(-1.00000000000000))*(x8300)*(x8301)))+(((IkReal(-1.00000000000000))*(x8300)*(x8302)))+(((cj5)*(r22)))));
sj3array[0]=IKsin(j3array[0]);
cj3array[0]=IKcos(j3array[0]);
if( j3array[0] > IKPI )
{
    j3array[0]-=IK2PI;
}
else if( j3array[0] < -IKPI )
{    j3array[0]+=IK2PI;
}
j3valid[0] = true;
for(int ij3 = 0; ij3 < 1; ++ij3)
{
if( !j3valid[ij3] )
{
    continue;
}
_ij3[0] = ij3; _ij3[1] = -1;
for(int iij3 = ij3+1; iij3 < 1; ++iij3)
{
if( j3valid[iij3] && IKabs(cj3array[ij3]-cj3array[iij3]) < IKFAST_SOLUTION_THRESH && IKabs(sj3array[ij3]-sj3array[iij3]) < IKFAST_SOLUTION_THRESH )
{
    j3valid[iij3]=false; _ij3[1] = iij3; break; 
}
}
j3 = j3array[ij3]; cj3 = cj3array[ij3]; sj3 = sj3array[ij3];
{
IkReal evalcond[4];
IkReal x8304=IKsin(j3);
IkReal x8305=IKcos(j3);
IkReal x8306=((sj0)*(sj5));
IkReal x8307=((r00)*(sj6));
IkReal x8308=((cj6)*(r01));
IkReal x8309=((cj0)*(cj5));
IkReal x8310=((IkReal(1.00000000000000))*(cj5));
IkReal x8311=((cj4)*(cj5));
IkReal x8312=((cj6)*(sj4));
IkReal x8313=((sj4)*(sj6));
IkReal x8314=((cj0)*(r11));
IkReal x8315=((IkReal(1.00000000000000))*(cj4));
IkReal x8316=((cj6)*(r21));
IkReal x8317=((r20)*(sj6));
IkReal x8318=((cj0)*(sj5));
IkReal x8319=((r10)*(sj6));
evalcond[0]=((((IkReal(-1.00000000000000))*(r22)*(x8310)))+(x8305)+(((sj5)*(x8316)))+(((sj5)*(x8317))));
evalcond[1]=((((x8311)*(x8317)))+(((x8311)*(x8316)))+(((r20)*(x8312)))+(((cj4)*(r22)*(sj5)))+(x8304)+(((IkReal(-1.00000000000000))*(r21)*(x8313))));
evalcond[2]=((((r12)*(x8309)))+(((IkReal(-1.00000000000000))*(r02)*(sj0)*(x8310)))+(((x8306)*(x8308)))+(((x8306)*(x8307)))+(((IkReal(-1.00000000000000))*(x8318)*(x8319)))+(((IkReal(-1.00000000000000))*(cj6)*(sj5)*(x8314)))+(x8304));
evalcond[3]=((((sj0)*(x8308)*(x8311)))+(((x8313)*(x8314)))+(((IkReal(-1.00000000000000))*(x8309)*(x8315)*(x8319)))+(((IkReal(-1.00000000000000))*(r01)*(sj0)*(x8313)))+(((sj0)*(x8307)*(x8311)))+(((IkReal(-1.00000000000000))*(x8305)))+(((IkReal(-1.00000000000000))*(cj0)*(r10)*(x8312)))+(((IkReal(-1.00000000000000))*(r12)*(x8315)*(x8318)))+(((cj4)*(r02)*(x8306)))+(((r00)*(sj0)*(x8312)))+(((IkReal(-1.00000000000000))*(cj6)*(r11)*(x8309)*(x8315))));
if( IKabs(evalcond[0]) > 0.000001  || IKabs(evalcond[1]) > 0.000001  || IKabs(evalcond[2]) > 0.000001  || IKabs(evalcond[3]) > 0.000001  )
{
continue;
}
}

{
std::vector<IkSingleDOFSolutionBase<IkReal> > vinfos(7);
vinfos[0].jointtype = 1;
vinfos[0].foffset = j0;
vinfos[0].indices[0] = _ij0[0];
vinfos[0].indices[1] = _ij0[1];
vinfos[0].maxsolutions = _nj0;
vinfos[1].jointtype = 1;
vinfos[1].foffset = j1;
vinfos[1].indices[0] = _ij1[0];
vinfos[1].indices[1] = _ij1[1];
vinfos[1].maxsolutions = _nj1;
vinfos[2].jointtype = 1;
vinfos[2].foffset = j2;
vinfos[2].indices[0] = _ij2[0];
vinfos[2].indices[1] = _ij2[1];
vinfos[2].maxsolutions = _nj2;
vinfos[3].jointtype = 1;
vinfos[3].foffset = j3;
vinfos[3].indices[0] = _ij3[0];
vinfos[3].indices[1] = _ij3[1];
vinfos[3].maxsolutions = _nj3;
vinfos[4].jointtype = 1;
vinfos[4].foffset = j4;
vinfos[4].indices[0] = _ij4[0];
vinfos[4].indices[1] = _ij4[1];
vinfos[4].maxsolutions = _nj4;
vinfos[5].jointtype = 1;
vinfos[5].foffset = j5;
vinfos[5].indices[0] = _ij5[0];
vinfos[5].indices[1] = _ij5[1];
vinfos[5].maxsolutions = _nj5;
vinfos[6].jointtype = 1;
vinfos[6].foffset = j6;
vinfos[6].indices[0] = _ij6[0];
vinfos[6].indices[1] = _ij6[1];
vinfos[6].maxsolutions = _nj6;
std::vector<int> vfree(0);
solutions.AddSolution(vinfos,vfree);
}
}
}

} else
{
if( 1 )
{
continue;

} else
{
}
}
}
}

} else
{
{
IkReal j3array[1], cj3array[1], sj3array[1];
bool j3valid[1]={false};
_nj3 = 1;
IkReal x8320=((cj5)*(r02));
IkReal x8321=((cj0)*(sj5));
IkReal x8322=((r10)*(sj6));
IkReal x8323=((IkReal(1.00000000000000))*(cj6));
IkReal x8324=((sj0)*(sj5));
IkReal x8325=((cj5)*(r12));
IkReal x8326=((IkReal(1.00000000000000))*(r00)*(sj6));
if( IKabs(((((IkReal(-1.00000000000000))*(cj0)*(x8325)))+(((x8321)*(x8322)))+(((sj0)*(x8320)))+(((IkReal(-1.00000000000000))*(x8324)*(x8326)))+(((IkReal(-1.00000000000000))*(r01)*(x8323)*(x8324)))+(((cj6)*(r11)*(x8321))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(((((IKabs(cj1) != 0)?((IkReal)1/(cj1)):(IkReal)1.0e30))*(((((sj0)*(x8325)))+(((IkReal(-1.00000000000000))*(x8322)*(x8324)))+(((IkReal(-1.00000000000000))*(r11)*(x8323)*(x8324)))+(((IkReal(-1.00000000000000))*(r01)*(x8321)*(x8323)))+(((IkReal(-1.00000000000000))*(x8321)*(x8326)))+(((cj0)*(x8320))))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(IKsqr(((((IkReal(-1.00000000000000))*(cj0)*(x8325)))+(((x8321)*(x8322)))+(((sj0)*(x8320)))+(((IkReal(-1.00000000000000))*(x8324)*(x8326)))+(((IkReal(-1.00000000000000))*(r01)*(x8323)*(x8324)))+(((cj6)*(r11)*(x8321)))))+IKsqr(((((IKabs(cj1) != 0)?((IkReal)1/(cj1)):(IkReal)1.0e30))*(((((sj0)*(x8325)))+(((IkReal(-1.00000000000000))*(x8322)*(x8324)))+(((IkReal(-1.00000000000000))*(r11)*(x8323)*(x8324)))+(((IkReal(-1.00000000000000))*(r01)*(x8321)*(x8323)))+(((IkReal(-1.00000000000000))*(x8321)*(x8326)))+(((cj0)*(x8320)))))))-1) <= IKFAST_SINCOS_THRESH )
    continue;
j3array[0]=IKatan2(((((IkReal(-1.00000000000000))*(cj0)*(x8325)))+(((x8321)*(x8322)))+(((sj0)*(x8320)))+(((IkReal(-1.00000000000000))*(x8324)*(x8326)))+(((IkReal(-1.00000000000000))*(r01)*(x8323)*(x8324)))+(((cj6)*(r11)*(x8321)))), ((((IKabs(cj1) != 0)?((IkReal)1/(cj1)):(IkReal)1.0e30))*(((((sj0)*(x8325)))+(((IkReal(-1.00000000000000))*(x8322)*(x8324)))+(((IkReal(-1.00000000000000))*(r11)*(x8323)*(x8324)))+(((IkReal(-1.00000000000000))*(r01)*(x8321)*(x8323)))+(((IkReal(-1.00000000000000))*(x8321)*(x8326)))+(((cj0)*(x8320)))))));
sj3array[0]=IKsin(j3array[0]);
cj3array[0]=IKcos(j3array[0]);
if( j3array[0] > IKPI )
{
    j3array[0]-=IK2PI;
}
else if( j3array[0] < -IKPI )
{    j3array[0]+=IK2PI;
}
j3valid[0] = true;
for(int ij3 = 0; ij3 < 1; ++ij3)
{
if( !j3valid[ij3] )
{
    continue;
}
_ij3[0] = ij3; _ij3[1] = -1;
for(int iij3 = ij3+1; iij3 < 1; ++iij3)
{
if( j3valid[iij3] && IKabs(cj3array[ij3]-cj3array[iij3]) < IKFAST_SOLUTION_THRESH && IKabs(sj3array[ij3]-sj3array[iij3]) < IKFAST_SOLUTION_THRESH )
{
    j3valid[iij3]=false; _ij3[1] = iij3; break; 
}
}
j3 = j3array[ij3]; cj3 = cj3array[ij3]; sj3 = sj3array[ij3];
{
IkReal evalcond[6];
IkReal x8327=IKsin(j3);
IkReal x8328=IKcos(j3);
IkReal x8329=((sj0)*(sj5));
IkReal x8330=((r00)*(sj6));
IkReal x8331=((IkReal(1.00000000000000))*(cj4));
IkReal x8332=((cj6)*(r01));
IkReal x8333=((cj0)*(cj5));
IkReal x8334=((cj5)*(sj0));
IkReal x8335=((cj6)*(r11));
IkReal x8336=((cj0)*(sj5));
IkReal x8337=((IkReal(1.00000000000000))*(cj1));
IkReal x8338=((cj6)*(sj4));
IkReal x8339=((IkReal(1.00000000000000))*(sj1));
IkReal x8340=((cj4)*(cj5));
IkReal x8341=((cj6)*(r21));
IkReal x8342=((r20)*(sj6));
IkReal x8343=((r10)*(sj6));
IkReal x8344=((IkReal(1.00000000000000))*(cj0));
IkReal x8345=((cj0)*(sj4)*(sj6));
IkReal x8346=((sj0)*(sj4)*(sj6));
evalcond[0]=((((sj5)*(x8342)))+(((IkReal(-1.00000000000000))*(cj5)*(r22)))+(((IkReal(-1.00000000000000))*(x8328)*(x8339)))+(((sj5)*(x8341))));
evalcond[1]=((((IkReal(-1.00000000000000))*(r21)*(sj4)*(sj6)))+(((x8340)*(x8342)))+(((r20)*(x8338)))+(((x8340)*(x8341)))+(((cj4)*(r22)*(sj5)))+(((IkReal(-1.00000000000000))*(x8327)*(x8339))));
evalcond[2]=((((IkReal(-1.00000000000000))*(x8336)*(x8343)))+(((x8329)*(x8330)))+(((IkReal(-1.00000000000000))*(x8335)*(x8336)))+(x8327)+(((r12)*(x8333)))+(((x8329)*(x8332)))+(((IkReal(-1.00000000000000))*(r02)*(x8334))));
evalcond[3]=((((IkReal(-1.00000000000000))*(x8332)*(x8336)))+(((IkReal(-1.00000000000000))*(x8329)*(x8343)))+(((IkReal(-1.00000000000000))*(x8328)*(x8337)))+(((IkReal(-1.00000000000000))*(x8329)*(x8335)))+(((r02)*(x8333)))+(((IkReal(-1.00000000000000))*(x8330)*(x8336)))+(((r12)*(x8334))));
evalcond[4]=((((cj4)*(r02)*(x8329)))+(((cj4)*(x8332)*(x8334)))+(((IkReal(-1.00000000000000))*(r12)*(x8331)*(x8336)))+(((IkReal(-1.00000000000000))*(r01)*(x8346)))+(((r00)*(sj0)*(x8338)))+(((cj4)*(x8330)*(x8334)))+(((IkReal(-1.00000000000000))*(x8328)))+(((r11)*(x8345)))+(((IkReal(-1.00000000000000))*(r10)*(x8338)*(x8344)))+(((IkReal(-1.00000000000000))*(x8331)*(x8333)*(x8343)))+(((IkReal(-1.00000000000000))*(x8331)*(x8333)*(x8335))));
evalcond[5]=((((IkReal(-1.00000000000000))*(r12)*(x8329)*(x8331)))+(((IkReal(-1.00000000000000))*(x8331)*(x8334)*(x8343)))+(((IkReal(-1.00000000000000))*(x8331)*(x8332)*(x8333)))+(((IkReal(-1.00000000000000))*(x8330)*(x8331)*(x8333)))+(((IkReal(-1.00000000000000))*(x8327)*(x8337)))+(((r01)*(x8345)))+(((IkReal(-1.00000000000000))*(x8331)*(x8334)*(x8335)))+(((IkReal(-1.00000000000000))*(r02)*(x8331)*(x8336)))+(((r11)*(x8346)))+(((IkReal(-1.00000000000000))*(r00)*(x8338)*(x8344)))+(((IkReal(-1.00000000000000))*(r10)*(sj0)*(x8338))));
if( IKabs(evalcond[0]) > 0.000001  || IKabs(evalcond[1]) > 0.000001  || IKabs(evalcond[2]) > 0.000001  || IKabs(evalcond[3]) > 0.000001  || IKabs(evalcond[4]) > 0.000001  || IKabs(evalcond[5]) > 0.000001  )
{
continue;
}
}

{
std::vector<IkSingleDOFSolutionBase<IkReal> > vinfos(7);
vinfos[0].jointtype = 1;
vinfos[0].foffset = j0;
vinfos[0].indices[0] = _ij0[0];
vinfos[0].indices[1] = _ij0[1];
vinfos[0].maxsolutions = _nj0;
vinfos[1].jointtype = 1;
vinfos[1].foffset = j1;
vinfos[1].indices[0] = _ij1[0];
vinfos[1].indices[1] = _ij1[1];
vinfos[1].maxsolutions = _nj1;
vinfos[2].jointtype = 1;
vinfos[2].foffset = j2;
vinfos[2].indices[0] = _ij2[0];
vinfos[2].indices[1] = _ij2[1];
vinfos[2].maxsolutions = _nj2;
vinfos[3].jointtype = 1;
vinfos[3].foffset = j3;
vinfos[3].indices[0] = _ij3[0];
vinfos[3].indices[1] = _ij3[1];
vinfos[3].maxsolutions = _nj3;
vinfos[4].jointtype = 1;
vinfos[4].foffset = j4;
vinfos[4].indices[0] = _ij4[0];
vinfos[4].indices[1] = _ij4[1];
vinfos[4].maxsolutions = _nj4;
vinfos[5].jointtype = 1;
vinfos[5].foffset = j5;
vinfos[5].indices[0] = _ij5[0];
vinfos[5].indices[1] = _ij5[1];
vinfos[5].maxsolutions = _nj5;
vinfos[6].jointtype = 1;
vinfos[6].foffset = j6;
vinfos[6].indices[0] = _ij6[0];
vinfos[6].indices[1] = _ij6[1];
vinfos[6].maxsolutions = _nj6;
std::vector<int> vfree(0);
solutions.AddSolution(vinfos,vfree);
}
}
}

}

}

} else
{
{
IkReal j3array[1], cj3array[1], sj3array[1];
bool j3valid[1]={false};
_nj3 = 1;
IkReal x8347=((sj5)*(sj6));
IkReal x8348=((IkReal(1.00000000000000))*(sj0));
IkReal x8349=((cj6)*(sj5));
IkReal x8350=((IkReal(1.00000000000000))*(cj5));
if( IKabs(((((cj0)*(r10)*(x8347)))+(((IkReal(-1.00000000000000))*(r01)*(x8348)*(x8349)))+(((IkReal(-1.00000000000000))*(r00)*(x8347)*(x8348)))+(((cj5)*(r02)*(sj0)))+(((cj0)*(r11)*(x8349)))+(((IkReal(-1.00000000000000))*(cj0)*(r12)*(x8350))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(((((IKabs(sj1) != 0)?((IkReal)1/(sj1)):(IkReal)1.0e30))*(((((r20)*(x8347)))+(((IkReal(-1.00000000000000))*(r22)*(x8350)))+(((r21)*(x8349))))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(IKsqr(((((cj0)*(r10)*(x8347)))+(((IkReal(-1.00000000000000))*(r01)*(x8348)*(x8349)))+(((IkReal(-1.00000000000000))*(r00)*(x8347)*(x8348)))+(((cj5)*(r02)*(sj0)))+(((cj0)*(r11)*(x8349)))+(((IkReal(-1.00000000000000))*(cj0)*(r12)*(x8350)))))+IKsqr(((((IKabs(sj1) != 0)?((IkReal)1/(sj1)):(IkReal)1.0e30))*(((((r20)*(x8347)))+(((IkReal(-1.00000000000000))*(r22)*(x8350)))+(((r21)*(x8349)))))))-1) <= IKFAST_SINCOS_THRESH )
    continue;
j3array[0]=IKatan2(((((cj0)*(r10)*(x8347)))+(((IkReal(-1.00000000000000))*(r01)*(x8348)*(x8349)))+(((IkReal(-1.00000000000000))*(r00)*(x8347)*(x8348)))+(((cj5)*(r02)*(sj0)))+(((cj0)*(r11)*(x8349)))+(((IkReal(-1.00000000000000))*(cj0)*(r12)*(x8350)))), ((((IKabs(sj1) != 0)?((IkReal)1/(sj1)):(IkReal)1.0e30))*(((((r20)*(x8347)))+(((IkReal(-1.00000000000000))*(r22)*(x8350)))+(((r21)*(x8349)))))));
sj3array[0]=IKsin(j3array[0]);
cj3array[0]=IKcos(j3array[0]);
if( j3array[0] > IKPI )
{
    j3array[0]-=IK2PI;
}
else if( j3array[0] < -IKPI )
{    j3array[0]+=IK2PI;
}
j3valid[0] = true;
for(int ij3 = 0; ij3 < 1; ++ij3)
{
if( !j3valid[ij3] )
{
    continue;
}
_ij3[0] = ij3; _ij3[1] = -1;
for(int iij3 = ij3+1; iij3 < 1; ++iij3)
{
if( j3valid[iij3] && IKabs(cj3array[ij3]-cj3array[iij3]) < IKFAST_SOLUTION_THRESH && IKabs(sj3array[ij3]-sj3array[iij3]) < IKFAST_SOLUTION_THRESH )
{
    j3valid[iij3]=false; _ij3[1] = iij3; break; 
}
}
j3 = j3array[ij3]; cj3 = cj3array[ij3]; sj3 = sj3array[ij3];
{
IkReal evalcond[6];
IkReal x8351=IKsin(j3);
IkReal x8352=IKcos(j3);
IkReal x8353=((sj0)*(sj5));
IkReal x8354=((r00)*(sj6));
IkReal x8355=((IkReal(1.00000000000000))*(cj4));
IkReal x8356=((cj6)*(r01));
IkReal x8357=((cj0)*(cj5));
IkReal x8358=((cj5)*(sj0));
IkReal x8359=((cj6)*(r11));
IkReal x8360=((cj0)*(sj5));
IkReal x8361=((IkReal(1.00000000000000))*(cj1));
IkReal x8362=((cj6)*(sj4));
IkReal x8363=((IkReal(1.00000000000000))*(sj1));
IkReal x8364=((cj4)*(cj5));
IkReal x8365=((cj6)*(r21));
IkReal x8366=((r20)*(sj6));
IkReal x8367=((r10)*(sj6));
IkReal x8368=((IkReal(1.00000000000000))*(cj0));
IkReal x8369=((cj0)*(sj4)*(sj6));
IkReal x8370=((sj0)*(sj4)*(sj6));
evalcond[0]=((((sj5)*(x8366)))+(((sj5)*(x8365)))+(((IkReal(-1.00000000000000))*(cj5)*(r22)))+(((IkReal(-1.00000000000000))*(x8352)*(x8363))));
evalcond[1]=((((IkReal(-1.00000000000000))*(r21)*(sj4)*(sj6)))+(((x8364)*(x8365)))+(((r20)*(x8362)))+(((IkReal(-1.00000000000000))*(x8351)*(x8363)))+(((cj4)*(r22)*(sj5)))+(((x8364)*(x8366))));
evalcond[2]=((((x8353)*(x8356)))+(((IkReal(-1.00000000000000))*(x8360)*(x8367)))+(x8351)+(((IkReal(-1.00000000000000))*(r02)*(x8358)))+(((x8353)*(x8354)))+(((r12)*(x8357)))+(((IkReal(-1.00000000000000))*(x8359)*(x8360))));
evalcond[3]=((((r12)*(x8358)))+(((IkReal(-1.00000000000000))*(x8353)*(x8359)))+(((IkReal(-1.00000000000000))*(x8353)*(x8367)))+(((IkReal(-1.00000000000000))*(x8356)*(x8360)))+(((IkReal(-1.00000000000000))*(x8352)*(x8361)))+(((IkReal(-1.00000000000000))*(x8354)*(x8360)))+(((r02)*(x8357))));
evalcond[4]=((((cj4)*(x8356)*(x8358)))+(((r11)*(x8369)))+(((IkReal(-1.00000000000000))*(r01)*(x8370)))+(((IkReal(-1.00000000000000))*(x8355)*(x8357)*(x8367)))+(((r00)*(sj0)*(x8362)))+(((IkReal(-1.00000000000000))*(x8355)*(x8357)*(x8359)))+(((cj4)*(x8354)*(x8358)))+(((IkReal(-1.00000000000000))*(x8352)))+(((IkReal(-1.00000000000000))*(r12)*(x8355)*(x8360)))+(((IkReal(-1.00000000000000))*(r10)*(x8362)*(x8368)))+(((cj4)*(r02)*(x8353))));
evalcond[5]=((((IkReal(-1.00000000000000))*(x8354)*(x8355)*(x8357)))+(((IkReal(-1.00000000000000))*(r12)*(x8353)*(x8355)))+(((IkReal(-1.00000000000000))*(x8351)*(x8361)))+(((IkReal(-1.00000000000000))*(x8355)*(x8358)*(x8359)))+(((IkReal(-1.00000000000000))*(r02)*(x8355)*(x8360)))+(((r11)*(x8370)))+(((IkReal(-1.00000000000000))*(x8355)*(x8358)*(x8367)))+(((IkReal(-1.00000000000000))*(r00)*(x8362)*(x8368)))+(((IkReal(-1.00000000000000))*(x8355)*(x8356)*(x8357)))+(((r01)*(x8369)))+(((IkReal(-1.00000000000000))*(r10)*(sj0)*(x8362))));
if( IKabs(evalcond[0]) > 0.000001  || IKabs(evalcond[1]) > 0.000001  || IKabs(evalcond[2]) > 0.000001  || IKabs(evalcond[3]) > 0.000001  || IKabs(evalcond[4]) > 0.000001  || IKabs(evalcond[5]) > 0.000001  )
{
continue;
}
}

{
std::vector<IkSingleDOFSolutionBase<IkReal> > vinfos(7);
vinfos[0].jointtype = 1;
vinfos[0].foffset = j0;
vinfos[0].indices[0] = _ij0[0];
vinfos[0].indices[1] = _ij0[1];
vinfos[0].maxsolutions = _nj0;
vinfos[1].jointtype = 1;
vinfos[1].foffset = j1;
vinfos[1].indices[0] = _ij1[0];
vinfos[1].indices[1] = _ij1[1];
vinfos[1].maxsolutions = _nj1;
vinfos[2].jointtype = 1;
vinfos[2].foffset = j2;
vinfos[2].indices[0] = _ij2[0];
vinfos[2].indices[1] = _ij2[1];
vinfos[2].maxsolutions = _nj2;
vinfos[3].jointtype = 1;
vinfos[3].foffset = j3;
vinfos[3].indices[0] = _ij3[0];
vinfos[3].indices[1] = _ij3[1];
vinfos[3].maxsolutions = _nj3;
vinfos[4].jointtype = 1;
vinfos[4].foffset = j4;
vinfos[4].indices[0] = _ij4[0];
vinfos[4].indices[1] = _ij4[1];
vinfos[4].maxsolutions = _nj4;
vinfos[5].jointtype = 1;
vinfos[5].foffset = j5;
vinfos[5].indices[0] = _ij5[0];
vinfos[5].indices[1] = _ij5[1];
vinfos[5].maxsolutions = _nj5;
vinfos[6].jointtype = 1;
vinfos[6].foffset = j6;
vinfos[6].indices[0] = _ij6[0];
vinfos[6].indices[1] = _ij6[1];
vinfos[6].maxsolutions = _nj6;
std::vector<int> vfree(0);
solutions.AddSolution(vinfos,vfree);
}
}
}

}

}

} else
{
{
IkReal j3array[1], cj3array[1], sj3array[1];
bool j3valid[1]={false};
_nj3 = 1;
IkReal x8371=((r20)*(sj6));
IkReal x8372=((cj4)*(cj5));
IkReal x8373=((cj6)*(r21));
if( IKabs(((gconst12)*(((((x8371)*(x8372)))+(((IkReal(-1.00000000000000))*(r21)*(sj4)*(sj6)))+(((cj6)*(r20)*(sj4)))+(((cj4)*(r22)*(sj5)))+(((x8372)*(x8373))))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(((gconst12)*(((((sj5)*(x8371)))+(((IkReal(-1.00000000000000))*(cj5)*(r22)))+(((sj5)*(x8373))))))) < IKFAST_ATAN2_MAGTHRESH )
    continue;
j3array[0]=IKatan2(((gconst12)*(((((x8371)*(x8372)))+(((IkReal(-1.00000000000000))*(r21)*(sj4)*(sj6)))+(((cj6)*(r20)*(sj4)))+(((cj4)*(r22)*(sj5)))+(((x8372)*(x8373)))))), ((gconst12)*(((((sj5)*(x8371)))+(((IkReal(-1.00000000000000))*(cj5)*(r22)))+(((sj5)*(x8373)))))));
sj3array[0]=IKsin(j3array[0]);
cj3array[0]=IKcos(j3array[0]);
if( j3array[0] > IKPI )
{
    j3array[0]-=IK2PI;
}
else if( j3array[0] < -IKPI )
{    j3array[0]+=IK2PI;
}
j3valid[0] = true;
for(int ij3 = 0; ij3 < 1; ++ij3)
{
if( !j3valid[ij3] )
{
    continue;
}
_ij3[0] = ij3; _ij3[1] = -1;
for(int iij3 = ij3+1; iij3 < 1; ++iij3)
{
if( j3valid[iij3] && IKabs(cj3array[ij3]-cj3array[iij3]) < IKFAST_SOLUTION_THRESH && IKabs(sj3array[ij3]-sj3array[iij3]) < IKFAST_SOLUTION_THRESH )
{
    j3valid[iij3]=false; _ij3[1] = iij3; break; 
}
}
j3 = j3array[ij3]; cj3 = cj3array[ij3]; sj3 = sj3array[ij3];
{
IkReal evalcond[6];
IkReal x8374=IKsin(j3);
IkReal x8375=IKcos(j3);
IkReal x8376=((sj0)*(sj5));
IkReal x8377=((r00)*(sj6));
IkReal x8378=((IkReal(1.00000000000000))*(cj4));
IkReal x8379=((cj6)*(r01));
IkReal x8380=((cj0)*(cj5));
IkReal x8381=((cj5)*(sj0));
IkReal x8382=((cj6)*(r11));
IkReal x8383=((cj0)*(sj5));
IkReal x8384=((IkReal(1.00000000000000))*(cj1));
IkReal x8385=((cj6)*(sj4));
IkReal x8386=((IkReal(1.00000000000000))*(sj1));
IkReal x8387=((cj4)*(cj5));
IkReal x8388=((cj6)*(r21));
IkReal x8389=((r20)*(sj6));
IkReal x8390=((r10)*(sj6));
IkReal x8391=((IkReal(1.00000000000000))*(cj0));
IkReal x8392=((cj0)*(sj4)*(sj6));
IkReal x8393=((sj0)*(sj4)*(sj6));
evalcond[0]=((((IkReal(-1.00000000000000))*(cj5)*(r22)))+(((sj5)*(x8389)))+(((IkReal(-1.00000000000000))*(x8375)*(x8386)))+(((sj5)*(x8388))));
evalcond[1]=((((IkReal(-1.00000000000000))*(r21)*(sj4)*(sj6)))+(((IkReal(-1.00000000000000))*(x8374)*(x8386)))+(((x8387)*(x8389)))+(((x8387)*(x8388)))+(((cj4)*(r22)*(sj5)))+(((r20)*(x8385))));
evalcond[2]=((((r12)*(x8380)))+(((IkReal(-1.00000000000000))*(r02)*(x8381)))+(x8374)+(((x8376)*(x8377)))+(((IkReal(-1.00000000000000))*(x8382)*(x8383)))+(((x8376)*(x8379)))+(((IkReal(-1.00000000000000))*(x8383)*(x8390))));
evalcond[3]=((((IkReal(-1.00000000000000))*(x8376)*(x8390)))+(((r02)*(x8380)))+(((r12)*(x8381)))+(((IkReal(-1.00000000000000))*(x8377)*(x8383)))+(((IkReal(-1.00000000000000))*(x8375)*(x8384)))+(((IkReal(-1.00000000000000))*(x8376)*(x8382)))+(((IkReal(-1.00000000000000))*(x8379)*(x8383))));
evalcond[4]=((((IkReal(-1.00000000000000))*(x8375)))+(((IkReal(-1.00000000000000))*(r12)*(x8378)*(x8383)))+(((IkReal(-1.00000000000000))*(r10)*(x8385)*(x8391)))+(((cj4)*(r02)*(x8376)))+(((r00)*(sj0)*(x8385)))+(((IkReal(-1.00000000000000))*(x8378)*(x8380)*(x8382)))+(((r11)*(x8392)))+(((IkReal(-1.00000000000000))*(x8378)*(x8380)*(x8390)))+(((IkReal(-1.00000000000000))*(r01)*(x8393)))+(((cj4)*(x8377)*(x8381)))+(((cj4)*(x8379)*(x8381))));
evalcond[5]=((((IkReal(-1.00000000000000))*(x8378)*(x8379)*(x8380)))+(((IkReal(-1.00000000000000))*(r12)*(x8376)*(x8378)))+(((IkReal(-1.00000000000000))*(x8377)*(x8378)*(x8380)))+(((IkReal(-1.00000000000000))*(x8378)*(x8381)*(x8390)))+(((r11)*(x8393)))+(((IkReal(-1.00000000000000))*(r02)*(x8378)*(x8383)))+(((IkReal(-1.00000000000000))*(x8378)*(x8381)*(x8382)))+(((IkReal(-1.00000000000000))*(r00)*(x8385)*(x8391)))+(((r01)*(x8392)))+(((IkReal(-1.00000000000000))*(r10)*(sj0)*(x8385)))+(((IkReal(-1.00000000000000))*(x8374)*(x8384))));
if( IKabs(evalcond[0]) > 0.000001  || IKabs(evalcond[1]) > 0.000001  || IKabs(evalcond[2]) > 0.000001  || IKabs(evalcond[3]) > 0.000001  || IKabs(evalcond[4]) > 0.000001  || IKabs(evalcond[5]) > 0.000001  )
{
continue;
}
}

{
std::vector<IkSingleDOFSolutionBase<IkReal> > vinfos(7);
vinfos[0].jointtype = 1;
vinfos[0].foffset = j0;
vinfos[0].indices[0] = _ij0[0];
vinfos[0].indices[1] = _ij0[1];
vinfos[0].maxsolutions = _nj0;
vinfos[1].jointtype = 1;
vinfos[1].foffset = j1;
vinfos[1].indices[0] = _ij1[0];
vinfos[1].indices[1] = _ij1[1];
vinfos[1].maxsolutions = _nj1;
vinfos[2].jointtype = 1;
vinfos[2].foffset = j2;
vinfos[2].indices[0] = _ij2[0];
vinfos[2].indices[1] = _ij2[1];
vinfos[2].maxsolutions = _nj2;
vinfos[3].jointtype = 1;
vinfos[3].foffset = j3;
vinfos[3].indices[0] = _ij3[0];
vinfos[3].indices[1] = _ij3[1];
vinfos[3].maxsolutions = _nj3;
vinfos[4].jointtype = 1;
vinfos[4].foffset = j4;
vinfos[4].indices[0] = _ij4[0];
vinfos[4].indices[1] = _ij4[1];
vinfos[4].maxsolutions = _nj4;
vinfos[5].jointtype = 1;
vinfos[5].foffset = j5;
vinfos[5].indices[0] = _ij5[0];
vinfos[5].indices[1] = _ij5[1];
vinfos[5].maxsolutions = _nj5;
vinfos[6].jointtype = 1;
vinfos[6].foffset = j6;
vinfos[6].indices[0] = _ij6[0];
vinfos[6].indices[1] = _ij6[1];
vinfos[6].maxsolutions = _nj6;
std::vector<int> vfree(0);
solutions.AddSolution(vinfos,vfree);
}
}
}

}

}

} else
{
if( 1 )
{
continue;

} else
{
}
}
}
}
}
}
}
}

} else
{
{
IkReal j3array[1], cj3array[1], sj3array[1];
bool j3valid[1]={false};
_nj3 = 1;
IkReal x8394=((IKabs(sj2) != 0)?((IkReal)1/(sj2)):(IkReal)1.0e30);
IkReal x8395=((sj5)*(sj6));
IkReal x8396=((r00)*(sj0));
IkReal x8397=((cj1)*(cj2));
IkReal x8398=((cj0)*(r10));
IkReal x8399=((cj6)*(sj5));
IkReal x8400=((r01)*(sj0));
IkReal x8401=((IkReal(1.00000000000000))*(cj0));
IkReal x8402=((cj5)*(r12));
IkReal x8403=((IkReal(1.00000000000000))*(cj5));
IkReal x8404=((r02)*(sj0));
if( IKabs(((x8394)*(((((IkReal(-1.00000000000000))*(x8395)*(x8398)))+(((x8399)*(x8400)))+(((IkReal(-1.00000000000000))*(r11)*(x8399)*(x8401)))+(((cj0)*(x8402)))+(((x8395)*(x8396)))+(((IkReal(-1.00000000000000))*(x8403)*(x8404))))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(((x8394)*(((IKabs(sj1) != 0)?((IkReal)1/(sj1)):(IkReal)1.0e30))*(((((r21)*(sj2)*(x8399)))+(((IkReal(-1.00000000000000))*(x8397)*(x8401)*(x8402)))+(((r20)*(sj2)*(x8395)))+(((cj0)*(r11)*(x8397)*(x8399)))+(((IkReal(-1.00000000000000))*(x8395)*(x8396)*(x8397)))+(((IkReal(-1.00000000000000))*(r22)*(sj2)*(x8403)))+(((IkReal(-1.00000000000000))*(x8397)*(x8399)*(x8400)))+(((x8395)*(x8397)*(x8398)))+(((cj5)*(x8397)*(x8404))))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(IKsqr(((x8394)*(((((IkReal(-1.00000000000000))*(x8395)*(x8398)))+(((x8399)*(x8400)))+(((IkReal(-1.00000000000000))*(r11)*(x8399)*(x8401)))+(((cj0)*(x8402)))+(((x8395)*(x8396)))+(((IkReal(-1.00000000000000))*(x8403)*(x8404)))))))+IKsqr(((x8394)*(((IKabs(sj1) != 0)?((IkReal)1/(sj1)):(IkReal)1.0e30))*(((((r21)*(sj2)*(x8399)))+(((IkReal(-1.00000000000000))*(x8397)*(x8401)*(x8402)))+(((r20)*(sj2)*(x8395)))+(((cj0)*(r11)*(x8397)*(x8399)))+(((IkReal(-1.00000000000000))*(x8395)*(x8396)*(x8397)))+(((IkReal(-1.00000000000000))*(r22)*(sj2)*(x8403)))+(((IkReal(-1.00000000000000))*(x8397)*(x8399)*(x8400)))+(((x8395)*(x8397)*(x8398)))+(((cj5)*(x8397)*(x8404)))))))-1) <= IKFAST_SINCOS_THRESH )
    continue;
j3array[0]=IKatan2(((x8394)*(((((IkReal(-1.00000000000000))*(x8395)*(x8398)))+(((x8399)*(x8400)))+(((IkReal(-1.00000000000000))*(r11)*(x8399)*(x8401)))+(((cj0)*(x8402)))+(((x8395)*(x8396)))+(((IkReal(-1.00000000000000))*(x8403)*(x8404)))))), ((x8394)*(((IKabs(sj1) != 0)?((IkReal)1/(sj1)):(IkReal)1.0e30))*(((((r21)*(sj2)*(x8399)))+(((IkReal(-1.00000000000000))*(x8397)*(x8401)*(x8402)))+(((r20)*(sj2)*(x8395)))+(((cj0)*(r11)*(x8397)*(x8399)))+(((IkReal(-1.00000000000000))*(x8395)*(x8396)*(x8397)))+(((IkReal(-1.00000000000000))*(r22)*(sj2)*(x8403)))+(((IkReal(-1.00000000000000))*(x8397)*(x8399)*(x8400)))+(((x8395)*(x8397)*(x8398)))+(((cj5)*(x8397)*(x8404)))))));
sj3array[0]=IKsin(j3array[0]);
cj3array[0]=IKcos(j3array[0]);
if( j3array[0] > IKPI )
{
    j3array[0]-=IK2PI;
}
else if( j3array[0] < -IKPI )
{    j3array[0]+=IK2PI;
}
j3valid[0] = true;
for(int ij3 = 0; ij3 < 1; ++ij3)
{
if( !j3valid[ij3] )
{
    continue;
}
_ij3[0] = ij3; _ij3[1] = -1;
for(int iij3 = ij3+1; iij3 < 1; ++iij3)
{
if( j3valid[iij3] && IKabs(cj3array[ij3]-cj3array[iij3]) < IKFAST_SOLUTION_THRESH && IKabs(sj3array[ij3]-sj3array[iij3]) < IKFAST_SOLUTION_THRESH )
{
    j3valid[iij3]=false; _ij3[1] = iij3; break; 
}
}
j3 = j3array[ij3]; cj3 = cj3array[ij3]; sj3 = sj3array[ij3];
{
IkReal evalcond[6];
IkReal x8405=IKcos(j3);
IkReal x8406=IKsin(j3);
IkReal x8407=((sj0)*(sj5));
IkReal x8408=((r00)*(sj6));
IkReal x8409=((IkReal(1.00000000000000))*(cj4));
IkReal x8410=((cj6)*(r01));
IkReal x8411=((cj0)*(cj5));
IkReal x8412=((cj5)*(sj0));
IkReal x8413=((cj6)*(r11));
IkReal x8414=((cj6)*(sj4));
IkReal x8415=((IkReal(1.00000000000000))*(cj1));
IkReal x8416=((cj4)*(cj5));
IkReal x8417=((cj6)*(r21));
IkReal x8418=((r20)*(sj6));
IkReal x8419=((r10)*(sj6));
IkReal x8420=((cj0)*(sj5));
IkReal x8421=((IkReal(1.00000000000000))*(cj0));
IkReal x8422=((IkReal(1.00000000000000))*(x8420));
IkReal x8423=((IkReal(1.00000000000000))*(x8406));
IkReal x8424=((cj0)*(sj4)*(sj6));
IkReal x8425=((cj2)*(x8406));
IkReal x8426=((sj0)*(sj4)*(sj6));
IkReal x8427=((IkReal(1.00000000000000))*(sj1)*(x8405));
evalcond[0]=((((sj5)*(x8418)))+(((IkReal(-1.00000000000000))*(x8415)*(x8425)))+(((IkReal(-1.00000000000000))*(cj5)*(r22)))+(((IkReal(-1.00000000000000))*(x8427)))+(((sj5)*(x8417))));
evalcond[1]=((((IkReal(-1.00000000000000))*(r21)*(sj4)*(sj6)))+(((x8416)*(x8418)))+(((r20)*(x8414)))+(((IkReal(-1.00000000000000))*(sj1)*(x8423)))+(((x8416)*(x8417)))+(((cj4)*(r22)*(sj5)))+(((cj1)*(cj2)*(x8405))));
evalcond[2]=((((IkReal(-1.00000000000000))*(x8413)*(x8422)))+(((IkReal(-1.00000000000000))*(x8419)*(x8422)))+(((x8407)*(x8410)))+(((x8407)*(x8408)))+(((IkReal(-1.00000000000000))*(sj2)*(x8423)))+(((IkReal(-1.00000000000000))*(r02)*(x8412)))+(((r12)*(x8411))));
evalcond[3]=((((IkReal(-1.00000000000000))*(x8410)*(x8422)))+(((sj1)*(x8425)))+(((IkReal(-1.00000000000000))*(x8405)*(x8415)))+(((IkReal(-1.00000000000000))*(x8408)*(x8422)))+(((r12)*(x8412)))+(((IkReal(-1.00000000000000))*(x8407)*(x8413)))+(((IkReal(-1.00000000000000))*(x8407)*(x8419)))+(((r02)*(x8411))));
evalcond[4]=((((cj4)*(x8408)*(x8412)))+(((IkReal(-1.00000000000000))*(r12)*(x8409)*(x8420)))+(((IkReal(-1.00000000000000))*(x8409)*(x8411)*(x8413)))+(((r00)*(sj0)*(x8414)))+(((IkReal(-1.00000000000000))*(r10)*(x8414)*(x8421)))+(((cj4)*(x8410)*(x8412)))+(((r11)*(x8424)))+(((cj4)*(r02)*(x8407)))+(((sj2)*(x8405)))+(((IkReal(-1.00000000000000))*(r01)*(x8426)))+(((IkReal(-1.00000000000000))*(x8409)*(x8411)*(x8419))));
evalcond[5]=((((IkReal(-1.00000000000000))*(r12)*(x8407)*(x8409)))+(((IkReal(-1.00000000000000))*(r00)*(x8414)*(x8421)))+(((IkReal(-1.00000000000000))*(x8409)*(x8412)*(x8413)))+(((IkReal(-1.00000000000000))*(r02)*(x8409)*(x8420)))+(((r11)*(x8426)))+(((IkReal(-1.00000000000000))*(r10)*(sj0)*(x8414)))+(((IkReal(-1.00000000000000))*(cj2)*(x8427)))+(((IkReal(-1.00000000000000))*(x8408)*(x8409)*(x8411)))+(((IkReal(-1.00000000000000))*(x8409)*(x8412)*(x8419)))+(((IkReal(-1.00000000000000))*(x8409)*(x8410)*(x8411)))+(((r01)*(x8424)))+(((IkReal(-1.00000000000000))*(x8406)*(x8415))));
if( IKabs(evalcond[0]) > 0.000001  || IKabs(evalcond[1]) > 0.000001  || IKabs(evalcond[2]) > 0.000001  || IKabs(evalcond[3]) > 0.000001  || IKabs(evalcond[4]) > 0.000001  || IKabs(evalcond[5]) > 0.000001  )
{
continue;
}
}

{
std::vector<IkSingleDOFSolutionBase<IkReal> > vinfos(7);
vinfos[0].jointtype = 1;
vinfos[0].foffset = j0;
vinfos[0].indices[0] = _ij0[0];
vinfos[0].indices[1] = _ij0[1];
vinfos[0].maxsolutions = _nj0;
vinfos[1].jointtype = 1;
vinfos[1].foffset = j1;
vinfos[1].indices[0] = _ij1[0];
vinfos[1].indices[1] = _ij1[1];
vinfos[1].maxsolutions = _nj1;
vinfos[2].jointtype = 1;
vinfos[2].foffset = j2;
vinfos[2].indices[0] = _ij2[0];
vinfos[2].indices[1] = _ij2[1];
vinfos[2].maxsolutions = _nj2;
vinfos[3].jointtype = 1;
vinfos[3].foffset = j3;
vinfos[3].indices[0] = _ij3[0];
vinfos[3].indices[1] = _ij3[1];
vinfos[3].maxsolutions = _nj3;
vinfos[4].jointtype = 1;
vinfos[4].foffset = j4;
vinfos[4].indices[0] = _ij4[0];
vinfos[4].indices[1] = _ij4[1];
vinfos[4].maxsolutions = _nj4;
vinfos[5].jointtype = 1;
vinfos[5].foffset = j5;
vinfos[5].indices[0] = _ij5[0];
vinfos[5].indices[1] = _ij5[1];
vinfos[5].maxsolutions = _nj5;
vinfos[6].jointtype = 1;
vinfos[6].foffset = j6;
vinfos[6].indices[0] = _ij6[0];
vinfos[6].indices[1] = _ij6[1];
vinfos[6].maxsolutions = _nj6;
std::vector<int> vfree(0);
solutions.AddSolution(vinfos,vfree);
}
}
}

}

}

} else
{
{
IkReal j3array[1], cj3array[1], sj3array[1];
bool j3valid[1]={false};
_nj3 = 1;
IkReal x8428=(cj1)*(cj1);
IkReal x8429=(sj1)*(sj1);
IkReal x8430=((r00)*(sj6));
IkReal x8431=((cj6)*(r01));
IkReal x8432=((IkReal(1.00000000000000))*(cj1));
IkReal x8433=((cj5)*(r22));
IkReal x8434=((sj5)*(sj6));
IkReal x8435=((r10)*(sj0));
IkReal x8436=((cj1)*(cj5));
IkReal x8437=((cj0)*(r02));
IkReal x8438=((r12)*(sj0));
IkReal x8439=((IkReal(1.00000000000000))*(sj1));
IkReal x8440=((cj6)*(sj5));
IkReal x8441=((cj0)*(sj5));
IkReal x8442=((r11)*(sj0));
IkReal x8443=((sj1)*(x8441));
if( IKabs(((((IKabs(((((cj2)*(x8428)))+(((cj2)*(x8429))))) != 0)?((IkReal)1/(((((cj2)*(x8428)))+(((cj2)*(x8429)))))):(IkReal)1.0e30))*(((((x8431)*(x8443)))+(((IkReal(-1.00000000000000))*(x8432)*(x8433)))+(((IkReal(-1.00000000000000))*(cj5)*(x8438)*(x8439)))+(((cj1)*(r20)*(x8434)))+(((x8430)*(x8443)))+(((sj1)*(x8440)*(x8442)))+(((cj1)*(r21)*(x8440)))+(((IkReal(-1.00000000000000))*(cj5)*(x8437)*(x8439)))+(((sj1)*(x8434)*(x8435))))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(((((IKabs(((x8428)+(x8429))) != 0)?((IkReal)1/(((x8428)+(x8429)))):(IkReal)1.0e30))*(((((r20)*(sj1)*(x8434)))+(((IkReal(-1.00000000000000))*(x8431)*(x8432)*(x8441)))+(((IkReal(-1.00000000000000))*(x8430)*(x8432)*(x8441)))+(((IkReal(-1.00000000000000))*(x8432)*(x8434)*(x8435)))+(((x8436)*(x8438)))+(((IkReal(-1.00000000000000))*(x8433)*(x8439)))+(((IkReal(-1.00000000000000))*(x8432)*(x8440)*(x8442)))+(((r21)*(sj1)*(x8440)))+(((x8436)*(x8437))))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(IKsqr(((((IKabs(((((cj2)*(x8428)))+(((cj2)*(x8429))))) != 0)?((IkReal)1/(((((cj2)*(x8428)))+(((cj2)*(x8429)))))):(IkReal)1.0e30))*(((((x8431)*(x8443)))+(((IkReal(-1.00000000000000))*(x8432)*(x8433)))+(((IkReal(-1.00000000000000))*(cj5)*(x8438)*(x8439)))+(((cj1)*(r20)*(x8434)))+(((x8430)*(x8443)))+(((sj1)*(x8440)*(x8442)))+(((cj1)*(r21)*(x8440)))+(((IkReal(-1.00000000000000))*(cj5)*(x8437)*(x8439)))+(((sj1)*(x8434)*(x8435)))))))+IKsqr(((((IKabs(((x8428)+(x8429))) != 0)?((IkReal)1/(((x8428)+(x8429)))):(IkReal)1.0e30))*(((((r20)*(sj1)*(x8434)))+(((IkReal(-1.00000000000000))*(x8431)*(x8432)*(x8441)))+(((IkReal(-1.00000000000000))*(x8430)*(x8432)*(x8441)))+(((IkReal(-1.00000000000000))*(x8432)*(x8434)*(x8435)))+(((x8436)*(x8438)))+(((IkReal(-1.00000000000000))*(x8433)*(x8439)))+(((IkReal(-1.00000000000000))*(x8432)*(x8440)*(x8442)))+(((r21)*(sj1)*(x8440)))+(((x8436)*(x8437)))))))-1) <= IKFAST_SINCOS_THRESH )
    continue;
j3array[0]=IKatan2(((((IKabs(((((cj2)*(x8428)))+(((cj2)*(x8429))))) != 0)?((IkReal)1/(((((cj2)*(x8428)))+(((cj2)*(x8429)))))):(IkReal)1.0e30))*(((((x8431)*(x8443)))+(((IkReal(-1.00000000000000))*(x8432)*(x8433)))+(((IkReal(-1.00000000000000))*(cj5)*(x8438)*(x8439)))+(((cj1)*(r20)*(x8434)))+(((x8430)*(x8443)))+(((sj1)*(x8440)*(x8442)))+(((cj1)*(r21)*(x8440)))+(((IkReal(-1.00000000000000))*(cj5)*(x8437)*(x8439)))+(((sj1)*(x8434)*(x8435)))))), ((((IKabs(((x8428)+(x8429))) != 0)?((IkReal)1/(((x8428)+(x8429)))):(IkReal)1.0e30))*(((((r20)*(sj1)*(x8434)))+(((IkReal(-1.00000000000000))*(x8431)*(x8432)*(x8441)))+(((IkReal(-1.00000000000000))*(x8430)*(x8432)*(x8441)))+(((IkReal(-1.00000000000000))*(x8432)*(x8434)*(x8435)))+(((x8436)*(x8438)))+(((IkReal(-1.00000000000000))*(x8433)*(x8439)))+(((IkReal(-1.00000000000000))*(x8432)*(x8440)*(x8442)))+(((r21)*(sj1)*(x8440)))+(((x8436)*(x8437)))))));
sj3array[0]=IKsin(j3array[0]);
cj3array[0]=IKcos(j3array[0]);
if( j3array[0] > IKPI )
{
    j3array[0]-=IK2PI;
}
else if( j3array[0] < -IKPI )
{    j3array[0]+=IK2PI;
}
j3valid[0] = true;
for(int ij3 = 0; ij3 < 1; ++ij3)
{
if( !j3valid[ij3] )
{
    continue;
}
_ij3[0] = ij3; _ij3[1] = -1;
for(int iij3 = ij3+1; iij3 < 1; ++iij3)
{
if( j3valid[iij3] && IKabs(cj3array[ij3]-cj3array[iij3]) < IKFAST_SOLUTION_THRESH && IKabs(sj3array[ij3]-sj3array[iij3]) < IKFAST_SOLUTION_THRESH )
{
    j3valid[iij3]=false; _ij3[1] = iij3; break; 
}
}
j3 = j3array[ij3]; cj3 = cj3array[ij3]; sj3 = sj3array[ij3];
{
IkReal evalcond[6];
IkReal x8444=IKcos(j3);
IkReal x8445=IKsin(j3);
IkReal x8446=((sj0)*(sj5));
IkReal x8447=((r00)*(sj6));
IkReal x8448=((IkReal(1.00000000000000))*(cj4));
IkReal x8449=((cj6)*(r01));
IkReal x8450=((cj0)*(cj5));
IkReal x8451=((cj5)*(sj0));
IkReal x8452=((cj6)*(r11));
IkReal x8453=((cj6)*(sj4));
IkReal x8454=((IkReal(1.00000000000000))*(cj1));
IkReal x8455=((cj4)*(cj5));
IkReal x8456=((cj6)*(r21));
IkReal x8457=((r20)*(sj6));
IkReal x8458=((r10)*(sj6));
IkReal x8459=((cj0)*(sj5));
IkReal x8460=((IkReal(1.00000000000000))*(cj0));
IkReal x8461=((IkReal(1.00000000000000))*(x8459));
IkReal x8462=((IkReal(1.00000000000000))*(x8445));
IkReal x8463=((cj0)*(sj4)*(sj6));
IkReal x8464=((cj2)*(x8445));
IkReal x8465=((sj0)*(sj4)*(sj6));
IkReal x8466=((IkReal(1.00000000000000))*(sj1)*(x8444));
evalcond[0]=((((IkReal(-1.00000000000000))*(x8466)))+(((sj5)*(x8456)))+(((IkReal(-1.00000000000000))*(cj5)*(r22)))+(((sj5)*(x8457)))+(((IkReal(-1.00000000000000))*(x8454)*(x8464))));
evalcond[1]=((((IkReal(-1.00000000000000))*(r21)*(sj4)*(sj6)))+(((x8455)*(x8457)))+(((IkReal(-1.00000000000000))*(sj1)*(x8462)))+(((cj4)*(r22)*(sj5)))+(((x8455)*(x8456)))+(((r20)*(x8453)))+(((cj1)*(cj2)*(x8444))));
evalcond[2]=((((x8446)*(x8449)))+(((IkReal(-1.00000000000000))*(sj2)*(x8462)))+(((IkReal(-1.00000000000000))*(x8458)*(x8461)))+(((IkReal(-1.00000000000000))*(r02)*(x8451)))+(((IkReal(-1.00000000000000))*(x8452)*(x8461)))+(((x8446)*(x8447)))+(((r12)*(x8450))));
evalcond[3]=((((IkReal(-1.00000000000000))*(x8446)*(x8458)))+(((r12)*(x8451)))+(((IkReal(-1.00000000000000))*(x8449)*(x8461)))+(((r02)*(x8450)))+(((IkReal(-1.00000000000000))*(x8444)*(x8454)))+(((IkReal(-1.00000000000000))*(x8447)*(x8461)))+(((IkReal(-1.00000000000000))*(x8446)*(x8452)))+(((sj1)*(x8464))));
evalcond[4]=((((r11)*(x8463)))+(((IkReal(-1.00000000000000))*(x8448)*(x8450)*(x8452)))+(((IkReal(-1.00000000000000))*(r12)*(x8448)*(x8459)))+(((IkReal(-1.00000000000000))*(r01)*(x8465)))+(((IkReal(-1.00000000000000))*(r10)*(x8453)*(x8460)))+(((IkReal(-1.00000000000000))*(x8448)*(x8450)*(x8458)))+(((cj4)*(x8447)*(x8451)))+(((cj4)*(x8449)*(x8451)))+(((sj2)*(x8444)))+(((r00)*(sj0)*(x8453)))+(((cj4)*(r02)*(x8446))));
evalcond[5]=((((IkReal(-1.00000000000000))*(x8448)*(x8451)*(x8452)))+(((IkReal(-1.00000000000000))*(x8447)*(x8448)*(x8450)))+(((IkReal(-1.00000000000000))*(x8445)*(x8454)))+(((IkReal(-1.00000000000000))*(cj2)*(x8466)))+(((r01)*(x8463)))+(((IkReal(-1.00000000000000))*(r02)*(x8448)*(x8459)))+(((IkReal(-1.00000000000000))*(x8448)*(x8449)*(x8450)))+(((IkReal(-1.00000000000000))*(r12)*(x8446)*(x8448)))+(((r11)*(x8465)))+(((IkReal(-1.00000000000000))*(x8448)*(x8451)*(x8458)))+(((IkReal(-1.00000000000000))*(r00)*(x8453)*(x8460)))+(((IkReal(-1.00000000000000))*(r10)*(sj0)*(x8453))));
if( IKabs(evalcond[0]) > 0.000001  || IKabs(evalcond[1]) > 0.000001  || IKabs(evalcond[2]) > 0.000001  || IKabs(evalcond[3]) > 0.000001  || IKabs(evalcond[4]) > 0.000001  || IKabs(evalcond[5]) > 0.000001  )
{
continue;
}
}

{
std::vector<IkSingleDOFSolutionBase<IkReal> > vinfos(7);
vinfos[0].jointtype = 1;
vinfos[0].foffset = j0;
vinfos[0].indices[0] = _ij0[0];
vinfos[0].indices[1] = _ij0[1];
vinfos[0].maxsolutions = _nj0;
vinfos[1].jointtype = 1;
vinfos[1].foffset = j1;
vinfos[1].indices[0] = _ij1[0];
vinfos[1].indices[1] = _ij1[1];
vinfos[1].maxsolutions = _nj1;
vinfos[2].jointtype = 1;
vinfos[2].foffset = j2;
vinfos[2].indices[0] = _ij2[0];
vinfos[2].indices[1] = _ij2[1];
vinfos[2].maxsolutions = _nj2;
vinfos[3].jointtype = 1;
vinfos[3].foffset = j3;
vinfos[3].indices[0] = _ij3[0];
vinfos[3].indices[1] = _ij3[1];
vinfos[3].maxsolutions = _nj3;
vinfos[4].jointtype = 1;
vinfos[4].foffset = j4;
vinfos[4].indices[0] = _ij4[0];
vinfos[4].indices[1] = _ij4[1];
vinfos[4].maxsolutions = _nj4;
vinfos[5].jointtype = 1;
vinfos[5].foffset = j5;
vinfos[5].indices[0] = _ij5[0];
vinfos[5].indices[1] = _ij5[1];
vinfos[5].maxsolutions = _nj5;
vinfos[6].jointtype = 1;
vinfos[6].foffset = j6;
vinfos[6].indices[0] = _ij6[0];
vinfos[6].indices[1] = _ij6[1];
vinfos[6].maxsolutions = _nj6;
std::vector<int> vfree(0);
solutions.AddSolution(vinfos,vfree);
}
}
}

}

}

} else
{
{
IkReal j3array[1], cj3array[1], sj3array[1];
bool j3valid[1]={false};
_nj3 = 1;
IkReal x8467=((sj1)*(sj6));
IkReal x8468=((r20)*(sj5));
IkReal x8469=((IkReal(1.00000000000000))*(r21));
IkReal x8470=((cj5)*(cj6));
IkReal x8471=((r22)*(sj5));
IkReal x8472=((cj4)*(sj1));
IkReal x8473=((cj1)*(cj2));
IkReal x8474=((cj5)*(r20));
IkReal x8475=((cj4)*(x8473));
IkReal x8476=((IkReal(1.00000000000000))*(cj5)*(r22));
IkReal x8477=((cj6)*(r20)*(sj4));
IkReal x8478=((cj6)*(r21)*(sj5));
if( IKabs(((gconst4)*(((((sj1)*(x8477)))+(((cj4)*(x8467)*(x8474)))+(((x8471)*(x8472)))+(((sj6)*(x8468)*(x8473)))+(((x8473)*(x8478)))+(((IkReal(-1.00000000000000))*(x8473)*(x8476)))+(((IkReal(-1.00000000000000))*(sj4)*(x8467)*(x8469)))+(((r21)*(x8470)*(x8472))))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(((gconst4)*(((((IkReal(-1.00000000000000))*(sj1)*(x8476)))+(((x8467)*(x8468)))+(((r21)*(sj4)*(sj6)*(x8473)))+(((IkReal(-1.00000000000000))*(x8473)*(x8477)))+(((IkReal(-1.00000000000000))*(x8471)*(x8475)))+(((sj1)*(x8478)))+(((IkReal(-1.00000000000000))*(sj6)*(x8474)*(x8475)))+(((IkReal(-1.00000000000000))*(x8469)*(x8470)*(x8475))))))) < IKFAST_ATAN2_MAGTHRESH )
    continue;
j3array[0]=IKatan2(((gconst4)*(((((sj1)*(x8477)))+(((cj4)*(x8467)*(x8474)))+(((x8471)*(x8472)))+(((sj6)*(x8468)*(x8473)))+(((x8473)*(x8478)))+(((IkReal(-1.00000000000000))*(x8473)*(x8476)))+(((IkReal(-1.00000000000000))*(sj4)*(x8467)*(x8469)))+(((r21)*(x8470)*(x8472)))))), ((gconst4)*(((((IkReal(-1.00000000000000))*(sj1)*(x8476)))+(((x8467)*(x8468)))+(((r21)*(sj4)*(sj6)*(x8473)))+(((IkReal(-1.00000000000000))*(x8473)*(x8477)))+(((IkReal(-1.00000000000000))*(x8471)*(x8475)))+(((sj1)*(x8478)))+(((IkReal(-1.00000000000000))*(sj6)*(x8474)*(x8475)))+(((IkReal(-1.00000000000000))*(x8469)*(x8470)*(x8475)))))));
sj3array[0]=IKsin(j3array[0]);
cj3array[0]=IKcos(j3array[0]);
if( j3array[0] > IKPI )
{
    j3array[0]-=IK2PI;
}
else if( j3array[0] < -IKPI )
{    j3array[0]+=IK2PI;
}
j3valid[0] = true;
for(int ij3 = 0; ij3 < 1; ++ij3)
{
if( !j3valid[ij3] )
{
    continue;
}
_ij3[0] = ij3; _ij3[1] = -1;
for(int iij3 = ij3+1; iij3 < 1; ++iij3)
{
if( j3valid[iij3] && IKabs(cj3array[ij3]-cj3array[iij3]) < IKFAST_SOLUTION_THRESH && IKabs(sj3array[ij3]-sj3array[iij3]) < IKFAST_SOLUTION_THRESH )
{
    j3valid[iij3]=false; _ij3[1] = iij3; break; 
}
}
j3 = j3array[ij3]; cj3 = cj3array[ij3]; sj3 = sj3array[ij3];
{
IkReal evalcond[6];
IkReal x8479=IKcos(j3);
IkReal x8480=IKsin(j3);
IkReal x8481=((sj0)*(sj5));
IkReal x8482=((r00)*(sj6));
IkReal x8483=((IkReal(1.00000000000000))*(cj4));
IkReal x8484=((cj6)*(r01));
IkReal x8485=((cj0)*(cj5));
IkReal x8486=((cj5)*(sj0));
IkReal x8487=((cj6)*(r11));
IkReal x8488=((cj6)*(sj4));
IkReal x8489=((IkReal(1.00000000000000))*(cj1));
IkReal x8490=((cj4)*(cj5));
IkReal x8491=((cj6)*(r21));
IkReal x8492=((r20)*(sj6));
IkReal x8493=((r10)*(sj6));
IkReal x8494=((cj0)*(sj5));
IkReal x8495=((IkReal(1.00000000000000))*(cj0));
IkReal x8496=((IkReal(1.00000000000000))*(x8494));
IkReal x8497=((IkReal(1.00000000000000))*(x8480));
IkReal x8498=((cj0)*(sj4)*(sj6));
IkReal x8499=((cj2)*(x8480));
IkReal x8500=((sj0)*(sj4)*(sj6));
IkReal x8501=((IkReal(1.00000000000000))*(sj1)*(x8479));
evalcond[0]=((((sj5)*(x8491)))+(((IkReal(-1.00000000000000))*(cj5)*(r22)))+(((IkReal(-1.00000000000000))*(x8489)*(x8499)))+(((sj5)*(x8492)))+(((IkReal(-1.00000000000000))*(x8501))));
evalcond[1]=((((cj1)*(cj2)*(x8479)))+(((x8490)*(x8492)))+(((IkReal(-1.00000000000000))*(r21)*(sj4)*(sj6)))+(((r20)*(x8488)))+(((x8490)*(x8491)))+(((cj4)*(r22)*(sj5)))+(((IkReal(-1.00000000000000))*(sj1)*(x8497))));
evalcond[2]=((((x8481)*(x8482)))+(((x8481)*(x8484)))+(((IkReal(-1.00000000000000))*(r02)*(x8486)))+(((IkReal(-1.00000000000000))*(x8493)*(x8496)))+(((IkReal(-1.00000000000000))*(sj2)*(x8497)))+(((IkReal(-1.00000000000000))*(x8487)*(x8496)))+(((r12)*(x8485))));
evalcond[3]=((((sj1)*(x8499)))+(((IkReal(-1.00000000000000))*(x8481)*(x8487)))+(((r02)*(x8485)))+(((IkReal(-1.00000000000000))*(x8484)*(x8496)))+(((IkReal(-1.00000000000000))*(x8481)*(x8493)))+(((IkReal(-1.00000000000000))*(x8482)*(x8496)))+(((IkReal(-1.00000000000000))*(x8479)*(x8489)))+(((r12)*(x8486))));
evalcond[4]=((((IkReal(-1.00000000000000))*(x8483)*(x8485)*(x8487)))+(((sj2)*(x8479)))+(((IkReal(-1.00000000000000))*(r12)*(x8483)*(x8494)))+(((IkReal(-1.00000000000000))*(x8483)*(x8485)*(x8493)))+(((IkReal(-1.00000000000000))*(r01)*(x8500)))+(((cj4)*(x8482)*(x8486)))+(((r11)*(x8498)))+(((r00)*(sj0)*(x8488)))+(((IkReal(-1.00000000000000))*(r10)*(x8488)*(x8495)))+(((cj4)*(x8484)*(x8486)))+(((cj4)*(r02)*(x8481))));
evalcond[5]=((((IkReal(-1.00000000000000))*(x8483)*(x8484)*(x8485)))+(((IkReal(-1.00000000000000))*(r12)*(x8481)*(x8483)))+(((r01)*(x8498)))+(((IkReal(-1.00000000000000))*(x8480)*(x8489)))+(((r11)*(x8500)))+(((IkReal(-1.00000000000000))*(x8483)*(x8486)*(x8487)))+(((IkReal(-1.00000000000000))*(cj2)*(x8501)))+(((IkReal(-1.00000000000000))*(r02)*(x8483)*(x8494)))+(((IkReal(-1.00000000000000))*(x8482)*(x8483)*(x8485)))+(((IkReal(-1.00000000000000))*(r10)*(sj0)*(x8488)))+(((IkReal(-1.00000000000000))*(x8483)*(x8486)*(x8493)))+(((IkReal(-1.00000000000000))*(r00)*(x8488)*(x8495))));
if( IKabs(evalcond[0]) > 0.000001  || IKabs(evalcond[1]) > 0.000001  || IKabs(evalcond[2]) > 0.000001  || IKabs(evalcond[3]) > 0.000001  || IKabs(evalcond[4]) > 0.000001  || IKabs(evalcond[5]) > 0.000001  )
{
continue;
}
}

{
std::vector<IkSingleDOFSolutionBase<IkReal> > vinfos(7);
vinfos[0].jointtype = 1;
vinfos[0].foffset = j0;
vinfos[0].indices[0] = _ij0[0];
vinfos[0].indices[1] = _ij0[1];
vinfos[0].maxsolutions = _nj0;
vinfos[1].jointtype = 1;
vinfos[1].foffset = j1;
vinfos[1].indices[0] = _ij1[0];
vinfos[1].indices[1] = _ij1[1];
vinfos[1].maxsolutions = _nj1;
vinfos[2].jointtype = 1;
vinfos[2].foffset = j2;
vinfos[2].indices[0] = _ij2[0];
vinfos[2].indices[1] = _ij2[1];
vinfos[2].maxsolutions = _nj2;
vinfos[3].jointtype = 1;
vinfos[3].foffset = j3;
vinfos[3].indices[0] = _ij3[0];
vinfos[3].indices[1] = _ij3[1];
vinfos[3].maxsolutions = _nj3;
vinfos[4].jointtype = 1;
vinfos[4].foffset = j4;
vinfos[4].indices[0] = _ij4[0];
vinfos[4].indices[1] = _ij4[1];
vinfos[4].maxsolutions = _nj4;
vinfos[5].jointtype = 1;
vinfos[5].foffset = j5;
vinfos[5].indices[0] = _ij5[0];
vinfos[5].indices[1] = _ij5[1];
vinfos[5].maxsolutions = _nj5;
vinfos[6].jointtype = 1;
vinfos[6].foffset = j6;
vinfos[6].indices[0] = _ij6[0];
vinfos[6].indices[1] = _ij6[1];
vinfos[6].maxsolutions = _nj6;
std::vector<int> vfree(0);
solutions.AddSolution(vinfos,vfree);
}
}
}

}

}
}
}

}

}
}
}

}

}

} else
{
{
IkReal j2array[1], cj2array[1], sj2array[1];
bool j2valid[1]={false};
_nj2 = 1;
IkReal x8502=((cj6)*(sj5));
IkReal x8503=((r01)*(sj0));
IkReal x8504=((cj5)*(cj6));
IkReal x8505=((sj5)*(sj6));
IkReal x8506=((cj0)*(r10));
IkReal x8507=((IkReal(5.42449275362319))*(sj0));
IkReal x8508=((IkReal(0.144927536231884))*(cj0));
IkReal x8509=((IkReal(5.42449275362319))*(cj0));
IkReal x8510=((IkReal(0.144927536231884))*(cj5)*(sj6));
if( IKabs(((((IkReal(14.4927536231884))*(cj0)*(py)))+(((IkReal(-14.4927536231884))*(px)*(sj0)))+(((IkReal(-1.00000000000000))*(x8506)*(x8510)))+(((IkReal(-1.00000000000000))*(r00)*(x8505)*(x8507)))+(((IkReal(-5.42449275362319))*(x8502)*(x8503)))+(((IkReal(0.144927536231884))*(r02)*(sj0)*(sj5)))+(((IkReal(-1.00000000000000))*(r11)*(x8504)*(x8508)))+(((IkReal(-1.00000000000000))*(r12)*(sj5)*(x8508)))+(((cj5)*(r02)*(x8507)))+(((r00)*(sj0)*(x8510)))+(((IkReal(-1.00000000000000))*(cj5)*(r12)*(x8509)))+(((r11)*(x8502)*(x8509)))+(((IkReal(5.42449275362319))*(x8505)*(x8506)))+(((IkReal(0.144927536231884))*(x8503)*(x8504))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(((IkReal(0.0144927536231884))*(((IKabs(cj1) != 0)?((IkReal)1/(cj1)):(IkReal)1.0e30))*(((((IkReal(374.290000000000))*(cj5)*(r22)))+(((IkReal(10.0000000000000))*(cj5)*(r20)*(sj6)))+(((IkReal(-374.290000000000))*(r20)*(x8505)))+(((IkReal(10.0000000000000))*(r22)*(sj5)))+(((IkReal(10.0000000000000))*(r21)*(x8504)))+(((IkReal(-1000.00000000000))*(pz)))+(((IkReal(-364.420000000000))*(sj1)))+(((IkReal(-374.290000000000))*(r21)*(x8502))))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(IKsqr(((((IkReal(14.4927536231884))*(cj0)*(py)))+(((IkReal(-14.4927536231884))*(px)*(sj0)))+(((IkReal(-1.00000000000000))*(x8506)*(x8510)))+(((IkReal(-1.00000000000000))*(r00)*(x8505)*(x8507)))+(((IkReal(-5.42449275362319))*(x8502)*(x8503)))+(((IkReal(0.144927536231884))*(r02)*(sj0)*(sj5)))+(((IkReal(-1.00000000000000))*(r11)*(x8504)*(x8508)))+(((IkReal(-1.00000000000000))*(r12)*(sj5)*(x8508)))+(((cj5)*(r02)*(x8507)))+(((r00)*(sj0)*(x8510)))+(((IkReal(-1.00000000000000))*(cj5)*(r12)*(x8509)))+(((r11)*(x8502)*(x8509)))+(((IkReal(5.42449275362319))*(x8505)*(x8506)))+(((IkReal(0.144927536231884))*(x8503)*(x8504)))))+IKsqr(((IkReal(0.0144927536231884))*(((IKabs(cj1) != 0)?((IkReal)1/(cj1)):(IkReal)1.0e30))*(((((IkReal(374.290000000000))*(cj5)*(r22)))+(((IkReal(10.0000000000000))*(cj5)*(r20)*(sj6)))+(((IkReal(-374.290000000000))*(r20)*(x8505)))+(((IkReal(10.0000000000000))*(r22)*(sj5)))+(((IkReal(10.0000000000000))*(r21)*(x8504)))+(((IkReal(-1000.00000000000))*(pz)))+(((IkReal(-364.420000000000))*(sj1)))+(((IkReal(-374.290000000000))*(r21)*(x8502)))))))-1) <= IKFAST_SINCOS_THRESH )
    continue;
j2array[0]=IKatan2(((((IkReal(14.4927536231884))*(cj0)*(py)))+(((IkReal(-14.4927536231884))*(px)*(sj0)))+(((IkReal(-1.00000000000000))*(x8506)*(x8510)))+(((IkReal(-1.00000000000000))*(r00)*(x8505)*(x8507)))+(((IkReal(-5.42449275362319))*(x8502)*(x8503)))+(((IkReal(0.144927536231884))*(r02)*(sj0)*(sj5)))+(((IkReal(-1.00000000000000))*(r11)*(x8504)*(x8508)))+(((IkReal(-1.00000000000000))*(r12)*(sj5)*(x8508)))+(((cj5)*(r02)*(x8507)))+(((r00)*(sj0)*(x8510)))+(((IkReal(-1.00000000000000))*(cj5)*(r12)*(x8509)))+(((r11)*(x8502)*(x8509)))+(((IkReal(5.42449275362319))*(x8505)*(x8506)))+(((IkReal(0.144927536231884))*(x8503)*(x8504)))), ((IkReal(0.0144927536231884))*(((IKabs(cj1) != 0)?((IkReal)1/(cj1)):(IkReal)1.0e30))*(((((IkReal(374.290000000000))*(cj5)*(r22)))+(((IkReal(10.0000000000000))*(cj5)*(r20)*(sj6)))+(((IkReal(-374.290000000000))*(r20)*(x8505)))+(((IkReal(10.0000000000000))*(r22)*(sj5)))+(((IkReal(10.0000000000000))*(r21)*(x8504)))+(((IkReal(-1000.00000000000))*(pz)))+(((IkReal(-364.420000000000))*(sj1)))+(((IkReal(-374.290000000000))*(r21)*(x8502)))))));
sj2array[0]=IKsin(j2array[0]);
cj2array[0]=IKcos(j2array[0]);
if( j2array[0] > IKPI )
{
    j2array[0]-=IK2PI;
}
else if( j2array[0] < -IKPI )
{    j2array[0]+=IK2PI;
}
j2valid[0] = true;
for(int ij2 = 0; ij2 < 1; ++ij2)
{
if( !j2valid[ij2] )
{
    continue;
}
_ij2[0] = ij2; _ij2[1] = -1;
for(int iij2 = ij2+1; iij2 < 1; ++iij2)
{
if( j2valid[iij2] && IKabs(cj2array[ij2]-cj2array[iij2]) < IKFAST_SOLUTION_THRESH && IKabs(sj2array[ij2]-sj2array[iij2]) < IKFAST_SOLUTION_THRESH )
{
    j2valid[iij2]=false; _ij2[1] = iij2; break; 
}
}
j2 = j2array[ij2]; cj2 = cj2array[ij2]; sj2 = sj2array[ij2];
{
IkReal evalcond[3];
IkReal x8511=IKcos(j2);
IkReal x8512=((IkReal(0.374290000000000))*(sj5));
IkReal x8513=((cj0)*(sj6));
IkReal x8514=((IkReal(0.0100000000000000))*(sj5));
IkReal x8515=((cj0)*(r02));
IkReal x8516=((IkReal(0.0100000000000000))*(cj5));
IkReal x8517=((IkReal(1.00000000000000))*(py));
IkReal x8518=((r01)*(sj0));
IkReal x8519=((r20)*(sj6));
IkReal x8520=((r11)*(sj0));
IkReal x8521=((IkReal(0.374290000000000))*(cj5));
IkReal x8522=((cj0)*(r12));
IkReal x8523=((sj0)*(x8521));
IkReal x8524=((cj6)*(x8516));
IkReal x8525=((IkReal(0.0690000000000000))*(x8511));
IkReal x8526=((r10)*(sj0)*(sj6));
IkReal x8527=((r00)*(sj0)*(sj6));
IkReal x8528=((cj0)*(cj6)*(x8512));
evalcond[0]=((((cj1)*(x8525)))+(((IkReal(0.364420000000000))*(sj1)))+(((IkReal(-1.00000000000000))*(r22)*(x8521)))+(((IkReal(-1.00000000000000))*(x8516)*(x8519)))+(pz)+(((IkReal(-1.00000000000000))*(r22)*(x8514)))+(((cj6)*(r21)*(x8512)))+(((x8512)*(x8519)))+(((IkReal(-1.00000000000000))*(r21)*(x8524))));
evalcond[1]=((((IkReal(-1.00000000000000))*(r10)*(x8512)*(x8513)))+(((IkReal(-1.00000000000000))*(r11)*(x8528)))+(((IkReal(-1.00000000000000))*(x8516)*(x8527)))+(((IkReal(-1.00000000000000))*(r02)*(x8523)))+(((x8512)*(x8527)))+(((x8521)*(x8522)))+(((r10)*(x8513)*(x8516)))+(((IkReal(-1.00000000000000))*(r02)*(sj0)*(x8514)))+(((IkReal(0.0690000000000000))*(IKsin(j2))))+(((IkReal(-1.00000000000000))*(x8518)*(x8524)))+(((IkReal(-1.00000000000000))*(cj0)*(x8517)))+(((px)*(sj0)))+(((cj6)*(x8512)*(x8518)))+(((cj0)*(r11)*(x8524)))+(((x8514)*(x8522))));
evalcond[2]=((IkReal(0.0690000000000000))+(((x8516)*(x8526)))+(((IkReal(-1.00000000000000))*(cj0)*(px)))+(((r12)*(x8523)))+(((IkReal(-1.00000000000000))*(x8512)*(x8526)))+(((IkReal(-1.00000000000000))*(sj0)*(x8517)))+(((IkReal(-1.00000000000000))*(cj6)*(x8512)*(x8520)))+(((IkReal(-1.00000000000000))*(r01)*(x8528)))+(((r00)*(x8513)*(x8516)))+(((x8515)*(x8521)))+(((IkReal(-1.00000000000000))*(sj1)*(x8525)))+(((IkReal(-1.00000000000000))*(r00)*(x8512)*(x8513)))+(((x8514)*(x8515)))+(((cj0)*(r01)*(x8524)))+(((IkReal(0.364420000000000))*(cj1)))+(((r12)*(sj0)*(x8514)))+(((x8520)*(x8524))));
if( IKabs(evalcond[0]) > 0.000001  || IKabs(evalcond[1]) > 0.000001  || IKabs(evalcond[2]) > 0.000001  )
{
continue;
}
}

{
IkReal dummyeval[1];
IkReal gconst0;
IkReal x8529=(cj6)*(cj6);
IkReal x8530=(sj6)*(sj6);
IkReal x8531=((IkReal(1.00000000000000))*(r01));
IkReal x8532=((sj0)*(sj5));
IkReal x8533=((cj6)*(r22));
IkReal x8534=((r21)*(sj6));
IkReal x8535=((r00)*(r21));
IkReal x8536=((cj0)*(sj5));
IkReal x8537=((cj6)*(r20));
IkReal x8538=((r22)*(sj6));
IkReal x8539=((cj0)*(cj5));
IkReal x8540=((IkReal(1.00000000000000))*(r10));
IkReal x8541=((cj5)*(sj0));
IkReal x8542=((r20)*(x8530));
IkReal x8543=((x8529)*(x8541));
gconst0=IKsign(((((r00)*(x8532)*(x8533)))+(((x8535)*(x8543)))+(((IkReal(-1.00000000000000))*(x8531)*(x8532)*(x8538)))+(((IkReal(-1.00000000000000))*(r02)*(x8532)*(x8537)))+(((IkReal(-1.00000000000000))*(r21)*(x8530)*(x8539)*(x8540)))+(((r12)*(x8536)*(x8537)))+(((IkReal(-1.00000000000000))*(x8531)*(x8541)*(x8542)))+(((IkReal(-1.00000000000000))*(r20)*(x8531)*(x8543)))+(((r11)*(x8536)*(x8538)))+(((x8530)*(x8535)*(x8541)))+(((IkReal(-1.00000000000000))*(x8533)*(x8536)*(x8540)))+(((r11)*(x8539)*(x8542)))+(((r11)*(r20)*(x8529)*(x8539)))+(((IkReal(-1.00000000000000))*(r21)*(x8529)*(x8539)*(x8540)))+(((r02)*(x8532)*(x8534)))+(((IkReal(-1.00000000000000))*(r12)*(x8534)*(x8536)))));
IkReal x8544=(cj6)*(cj6);
IkReal x8545=(sj6)*(sj6);
IkReal x8546=((IkReal(1.00000000000000))*(r01));
IkReal x8547=((sj0)*(sj5));
IkReal x8548=((cj6)*(r22));
IkReal x8549=((r21)*(sj6));
IkReal x8550=((r00)*(r21));
IkReal x8551=((cj0)*(sj5));
IkReal x8552=((cj6)*(r20));
IkReal x8553=((r22)*(sj6));
IkReal x8554=((cj0)*(cj5));
IkReal x8555=((IkReal(1.00000000000000))*(r10));
IkReal x8556=((cj5)*(sj0));
IkReal x8557=((r20)*(x8545));
IkReal x8558=((x8544)*(x8556));
dummyeval[0]=((((x8545)*(x8550)*(x8556)))+(((IkReal(-1.00000000000000))*(r21)*(x8544)*(x8554)*(x8555)))+(((r11)*(x8551)*(x8553)))+(((r11)*(r20)*(x8544)*(x8554)))+(((r02)*(x8547)*(x8549)))+(((IkReal(-1.00000000000000))*(x8546)*(x8547)*(x8553)))+(((r11)*(x8554)*(x8557)))+(((IkReal(-1.00000000000000))*(r20)*(x8546)*(x8558)))+(((IkReal(-1.00000000000000))*(r12)*(x8549)*(x8551)))+(((IkReal(-1.00000000000000))*(x8548)*(x8551)*(x8555)))+(((IkReal(-1.00000000000000))*(r02)*(x8547)*(x8552)))+(((r12)*(x8551)*(x8552)))+(((r00)*(x8547)*(x8548)))+(((x8550)*(x8558)))+(((IkReal(-1.00000000000000))*(x8546)*(x8556)*(x8557)))+(((IkReal(-1.00000000000000))*(r21)*(x8545)*(x8554)*(x8555))));
if( IKabs(dummyeval[0]) < 0.0000010000000000  )
{
{
IkReal dummyeval[1];
IkReal gconst1;
IkReal x8559=(cj6)*(cj6);
IkReal x8560=(sj6)*(sj6);
IkReal x8561=((sj5)*(sj6));
IkReal x8562=((IkReal(1.00000000000000))*(cj0));
IkReal x8563=((cj6)*(sj5));
IkReal x8564=((r20)*(sj0));
IkReal x8565=((cj0)*(r20));
IkReal x8566=((r00)*(r21));
IkReal x8567=((r22)*(sj0));
IkReal x8568=((IkReal(1.00000000000000))*(r21)*(sj0));
IkReal x8569=((cj5)*(x8560));
IkReal x8570=((cj5)*(x8559));
gconst1=IKsign(((((r12)*(x8563)*(x8564)))+(((r11)*(x8564)*(x8570)))+(((IkReal(-1.00000000000000))*(r10)*(x8568)*(x8570)))+(((IkReal(-1.00000000000000))*(r10)*(x8568)*(x8569)))+(((IkReal(-1.00000000000000))*(r10)*(x8563)*(x8567)))+(((IkReal(-1.00000000000000))*(x8562)*(x8566)*(x8569)))+(((r01)*(x8565)*(x8569)))+(((r02)*(x8563)*(x8565)))+(((cj0)*(r01)*(r22)*(x8561)))+(((r01)*(x8565)*(x8570)))+(((IkReal(-1.00000000000000))*(x8562)*(x8566)*(x8570)))+(((r11)*(x8564)*(x8569)))+(((IkReal(-1.00000000000000))*(r00)*(r22)*(x8562)*(x8563)))+(((IkReal(-1.00000000000000))*(r02)*(r21)*(x8561)*(x8562)))+(((r11)*(x8561)*(x8567)))+(((IkReal(-1.00000000000000))*(r12)*(x8561)*(x8568)))));
IkReal x8571=(cj6)*(cj6);
IkReal x8572=(sj6)*(sj6);
IkReal x8573=((sj5)*(sj6));
IkReal x8574=((IkReal(1.00000000000000))*(cj0));
IkReal x8575=((cj6)*(sj5));
IkReal x8576=((r20)*(sj0));
IkReal x8577=((cj0)*(r20));
IkReal x8578=((r00)*(r21));
IkReal x8579=((r22)*(sj0));
IkReal x8580=((IkReal(1.00000000000000))*(r21)*(sj0));
IkReal x8581=((cj5)*(x8572));
IkReal x8582=((cj5)*(x8571));
dummyeval[0]=((((IkReal(-1.00000000000000))*(r12)*(x8573)*(x8580)))+(((cj0)*(r01)*(r22)*(x8573)))+(((r12)*(x8575)*(x8576)))+(((IkReal(-1.00000000000000))*(r00)*(r22)*(x8574)*(x8575)))+(((r01)*(x8577)*(x8581)))+(((IkReal(-1.00000000000000))*(r10)*(x8575)*(x8579)))+(((IkReal(-1.00000000000000))*(x8574)*(x8578)*(x8582)))+(((r11)*(x8576)*(x8582)))+(((r11)*(x8576)*(x8581)))+(((r11)*(x8573)*(x8579)))+(((r01)*(x8577)*(x8582)))+(((IkReal(-1.00000000000000))*(r10)*(x8580)*(x8581)))+(((IkReal(-1.00000000000000))*(r02)*(r21)*(x8573)*(x8574)))+(((IkReal(-1.00000000000000))*(x8574)*(x8578)*(x8581)))+(((r02)*(x8575)*(x8577)))+(((IkReal(-1.00000000000000))*(r10)*(x8580)*(x8582))));
if( IKabs(dummyeval[0]) < 0.0000010000000000  )
{
{
IkReal dummyeval[2];
IkReal x8583=(cj1)*(cj1);
IkReal x8584=(sj1)*(sj1);
dummyeval[0]=((((cj2)*(x8584)))+(((cj2)*(x8583))));
dummyeval[1]=((x8583)+(x8584));
if( IKabs(dummyeval[0]) < 0.0000010000000000  || IKabs(dummyeval[1]) < 0.0000010000000000  )
{
{
IkReal evalcond[4];
IkReal x8585=((IkReal(0.374290000000000))*(sj5));
IkReal x8586=((cj0)*(sj6));
IkReal x8587=((IkReal(0.0100000000000000))*(sj5));
IkReal x8588=((cj0)*(r02));
IkReal x8589=((IkReal(0.0100000000000000))*(cj5));
IkReal x8590=((IkReal(1.00000000000000))*(py));
IkReal x8591=((r01)*(sj0));
IkReal x8592=((r20)*(sj6));
IkReal x8593=((r11)*(sj0));
IkReal x8594=((IkReal(0.374290000000000))*(cj5));
IkReal x8595=((cj0)*(r12));
IkReal x8596=((sj0)*(x8594));
IkReal x8597=((cj6)*(x8589));
IkReal x8598=((r10)*(sj0)*(sj6));
IkReal x8599=((r00)*(sj0)*(sj6));
IkReal x8600=((cj0)*(cj6)*(x8585));
evalcond[0]=((IkReal(-3.14159265358979))+(IKfmod(((IkReal(1.57079632679490))+(j2)), IkReal(6.28318530717959))));
evalcond[1]=((((IkReal(0.364420000000000))*(sj1)))+(((IkReal(-1.00000000000000))*(r22)*(x8594)))+(((IkReal(-1.00000000000000))*(r22)*(x8587)))+(((cj6)*(r21)*(x8585)))+(pz)+(((IkReal(-1.00000000000000))*(x8589)*(x8592)))+(((IkReal(-1.00000000000000))*(r21)*(x8597)))+(((x8585)*(x8592))));
evalcond[2]=((IkReal(0.0690000000000000))+(((IkReal(-1.00000000000000))*(x8591)*(x8597)))+(((IkReal(-1.00000000000000))*(r10)*(x8585)*(x8586)))+(((IkReal(-1.00000000000000))*(cj0)*(x8590)))+(((IkReal(-1.00000000000000))*(x8589)*(x8599)))+(((cj0)*(r11)*(x8597)))+(((x8587)*(x8595)))+(((x8585)*(x8599)))+(((IkReal(-1.00000000000000))*(r02)*(x8596)))+(((r10)*(x8586)*(x8589)))+(((IkReal(-1.00000000000000))*(r02)*(sj0)*(x8587)))+(((px)*(sj0)))+(((cj6)*(x8585)*(x8591)))+(((x8594)*(x8595)))+(((IkReal(-1.00000000000000))*(r11)*(x8600))));
evalcond[3]=((IkReal(0.0690000000000000))+(((IkReal(-1.00000000000000))*(cj0)*(px)))+(((x8588)*(x8594)))+(((IkReal(-1.00000000000000))*(cj6)*(x8585)*(x8593)))+(((r00)*(x8586)*(x8589)))+(((x8587)*(x8588)))+(((IkReal(-1.00000000000000))*(r01)*(x8600)))+(((r12)*(sj0)*(x8587)))+(((IkReal(-1.00000000000000))*(r00)*(x8585)*(x8586)))+(((x8589)*(x8598)))+(((r12)*(x8596)))+(((cj0)*(r01)*(x8597)))+(((IkReal(-1.00000000000000))*(x8585)*(x8598)))+(((IkReal(-1.00000000000000))*(sj0)*(x8590)))+(((x8593)*(x8597)))+(((IkReal(0.364420000000000))*(cj1))));
if( IKabs(evalcond[0]) < 0.0000010000000000  && IKabs(evalcond[1]) < 0.0000010000000000  && IKabs(evalcond[2]) < 0.0000010000000000  && IKabs(evalcond[3]) < 0.0000010000000000  )
{
{
IkReal dummyeval[1];
IkReal gconst13;
IkReal x8601=(cj6)*(cj6);
IkReal x8602=(sj6)*(sj6);
IkReal x8603=((IkReal(1.00000000000000))*(r21));
IkReal x8604=((cj6)*(r20));
IkReal x8605=((r22)*(sj5));
IkReal x8606=((r01)*(sj0));
IkReal x8607=((r00)*(sj0));
IkReal x8608=((cj0)*(r10));
IkReal x8609=((r02)*(sj0)*(sj5));
IkReal x8610=((cj5)*(x8601));
IkReal x8611=((cj0)*(r12)*(sj5));
IkReal x8612=((IkReal(1.00000000000000))*(cj0)*(r11));
IkReal x8613=((cj5)*(x8602));
IkReal x8614=((r20)*(x8613));
gconst13=IKsign(((((IkReal(-1.00000000000000))*(x8612)*(x8614)))+(((r20)*(x8606)*(x8610)))+(((IkReal(-1.00000000000000))*(x8603)*(x8607)*(x8610)))+(((x8604)*(x8609)))+(((IkReal(-1.00000000000000))*(sj6)*(x8603)*(x8609)))+(((IkReal(-1.00000000000000))*(cj6)*(x8605)*(x8607)))+(((IkReal(-1.00000000000000))*(r20)*(x8610)*(x8612)))+(((IkReal(-1.00000000000000))*(x8603)*(x8607)*(x8613)))+(((IkReal(-1.00000000000000))*(x8604)*(x8611)))+(((x8606)*(x8614)))+(((r21)*(x8608)*(x8610)))+(((sj6)*(x8605)*(x8606)))+(((IkReal(-1.00000000000000))*(sj6)*(x8605)*(x8612)))+(((r21)*(sj6)*(x8611)))+(((cj6)*(x8605)*(x8608)))+(((r21)*(x8608)*(x8613)))));
IkReal x8615=(cj6)*(cj6);
IkReal x8616=(sj6)*(sj6);
IkReal x8617=((IkReal(1.00000000000000))*(r21));
IkReal x8618=((cj6)*(r20));
IkReal x8619=((r22)*(sj5));
IkReal x8620=((r01)*(sj0));
IkReal x8621=((r00)*(sj0));
IkReal x8622=((cj0)*(r10));
IkReal x8623=((r02)*(sj0)*(sj5));
IkReal x8624=((cj5)*(x8615));
IkReal x8625=((cj0)*(r12)*(sj5));
IkReal x8626=((IkReal(1.00000000000000))*(cj0)*(r11));
IkReal x8627=((cj5)*(x8616));
IkReal x8628=((r20)*(x8627));
dummyeval[0]=((((r21)*(sj6)*(x8625)))+(((r20)*(x8620)*(x8624)))+(((IkReal(-1.00000000000000))*(x8626)*(x8628)))+(((IkReal(-1.00000000000000))*(r20)*(x8624)*(x8626)))+(((r21)*(x8622)*(x8624)))+(((IkReal(-1.00000000000000))*(x8618)*(x8625)))+(((IkReal(-1.00000000000000))*(sj6)*(x8617)*(x8623)))+(((IkReal(-1.00000000000000))*(x8617)*(x8621)*(x8624)))+(((x8620)*(x8628)))+(((cj6)*(x8619)*(x8622)))+(((x8618)*(x8623)))+(((r21)*(x8622)*(x8627)))+(((IkReal(-1.00000000000000))*(sj6)*(x8619)*(x8626)))+(((IkReal(-1.00000000000000))*(x8617)*(x8621)*(x8627)))+(((IkReal(-1.00000000000000))*(cj6)*(x8619)*(x8621)))+(((sj6)*(x8619)*(x8620))));
if( IKabs(dummyeval[0]) < 0.0000010000000000  )
{
{
IkReal dummyeval[1];
IkReal gconst14;
IkReal x8629=(cj6)*(cj6);
IkReal x8630=(sj6)*(sj6);
IkReal x8631=((sj5)*(sj6));
IkReal x8632=((IkReal(1.00000000000000))*(cj0));
IkReal x8633=((cj6)*(sj5));
IkReal x8634=((r20)*(sj0));
IkReal x8635=((cj0)*(r20));
IkReal x8636=((r00)*(r21));
IkReal x8637=((r22)*(sj0));
IkReal x8638=((IkReal(1.00000000000000))*(r21)*(sj0));
IkReal x8639=((cj5)*(x8630));
IkReal x8640=((cj5)*(x8629));
gconst14=IKsign(((((IkReal(-1.00000000000000))*(r10)*(x8638)*(x8639)))+(((IkReal(-1.00000000000000))*(r10)*(x8638)*(x8640)))+(((r01)*(x8635)*(x8640)))+(((r11)*(x8634)*(x8639)))+(((r02)*(x8633)*(x8635)))+(((r12)*(x8633)*(x8634)))+(((r11)*(x8634)*(x8640)))+(((IkReal(-1.00000000000000))*(r10)*(x8633)*(x8637)))+(((cj0)*(r01)*(r22)*(x8631)))+(((r01)*(x8635)*(x8639)))+(((IkReal(-1.00000000000000))*(r12)*(x8631)*(x8638)))+(((r11)*(x8631)*(x8637)))+(((IkReal(-1.00000000000000))*(x8632)*(x8636)*(x8639)))+(((IkReal(-1.00000000000000))*(r02)*(r21)*(x8631)*(x8632)))+(((IkReal(-1.00000000000000))*(r00)*(r22)*(x8632)*(x8633)))+(((IkReal(-1.00000000000000))*(x8632)*(x8636)*(x8640)))));
IkReal x8641=(cj6)*(cj6);
IkReal x8642=(sj6)*(sj6);
IkReal x8643=((sj5)*(sj6));
IkReal x8644=((IkReal(1.00000000000000))*(cj0));
IkReal x8645=((cj6)*(sj5));
IkReal x8646=((r20)*(sj0));
IkReal x8647=((cj0)*(r20));
IkReal x8648=((r00)*(r21));
IkReal x8649=((r22)*(sj0));
IkReal x8650=((IkReal(1.00000000000000))*(r21)*(sj0));
IkReal x8651=((cj5)*(x8642));
IkReal x8652=((cj5)*(x8641));
dummyeval[0]=((((cj0)*(r01)*(r22)*(x8643)))+(((r01)*(x8647)*(x8652)))+(((r11)*(x8646)*(x8652)))+(((IkReal(-1.00000000000000))*(r10)*(x8650)*(x8652)))+(((IkReal(-1.00000000000000))*(r10)*(x8645)*(x8649)))+(((r02)*(x8645)*(x8647)))+(((r11)*(x8643)*(x8649)))+(((IkReal(-1.00000000000000))*(r12)*(x8643)*(x8650)))+(((IkReal(-1.00000000000000))*(r10)*(x8650)*(x8651)))+(((IkReal(-1.00000000000000))*(r02)*(r21)*(x8643)*(x8644)))+(((r01)*(x8647)*(x8651)))+(((IkReal(-1.00000000000000))*(r00)*(r22)*(x8644)*(x8645)))+(((IkReal(-1.00000000000000))*(x8644)*(x8648)*(x8651)))+(((r12)*(x8645)*(x8646)))+(((r11)*(x8646)*(x8651)))+(((IkReal(-1.00000000000000))*(x8644)*(x8648)*(x8652))));
if( IKabs(dummyeval[0]) < 0.0000010000000000  )
{
{
IkReal dummyeval[1];
dummyeval[0]=sj1;
if( IKabs(dummyeval[0]) < 0.0000010000000000  )
{
{
IkReal evalcond[5];
IkReal x8653=((cj5)*(r22));
IkReal x8654=((IkReal(0.374290000000000))*(sj5));
IkReal x8655=((cj0)*(sj6));
IkReal x8656=((cj6)*(r21));
IkReal x8657=((IkReal(0.0100000000000000))*(sj5));
IkReal x8658=((cj0)*(r02));
IkReal x8659=((IkReal(0.0100000000000000))*(cj5));
IkReal x8660=((IkReal(1.00000000000000))*(py));
IkReal x8661=((r01)*(sj0));
IkReal x8662=((r20)*(sj6));
IkReal x8663=((r11)*(sj0));
IkReal x8664=((IkReal(0.374290000000000))*(cj5));
IkReal x8665=((cj0)*(r12));
IkReal x8666=((sj0)*(x8664));
IkReal x8667=((cj6)*(x8659));
IkReal x8668=((r10)*(sj0)*(sj6));
IkReal x8669=((r00)*(sj0)*(sj6));
IkReal x8670=((cj0)*(cj6)*(x8654));
evalcond[0]=((IkReal(-3.14159265358979))+(IKfmod(((IkReal(3.14159265358979))+(j1)), IkReal(6.28318530717959))));
evalcond[1]=((((sj5)*(x8656)))+(((sj5)*(x8662)))+(((IkReal(-1.00000000000000))*(x8653))));
evalcond[2]=((((x8654)*(x8656)))+(((IkReal(-0.374290000000000))*(x8653)))+(((IkReal(-1.00000000000000))*(x8659)*(x8662)))+(((IkReal(-1.00000000000000))*(x8656)*(x8659)))+(((x8654)*(x8662)))+(pz)+(((IkReal(-1.00000000000000))*(r22)*(x8657))));
evalcond[3]=((IkReal(0.0690000000000000))+(((IkReal(-1.00000000000000))*(x8659)*(x8669)))+(((IkReal(-1.00000000000000))*(r11)*(x8670)))+(((cj6)*(x8654)*(x8661)))+(((IkReal(-1.00000000000000))*(r02)*(sj0)*(x8657)))+(((x8657)*(x8665)))+(((IkReal(-1.00000000000000))*(r10)*(x8654)*(x8655)))+(((IkReal(-1.00000000000000))*(x8661)*(x8667)))+(((x8654)*(x8669)))+(((IkReal(-1.00000000000000))*(cj0)*(x8660)))+(((r10)*(x8655)*(x8659)))+(((IkReal(-1.00000000000000))*(r02)*(x8666)))+(((px)*(sj0)))+(((x8664)*(x8665)))+(((cj0)*(r11)*(x8667))));
evalcond[4]=((IkReal(0.433420000000000))+(((IkReal(-1.00000000000000))*(cj0)*(px)))+(((r00)*(x8655)*(x8659)))+(((r12)*(sj0)*(x8657)))+(((IkReal(-1.00000000000000))*(r00)*(x8654)*(x8655)))+(((IkReal(-1.00000000000000))*(x8654)*(x8668)))+(((x8657)*(x8658)))+(((IkReal(-1.00000000000000))*(r01)*(x8670)))+(((x8659)*(x8668)))+(((r12)*(x8666)))+(((x8658)*(x8664)))+(((x8663)*(x8667)))+(((cj0)*(r01)*(x8667)))+(((IkReal(-1.00000000000000))*(sj0)*(x8660)))+(((IkReal(-1.00000000000000))*(cj6)*(x8654)*(x8663))));
if( IKabs(evalcond[0]) < 0.0000010000000000  && IKabs(evalcond[1]) < 0.0000010000000000  && IKabs(evalcond[2]) < 0.0000010000000000  && IKabs(evalcond[3]) < 0.0000010000000000  && IKabs(evalcond[4]) < 0.0000010000000000  )
{
{
IkReal j3array[1], cj3array[1], sj3array[1];
bool j3valid[1]={false};
_nj3 = 1;
IkReal x8671=((cj0)*(cj5));
IkReal x8672=((IkReal(1.00000000000000))*(cj0));
IkReal x8673=((cj6)*(r11));
IkReal x8674=((r10)*(sj6));
IkReal x8675=((cj5)*(sj0));
IkReal x8676=((r00)*(sj5)*(sj6));
IkReal x8677=((cj6)*(r01)*(sj5));
IkReal x8678=((IkReal(1.00000000000000))*(sj0)*(sj5));
if( IKabs(((((sj0)*(x8677)))+(((r12)*(x8671)))+(((IkReal(-1.00000000000000))*(sj5)*(x8672)*(x8673)))+(((IkReal(-1.00000000000000))*(sj5)*(x8672)*(x8674)))+(((sj0)*(x8676)))+(((IkReal(-1.00000000000000))*(r02)*(x8675))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(((((IkReal(-1.00000000000000))*(x8672)*(x8677)))+(((r02)*(x8671)))+(((IkReal(-1.00000000000000))*(x8672)*(x8676)))+(((IkReal(-1.00000000000000))*(x8674)*(x8678)))+(((IkReal(-1.00000000000000))*(x8673)*(x8678)))+(((r12)*(x8675))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(IKsqr(((((sj0)*(x8677)))+(((r12)*(x8671)))+(((IkReal(-1.00000000000000))*(sj5)*(x8672)*(x8673)))+(((IkReal(-1.00000000000000))*(sj5)*(x8672)*(x8674)))+(((sj0)*(x8676)))+(((IkReal(-1.00000000000000))*(r02)*(x8675)))))+IKsqr(((((IkReal(-1.00000000000000))*(x8672)*(x8677)))+(((r02)*(x8671)))+(((IkReal(-1.00000000000000))*(x8672)*(x8676)))+(((IkReal(-1.00000000000000))*(x8674)*(x8678)))+(((IkReal(-1.00000000000000))*(x8673)*(x8678)))+(((r12)*(x8675)))))-1) <= IKFAST_SINCOS_THRESH )
    continue;
j3array[0]=IKatan2(((((sj0)*(x8677)))+(((r12)*(x8671)))+(((IkReal(-1.00000000000000))*(sj5)*(x8672)*(x8673)))+(((IkReal(-1.00000000000000))*(sj5)*(x8672)*(x8674)))+(((sj0)*(x8676)))+(((IkReal(-1.00000000000000))*(r02)*(x8675)))), ((((IkReal(-1.00000000000000))*(x8672)*(x8677)))+(((r02)*(x8671)))+(((IkReal(-1.00000000000000))*(x8672)*(x8676)))+(((IkReal(-1.00000000000000))*(x8674)*(x8678)))+(((IkReal(-1.00000000000000))*(x8673)*(x8678)))+(((r12)*(x8675)))));
sj3array[0]=IKsin(j3array[0]);
cj3array[0]=IKcos(j3array[0]);
if( j3array[0] > IKPI )
{
    j3array[0]-=IK2PI;
}
else if( j3array[0] < -IKPI )
{    j3array[0]+=IK2PI;
}
j3valid[0] = true;
for(int ij3 = 0; ij3 < 1; ++ij3)
{
if( !j3valid[ij3] )
{
    continue;
}
_ij3[0] = ij3; _ij3[1] = -1;
for(int iij3 = ij3+1; iij3 < 1; ++iij3)
{
if( j3valid[iij3] && IKabs(cj3array[ij3]-cj3array[iij3]) < IKFAST_SOLUTION_THRESH && IKabs(sj3array[ij3]-sj3array[iij3]) < IKFAST_SOLUTION_THRESH )
{
    j3valid[iij3]=false; _ij3[1] = iij3; break; 
}
}
j3 = j3array[ij3]; cj3 = cj3array[ij3]; sj3 = sj3array[ij3];
{
IkReal evalcond[2];
IkReal x8679=((cj0)*(cj5));
IkReal x8680=((IkReal(1.00000000000000))*(cj0));
IkReal x8681=((cj6)*(r11));
IkReal x8682=((r10)*(sj6));
IkReal x8683=((cj5)*(sj0));
IkReal x8684=((r00)*(sj5)*(sj6));
IkReal x8685=((cj6)*(r01)*(sj5));
IkReal x8686=((IkReal(1.00000000000000))*(sj0)*(sj5));
evalcond[0]=((((IkReal(-1.00000000000000))*(r02)*(x8683)))+(((IkReal(-1.00000000000000))*(sj5)*(x8680)*(x8682)))+(((sj0)*(x8684)))+(((r12)*(x8679)))+(((IkReal(-1.00000000000000))*(IKsin(j3))))+(((IkReal(-1.00000000000000))*(sj5)*(x8680)*(x8681)))+(((sj0)*(x8685))));
evalcond[1]=((((r02)*(x8679)))+(((IkReal(-1.00000000000000))*(IKcos(j3))))+(((IkReal(-1.00000000000000))*(x8680)*(x8684)))+(((IkReal(-1.00000000000000))*(x8682)*(x8686)))+(((IkReal(-1.00000000000000))*(x8680)*(x8685)))+(((IkReal(-1.00000000000000))*(x8681)*(x8686)))+(((r12)*(x8683))));
if( IKabs(evalcond[0]) > 0.000001  || IKabs(evalcond[1]) > 0.000001  )
{
continue;
}
}

{
IkReal dummyeval[1];
IkReal gconst20;
IkReal x8687=(cj5)*(cj5);
IkReal x8688=(r20)*(r20);
IkReal x8689=(sj6)*(sj6);
IkReal x8690=(cj6)*(cj6);
IkReal x8691=(r21)*(r21);
IkReal x8692=((cj6)*(r21));
IkReal x8693=((IkReal(2.00000000000000))*(r20)*(sj6));
IkReal x8694=((cj5)*(r22)*(sj5));
gconst20=IKsign(((((x8687)*(x8690)*(x8691)))+(((IkReal(-1.00000000000000))*(x8692)*(x8693)))+((((r22)*(r22))*((sj5)*(sj5))))+(((x8687)*(x8688)*(x8689)))+(((x8689)*(x8691)))+(((x8687)*(x8692)*(x8693)))+(((x8688)*(x8690)))+(((x8693)*(x8694)))+(((IkReal(2.00000000000000))*(x8692)*(x8694)))));
IkReal x8695=(cj5)*(cj5);
IkReal x8696=(r20)*(r20);
IkReal x8697=(sj6)*(sj6);
IkReal x8698=(cj6)*(cj6);
IkReal x8699=(r21)*(r21);
IkReal x8700=((cj6)*(r21));
IkReal x8701=((IkReal(2.00000000000000))*(r20)*(sj6));
IkReal x8702=((cj5)*(r22)*(sj5));
dummyeval[0]=((((IkReal(2.00000000000000))*(x8700)*(x8702)))+((((r22)*(r22))*((sj5)*(sj5))))+(((x8695)*(x8700)*(x8701)))+(((x8696)*(x8698)))+(((x8697)*(x8699)))+(((x8695)*(x8698)*(x8699)))+(((IkReal(-1.00000000000000))*(x8700)*(x8701)))+(((x8701)*(x8702)))+(((x8695)*(x8696)*(x8697))));
if( IKabs(dummyeval[0]) < 0.0000010000000000  )
{
{
IkReal dummyeval[1];
IkReal gconst21;
IkReal x8703=(cj6)*(cj6);
IkReal x8704=(sj6)*(sj6);
IkReal x8705=((IkReal(1.00000000000000))*(r21));
IkReal x8706=((cj6)*(r20));
IkReal x8707=((r22)*(sj5));
IkReal x8708=((r01)*(sj0));
IkReal x8709=((r00)*(sj0));
IkReal x8710=((cj0)*(r10));
IkReal x8711=((r02)*(sj0)*(sj5));
IkReal x8712=((cj5)*(x8703));
IkReal x8713=((cj0)*(r12)*(sj5));
IkReal x8714=((IkReal(1.00000000000000))*(cj0)*(r11));
IkReal x8715=((cj5)*(x8704));
IkReal x8716=((r20)*(x8715));
gconst21=IKsign(((((r21)*(x8710)*(x8715)))+(((sj6)*(x8707)*(x8708)))+(((cj6)*(x8707)*(x8710)))+(((IkReal(-1.00000000000000))*(r20)*(x8712)*(x8714)))+(((IkReal(-1.00000000000000))*(cj6)*(x8707)*(x8709)))+(((x8706)*(x8711)))+(((x8708)*(x8716)))+(((IkReal(-1.00000000000000))*(x8706)*(x8713)))+(((r20)*(x8708)*(x8712)))+(((IkReal(-1.00000000000000))*(sj6)*(x8707)*(x8714)))+(((IkReal(-1.00000000000000))*(x8705)*(x8709)*(x8712)))+(((r21)*(sj6)*(x8713)))+(((IkReal(-1.00000000000000))*(x8705)*(x8709)*(x8715)))+(((IkReal(-1.00000000000000))*(sj6)*(x8705)*(x8711)))+(((r21)*(x8710)*(x8712)))+(((IkReal(-1.00000000000000))*(x8714)*(x8716)))));
IkReal x8717=(cj6)*(cj6);
IkReal x8718=(sj6)*(sj6);
IkReal x8719=((IkReal(1.00000000000000))*(r21));
IkReal x8720=((cj6)*(r20));
IkReal x8721=((r22)*(sj5));
IkReal x8722=((r01)*(sj0));
IkReal x8723=((r00)*(sj0));
IkReal x8724=((cj0)*(r10));
IkReal x8725=((r02)*(sj0)*(sj5));
IkReal x8726=((cj5)*(x8717));
IkReal x8727=((cj0)*(r12)*(sj5));
IkReal x8728=((IkReal(1.00000000000000))*(cj0)*(r11));
IkReal x8729=((cj5)*(x8718));
IkReal x8730=((r20)*(x8729));
dummyeval[0]=((((x8722)*(x8730)))+(((r21)*(sj6)*(x8727)))+(((IkReal(-1.00000000000000))*(x8728)*(x8730)))+(((r21)*(x8724)*(x8729)))+(((sj6)*(x8721)*(x8722)))+(((x8720)*(x8725)))+(((r21)*(x8724)*(x8726)))+(((IkReal(-1.00000000000000))*(cj6)*(x8721)*(x8723)))+(((IkReal(-1.00000000000000))*(x8719)*(x8723)*(x8726)))+(((IkReal(-1.00000000000000))*(r20)*(x8726)*(x8728)))+(((r20)*(x8722)*(x8726)))+(((IkReal(-1.00000000000000))*(x8720)*(x8727)))+(((cj6)*(x8721)*(x8724)))+(((IkReal(-1.00000000000000))*(x8719)*(x8723)*(x8729)))+(((IkReal(-1.00000000000000))*(sj6)*(x8721)*(x8728)))+(((IkReal(-1.00000000000000))*(sj6)*(x8719)*(x8725))));
if( IKabs(dummyeval[0]) < 0.0000010000000000  )
{
continue;

} else
{
{
IkReal j4array[1], cj4array[1], sj4array[1];
bool j4valid[1]={false};
_nj4 = 1;
IkReal x8731=((sj0)*(sj6));
IkReal x8732=((cj0)*(cj6));
IkReal x8733=((IkReal(1.00000000000000))*(cj5));
IkReal x8734=((cj6)*(sj0));
IkReal x8735=((cj0)*(sj6));
if( IKabs(((gconst21)*(((((r01)*(x8731)))+(((IkReal(-1.00000000000000))*(r11)*(x8735)))+(((r10)*(x8732)))+(((IkReal(-1.00000000000000))*(r00)*(x8734))))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(((gconst21)*(((((IkReal(-1.00000000000000))*(r00)*(x8731)*(x8733)))+(((IkReal(-1.00000000000000))*(r01)*(x8733)*(x8734)))+(((cj0)*(r12)*(sj5)))+(((cj5)*(r11)*(x8732)))+(((IkReal(-1.00000000000000))*(r02)*(sj0)*(sj5)))+(((cj5)*(r10)*(x8735))))))) < IKFAST_ATAN2_MAGTHRESH )
    continue;
j4array[0]=IKatan2(((gconst21)*(((((r01)*(x8731)))+(((IkReal(-1.00000000000000))*(r11)*(x8735)))+(((r10)*(x8732)))+(((IkReal(-1.00000000000000))*(r00)*(x8734)))))), ((gconst21)*(((((IkReal(-1.00000000000000))*(r00)*(x8731)*(x8733)))+(((IkReal(-1.00000000000000))*(r01)*(x8733)*(x8734)))+(((cj0)*(r12)*(sj5)))+(((cj5)*(r11)*(x8732)))+(((IkReal(-1.00000000000000))*(r02)*(sj0)*(sj5)))+(((cj5)*(r10)*(x8735)))))));
sj4array[0]=IKsin(j4array[0]);
cj4array[0]=IKcos(j4array[0]);
if( j4array[0] > IKPI )
{
    j4array[0]-=IK2PI;
}
else if( j4array[0] < -IKPI )
{    j4array[0]+=IK2PI;
}
j4valid[0] = true;
for(int ij4 = 0; ij4 < 1; ++ij4)
{
if( !j4valid[ij4] )
{
    continue;
}
_ij4[0] = ij4; _ij4[1] = -1;
for(int iij4 = ij4+1; iij4 < 1; ++iij4)
{
if( j4valid[iij4] && IKabs(cj4array[ij4]-cj4array[iij4]) < IKFAST_SOLUTION_THRESH && IKabs(sj4array[ij4]-sj4array[iij4]) < IKFAST_SOLUTION_THRESH )
{
    j4valid[iij4]=false; _ij4[1] = iij4; break; 
}
}
j4 = j4array[ij4]; cj4 = cj4array[ij4]; sj4 = sj4array[ij4];
{
IkReal evalcond[6];
IkReal x8736=IKsin(j4);
IkReal x8737=IKcos(j4);
IkReal x8738=((r22)*(sj5));
IkReal x8739=((IkReal(1.00000000000000))*(cj6));
IkReal x8740=((IkReal(1.00000000000000))*(cj0));
IkReal x8741=((cj5)*(r11));
IkReal x8742=((cj5)*(cj6));
IkReal x8743=((r11)*(sj6));
IkReal x8744=((IkReal(1.00000000000000))*(sj6));
IkReal x8745=((cj6)*(r00));
IkReal x8746=((r12)*(sj5));
IkReal x8747=((r02)*(sj5));
IkReal x8748=((cj6)*(r10));
IkReal x8749=((cj5)*(sj6));
IkReal x8750=((cj5)*(r01));
IkReal x8751=((sj0)*(x8736));
IkReal x8752=((r00)*(x8749));
IkReal x8753=((cj0)*(x8736));
IkReal x8754=((sj0)*(x8737));
IkReal x8755=((r20)*(x8737));
IkReal x8756=((cj0)*(x8737));
IkReal x8757=((r21)*(x8736));
IkReal x8758=((r21)*(x8737));
IkReal x8759=((r20)*(x8736));
IkReal x8760=((x8737)*(x8746));
IkReal x8761=((r01)*(sj6)*(x8737));
IkReal x8762=((cj5)*(r10)*(x8744));
evalcond[0]=((IkReal(-1.00000000000000))+(((x8736)*(x8738)))+(((IkReal(-1.00000000000000))*(x8739)*(x8755)))+(((x8749)*(x8759)))+(((x8742)*(x8757)))+(((sj6)*(x8758))));
evalcond[1]=((((x8749)*(x8755)))+(((x8742)*(x8758)))+(((IkReal(-1.00000000000000))*(x8744)*(x8757)))+(((cj6)*(x8759)))+(((x8737)*(x8738))));
evalcond[2]=((((IkReal(-1.00000000000000))*(x8739)*(x8741)*(x8753)))+(((IkReal(-1.00000000000000))*(x8737)*(x8740)*(x8743)))+(((x8748)*(x8756)))+(((IkReal(-1.00000000000000))*(r10)*(x8736)*(x8740)*(x8749)))+(((IkReal(-1.00000000000000))*(x8736)*(x8740)*(x8746)))+(((x8747)*(x8751)))+(((r01)*(x8742)*(x8751)))+(((x8751)*(x8752)))+(((r01)*(sj6)*(x8754)))+(((IkReal(-1.00000000000000))*(r00)*(x8739)*(x8754))));
evalcond[3]=((((x8747)*(x8754)))+(((r01)*(x8742)*(x8754)))+(((IkReal(-1.00000000000000))*(r10)*(x8739)*(x8753)))+(((IkReal(-1.00000000000000))*(x8740)*(x8760)))+(((x8752)*(x8754)))+(((IkReal(-1.00000000000000))*(r10)*(x8737)*(x8740)*(x8749)))+(cj3)+(((x8743)*(x8753)))+(((IkReal(-1.00000000000000))*(x8739)*(x8741)*(x8756)))+(((x8745)*(x8751)))+(((IkReal(-1.00000000000000))*(r01)*(x8744)*(x8751))));
evalcond[4]=((((IkReal(-1.00000000000000))*(x8743)*(x8754)))+(((IkReal(-1.00000000000000))*(x8739)*(x8750)*(x8753)))+(((IkReal(-1.00000000000000))*(x8736)*(x8740)*(x8752)))+(((IkReal(-1.00000000000000))*(x8736)*(x8740)*(x8747)))+(((x8748)*(x8754)))+(((IkReal(-1.00000000000000))*(x8746)*(x8751)))+(((IkReal(-1.00000000000000))*(x8739)*(x8741)*(x8751)))+(((x8745)*(x8756)))+(((IkReal(-1.00000000000000))*(x8751)*(x8762)))+(((IkReal(-1.00000000000000))*(x8740)*(x8761))));
evalcond[5]=((((IkReal(-1.00000000000000))*(x8737)*(x8740)*(x8747)))+(((r01)*(sj6)*(x8753)))+(((IkReal(-1.00000000000000))*(x8746)*(x8754)))+(((x8743)*(x8751)))+(((IkReal(-1.00000000000000))*(x8739)*(x8750)*(x8756)))+(((IkReal(-1.00000000000000))*(r00)*(x8739)*(x8753)))+(((IkReal(-1.00000000000000))*(x8737)*(x8740)*(x8752)))+(((IkReal(-1.00000000000000))*(x8739)*(x8741)*(x8754)))+(((IkReal(-1.00000000000000))*(sj3)))+(((IkReal(-1.00000000000000))*(r10)*(x8739)*(x8751)))+(((IkReal(-1.00000000000000))*(x8754)*(x8762))));
if( IKabs(evalcond[0]) > 0.000001  || IKabs(evalcond[1]) > 0.000001  || IKabs(evalcond[2]) > 0.000001  || IKabs(evalcond[3]) > 0.000001  || IKabs(evalcond[4]) > 0.000001  || IKabs(evalcond[5]) > 0.000001  )
{
continue;
}
}

{
std::vector<IkSingleDOFSolutionBase<IkReal> > vinfos(7);
vinfos[0].jointtype = 1;
vinfos[0].foffset = j0;
vinfos[0].indices[0] = _ij0[0];
vinfos[0].indices[1] = _ij0[1];
vinfos[0].maxsolutions = _nj0;
vinfos[1].jointtype = 1;
vinfos[1].foffset = j1;
vinfos[1].indices[0] = _ij1[0];
vinfos[1].indices[1] = _ij1[1];
vinfos[1].maxsolutions = _nj1;
vinfos[2].jointtype = 1;
vinfos[2].foffset = j2;
vinfos[2].indices[0] = _ij2[0];
vinfos[2].indices[1] = _ij2[1];
vinfos[2].maxsolutions = _nj2;
vinfos[3].jointtype = 1;
vinfos[3].foffset = j3;
vinfos[3].indices[0] = _ij3[0];
vinfos[3].indices[1] = _ij3[1];
vinfos[3].maxsolutions = _nj3;
vinfos[4].jointtype = 1;
vinfos[4].foffset = j4;
vinfos[4].indices[0] = _ij4[0];
vinfos[4].indices[1] = _ij4[1];
vinfos[4].maxsolutions = _nj4;
vinfos[5].jointtype = 1;
vinfos[5].foffset = j5;
vinfos[5].indices[0] = _ij5[0];
vinfos[5].indices[1] = _ij5[1];
vinfos[5].maxsolutions = _nj5;
vinfos[6].jointtype = 1;
vinfos[6].foffset = j6;
vinfos[6].indices[0] = _ij6[0];
vinfos[6].indices[1] = _ij6[1];
vinfos[6].maxsolutions = _nj6;
std::vector<int> vfree(0);
solutions.AddSolution(vinfos,vfree);
}
}
}

}

}

} else
{
{
IkReal j4array[1], cj4array[1], sj4array[1];
bool j4valid[1]={false};
_nj4 = 1;
if( IKabs(((gconst20)*(((((cj5)*(r20)*(sj6)))+(((r22)*(sj5)))+(((cj5)*(cj6)*(r21))))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(((gconst20)*(((((r21)*(sj6)))+(((IkReal(-1.00000000000000))*(cj6)*(r20))))))) < IKFAST_ATAN2_MAGTHRESH )
    continue;
j4array[0]=IKatan2(((gconst20)*(((((cj5)*(r20)*(sj6)))+(((r22)*(sj5)))+(((cj5)*(cj6)*(r21)))))), ((gconst20)*(((((r21)*(sj6)))+(((IkReal(-1.00000000000000))*(cj6)*(r20)))))));
sj4array[0]=IKsin(j4array[0]);
cj4array[0]=IKcos(j4array[0]);
if( j4array[0] > IKPI )
{
    j4array[0]-=IK2PI;
}
else if( j4array[0] < -IKPI )
{    j4array[0]+=IK2PI;
}
j4valid[0] = true;
for(int ij4 = 0; ij4 < 1; ++ij4)
{
if( !j4valid[ij4] )
{
    continue;
}
_ij4[0] = ij4; _ij4[1] = -1;
for(int iij4 = ij4+1; iij4 < 1; ++iij4)
{
if( j4valid[iij4] && IKabs(cj4array[ij4]-cj4array[iij4]) < IKFAST_SOLUTION_THRESH && IKabs(sj4array[ij4]-sj4array[iij4]) < IKFAST_SOLUTION_THRESH )
{
    j4valid[iij4]=false; _ij4[1] = iij4; break; 
}
}
j4 = j4array[ij4]; cj4 = cj4array[ij4]; sj4 = sj4array[ij4];
{
IkReal evalcond[6];
IkReal x8763=IKsin(j4);
IkReal x8764=IKcos(j4);
IkReal x8765=((r22)*(sj5));
IkReal x8766=((IkReal(1.00000000000000))*(cj6));
IkReal x8767=((IkReal(1.00000000000000))*(cj0));
IkReal x8768=((cj5)*(r11));
IkReal x8769=((cj5)*(cj6));
IkReal x8770=((r11)*(sj6));
IkReal x8771=((IkReal(1.00000000000000))*(sj6));
IkReal x8772=((cj6)*(r00));
IkReal x8773=((r12)*(sj5));
IkReal x8774=((r02)*(sj5));
IkReal x8775=((cj6)*(r10));
IkReal x8776=((cj5)*(sj6));
IkReal x8777=((cj5)*(r01));
IkReal x8778=((sj0)*(x8763));
IkReal x8779=((r00)*(x8776));
IkReal x8780=((cj0)*(x8763));
IkReal x8781=((sj0)*(x8764));
IkReal x8782=((r20)*(x8764));
IkReal x8783=((cj0)*(x8764));
IkReal x8784=((r21)*(x8763));
IkReal x8785=((r21)*(x8764));
IkReal x8786=((r20)*(x8763));
IkReal x8787=((x8764)*(x8773));
IkReal x8788=((r01)*(sj6)*(x8764));
IkReal x8789=((cj5)*(r10)*(x8771));
evalcond[0]=((IkReal(-1.00000000000000))+(((x8763)*(x8765)))+(((x8769)*(x8784)))+(((IkReal(-1.00000000000000))*(x8766)*(x8782)))+(((sj6)*(x8785)))+(((x8776)*(x8786))));
evalcond[1]=((((x8769)*(x8785)))+(((IkReal(-1.00000000000000))*(x8771)*(x8784)))+(((cj6)*(x8786)))+(((x8764)*(x8765)))+(((x8776)*(x8782))));
evalcond[2]=((((r01)*(sj6)*(x8781)))+(((IkReal(-1.00000000000000))*(r00)*(x8766)*(x8781)))+(((r01)*(x8769)*(x8778)))+(((IkReal(-1.00000000000000))*(r10)*(x8763)*(x8767)*(x8776)))+(((IkReal(-1.00000000000000))*(x8764)*(x8767)*(x8770)))+(((x8774)*(x8778)))+(((IkReal(-1.00000000000000))*(x8766)*(x8768)*(x8780)))+(((IkReal(-1.00000000000000))*(x8763)*(x8767)*(x8773)))+(((x8775)*(x8783)))+(((x8778)*(x8779))));
evalcond[3]=((((r01)*(x8769)*(x8781)))+(((x8770)*(x8780)))+(((x8779)*(x8781)))+(((IkReal(-1.00000000000000))*(r10)*(x8764)*(x8767)*(x8776)))+(((IkReal(-1.00000000000000))*(x8766)*(x8768)*(x8783)))+(((IkReal(-1.00000000000000))*(r01)*(x8771)*(x8778)))+(((IkReal(-1.00000000000000))*(r10)*(x8766)*(x8780)))+(cj3)+(((IkReal(-1.00000000000000))*(x8767)*(x8787)))+(((x8772)*(x8778)))+(((x8774)*(x8781))));
evalcond[4]=((((x8775)*(x8781)))+(((IkReal(-1.00000000000000))*(x8763)*(x8767)*(x8774)))+(((x8772)*(x8783)))+(((IkReal(-1.00000000000000))*(x8773)*(x8778)))+(((IkReal(-1.00000000000000))*(x8763)*(x8767)*(x8779)))+(((IkReal(-1.00000000000000))*(x8767)*(x8788)))+(((IkReal(-1.00000000000000))*(x8766)*(x8768)*(x8778)))+(((IkReal(-1.00000000000000))*(x8778)*(x8789)))+(((IkReal(-1.00000000000000))*(x8770)*(x8781)))+(((IkReal(-1.00000000000000))*(x8766)*(x8777)*(x8780))));
evalcond[5]=((((IkReal(-1.00000000000000))*(x8764)*(x8767)*(x8779)))+(((IkReal(-1.00000000000000))*(r00)*(x8766)*(x8780)))+(((IkReal(-1.00000000000000))*(x8764)*(x8767)*(x8774)))+(((IkReal(-1.00000000000000))*(r10)*(x8766)*(x8778)))+(((IkReal(-1.00000000000000))*(x8766)*(x8768)*(x8781)))+(((r01)*(sj6)*(x8780)))+(((IkReal(-1.00000000000000))*(x8766)*(x8777)*(x8783)))+(((IkReal(-1.00000000000000))*(x8773)*(x8781)))+(((IkReal(-1.00000000000000))*(sj3)))+(((x8770)*(x8778)))+(((IkReal(-1.00000000000000))*(x8781)*(x8789))));
if( IKabs(evalcond[0]) > 0.000001  || IKabs(evalcond[1]) > 0.000001  || IKabs(evalcond[2]) > 0.000001  || IKabs(evalcond[3]) > 0.000001  || IKabs(evalcond[4]) > 0.000001  || IKabs(evalcond[5]) > 0.000001  )
{
continue;
}
}

{
std::vector<IkSingleDOFSolutionBase<IkReal> > vinfos(7);
vinfos[0].jointtype = 1;
vinfos[0].foffset = j0;
vinfos[0].indices[0] = _ij0[0];
vinfos[0].indices[1] = _ij0[1];
vinfos[0].maxsolutions = _nj0;
vinfos[1].jointtype = 1;
vinfos[1].foffset = j1;
vinfos[1].indices[0] = _ij1[0];
vinfos[1].indices[1] = _ij1[1];
vinfos[1].maxsolutions = _nj1;
vinfos[2].jointtype = 1;
vinfos[2].foffset = j2;
vinfos[2].indices[0] = _ij2[0];
vinfos[2].indices[1] = _ij2[1];
vinfos[2].maxsolutions = _nj2;
vinfos[3].jointtype = 1;
vinfos[3].foffset = j3;
vinfos[3].indices[0] = _ij3[0];
vinfos[3].indices[1] = _ij3[1];
vinfos[3].maxsolutions = _nj3;
vinfos[4].jointtype = 1;
vinfos[4].foffset = j4;
vinfos[4].indices[0] = _ij4[0];
vinfos[4].indices[1] = _ij4[1];
vinfos[4].maxsolutions = _nj4;
vinfos[5].jointtype = 1;
vinfos[5].foffset = j5;
vinfos[5].indices[0] = _ij5[0];
vinfos[5].indices[1] = _ij5[1];
vinfos[5].maxsolutions = _nj5;
vinfos[6].jointtype = 1;
vinfos[6].foffset = j6;
vinfos[6].indices[0] = _ij6[0];
vinfos[6].indices[1] = _ij6[1];
vinfos[6].maxsolutions = _nj6;
std::vector<int> vfree(0);
solutions.AddSolution(vinfos,vfree);
}
}
}

}

}
}
}

} else
{
IkReal x8790=((cj5)*(r22));
IkReal x8791=((IkReal(0.374290000000000))*(sj5));
IkReal x8792=((cj0)*(sj6));
IkReal x8793=((cj6)*(r21));
IkReal x8794=((IkReal(0.0100000000000000))*(sj5));
IkReal x8795=((cj0)*(r02));
IkReal x8796=((IkReal(0.0100000000000000))*(cj5));
IkReal x8797=((IkReal(1.00000000000000))*(py));
IkReal x8798=((r01)*(sj0));
IkReal x8799=((r20)*(sj6));
IkReal x8800=((r11)*(sj0));
IkReal x8801=((IkReal(0.374290000000000))*(cj5));
IkReal x8802=((cj0)*(r12));
IkReal x8803=((sj0)*(x8801));
IkReal x8804=((cj6)*(x8796));
IkReal x8805=((r10)*(sj0)*(sj6));
IkReal x8806=((r00)*(sj0)*(sj6));
IkReal x8807=((cj0)*(cj6)*(x8791));
evalcond[0]=((IkReal(-3.14159265358979))+(IKfmod(j1, IkReal(6.28318530717959))));
evalcond[1]=((((sj5)*(x8793)))+(((sj5)*(x8799)))+(((IkReal(-1.00000000000000))*(x8790))));
evalcond[2]=((((IkReal(-1.00000000000000))*(x8793)*(x8796)))+(((x8791)*(x8799)))+(((x8791)*(x8793)))+(((IkReal(-1.00000000000000))*(x8796)*(x8799)))+(((IkReal(-0.374290000000000))*(x8790)))+(pz)+(((IkReal(-1.00000000000000))*(r22)*(x8794))));
evalcond[3]=((IkReal(0.0690000000000000))+(((x8794)*(x8802)))+(((cj6)*(x8791)*(x8798)))+(((IkReal(-1.00000000000000))*(x8796)*(x8806)))+(((x8791)*(x8806)))+(((cj0)*(r11)*(x8804)))+(((IkReal(-1.00000000000000))*(r10)*(x8791)*(x8792)))+(((IkReal(-1.00000000000000))*(r11)*(x8807)))+(((IkReal(-1.00000000000000))*(r02)*(sj0)*(x8794)))+(((IkReal(-1.00000000000000))*(r02)*(x8803)))+(((px)*(sj0)))+(((x8801)*(x8802)))+(((IkReal(-1.00000000000000))*(x8798)*(x8804)))+(((IkReal(-1.00000000000000))*(cj0)*(x8797)))+(((r10)*(x8792)*(x8796))));
evalcond[4]=((IkReal(-0.295420000000000))+(((IkReal(-1.00000000000000))*(cj0)*(px)))+(((x8800)*(x8804)))+(((x8796)*(x8805)))+(((r00)*(x8792)*(x8796)))+(((r12)*(sj0)*(x8794)))+(((IkReal(-1.00000000000000))*(x8791)*(x8805)))+(((x8794)*(x8795)))+(((IkReal(-1.00000000000000))*(cj6)*(x8791)*(x8800)))+(((IkReal(-1.00000000000000))*(r00)*(x8791)*(x8792)))+(((r12)*(x8803)))+(((cj0)*(r01)*(x8804)))+(((IkReal(-1.00000000000000))*(r01)*(x8807)))+(((x8795)*(x8801)))+(((IkReal(-1.00000000000000))*(sj0)*(x8797))));
if( IKabs(evalcond[0]) < 0.0000010000000000  && IKabs(evalcond[1]) < 0.0000010000000000  && IKabs(evalcond[2]) < 0.0000010000000000  && IKabs(evalcond[3]) < 0.0000010000000000  && IKabs(evalcond[4]) < 0.0000010000000000  )
{
{
IkReal j3array[1], cj3array[1], sj3array[1];
bool j3valid[1]={false};
_nj3 = 1;
IkReal x8808=((sj0)*(sj5));
IkReal x8809=((r00)*(sj6));
IkReal x8810=((IkReal(1.00000000000000))*(cj5));
IkReal x8811=((cj6)*(r11));
IkReal x8812=((cj6)*(r01));
IkReal x8813=((r10)*(sj6));
IkReal x8814=((cj0)*(sj5));
if( IKabs(((((x8808)*(x8812)))+(((IkReal(-1.00000000000000))*(x8813)*(x8814)))+(((cj0)*(cj5)*(r12)))+(((IkReal(-1.00000000000000))*(r02)*(sj0)*(x8810)))+(((x8808)*(x8809)))+(((IkReal(-1.00000000000000))*(x8811)*(x8814))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(((((x8808)*(x8811)))+(((x8808)*(x8813)))+(((x8809)*(x8814)))+(((x8812)*(x8814)))+(((IkReal(-1.00000000000000))*(cj0)*(r02)*(x8810)))+(((IkReal(-1.00000000000000))*(r12)*(sj0)*(x8810))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(IKsqr(((((x8808)*(x8812)))+(((IkReal(-1.00000000000000))*(x8813)*(x8814)))+(((cj0)*(cj5)*(r12)))+(((IkReal(-1.00000000000000))*(r02)*(sj0)*(x8810)))+(((x8808)*(x8809)))+(((IkReal(-1.00000000000000))*(x8811)*(x8814)))))+IKsqr(((((x8808)*(x8811)))+(((x8808)*(x8813)))+(((x8809)*(x8814)))+(((x8812)*(x8814)))+(((IkReal(-1.00000000000000))*(cj0)*(r02)*(x8810)))+(((IkReal(-1.00000000000000))*(r12)*(sj0)*(x8810)))))-1) <= IKFAST_SINCOS_THRESH )
    continue;
j3array[0]=IKatan2(((((x8808)*(x8812)))+(((IkReal(-1.00000000000000))*(x8813)*(x8814)))+(((cj0)*(cj5)*(r12)))+(((IkReal(-1.00000000000000))*(r02)*(sj0)*(x8810)))+(((x8808)*(x8809)))+(((IkReal(-1.00000000000000))*(x8811)*(x8814)))), ((((x8808)*(x8811)))+(((x8808)*(x8813)))+(((x8809)*(x8814)))+(((x8812)*(x8814)))+(((IkReal(-1.00000000000000))*(cj0)*(r02)*(x8810)))+(((IkReal(-1.00000000000000))*(r12)*(sj0)*(x8810)))));
sj3array[0]=IKsin(j3array[0]);
cj3array[0]=IKcos(j3array[0]);
if( j3array[0] > IKPI )
{
    j3array[0]-=IK2PI;
}
else if( j3array[0] < -IKPI )
{    j3array[0]+=IK2PI;
}
j3valid[0] = true;
for(int ij3 = 0; ij3 < 1; ++ij3)
{
if( !j3valid[ij3] )
{
    continue;
}
_ij3[0] = ij3; _ij3[1] = -1;
for(int iij3 = ij3+1; iij3 < 1; ++iij3)
{
if( j3valid[iij3] && IKabs(cj3array[ij3]-cj3array[iij3]) < IKFAST_SOLUTION_THRESH && IKabs(sj3array[ij3]-sj3array[iij3]) < IKFAST_SOLUTION_THRESH )
{
    j3valid[iij3]=false; _ij3[1] = iij3; break; 
}
}
j3 = j3array[ij3]; cj3 = cj3array[ij3]; sj3 = sj3array[ij3];
{
IkReal evalcond[2];
IkReal x8815=((cj0)*(cj5));
IkReal x8816=((IkReal(1.00000000000000))*(cj0));
IkReal x8817=((cj6)*(r11));
IkReal x8818=((r10)*(sj6));
IkReal x8819=((cj5)*(sj0));
IkReal x8820=((r00)*(sj5)*(sj6));
IkReal x8821=((cj6)*(r01)*(sj5));
IkReal x8822=((IkReal(1.00000000000000))*(sj0)*(sj5));
evalcond[0]=((((sj0)*(x8821)))+(((r12)*(x8815)))+(((IkReal(-1.00000000000000))*(r02)*(x8819)))+(((sj0)*(x8820)))+(((IkReal(-1.00000000000000))*(sj5)*(x8816)*(x8817)))+(((IkReal(-1.00000000000000))*(sj5)*(x8816)*(x8818)))+(((IkReal(-1.00000000000000))*(IKsin(j3)))));
evalcond[1]=((((IkReal(-1.00000000000000))*(x8817)*(x8822)))+(((r12)*(x8819)))+(((IkReal(-1.00000000000000))*(x8816)*(x8820)))+(IKcos(j3))+(((IkReal(-1.00000000000000))*(x8818)*(x8822)))+(((r02)*(x8815)))+(((IkReal(-1.00000000000000))*(x8816)*(x8821))));
if( IKabs(evalcond[0]) > 0.000001  || IKabs(evalcond[1]) > 0.000001  )
{
continue;
}
}

{
IkReal dummyeval[1];
IkReal gconst24;
IkReal x8823=(r21)*(r21);
IkReal x8824=(cj5)*(cj5);
IkReal x8825=(sj6)*(sj6);
IkReal x8826=(cj6)*(cj6);
IkReal x8827=(r20)*(r20);
IkReal x8828=((cj6)*(r21));
IkReal x8829=((IkReal(2.00000000000000))*(r20)*(sj6));
IkReal x8830=((cj5)*(r22)*(sj5));
IkReal x8831=((IkReal(1.00000000000000))*(x8825));
IkReal x8832=((IkReal(1.00000000000000))*(x8826));
gconst24=IKsign(((((IkReal(-1.00000000000000))*(x8823)*(x8824)*(x8832)))+(((IkReal(-2.00000000000000))*(x8828)*(x8830)))+(((IkReal(-1.00000000000000))*(x8823)*(x8831)))+(((IkReal(-1.00000000000000))*(x8824)*(x8828)*(x8829)))+(((IkReal(-1.00000000000000))*((r22)*(r22))*((sj5)*(sj5))))+(((IkReal(-1.00000000000000))*(x8829)*(x8830)))+(((IkReal(-1.00000000000000))*(x8824)*(x8827)*(x8831)))+(((x8828)*(x8829)))+(((IkReal(-1.00000000000000))*(x8827)*(x8832)))));
IkReal x8833=(r21)*(r21);
IkReal x8834=(cj5)*(cj5);
IkReal x8835=(sj6)*(sj6);
IkReal x8836=(cj6)*(cj6);
IkReal x8837=(r20)*(r20);
IkReal x8838=((cj6)*(r21));
IkReal x8839=((IkReal(2.00000000000000))*(r20)*(sj6));
IkReal x8840=((cj5)*(r22)*(sj5));
IkReal x8841=((IkReal(1.00000000000000))*(x8835));
IkReal x8842=((IkReal(1.00000000000000))*(x8836));
dummyeval[0]=((((IkReal(-1.00000000000000))*(x8833)*(x8834)*(x8842)))+(((IkReal(-1.00000000000000))*(x8834)*(x8837)*(x8841)))+(((x8838)*(x8839)))+(((IkReal(-2.00000000000000))*(x8838)*(x8840)))+(((IkReal(-1.00000000000000))*(x8833)*(x8841)))+(((IkReal(-1.00000000000000))*((r22)*(r22))*((sj5)*(sj5))))+(((IkReal(-1.00000000000000))*(x8837)*(x8842)))+(((IkReal(-1.00000000000000))*(x8834)*(x8838)*(x8839)))+(((IkReal(-1.00000000000000))*(x8839)*(x8840))));
if( IKabs(dummyeval[0]) < 0.0000010000000000  )
{
{
IkReal dummyeval[1];
IkReal gconst25;
IkReal x8843=(cj6)*(cj6);
IkReal x8844=(sj6)*(sj6);
IkReal x8845=((IkReal(1.00000000000000))*(r01));
IkReal x8846=((sj0)*(sj5));
IkReal x8847=((cj6)*(r22));
IkReal x8848=((r21)*(sj6));
IkReal x8849=((r00)*(r21));
IkReal x8850=((cj0)*(sj5));
IkReal x8851=((cj6)*(r20));
IkReal x8852=((r22)*(sj6));
IkReal x8853=((cj0)*(cj5));
IkReal x8854=((IkReal(1.00000000000000))*(r10));
IkReal x8855=((cj5)*(sj0));
IkReal x8856=((r20)*(x8844));
IkReal x8857=((x8843)*(x8855));
gconst25=IKsign(((((IkReal(-1.00000000000000))*(x8845)*(x8855)*(x8856)))+(((IkReal(-1.00000000000000))*(r12)*(x8848)*(x8850)))+(((r02)*(x8846)*(x8848)))+(((IkReal(-1.00000000000000))*(r21)*(x8843)*(x8853)*(x8854)))+(((r11)*(x8853)*(x8856)))+(((x8849)*(x8857)))+(((IkReal(-1.00000000000000))*(r02)*(x8846)*(x8851)))+(((r11)*(r20)*(x8843)*(x8853)))+(((x8844)*(x8849)*(x8855)))+(((r12)*(x8850)*(x8851)))+(((IkReal(-1.00000000000000))*(r20)*(x8845)*(x8857)))+(((IkReal(-1.00000000000000))*(x8845)*(x8846)*(x8852)))+(((r00)*(x8846)*(x8847)))+(((IkReal(-1.00000000000000))*(r21)*(x8844)*(x8853)*(x8854)))+(((r11)*(x8850)*(x8852)))+(((IkReal(-1.00000000000000))*(x8847)*(x8850)*(x8854)))));
IkReal x8858=(cj6)*(cj6);
IkReal x8859=(sj6)*(sj6);
IkReal x8860=((IkReal(1.00000000000000))*(r01));
IkReal x8861=((sj0)*(sj5));
IkReal x8862=((cj6)*(r22));
IkReal x8863=((r21)*(sj6));
IkReal x8864=((r00)*(r21));
IkReal x8865=((cj0)*(sj5));
IkReal x8866=((cj6)*(r20));
IkReal x8867=((r22)*(sj6));
IkReal x8868=((cj0)*(cj5));
IkReal x8869=((IkReal(1.00000000000000))*(r10));
IkReal x8870=((cj5)*(sj0));
IkReal x8871=((r20)*(x8859));
IkReal x8872=((x8858)*(x8870));
dummyeval[0]=((((IkReal(-1.00000000000000))*(x8860)*(x8870)*(x8871)))+(((IkReal(-1.00000000000000))*(r21)*(x8858)*(x8868)*(x8869)))+(((IkReal(-1.00000000000000))*(x8860)*(x8861)*(x8867)))+(((IkReal(-1.00000000000000))*(x8862)*(x8865)*(x8869)))+(((x8864)*(x8872)))+(((r02)*(x8861)*(x8863)))+(((IkReal(-1.00000000000000))*(r21)*(x8859)*(x8868)*(x8869)))+(((IkReal(-1.00000000000000))*(r02)*(x8861)*(x8866)))+(((r11)*(x8865)*(x8867)))+(((r12)*(x8865)*(x8866)))+(((r00)*(x8861)*(x8862)))+(((r11)*(x8868)*(x8871)))+(((x8859)*(x8864)*(x8870)))+(((r11)*(r20)*(x8858)*(x8868)))+(((IkReal(-1.00000000000000))*(r20)*(x8860)*(x8872)))+(((IkReal(-1.00000000000000))*(r12)*(x8863)*(x8865))));
if( IKabs(dummyeval[0]) < 0.0000010000000000  )
{
continue;

} else
{
{
IkReal j4array[1], cj4array[1], sj4array[1];
bool j4valid[1]={false};
_nj4 = 1;
IkReal x8873=((r01)*(sj0));
IkReal x8874=((IkReal(1.00000000000000))*(cj5));
IkReal x8875=((cj0)*(r10));
IkReal x8876=((r00)*(sj0));
IkReal x8877=((cj0)*(r11));
if( IKabs(((gconst25)*(((((cj6)*(x8875)))+(((sj6)*(x8873)))+(((IkReal(-1.00000000000000))*(sj6)*(x8877)))+(((IkReal(-1.00000000000000))*(cj6)*(x8876))))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(((gconst25)*(((((IkReal(-1.00000000000000))*(sj6)*(x8874)*(x8876)))+(((cj0)*(r12)*(sj5)))+(((IkReal(-1.00000000000000))*(r02)*(sj0)*(sj5)))+(((cj5)*(cj6)*(x8877)))+(((IkReal(-1.00000000000000))*(cj6)*(x8873)*(x8874)))+(((cj5)*(sj6)*(x8875))))))) < IKFAST_ATAN2_MAGTHRESH )
    continue;
j4array[0]=IKatan2(((gconst25)*(((((cj6)*(x8875)))+(((sj6)*(x8873)))+(((IkReal(-1.00000000000000))*(sj6)*(x8877)))+(((IkReal(-1.00000000000000))*(cj6)*(x8876)))))), ((gconst25)*(((((IkReal(-1.00000000000000))*(sj6)*(x8874)*(x8876)))+(((cj0)*(r12)*(sj5)))+(((IkReal(-1.00000000000000))*(r02)*(sj0)*(sj5)))+(((cj5)*(cj6)*(x8877)))+(((IkReal(-1.00000000000000))*(cj6)*(x8873)*(x8874)))+(((cj5)*(sj6)*(x8875)))))));
sj4array[0]=IKsin(j4array[0]);
cj4array[0]=IKcos(j4array[0]);
if( j4array[0] > IKPI )
{
    j4array[0]-=IK2PI;
}
else if( j4array[0] < -IKPI )
{    j4array[0]+=IK2PI;
}
j4valid[0] = true;
for(int ij4 = 0; ij4 < 1; ++ij4)
{
if( !j4valid[ij4] )
{
    continue;
}
_ij4[0] = ij4; _ij4[1] = -1;
for(int iij4 = ij4+1; iij4 < 1; ++iij4)
{
if( j4valid[iij4] && IKabs(cj4array[ij4]-cj4array[iij4]) < IKFAST_SOLUTION_THRESH && IKabs(sj4array[ij4]-sj4array[iij4]) < IKFAST_SOLUTION_THRESH )
{
    j4valid[iij4]=false; _ij4[1] = iij4; break; 
}
}
j4 = j4array[ij4]; cj4 = cj4array[ij4]; sj4 = sj4array[ij4];
{
IkReal evalcond[6];
IkReal x8878=IKsin(j4);
IkReal x8879=IKcos(j4);
IkReal x8880=((r22)*(sj5));
IkReal x8881=((IkReal(1.00000000000000))*(cj6));
IkReal x8882=((IkReal(1.00000000000000))*(cj0));
IkReal x8883=((cj5)*(r11));
IkReal x8884=((cj5)*(cj6));
IkReal x8885=((r11)*(sj6));
IkReal x8886=((IkReal(1.00000000000000))*(sj6));
IkReal x8887=((cj6)*(r00));
IkReal x8888=((r12)*(sj5));
IkReal x8889=((r02)*(sj5));
IkReal x8890=((cj6)*(r10));
IkReal x8891=((cj5)*(sj6));
IkReal x8892=((cj5)*(r01));
IkReal x8893=((sj0)*(x8878));
IkReal x8894=((r00)*(x8891));
IkReal x8895=((cj0)*(x8878));
IkReal x8896=((sj0)*(x8879));
IkReal x8897=((r20)*(x8879));
IkReal x8898=((cj0)*(x8879));
IkReal x8899=((r21)*(x8878));
IkReal x8900=((r21)*(x8879));
IkReal x8901=((r20)*(x8878));
IkReal x8902=((x8879)*(x8888));
IkReal x8903=((r01)*(sj6)*(x8879));
IkReal x8904=((cj5)*(r10)*(x8886));
evalcond[0]=((IkReal(1.00000000000000))+(((x8884)*(x8899)))+(((sj6)*(x8900)))+(((x8878)*(x8880)))+(((x8891)*(x8901)))+(((IkReal(-1.00000000000000))*(x8881)*(x8897))));
evalcond[1]=((((x8879)*(x8880)))+(((x8891)*(x8897)))+(((cj6)*(x8901)))+(((IkReal(-1.00000000000000))*(x8886)*(x8899)))+(((x8884)*(x8900))));
evalcond[2]=((((r01)*(x8884)*(x8893)))+(((r01)*(sj6)*(x8896)))+(((IkReal(-1.00000000000000))*(x8879)*(x8882)*(x8885)))+(((x8890)*(x8898)))+(((x8889)*(x8893)))+(((IkReal(-1.00000000000000))*(r10)*(x8878)*(x8882)*(x8891)))+(((IkReal(-1.00000000000000))*(x8878)*(x8882)*(x8888)))+(((IkReal(-1.00000000000000))*(x8881)*(x8883)*(x8895)))+(((x8893)*(x8894)))+(((IkReal(-1.00000000000000))*(r00)*(x8881)*(x8896))));
evalcond[3]=((((r01)*(x8884)*(x8896)))+(((IkReal(-1.00000000000000))*(r10)*(x8881)*(x8895)))+(((IkReal(-1.00000000000000))*(x8881)*(x8883)*(x8898)))+(((IkReal(-1.00000000000000))*(x8882)*(x8902)))+(((IkReal(-1.00000000000000))*(r01)*(x8886)*(x8893)))+(cj3)+(((x8885)*(x8895)))+(((x8887)*(x8893)))+(((IkReal(-1.00000000000000))*(r10)*(x8879)*(x8882)*(x8891)))+(((x8889)*(x8896)))+(((x8894)*(x8896))));
evalcond[4]=((((IkReal(-1.00000000000000))*(x8881)*(x8892)*(x8895)))+(((IkReal(-1.00000000000000))*(x8878)*(x8882)*(x8894)))+(((IkReal(-1.00000000000000))*(x8878)*(x8882)*(x8889)))+(((x8890)*(x8896)))+(((IkReal(-1.00000000000000))*(x8888)*(x8893)))+(((IkReal(-1.00000000000000))*(x8893)*(x8904)))+(((IkReal(-1.00000000000000))*(x8881)*(x8883)*(x8893)))+(((IkReal(-1.00000000000000))*(x8885)*(x8896)))+(((x8887)*(x8898)))+(((IkReal(-1.00000000000000))*(x8882)*(x8903))));
evalcond[5]=((((IkReal(-1.00000000000000))*(r00)*(x8881)*(x8895)))+(sj3)+(((IkReal(-1.00000000000000))*(x8879)*(x8882)*(x8889)))+(((IkReal(-1.00000000000000))*(x8881)*(x8883)*(x8896)))+(((IkReal(-1.00000000000000))*(x8888)*(x8896)))+(((IkReal(-1.00000000000000))*(x8896)*(x8904)))+(((IkReal(-1.00000000000000))*(x8879)*(x8882)*(x8894)))+(((IkReal(-1.00000000000000))*(r10)*(x8881)*(x8893)))+(((r01)*(sj6)*(x8895)))+(((IkReal(-1.00000000000000))*(x8881)*(x8892)*(x8898)))+(((x8885)*(x8893))));
if( IKabs(evalcond[0]) > 0.000001  || IKabs(evalcond[1]) > 0.000001  || IKabs(evalcond[2]) > 0.000001  || IKabs(evalcond[3]) > 0.000001  || IKabs(evalcond[4]) > 0.000001  || IKabs(evalcond[5]) > 0.000001  )
{
continue;
}
}

{
std::vector<IkSingleDOFSolutionBase<IkReal> > vinfos(7);
vinfos[0].jointtype = 1;
vinfos[0].foffset = j0;
vinfos[0].indices[0] = _ij0[0];
vinfos[0].indices[1] = _ij0[1];
vinfos[0].maxsolutions = _nj0;
vinfos[1].jointtype = 1;
vinfos[1].foffset = j1;
vinfos[1].indices[0] = _ij1[0];
vinfos[1].indices[1] = _ij1[1];
vinfos[1].maxsolutions = _nj1;
vinfos[2].jointtype = 1;
vinfos[2].foffset = j2;
vinfos[2].indices[0] = _ij2[0];
vinfos[2].indices[1] = _ij2[1];
vinfos[2].maxsolutions = _nj2;
vinfos[3].jointtype = 1;
vinfos[3].foffset = j3;
vinfos[3].indices[0] = _ij3[0];
vinfos[3].indices[1] = _ij3[1];
vinfos[3].maxsolutions = _nj3;
vinfos[4].jointtype = 1;
vinfos[4].foffset = j4;
vinfos[4].indices[0] = _ij4[0];
vinfos[4].indices[1] = _ij4[1];
vinfos[4].maxsolutions = _nj4;
vinfos[5].jointtype = 1;
vinfos[5].foffset = j5;
vinfos[5].indices[0] = _ij5[0];
vinfos[5].indices[1] = _ij5[1];
vinfos[5].maxsolutions = _nj5;
vinfos[6].jointtype = 1;
vinfos[6].foffset = j6;
vinfos[6].indices[0] = _ij6[0];
vinfos[6].indices[1] = _ij6[1];
vinfos[6].maxsolutions = _nj6;
std::vector<int> vfree(0);
solutions.AddSolution(vinfos,vfree);
}
}
}

}

}

} else
{
{
IkReal j4array[1], cj4array[1], sj4array[1];
bool j4valid[1]={false};
_nj4 = 1;
if( IKabs(((gconst24)*(((((cj5)*(r20)*(sj6)))+(((r22)*(sj5)))+(((cj5)*(cj6)*(r21))))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(((gconst24)*(((((r21)*(sj6)))+(((IkReal(-1.00000000000000))*(cj6)*(r20))))))) < IKFAST_ATAN2_MAGTHRESH )
    continue;
j4array[0]=IKatan2(((gconst24)*(((((cj5)*(r20)*(sj6)))+(((r22)*(sj5)))+(((cj5)*(cj6)*(r21)))))), ((gconst24)*(((((r21)*(sj6)))+(((IkReal(-1.00000000000000))*(cj6)*(r20)))))));
sj4array[0]=IKsin(j4array[0]);
cj4array[0]=IKcos(j4array[0]);
if( j4array[0] > IKPI )
{
    j4array[0]-=IK2PI;
}
else if( j4array[0] < -IKPI )
{    j4array[0]+=IK2PI;
}
j4valid[0] = true;
for(int ij4 = 0; ij4 < 1; ++ij4)
{
if( !j4valid[ij4] )
{
    continue;
}
_ij4[0] = ij4; _ij4[1] = -1;
for(int iij4 = ij4+1; iij4 < 1; ++iij4)
{
if( j4valid[iij4] && IKabs(cj4array[ij4]-cj4array[iij4]) < IKFAST_SOLUTION_THRESH && IKabs(sj4array[ij4]-sj4array[iij4]) < IKFAST_SOLUTION_THRESH )
{
    j4valid[iij4]=false; _ij4[1] = iij4; break; 
}
}
j4 = j4array[ij4]; cj4 = cj4array[ij4]; sj4 = sj4array[ij4];
{
IkReal evalcond[6];
IkReal x8905=IKsin(j4);
IkReal x8906=IKcos(j4);
IkReal x8907=((r22)*(sj5));
IkReal x8908=((IkReal(1.00000000000000))*(cj6));
IkReal x8909=((IkReal(1.00000000000000))*(cj0));
IkReal x8910=((cj5)*(r11));
IkReal x8911=((cj5)*(cj6));
IkReal x8912=((r11)*(sj6));
IkReal x8913=((IkReal(1.00000000000000))*(sj6));
IkReal x8914=((cj6)*(r00));
IkReal x8915=((r12)*(sj5));
IkReal x8916=((r02)*(sj5));
IkReal x8917=((cj6)*(r10));
IkReal x8918=((cj5)*(sj6));
IkReal x8919=((cj5)*(r01));
IkReal x8920=((sj0)*(x8905));
IkReal x8921=((r00)*(x8918));
IkReal x8922=((cj0)*(x8905));
IkReal x8923=((sj0)*(x8906));
IkReal x8924=((r20)*(x8906));
IkReal x8925=((cj0)*(x8906));
IkReal x8926=((r21)*(x8905));
IkReal x8927=((r21)*(x8906));
IkReal x8928=((r20)*(x8905));
IkReal x8929=((x8906)*(x8915));
IkReal x8930=((r01)*(sj6)*(x8906));
IkReal x8931=((cj5)*(r10)*(x8913));
evalcond[0]=((IkReal(1.00000000000000))+(((x8905)*(x8907)))+(((IkReal(-1.00000000000000))*(x8908)*(x8924)))+(((x8918)*(x8928)))+(((sj6)*(x8927)))+(((x8911)*(x8926))));
evalcond[1]=((((x8906)*(x8907)))+(((cj6)*(x8928)))+(((x8918)*(x8924)))+(((x8911)*(x8927)))+(((IkReal(-1.00000000000000))*(x8913)*(x8926))));
evalcond[2]=((((IkReal(-1.00000000000000))*(r10)*(x8905)*(x8909)*(x8918)))+(((IkReal(-1.00000000000000))*(x8908)*(x8910)*(x8922)))+(((x8920)*(x8921)))+(((r01)*(x8911)*(x8920)))+(((IkReal(-1.00000000000000))*(x8905)*(x8909)*(x8915)))+(((x8917)*(x8925)))+(((IkReal(-1.00000000000000))*(x8906)*(x8909)*(x8912)))+(((IkReal(-1.00000000000000))*(r00)*(x8908)*(x8923)))+(((r01)*(sj6)*(x8923)))+(((x8916)*(x8920))));
evalcond[3]=((((IkReal(-1.00000000000000))*(r10)*(x8906)*(x8909)*(x8918)))+(((x8914)*(x8920)))+(((IkReal(-1.00000000000000))*(x8909)*(x8929)))+(((r01)*(x8911)*(x8923)))+(((IkReal(-1.00000000000000))*(r10)*(x8908)*(x8922)))+(((x8921)*(x8923)))+(((IkReal(-1.00000000000000))*(x8908)*(x8910)*(x8925)))+(((x8916)*(x8923)))+(cj3)+(((IkReal(-1.00000000000000))*(r01)*(x8913)*(x8920)))+(((x8912)*(x8922))));
evalcond[4]=((((x8917)*(x8923)))+(((IkReal(-1.00000000000000))*(x8908)*(x8910)*(x8920)))+(((x8914)*(x8925)))+(((IkReal(-1.00000000000000))*(x8920)*(x8931)))+(((IkReal(-1.00000000000000))*(x8909)*(x8930)))+(((IkReal(-1.00000000000000))*(x8905)*(x8909)*(x8916)))+(((IkReal(-1.00000000000000))*(x8915)*(x8920)))+(((IkReal(-1.00000000000000))*(x8908)*(x8919)*(x8922)))+(((IkReal(-1.00000000000000))*(x8912)*(x8923)))+(((IkReal(-1.00000000000000))*(x8905)*(x8909)*(x8921))));
evalcond[5]=((((IkReal(-1.00000000000000))*(r10)*(x8908)*(x8920)))+(((IkReal(-1.00000000000000))*(x8906)*(x8909)*(x8921)))+(sj3)+(((IkReal(-1.00000000000000))*(r00)*(x8908)*(x8922)))+(((IkReal(-1.00000000000000))*(x8923)*(x8931)))+(((IkReal(-1.00000000000000))*(x8908)*(x8910)*(x8923)))+(((r01)*(sj6)*(x8922)))+(((IkReal(-1.00000000000000))*(x8906)*(x8909)*(x8916)))+(((IkReal(-1.00000000000000))*(x8908)*(x8919)*(x8925)))+(((IkReal(-1.00000000000000))*(x8915)*(x8923)))+(((x8912)*(x8920))));
if( IKabs(evalcond[0]) > 0.000001  || IKabs(evalcond[1]) > 0.000001  || IKabs(evalcond[2]) > 0.000001  || IKabs(evalcond[3]) > 0.000001  || IKabs(evalcond[4]) > 0.000001  || IKabs(evalcond[5]) > 0.000001  )
{
continue;
}
}

{
std::vector<IkSingleDOFSolutionBase<IkReal> > vinfos(7);
vinfos[0].jointtype = 1;
vinfos[0].foffset = j0;
vinfos[0].indices[0] = _ij0[0];
vinfos[0].indices[1] = _ij0[1];
vinfos[0].maxsolutions = _nj0;
vinfos[1].jointtype = 1;
vinfos[1].foffset = j1;
vinfos[1].indices[0] = _ij1[0];
vinfos[1].indices[1] = _ij1[1];
vinfos[1].maxsolutions = _nj1;
vinfos[2].jointtype = 1;
vinfos[2].foffset = j2;
vinfos[2].indices[0] = _ij2[0];
vinfos[2].indices[1] = _ij2[1];
vinfos[2].maxsolutions = _nj2;
vinfos[3].jointtype = 1;
vinfos[3].foffset = j3;
vinfos[3].indices[0] = _ij3[0];
vinfos[3].indices[1] = _ij3[1];
vinfos[3].maxsolutions = _nj3;
vinfos[4].jointtype = 1;
vinfos[4].foffset = j4;
vinfos[4].indices[0] = _ij4[0];
vinfos[4].indices[1] = _ij4[1];
vinfos[4].maxsolutions = _nj4;
vinfos[5].jointtype = 1;
vinfos[5].foffset = j5;
vinfos[5].indices[0] = _ij5[0];
vinfos[5].indices[1] = _ij5[1];
vinfos[5].maxsolutions = _nj5;
vinfos[6].jointtype = 1;
vinfos[6].foffset = j6;
vinfos[6].indices[0] = _ij6[0];
vinfos[6].indices[1] = _ij6[1];
vinfos[6].maxsolutions = _nj6;
std::vector<int> vfree(0);
solutions.AddSolution(vinfos,vfree);
}
}
}

}

}
}
}

} else
{
if( 1 )
{
continue;

} else
{
}
}
}
}

} else
{
{
IkReal j3array[1], cj3array[1], sj3array[1];
bool j3valid[1]={false};
_nj3 = 1;
IkReal x8932=((sj5)*(sj6));
IkReal x8933=((cj6)*(sj5));
IkReal x8934=((IkReal(1.00000000000000))*(cj0));
IkReal x8935=((IkReal(1.00000000000000))*(cj5));
if( IKabs(((((IkReal(-1.00000000000000))*(r11)*(x8933)*(x8934)))+(((r01)*(sj0)*(x8933)))+(((cj0)*(cj5)*(r12)))+(((r00)*(sj0)*(x8932)))+(((IkReal(-1.00000000000000))*(r10)*(x8932)*(x8934)))+(((IkReal(-1.00000000000000))*(r02)*(sj0)*(x8935))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(((((IKabs(sj1) != 0)?((IkReal)1/(sj1)):(IkReal)1.0e30))*(((((r21)*(x8933)))+(((IkReal(-1.00000000000000))*(r22)*(x8935)))+(((r20)*(x8932))))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(IKsqr(((((IkReal(-1.00000000000000))*(r11)*(x8933)*(x8934)))+(((r01)*(sj0)*(x8933)))+(((cj0)*(cj5)*(r12)))+(((r00)*(sj0)*(x8932)))+(((IkReal(-1.00000000000000))*(r10)*(x8932)*(x8934)))+(((IkReal(-1.00000000000000))*(r02)*(sj0)*(x8935)))))+IKsqr(((((IKabs(sj1) != 0)?((IkReal)1/(sj1)):(IkReal)1.0e30))*(((((r21)*(x8933)))+(((IkReal(-1.00000000000000))*(r22)*(x8935)))+(((r20)*(x8932)))))))-1) <= IKFAST_SINCOS_THRESH )
    continue;
j3array[0]=IKatan2(((((IkReal(-1.00000000000000))*(r11)*(x8933)*(x8934)))+(((r01)*(sj0)*(x8933)))+(((cj0)*(cj5)*(r12)))+(((r00)*(sj0)*(x8932)))+(((IkReal(-1.00000000000000))*(r10)*(x8932)*(x8934)))+(((IkReal(-1.00000000000000))*(r02)*(sj0)*(x8935)))), ((((IKabs(sj1) != 0)?((IkReal)1/(sj1)):(IkReal)1.0e30))*(((((r21)*(x8933)))+(((IkReal(-1.00000000000000))*(r22)*(x8935)))+(((r20)*(x8932)))))));
sj3array[0]=IKsin(j3array[0]);
cj3array[0]=IKcos(j3array[0]);
if( j3array[0] > IKPI )
{
    j3array[0]-=IK2PI;
}
else if( j3array[0] < -IKPI )
{    j3array[0]+=IK2PI;
}
j3valid[0] = true;
for(int ij3 = 0; ij3 < 1; ++ij3)
{
if( !j3valid[ij3] )
{
    continue;
}
_ij3[0] = ij3; _ij3[1] = -1;
for(int iij3 = ij3+1; iij3 < 1; ++iij3)
{
if( j3valid[iij3] && IKabs(cj3array[ij3]-cj3array[iij3]) < IKFAST_SOLUTION_THRESH && IKabs(sj3array[ij3]-sj3array[iij3]) < IKFAST_SOLUTION_THRESH )
{
    j3valid[iij3]=false; _ij3[1] = iij3; break; 
}
}
j3 = j3array[ij3]; cj3 = cj3array[ij3]; sj3 = sj3array[ij3];
{
IkReal evalcond[3];
IkReal x8936=IKcos(j3);
IkReal x8937=((sj5)*(sj6));
IkReal x8938=((cj0)*(cj5));
IkReal x8939=((IkReal(1.00000000000000))*(cj0));
IkReal x8940=((IkReal(1.00000000000000))*(sj0));
IkReal x8941=((IkReal(1.00000000000000))*(x8936));
IkReal x8942=((cj6)*(r01)*(sj5));
IkReal x8943=((cj6)*(r11)*(sj5));
evalcond[0]=((((IkReal(-1.00000000000000))*(sj1)*(x8941)))+(((cj6)*(r21)*(sj5)))+(((IkReal(-1.00000000000000))*(cj5)*(r22)))+(((r20)*(x8937))));
evalcond[1]=((((r00)*(sj0)*(x8937)))+(((IkReal(-1.00000000000000))*(cj5)*(r02)*(x8940)))+(((IkReal(-1.00000000000000))*(r10)*(x8937)*(x8939)))+(((IkReal(-1.00000000000000))*(IKsin(j3))))+(((IkReal(-1.00000000000000))*(x8939)*(x8943)))+(((sj0)*(x8942)))+(((r12)*(x8938))));
evalcond[2]=((((IkReal(-1.00000000000000))*(r10)*(x8937)*(x8940)))+(((IkReal(-1.00000000000000))*(cj1)*(x8941)))+(((cj5)*(r12)*(sj0)))+(((IkReal(-1.00000000000000))*(r00)*(x8937)*(x8939)))+(((IkReal(-1.00000000000000))*(x8940)*(x8943)))+(((IkReal(-1.00000000000000))*(x8939)*(x8942)))+(((r02)*(x8938))));
if( IKabs(evalcond[0]) > 0.000001  || IKabs(evalcond[1]) > 0.000001  || IKabs(evalcond[2]) > 0.000001  )
{
continue;
}
}

{
IkReal dummyeval[1];
IkReal gconst15;
IkReal x8944=(r21)*(r21);
IkReal x8945=(cj5)*(cj5);
IkReal x8946=(sj6)*(sj6);
IkReal x8947=(cj6)*(cj6);
IkReal x8948=(r20)*(r20);
IkReal x8949=((cj6)*(r21));
IkReal x8950=((IkReal(2.00000000000000))*(r20)*(sj6));
IkReal x8951=((cj5)*(r22)*(sj5));
IkReal x8952=((IkReal(1.00000000000000))*(x8946));
IkReal x8953=((IkReal(1.00000000000000))*(x8947));
gconst15=IKsign(((((IkReal(-1.00000000000000))*(x8945)*(x8948)*(x8952)))+(((IkReal(-1.00000000000000))*(x8944)*(x8952)))+(((x8949)*(x8950)))+(((IkReal(-1.00000000000000))*(x8944)*(x8945)*(x8953)))+(((IkReal(-1.00000000000000))*((r22)*(r22))*((sj5)*(sj5))))+(((IkReal(-1.00000000000000))*(x8948)*(x8953)))+(((IkReal(-1.00000000000000))*(x8945)*(x8949)*(x8950)))+(((IkReal(-2.00000000000000))*(x8949)*(x8951)))+(((IkReal(-1.00000000000000))*(x8950)*(x8951)))));
IkReal x8954=(r21)*(r21);
IkReal x8955=(cj5)*(cj5);
IkReal x8956=(sj6)*(sj6);
IkReal x8957=(cj6)*(cj6);
IkReal x8958=(r20)*(r20);
IkReal x8959=((cj6)*(r21));
IkReal x8960=((IkReal(2.00000000000000))*(r20)*(sj6));
IkReal x8961=((cj5)*(r22)*(sj5));
IkReal x8962=((IkReal(1.00000000000000))*(x8956));
IkReal x8963=((IkReal(1.00000000000000))*(x8957));
dummyeval[0]=((((IkReal(-1.00000000000000))*(x8955)*(x8958)*(x8962)))+(((IkReal(-1.00000000000000))*(x8958)*(x8963)))+(((IkReal(-1.00000000000000))*((r22)*(r22))*((sj5)*(sj5))))+(((IkReal(-1.00000000000000))*(x8960)*(x8961)))+(((IkReal(-1.00000000000000))*(x8954)*(x8962)))+(((IkReal(-1.00000000000000))*(x8955)*(x8959)*(x8960)))+(((IkReal(-2.00000000000000))*(x8959)*(x8961)))+(((x8959)*(x8960)))+(((IkReal(-1.00000000000000))*(x8954)*(x8955)*(x8963))));
if( IKabs(dummyeval[0]) < 0.0000010000000000  )
{
{
IkReal dummyeval[1];
IkReal gconst16;
IkReal x8964=(cj6)*(cj6);
IkReal x8965=(sj6)*(sj6);
IkReal x8966=((IkReal(1.00000000000000))*(r21));
IkReal x8967=((cj6)*(r20));
IkReal x8968=((r22)*(sj5));
IkReal x8969=((r01)*(sj0));
IkReal x8970=((r00)*(sj0));
IkReal x8971=((cj0)*(r10));
IkReal x8972=((r02)*(sj0)*(sj5));
IkReal x8973=((cj5)*(x8964));
IkReal x8974=((cj0)*(r12)*(sj5));
IkReal x8975=((IkReal(1.00000000000000))*(cj0)*(r11));
IkReal x8976=((cj5)*(x8965));
IkReal x8977=((r20)*(x8976));
gconst16=IKsign(((((IkReal(-1.00000000000000))*(sj6)*(x8966)*(x8972)))+(((sj6)*(x8968)*(x8969)))+(((r20)*(x8969)*(x8973)))+(((IkReal(-1.00000000000000))*(x8966)*(x8970)*(x8976)))+(((IkReal(-1.00000000000000))*(r20)*(x8973)*(x8975)))+(((r21)*(sj6)*(x8974)))+(((r21)*(x8971)*(x8976)))+(((IkReal(-1.00000000000000))*(cj6)*(x8968)*(x8970)))+(((IkReal(-1.00000000000000))*(x8975)*(x8977)))+(((IkReal(-1.00000000000000))*(x8966)*(x8970)*(x8973)))+(((cj6)*(x8968)*(x8971)))+(((x8969)*(x8977)))+(((IkReal(-1.00000000000000))*(sj6)*(x8968)*(x8975)))+(((IkReal(-1.00000000000000))*(x8967)*(x8974)))+(((r21)*(x8971)*(x8973)))+(((x8967)*(x8972)))));
IkReal x8978=(cj6)*(cj6);
IkReal x8979=(sj6)*(sj6);
IkReal x8980=((IkReal(1.00000000000000))*(r21));
IkReal x8981=((cj6)*(r20));
IkReal x8982=((r22)*(sj5));
IkReal x8983=((r01)*(sj0));
IkReal x8984=((r00)*(sj0));
IkReal x8985=((cj0)*(r10));
IkReal x8986=((r02)*(sj0)*(sj5));
IkReal x8987=((cj5)*(x8978));
IkReal x8988=((cj0)*(r12)*(sj5));
IkReal x8989=((IkReal(1.00000000000000))*(cj0)*(r11));
IkReal x8990=((cj5)*(x8979));
IkReal x8991=((r20)*(x8990));
dummyeval[0]=((((IkReal(-1.00000000000000))*(x8989)*(x8991)))+(((r21)*(x8985)*(x8987)))+(((IkReal(-1.00000000000000))*(sj6)*(x8980)*(x8986)))+(((x8983)*(x8991)))+(((r21)*(x8985)*(x8990)))+(((IkReal(-1.00000000000000))*(x8981)*(x8988)))+(((cj6)*(x8982)*(x8985)))+(((r20)*(x8983)*(x8987)))+(((sj6)*(x8982)*(x8983)))+(((IkReal(-1.00000000000000))*(x8980)*(x8984)*(x8987)))+(((IkReal(-1.00000000000000))*(sj6)*(x8982)*(x8989)))+(((IkReal(-1.00000000000000))*(x8980)*(x8984)*(x8990)))+(((IkReal(-1.00000000000000))*(r20)*(x8987)*(x8989)))+(((r21)*(sj6)*(x8988)))+(((x8981)*(x8986)))+(((IkReal(-1.00000000000000))*(cj6)*(x8982)*(x8984))));
if( IKabs(dummyeval[0]) < 0.0000010000000000  )
{
continue;

} else
{
{
IkReal j4array[1], cj4array[1], sj4array[1];
bool j4valid[1]={false};
_nj4 = 1;
IkReal x8992=((cj1)*(sj6));
IkReal x8993=((r01)*(sj0));
IkReal x8994=((cj0)*(r11));
IkReal x8995=((cj1)*(cj6));
IkReal x8996=((cj0)*(r10));
IkReal x8997=((IkReal(1.00000000000000))*(sj0));
IkReal x8998=((cj1)*(sj5));
if( IKabs(((gconst16)*(((((IkReal(-1.00000000000000))*(x8992)*(x8994)))+(((IkReal(-1.00000000000000))*(r00)*(x8995)*(x8997)))+(((x8992)*(x8993)))+(((x8995)*(x8996))))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(((gconst16)*(((((cj0)*(r12)*(x8998)))+(((IkReal(-1.00000000000000))*(r02)*(x8997)*(x8998)))+(((IkReal(-1.00000000000000))*(cj5)*(x8993)*(x8995)))+(((IkReal(-1.00000000000000))*(cj5)*(r00)*(x8992)*(x8997)))+(((cj5)*(x8992)*(x8996)))+(((cj5)*(x8994)*(x8995))))))) < IKFAST_ATAN2_MAGTHRESH )
    continue;
j4array[0]=IKatan2(((gconst16)*(((((IkReal(-1.00000000000000))*(x8992)*(x8994)))+(((IkReal(-1.00000000000000))*(r00)*(x8995)*(x8997)))+(((x8992)*(x8993)))+(((x8995)*(x8996)))))), ((gconst16)*(((((cj0)*(r12)*(x8998)))+(((IkReal(-1.00000000000000))*(r02)*(x8997)*(x8998)))+(((IkReal(-1.00000000000000))*(cj5)*(x8993)*(x8995)))+(((IkReal(-1.00000000000000))*(cj5)*(r00)*(x8992)*(x8997)))+(((cj5)*(x8992)*(x8996)))+(((cj5)*(x8994)*(x8995)))))));
sj4array[0]=IKsin(j4array[0]);
cj4array[0]=IKcos(j4array[0]);
if( j4array[0] > IKPI )
{
    j4array[0]-=IK2PI;
}
else if( j4array[0] < -IKPI )
{    j4array[0]+=IK2PI;
}
j4valid[0] = true;
for(int ij4 = 0; ij4 < 1; ++ij4)
{
if( !j4valid[ij4] )
{
    continue;
}
_ij4[0] = ij4; _ij4[1] = -1;
for(int iij4 = ij4+1; iij4 < 1; ++iij4)
{
if( j4valid[iij4] && IKabs(cj4array[ij4]-cj4array[iij4]) < IKFAST_SOLUTION_THRESH && IKabs(sj4array[ij4]-sj4array[iij4]) < IKFAST_SOLUTION_THRESH )
{
    j4valid[iij4]=false; _ij4[1] = iij4; break; 
}
}
j4 = j4array[ij4]; cj4 = cj4array[ij4]; sj4 = sj4array[ij4];
{
IkReal evalcond[6];
IkReal x8999=IKsin(j4);
IkReal x9000=IKcos(j4);
IkReal x9001=((r22)*(sj5));
IkReal x9002=((IkReal(1.00000000000000))*(cj6));
IkReal x9003=((IkReal(1.00000000000000))*(cj0));
IkReal x9004=((cj5)*(r11));
IkReal x9005=((cj5)*(cj6));
IkReal x9006=((IkReal(1.00000000000000))*(sj3));
IkReal x9007=((r11)*(sj6));
IkReal x9008=((IkReal(1.00000000000000))*(sj6));
IkReal x9009=((cj6)*(r00));
IkReal x9010=((r12)*(sj5));
IkReal x9011=((r02)*(sj5));
IkReal x9012=((cj6)*(r10));
IkReal x9013=((cj5)*(sj6));
IkReal x9014=((cj5)*(r01));
IkReal x9015=((sj0)*(x8999));
IkReal x9016=((r00)*(x9013));
IkReal x9017=((cj0)*(x8999));
IkReal x9018=((sj0)*(x9000));
IkReal x9019=((r20)*(x9000));
IkReal x9020=((cj0)*(x9000));
IkReal x9021=((r21)*(x8999));
IkReal x9022=((r21)*(x9000));
IkReal x9023=((r20)*(x8999));
IkReal x9024=((x9000)*(x9010));
IkReal x9025=((r01)*(sj6)*(x9000));
IkReal x9026=((cj5)*(r10)*(x9008));
evalcond[0]=((((IkReal(-1.00000000000000))*(x9002)*(x9019)))+(((IkReal(-1.00000000000000))*(cj1)))+(((x9005)*(x9021)))+(((x8999)*(x9001)))+(((x9013)*(x9023)))+(((sj6)*(x9022))));
evalcond[1]=((((IkReal(-1.00000000000000))*(sj1)*(x9006)))+(((x9000)*(x9001)))+(((x9005)*(x9022)))+(((IkReal(-1.00000000000000))*(x9008)*(x9021)))+(((x9013)*(x9019)))+(((cj6)*(x9023))));
evalcond[2]=((((x9012)*(x9020)))+(((IkReal(-1.00000000000000))*(r10)*(x8999)*(x9003)*(x9013)))+(((x9011)*(x9015)))+(((IkReal(-1.00000000000000))*(r00)*(x9002)*(x9018)))+(((IkReal(-1.00000000000000))*(x9002)*(x9004)*(x9017)))+(((IkReal(-1.00000000000000))*(x8999)*(x9003)*(x9010)))+(((r01)*(sj6)*(x9018)))+(((r01)*(x9005)*(x9015)))+(((IkReal(-1.00000000000000))*(x9000)*(x9003)*(x9007)))+(((x9015)*(x9016))));
evalcond[3]=((((IkReal(-1.00000000000000))*(x9003)*(x9024)))+(((IkReal(-1.00000000000000))*(r10)*(x9002)*(x9017)))+(((x9011)*(x9018)))+(((x9007)*(x9017)))+(cj3)+(((r01)*(x9005)*(x9018)))+(((IkReal(-1.00000000000000))*(x9002)*(x9004)*(x9020)))+(((IkReal(-1.00000000000000))*(r01)*(x9008)*(x9015)))+(((x9009)*(x9015)))+(((x9016)*(x9018)))+(((IkReal(-1.00000000000000))*(r10)*(x9000)*(x9003)*(x9013))));
evalcond[4]=((((IkReal(-1.00000000000000))*(x8999)*(x9003)*(x9011)))+(((IkReal(-1.00000000000000))*(x9010)*(x9015)))+(((x9012)*(x9018)))+(((x9009)*(x9020)))+(sj1)+(((IkReal(-1.00000000000000))*(x9015)*(x9026)))+(((IkReal(-1.00000000000000))*(x9007)*(x9018)))+(((IkReal(-1.00000000000000))*(x9002)*(x9014)*(x9017)))+(((IkReal(-1.00000000000000))*(x8999)*(x9003)*(x9016)))+(((IkReal(-1.00000000000000))*(x9002)*(x9004)*(x9015)))+(((IkReal(-1.00000000000000))*(x9003)*(x9025))));
evalcond[5]=((((IkReal(-1.00000000000000))*(r00)*(x9002)*(x9017)))+(((IkReal(-1.00000000000000))*(x9002)*(x9014)*(x9020)))+(((IkReal(-1.00000000000000))*(x9000)*(x9003)*(x9011)))+(((IkReal(-1.00000000000000))*(x9010)*(x9018)))+(((IkReal(-1.00000000000000))*(r10)*(x9002)*(x9015)))+(((IkReal(-1.00000000000000))*(x9002)*(x9004)*(x9018)))+(((IkReal(-1.00000000000000))*(x9000)*(x9003)*(x9016)))+(((IkReal(-1.00000000000000))*(cj1)*(x9006)))+(((x9007)*(x9015)))+(((r01)*(sj6)*(x9017)))+(((IkReal(-1.00000000000000))*(x9018)*(x9026))));
if( IKabs(evalcond[0]) > 0.000001  || IKabs(evalcond[1]) > 0.000001  || IKabs(evalcond[2]) > 0.000001  || IKabs(evalcond[3]) > 0.000001  || IKabs(evalcond[4]) > 0.000001  || IKabs(evalcond[5]) > 0.000001  )
{
continue;
}
}

{
std::vector<IkSingleDOFSolutionBase<IkReal> > vinfos(7);
vinfos[0].jointtype = 1;
vinfos[0].foffset = j0;
vinfos[0].indices[0] = _ij0[0];
vinfos[0].indices[1] = _ij0[1];
vinfos[0].maxsolutions = _nj0;
vinfos[1].jointtype = 1;
vinfos[1].foffset = j1;
vinfos[1].indices[0] = _ij1[0];
vinfos[1].indices[1] = _ij1[1];
vinfos[1].maxsolutions = _nj1;
vinfos[2].jointtype = 1;
vinfos[2].foffset = j2;
vinfos[2].indices[0] = _ij2[0];
vinfos[2].indices[1] = _ij2[1];
vinfos[2].maxsolutions = _nj2;
vinfos[3].jointtype = 1;
vinfos[3].foffset = j3;
vinfos[3].indices[0] = _ij3[0];
vinfos[3].indices[1] = _ij3[1];
vinfos[3].maxsolutions = _nj3;
vinfos[4].jointtype = 1;
vinfos[4].foffset = j4;
vinfos[4].indices[0] = _ij4[0];
vinfos[4].indices[1] = _ij4[1];
vinfos[4].maxsolutions = _nj4;
vinfos[5].jointtype = 1;
vinfos[5].foffset = j5;
vinfos[5].indices[0] = _ij5[0];
vinfos[5].indices[1] = _ij5[1];
vinfos[5].maxsolutions = _nj5;
vinfos[6].jointtype = 1;
vinfos[6].foffset = j6;
vinfos[6].indices[0] = _ij6[0];
vinfos[6].indices[1] = _ij6[1];
vinfos[6].maxsolutions = _nj6;
std::vector<int> vfree(0);
solutions.AddSolution(vinfos,vfree);
}
}
}

}

}

} else
{
{
IkReal j4array[1], cj4array[1], sj4array[1];
bool j4valid[1]={false};
_nj4 = 1;
IkReal x9027=((IkReal(1.00000000000000))*(cj1));
IkReal x9028=((sj1)*(sj3));
IkReal x9029=((r21)*(sj6));
IkReal x9030=((r22)*(sj5));
IkReal x9031=((cj6)*(r20));
IkReal x9032=((cj5)*(r20)*(sj6));
IkReal x9033=((cj5)*(cj6)*(r21));
if( IKabs(((gconst15)*(((((IkReal(-1.00000000000000))*(x9027)*(x9032)))+(((x9028)*(x9029)))+(((IkReal(-1.00000000000000))*(x9027)*(x9030)))+(((IkReal(-1.00000000000000))*(x9028)*(x9031)))+(((IkReal(-1.00000000000000))*(x9027)*(x9033))))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(((gconst15)*(((((IkReal(-1.00000000000000))*(x9028)*(x9030)))+(((IkReal(-1.00000000000000))*(x9028)*(x9032)))+(((IkReal(-1.00000000000000))*(x9027)*(x9029)))+(((cj1)*(x9031)))+(((IkReal(-1.00000000000000))*(x9028)*(x9033))))))) < IKFAST_ATAN2_MAGTHRESH )
    continue;
j4array[0]=IKatan2(((gconst15)*(((((IkReal(-1.00000000000000))*(x9027)*(x9032)))+(((x9028)*(x9029)))+(((IkReal(-1.00000000000000))*(x9027)*(x9030)))+(((IkReal(-1.00000000000000))*(x9028)*(x9031)))+(((IkReal(-1.00000000000000))*(x9027)*(x9033)))))), ((gconst15)*(((((IkReal(-1.00000000000000))*(x9028)*(x9030)))+(((IkReal(-1.00000000000000))*(x9028)*(x9032)))+(((IkReal(-1.00000000000000))*(x9027)*(x9029)))+(((cj1)*(x9031)))+(((IkReal(-1.00000000000000))*(x9028)*(x9033)))))));
sj4array[0]=IKsin(j4array[0]);
cj4array[0]=IKcos(j4array[0]);
if( j4array[0] > IKPI )
{
    j4array[0]-=IK2PI;
}
else if( j4array[0] < -IKPI )
{    j4array[0]+=IK2PI;
}
j4valid[0] = true;
for(int ij4 = 0; ij4 < 1; ++ij4)
{
if( !j4valid[ij4] )
{
    continue;
}
_ij4[0] = ij4; _ij4[1] = -1;
for(int iij4 = ij4+1; iij4 < 1; ++iij4)
{
if( j4valid[iij4] && IKabs(cj4array[ij4]-cj4array[iij4]) < IKFAST_SOLUTION_THRESH && IKabs(sj4array[ij4]-sj4array[iij4]) < IKFAST_SOLUTION_THRESH )
{
    j4valid[iij4]=false; _ij4[1] = iij4; break; 
}
}
j4 = j4array[ij4]; cj4 = cj4array[ij4]; sj4 = sj4array[ij4];
{
IkReal evalcond[6];
IkReal x9034=IKsin(j4);
IkReal x9035=IKcos(j4);
IkReal x9036=((r22)*(sj5));
IkReal x9037=((IkReal(1.00000000000000))*(cj6));
IkReal x9038=((IkReal(1.00000000000000))*(cj0));
IkReal x9039=((cj5)*(r11));
IkReal x9040=((cj5)*(cj6));
IkReal x9041=((IkReal(1.00000000000000))*(sj3));
IkReal x9042=((r11)*(sj6));
IkReal x9043=((IkReal(1.00000000000000))*(sj6));
IkReal x9044=((cj6)*(r00));
IkReal x9045=((r12)*(sj5));
IkReal x9046=((r02)*(sj5));
IkReal x9047=((cj6)*(r10));
IkReal x9048=((cj5)*(sj6));
IkReal x9049=((cj5)*(r01));
IkReal x9050=((sj0)*(x9034));
IkReal x9051=((r00)*(x9048));
IkReal x9052=((cj0)*(x9034));
IkReal x9053=((sj0)*(x9035));
IkReal x9054=((r20)*(x9035));
IkReal x9055=((cj0)*(x9035));
IkReal x9056=((r21)*(x9034));
IkReal x9057=((r21)*(x9035));
IkReal x9058=((r20)*(x9034));
IkReal x9059=((x9035)*(x9045));
IkReal x9060=((r01)*(sj6)*(x9035));
IkReal x9061=((cj5)*(r10)*(x9043));
evalcond[0]=((((IkReal(-1.00000000000000))*(x9037)*(x9054)))+(((sj6)*(x9057)))+(((x9048)*(x9058)))+(((IkReal(-1.00000000000000))*(cj1)))+(((x9040)*(x9056)))+(((x9034)*(x9036))));
evalcond[1]=((((x9035)*(x9036)))+(((IkReal(-1.00000000000000))*(sj1)*(x9041)))+(((IkReal(-1.00000000000000))*(x9043)*(x9056)))+(((x9048)*(x9054)))+(((x9040)*(x9057)))+(((cj6)*(x9058))));
evalcond[2]=((((r01)*(x9040)*(x9050)))+(((IkReal(-1.00000000000000))*(x9037)*(x9039)*(x9052)))+(((x9046)*(x9050)))+(((r01)*(sj6)*(x9053)))+(((x9050)*(x9051)))+(((IkReal(-1.00000000000000))*(x9034)*(x9038)*(x9045)))+(((IkReal(-1.00000000000000))*(x9035)*(x9038)*(x9042)))+(((IkReal(-1.00000000000000))*(r10)*(x9034)*(x9038)*(x9048)))+(((IkReal(-1.00000000000000))*(r00)*(x9037)*(x9053)))+(((x9047)*(x9055))));
evalcond[3]=((((x9051)*(x9053)))+(((IkReal(-1.00000000000000))*(x9038)*(x9059)))+(((IkReal(-1.00000000000000))*(r10)*(x9035)*(x9038)*(x9048)))+(((IkReal(-1.00000000000000))*(x9037)*(x9039)*(x9055)))+(((x9044)*(x9050)))+(((x9046)*(x9053)))+(cj3)+(((r01)*(x9040)*(x9053)))+(((IkReal(-1.00000000000000))*(r01)*(x9043)*(x9050)))+(((x9042)*(x9052)))+(((IkReal(-1.00000000000000))*(r10)*(x9037)*(x9052))));
evalcond[4]=((((IkReal(-1.00000000000000))*(x9050)*(x9061)))+(((x9044)*(x9055)))+(((x9047)*(x9053)))+(((IkReal(-1.00000000000000))*(x9034)*(x9038)*(x9051)))+(sj1)+(((IkReal(-1.00000000000000))*(x9034)*(x9038)*(x9046)))+(((IkReal(-1.00000000000000))*(x9037)*(x9049)*(x9052)))+(((IkReal(-1.00000000000000))*(x9045)*(x9050)))+(((IkReal(-1.00000000000000))*(x9042)*(x9053)))+(((IkReal(-1.00000000000000))*(x9037)*(x9039)*(x9050)))+(((IkReal(-1.00000000000000))*(x9038)*(x9060))));
evalcond[5]=((((IkReal(-1.00000000000000))*(r10)*(x9037)*(x9050)))+(((IkReal(-1.00000000000000))*(x9035)*(x9038)*(x9046)))+(((IkReal(-1.00000000000000))*(x9037)*(x9039)*(x9053)))+(((IkReal(-1.00000000000000))*(cj1)*(x9041)))+(((IkReal(-1.00000000000000))*(r00)*(x9037)*(x9052)))+(((x9042)*(x9050)))+(((IkReal(-1.00000000000000))*(x9035)*(x9038)*(x9051)))+(((IkReal(-1.00000000000000))*(x9053)*(x9061)))+(((r01)*(sj6)*(x9052)))+(((IkReal(-1.00000000000000))*(x9045)*(x9053)))+(((IkReal(-1.00000000000000))*(x9037)*(x9049)*(x9055))));
if( IKabs(evalcond[0]) > 0.000001  || IKabs(evalcond[1]) > 0.000001  || IKabs(evalcond[2]) > 0.000001  || IKabs(evalcond[3]) > 0.000001  || IKabs(evalcond[4]) > 0.000001  || IKabs(evalcond[5]) > 0.000001  )
{
continue;
}
}

{
std::vector<IkSingleDOFSolutionBase<IkReal> > vinfos(7);
vinfos[0].jointtype = 1;
vinfos[0].foffset = j0;
vinfos[0].indices[0] = _ij0[0];
vinfos[0].indices[1] = _ij0[1];
vinfos[0].maxsolutions = _nj0;
vinfos[1].jointtype = 1;
vinfos[1].foffset = j1;
vinfos[1].indices[0] = _ij1[0];
vinfos[1].indices[1] = _ij1[1];
vinfos[1].maxsolutions = _nj1;
vinfos[2].jointtype = 1;
vinfos[2].foffset = j2;
vinfos[2].indices[0] = _ij2[0];
vinfos[2].indices[1] = _ij2[1];
vinfos[2].maxsolutions = _nj2;
vinfos[3].jointtype = 1;
vinfos[3].foffset = j3;
vinfos[3].indices[0] = _ij3[0];
vinfos[3].indices[1] = _ij3[1];
vinfos[3].maxsolutions = _nj3;
vinfos[4].jointtype = 1;
vinfos[4].foffset = j4;
vinfos[4].indices[0] = _ij4[0];
vinfos[4].indices[1] = _ij4[1];
vinfos[4].maxsolutions = _nj4;
vinfos[5].jointtype = 1;
vinfos[5].foffset = j5;
vinfos[5].indices[0] = _ij5[0];
vinfos[5].indices[1] = _ij5[1];
vinfos[5].maxsolutions = _nj5;
vinfos[6].jointtype = 1;
vinfos[6].foffset = j6;
vinfos[6].indices[0] = _ij6[0];
vinfos[6].indices[1] = _ij6[1];
vinfos[6].maxsolutions = _nj6;
std::vector<int> vfree(0);
solutions.AddSolution(vinfos,vfree);
}
}
}

}

}
}
}

}

}

} else
{
{
IkReal j4array[1], cj4array[1], sj4array[1];
bool j4valid[1]={false};
_nj4 = 1;
IkReal x9062=((sj0)*(sj6));
IkReal x9063=((cj0)*(cj6));
IkReal x9064=((cj0)*(sj6));
IkReal x9065=((IkReal(1.00000000000000))*(cj1));
IkReal x9066=((r20)*(sj1));
IkReal x9067=((cj6)*(sj0));
IkReal x9068=((r21)*(sj1));
IkReal x9069=((cj5)*(x9065));
if( IKabs(((gconst14)*(((((IkReal(-1.00000000000000))*(r00)*(x9063)*(x9065)))+(((cj6)*(x9066)))+(((cj1)*(r11)*(x9062)))+(((IkReal(-1.00000000000000))*(sj6)*(x9068)))+(((IkReal(-1.00000000000000))*(r10)*(x9065)*(x9067)))+(((cj1)*(r01)*(x9064))))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(((gconst14)*(((((IkReal(-1.00000000000000))*(cj0)*(r02)*(sj5)*(x9065)))+(((IkReal(-1.00000000000000))*(r11)*(x9067)*(x9069)))+(((cj5)*(sj6)*(x9066)))+(((IkReal(-1.00000000000000))*(r00)*(x9064)*(x9069)))+(((IkReal(-1.00000000000000))*(r12)*(sj0)*(sj5)*(x9065)))+(((IkReal(-1.00000000000000))*(r10)*(x9062)*(x9069)))+(((cj5)*(cj6)*(x9068)))+(((r22)*(sj1)*(sj5)))+(((IkReal(-1.00000000000000))*(r01)*(x9063)*(x9069))))))) < IKFAST_ATAN2_MAGTHRESH )
    continue;
j4array[0]=IKatan2(((gconst14)*(((((IkReal(-1.00000000000000))*(r00)*(x9063)*(x9065)))+(((cj6)*(x9066)))+(((cj1)*(r11)*(x9062)))+(((IkReal(-1.00000000000000))*(sj6)*(x9068)))+(((IkReal(-1.00000000000000))*(r10)*(x9065)*(x9067)))+(((cj1)*(r01)*(x9064)))))), ((gconst14)*(((((IkReal(-1.00000000000000))*(cj0)*(r02)*(sj5)*(x9065)))+(((IkReal(-1.00000000000000))*(r11)*(x9067)*(x9069)))+(((cj5)*(sj6)*(x9066)))+(((IkReal(-1.00000000000000))*(r00)*(x9064)*(x9069)))+(((IkReal(-1.00000000000000))*(r12)*(sj0)*(sj5)*(x9065)))+(((IkReal(-1.00000000000000))*(r10)*(x9062)*(x9069)))+(((cj5)*(cj6)*(x9068)))+(((r22)*(sj1)*(sj5)))+(((IkReal(-1.00000000000000))*(r01)*(x9063)*(x9069)))))));
sj4array[0]=IKsin(j4array[0]);
cj4array[0]=IKcos(j4array[0]);
if( j4array[0] > IKPI )
{
    j4array[0]-=IK2PI;
}
else if( j4array[0] < -IKPI )
{    j4array[0]+=IK2PI;
}
j4valid[0] = true;
for(int ij4 = 0; ij4 < 1; ++ij4)
{
if( !j4valid[ij4] )
{
    continue;
}
_ij4[0] = ij4; _ij4[1] = -1;
for(int iij4 = ij4+1; iij4 < 1; ++iij4)
{
if( j4valid[iij4] && IKabs(cj4array[ij4]-cj4array[iij4]) < IKFAST_SOLUTION_THRESH && IKabs(sj4array[ij4]-sj4array[iij4]) < IKFAST_SOLUTION_THRESH )
{
    j4valid[iij4]=false; _ij4[1] = iij4; break; 
}
}
j4 = j4array[ij4]; cj4 = cj4array[ij4]; sj4 = sj4array[ij4];
{
IkReal evalcond[3];
IkReal x9070=IKsin(j4);
IkReal x9071=IKcos(j4);
IkReal x9072=((r00)*(sj6));
IkReal x9073=((cj6)*(r01));
IkReal x9074=((IkReal(1.00000000000000))*(cj0));
IkReal x9075=((IkReal(1.00000000000000))*(sj0));
IkReal x9076=((r10)*(sj6));
IkReal x9077=((sj5)*(x9070));
IkReal x9078=((IkReal(1.00000000000000))*(cj6)*(r11));
IkReal x9079=((cj5)*(x9070));
IkReal x9080=((cj6)*(x9071));
IkReal x9081=((sj0)*(x9079));
IkReal x9082=((r01)*(sj6)*(x9071));
IkReal x9083=((r11)*(sj6)*(x9071));
evalcond[0]=((((IkReal(-1.00000000000000))*(r20)*(x9080)))+(((r20)*(sj6)*(x9079)))+(((r21)*(sj6)*(x9071)))+(((cj6)*(r21)*(x9079)))+(((IkReal(-1.00000000000000))*(cj1)))+(((r22)*(x9077))));
evalcond[1]=((((IkReal(-1.00000000000000))*(cj6)*(r11)*(x9074)*(x9079)))+(((IkReal(-1.00000000000000))*(r12)*(x9074)*(x9077)))+(((r02)*(sj0)*(x9077)))+(((IkReal(-1.00000000000000))*(x9074)*(x9076)*(x9079)))+(((sj0)*(x9082)))+(((IkReal(-1.00000000000000))*(x9074)*(x9083)))+(((x9073)*(x9081)))+(((IkReal(-1.00000000000000))*(r00)*(x9075)*(x9080)))+(((x9072)*(x9081)))+(((cj0)*(r10)*(x9080))));
evalcond[2]=((((IkReal(-1.00000000000000))*(x9074)*(x9082)))+(((r10)*(sj0)*(x9080)))+(((IkReal(-1.00000000000000))*(x9072)*(x9074)*(x9079)))+(((IkReal(-1.00000000000000))*(x9073)*(x9074)*(x9079)))+(((IkReal(-1.00000000000000))*(r12)*(x9075)*(x9077)))+(sj1)+(((IkReal(-1.00000000000000))*(cj6)*(r11)*(x9075)*(x9079)))+(((IkReal(-1.00000000000000))*(x9075)*(x9076)*(x9079)))+(((IkReal(-1.00000000000000))*(r02)*(x9074)*(x9077)))+(((cj0)*(r00)*(x9080)))+(((IkReal(-1.00000000000000))*(x9075)*(x9083))));
if( IKabs(evalcond[0]) > 0.000001  || IKabs(evalcond[1]) > 0.000001  || IKabs(evalcond[2]) > 0.000001  )
{
continue;
}
}

{
IkReal dummyeval[1];
IkReal gconst17;
gconst17=IKsign(sj1);
dummyeval[0]=sj1;
if( IKabs(dummyeval[0]) < 0.0000010000000000  )
{
{
IkReal dummyeval[1];
dummyeval[0]=sj1;
if( IKabs(dummyeval[0]) < 0.0000010000000000  )
{
{
IkReal dummyeval[1];
dummyeval[0]=cj1;
if( IKabs(dummyeval[0]) < 0.0000010000000000  )
{
{
IkReal evalcond[9];
IkReal x9084=((IkReal(1.00000000000000))*(cj0));
IkReal x9085=((cj4)*(sj6));
IkReal x9086=((sj0)*(sj6));
IkReal x9087=((cj5)*(sj4));
IkReal x9088=((IkReal(0.374290000000000))*(sj5));
IkReal x9089=((sj4)*(sj5));
IkReal x9090=((cj0)*(cj6));
IkReal x9091=((IkReal(0.0100000000000000))*(cj5));
IkReal x9092=((cj4)*(sj5));
IkReal x9093=((cj5)*(sj0));
IkReal x9094=((IkReal(0.374290000000000))*(r02));
IkReal x9095=((r20)*(sj6));
IkReal x9096=((cj6)*(r21));
IkReal x9097=((IkReal(1.00000000000000))*(sj0));
IkReal x9098=((cj0)*(sj6));
IkReal x9099=((cj4)*(cj6));
IkReal x9100=((IkReal(0.374290000000000))*(r12));
IkReal x9101=((cj0)*(cj5));
IkReal x9102=((cj6)*(sj5));
IkReal x9103=((cj6)*(r01));
IkReal x9104=((r00)*(sj6));
IkReal x9105=((IkReal(0.0100000000000000))*(sj5));
IkReal x9106=((cj6)*(r11));
IkReal x9107=((IkReal(1.00000000000000))*(r10));
IkReal x9108=((r02)*(sj0));
IkReal x9109=((cj6)*(sj4));
IkReal x9110=((r12)*(x9097));
evalcond[0]=((IkReal(-3.14159265358979))+(IKfmod(((IkReal(1.57079632679490))+(j1)), IkReal(6.28318530717959))));
evalcond[1]=((((x9087)*(x9096)))+(((r21)*(x9085)))+(((IkReal(-1.00000000000000))*(r20)*(x9099)))+(((r22)*(x9089)))+(((x9087)*(x9095))));
evalcond[2]=((IkReal(0.364420000000000))+(((IkReal(-1.00000000000000))*(x9091)*(x9096)))+(((IkReal(-1.00000000000000))*(r22)*(x9105)))+(((IkReal(-0.374290000000000))*(cj5)*(r22)))+(((x9088)*(x9095)))+(((IkReal(-1.00000000000000))*(x9091)*(x9095)))+(pz)+(((x9088)*(x9096))));
evalcond[3]=((((IkReal(-1.00000000000000))*(sj5)*(x9086)*(x9107)))+(((r12)*(x9093)))+(((r02)*(x9101)))+(((IkReal(-1.00000000000000))*(r01)*(x9084)*(x9102)))+(((IkReal(-1.00000000000000))*(sj5)*(x9084)*(x9104)))+(((IkReal(-1.00000000000000))*(r11)*(x9097)*(x9102))));
evalcond[4]=((((sj0)*(x9087)*(x9103)))+(((IkReal(-1.00000000000000))*(r10)*(sj6)*(x9084)*(x9087)))+(((IkReal(-1.00000000000000))*(r11)*(x9084)*(x9085)))+(((x9089)*(x9108)))+(((r01)*(sj0)*(x9085)))+(((IkReal(-1.00000000000000))*(x9084)*(x9087)*(x9106)))+(((r00)*(x9086)*(x9087)))+(((IkReal(-1.00000000000000))*(r12)*(x9084)*(x9089)))+(((IkReal(-1.00000000000000))*(r00)*(x9097)*(x9099)))+(((cj4)*(r10)*(x9090))));
evalcond[5]=((IkReal(1.00000000000000))+(((r10)*(sj0)*(x9099)))+(((IkReal(-1.00000000000000))*(x9084)*(x9087)*(x9103)))+(((IkReal(-1.00000000000000))*(x9087)*(x9097)*(x9106)))+(((IkReal(-1.00000000000000))*(x9089)*(x9110)))+(((IkReal(-1.00000000000000))*(r01)*(x9084)*(x9085)))+(((IkReal(-1.00000000000000))*(x9084)*(x9087)*(x9104)))+(((IkReal(-1.00000000000000))*(x9086)*(x9087)*(x9107)))+(((IkReal(-1.00000000000000))*(r02)*(x9084)*(x9089)))+(((IkReal(-1.00000000000000))*(r11)*(x9085)*(x9097)))+(((cj4)*(r00)*(x9090))));
evalcond[6]=((IkReal(0.0690000000000000))+(((r10)*(x9091)*(x9098)))+(((x9100)*(x9101)))+(((IkReal(-1.00000000000000))*(py)*(x9084)))+(((IkReal(-1.00000000000000))*(x9093)*(x9094)))+(((cj0)*(r12)*(x9105)))+(((sj0)*(x9088)*(x9103)))+(((r00)*(x9086)*(x9088)))+(((IkReal(-1.00000000000000))*(x9105)*(x9108)))+(((IkReal(-1.00000000000000))*(r00)*(x9086)*(x9091)))+(((IkReal(-1.00000000000000))*(r10)*(x9088)*(x9098)))+(((r11)*(x9090)*(x9091)))+(((IkReal(-1.00000000000000))*(r11)*(x9088)*(x9090)))+(((px)*(sj0)))+(((IkReal(-1.00000000000000))*(sj0)*(x9091)*(x9103))));
evalcond[7]=((((IkReal(-1.00000000000000))*(x9085)*(x9093)*(x9107)))+(((IkReal(-1.00000000000000))*(cj5)*(r00)*(x9084)*(x9085)))+(((IkReal(-1.00000000000000))*(r11)*(x9093)*(x9099)))+(((IkReal(-1.00000000000000))*(r00)*(x9084)*(x9109)))+(((IkReal(-1.00000000000000))*(r10)*(x9097)*(x9109)))+(((r01)*(sj4)*(x9098)))+(((r11)*(sj4)*(x9086)))+(((IkReal(-1.00000000000000))*(cj5)*(r01)*(x9084)*(x9099)))+(((IkReal(-1.00000000000000))*(x9092)*(x9110)))+(((IkReal(-1.00000000000000))*(r02)*(x9084)*(x9092))));
evalcond[8]=((IkReal(0.0690000000000000))+(((IkReal(-1.00000000000000))*(r00)*(x9088)*(x9098)))+(((IkReal(-1.00000000000000))*(sj0)*(x9088)*(x9106)))+(((IkReal(-1.00000000000000))*(px)*(x9084)))+(((r10)*(x9086)*(x9091)))+(((cj0)*(r02)*(x9105)))+(((IkReal(-1.00000000000000))*(r10)*(x9086)*(x9088)))+(((r00)*(x9091)*(x9098)))+(((x9093)*(x9100)))+(((r12)*(sj0)*(x9105)))+(((r01)*(x9090)*(x9091)))+(((IkReal(-1.00000000000000))*(r01)*(x9088)*(x9090)))+(((x9094)*(x9101)))+(((sj0)*(x9091)*(x9106)))+(((IkReal(-1.00000000000000))*(py)*(x9097))));
if( IKabs(evalcond[0]) < 0.0000010000000000  && IKabs(evalcond[1]) < 0.0000010000000000  && IKabs(evalcond[2]) < 0.0000010000000000  && IKabs(evalcond[3]) < 0.0000010000000000  && IKabs(evalcond[4]) < 0.0000010000000000  && IKabs(evalcond[5]) < 0.0000010000000000  && IKabs(evalcond[6]) < 0.0000010000000000  && IKabs(evalcond[7]) < 0.0000010000000000  && IKabs(evalcond[8]) < 0.0000010000000000  )
{
{
IkReal j3array[1], cj3array[1], sj3array[1];
bool j3valid[1]={false};
_nj3 = 1;
IkReal x9111=((r20)*(sj6));
IkReal x9112=((cj4)*(cj5));
IkReal x9113=((cj6)*(r21));
if( IKabs(((((IkReal(-1.00000000000000))*(r21)*(sj4)*(sj6)))+(((cj6)*(r20)*(sj4)))+(((cj4)*(r22)*(sj5)))+(((x9112)*(x9113)))+(((x9111)*(x9112))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(((((IkReal(-1.00000000000000))*(cj5)*(r22)))+(((sj5)*(x9113)))+(((sj5)*(x9111))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(IKsqr(((((IkReal(-1.00000000000000))*(r21)*(sj4)*(sj6)))+(((cj6)*(r20)*(sj4)))+(((cj4)*(r22)*(sj5)))+(((x9112)*(x9113)))+(((x9111)*(x9112)))))+IKsqr(((((IkReal(-1.00000000000000))*(cj5)*(r22)))+(((sj5)*(x9113)))+(((sj5)*(x9111)))))-1) <= IKFAST_SINCOS_THRESH )
    continue;
j3array[0]=IKatan2(((((IkReal(-1.00000000000000))*(r21)*(sj4)*(sj6)))+(((cj6)*(r20)*(sj4)))+(((cj4)*(r22)*(sj5)))+(((x9112)*(x9113)))+(((x9111)*(x9112)))), ((((IkReal(-1.00000000000000))*(cj5)*(r22)))+(((sj5)*(x9113)))+(((sj5)*(x9111)))));
sj3array[0]=IKsin(j3array[0]);
cj3array[0]=IKcos(j3array[0]);
if( j3array[0] > IKPI )
{
    j3array[0]-=IK2PI;
}
else if( j3array[0] < -IKPI )
{    j3array[0]+=IK2PI;
}
j3valid[0] = true;
for(int ij3 = 0; ij3 < 1; ++ij3)
{
if( !j3valid[ij3] )
{
    continue;
}
_ij3[0] = ij3; _ij3[1] = -1;
for(int iij3 = ij3+1; iij3 < 1; ++iij3)
{
if( j3valid[iij3] && IKabs(cj3array[ij3]-cj3array[iij3]) < IKFAST_SOLUTION_THRESH && IKabs(sj3array[ij3]-sj3array[iij3]) < IKFAST_SOLUTION_THRESH )
{
    j3valid[iij3]=false; _ij3[1] = iij3; break; 
}
}
j3 = j3array[ij3]; cj3 = cj3array[ij3]; sj3 = sj3array[ij3];
{
IkReal evalcond[4];
IkReal x9114=IKcos(j3);
IkReal x9115=((sj0)*(sj5));
IkReal x9116=((r00)*(sj6));
IkReal x9117=((cj6)*(r01));
IkReal x9118=((cj5)*(sj0));
IkReal x9119=((cj0)*(cj5));
IkReal x9120=((cj6)*(sj4));
IkReal x9121=((sj4)*(sj6));
IkReal x9122=((cj0)*(r11));
IkReal x9123=((cj4)*(cj6));
IkReal x9124=((cj4)*(sj6));
IkReal x9125=((IkReal(1.00000000000000))*(cj0));
IkReal x9126=((cj4)*(sj5));
IkReal x9127=((sj5)*(sj6));
IkReal x9128=((cj6)*(sj5));
IkReal x9129=((IkReal(1.00000000000000))*(IKsin(j3)));
evalcond[0]=((((r21)*(x9128)))+(((r20)*(x9127)))+(((IkReal(-1.00000000000000))*(cj5)*(r22)))+(((IkReal(-1.00000000000000))*(x9114))));
evalcond[1]=((((cj5)*(r20)*(x9124)))+(((cj5)*(r21)*(x9123)))+(((IkReal(-1.00000000000000))*(x9129)))+(((r22)*(x9126)))+(((IkReal(-1.00000000000000))*(r21)*(x9121)))+(((r20)*(x9120))));
evalcond[2]=((((IkReal(-1.00000000000000))*(x9122)*(x9128)))+(((IkReal(-1.00000000000000))*(x9129)))+(((r12)*(x9119)))+(((IkReal(-1.00000000000000))*(r02)*(x9118)))+(((x9115)*(x9116)))+(((x9115)*(x9117)))+(((IkReal(-1.00000000000000))*(r10)*(x9125)*(x9127))));
evalcond[3]=((((IkReal(-1.00000000000000))*(r10)*(x9120)*(x9125)))+(((IkReal(-1.00000000000000))*(r11)*(x9119)*(x9123)))+(((cj4)*(r02)*(x9115)))+(((r00)*(sj0)*(x9120)))+(((cj4)*(x9117)*(x9118)))+(x9114)+(((cj4)*(x9116)*(x9118)))+(((x9121)*(x9122)))+(((IkReal(-1.00000000000000))*(r12)*(x9125)*(x9126)))+(((IkReal(-1.00000000000000))*(r01)*(sj0)*(x9121)))+(((IkReal(-1.00000000000000))*(r10)*(x9119)*(x9124))));
if( IKabs(evalcond[0]) > 0.000001  || IKabs(evalcond[1]) > 0.000001  || IKabs(evalcond[2]) > 0.000001  || IKabs(evalcond[3]) > 0.000001  )
{
continue;
}
}

{
std::vector<IkSingleDOFSolutionBase<IkReal> > vinfos(7);
vinfos[0].jointtype = 1;
vinfos[0].foffset = j0;
vinfos[0].indices[0] = _ij0[0];
vinfos[0].indices[1] = _ij0[1];
vinfos[0].maxsolutions = _nj0;
vinfos[1].jointtype = 1;
vinfos[1].foffset = j1;
vinfos[1].indices[0] = _ij1[0];
vinfos[1].indices[1] = _ij1[1];
vinfos[1].maxsolutions = _nj1;
vinfos[2].jointtype = 1;
vinfos[2].foffset = j2;
vinfos[2].indices[0] = _ij2[0];
vinfos[2].indices[1] = _ij2[1];
vinfos[2].maxsolutions = _nj2;
vinfos[3].jointtype = 1;
vinfos[3].foffset = j3;
vinfos[3].indices[0] = _ij3[0];
vinfos[3].indices[1] = _ij3[1];
vinfos[3].maxsolutions = _nj3;
vinfos[4].jointtype = 1;
vinfos[4].foffset = j4;
vinfos[4].indices[0] = _ij4[0];
vinfos[4].indices[1] = _ij4[1];
vinfos[4].maxsolutions = _nj4;
vinfos[5].jointtype = 1;
vinfos[5].foffset = j5;
vinfos[5].indices[0] = _ij5[0];
vinfos[5].indices[1] = _ij5[1];
vinfos[5].maxsolutions = _nj5;
vinfos[6].jointtype = 1;
vinfos[6].foffset = j6;
vinfos[6].indices[0] = _ij6[0];
vinfos[6].indices[1] = _ij6[1];
vinfos[6].maxsolutions = _nj6;
std::vector<int> vfree(0);
solutions.AddSolution(vinfos,vfree);
}
}
}

} else
{
IkReal x9130=((IkReal(1.00000000000000))*(cj0));
IkReal x9131=((cj4)*(sj6));
IkReal x9132=((sj0)*(sj6));
IkReal x9133=((cj5)*(sj4));
IkReal x9134=((IkReal(0.374290000000000))*(sj5));
IkReal x9135=((sj4)*(sj5));
IkReal x9136=((cj0)*(cj6));
IkReal x9137=((IkReal(0.0100000000000000))*(cj5));
IkReal x9138=((cj4)*(sj5));
IkReal x9139=((cj5)*(sj0));
IkReal x9140=((IkReal(0.374290000000000))*(r02));
IkReal x9141=((r20)*(sj6));
IkReal x9142=((cj6)*(r21));
IkReal x9143=((IkReal(1.00000000000000))*(sj0));
IkReal x9144=((cj0)*(sj6));
IkReal x9145=((cj4)*(cj6));
IkReal x9146=((IkReal(0.374290000000000))*(r12));
IkReal x9147=((cj0)*(cj5));
IkReal x9148=((cj6)*(sj5));
IkReal x9149=((cj6)*(r01));
IkReal x9150=((r00)*(sj6));
IkReal x9151=((IkReal(0.0100000000000000))*(sj5));
IkReal x9152=((cj6)*(r11));
IkReal x9153=((IkReal(1.00000000000000))*(r10));
IkReal x9154=((r02)*(sj0));
IkReal x9155=((cj6)*(sj4));
IkReal x9156=((r12)*(x9143));
evalcond[0]=((IkReal(-3.14159265358979))+(IKfmod(((IkReal(4.71238898038469))+(j1)), IkReal(6.28318530717959))));
evalcond[1]=((((x9133)*(x9142)))+(((x9133)*(x9141)))+(((r22)*(x9135)))+(((r21)*(x9131)))+(((IkReal(-1.00000000000000))*(r20)*(x9145))));
evalcond[2]=((IkReal(-0.364420000000000))+(((x9134)*(x9142)))+(((x9134)*(x9141)))+(((IkReal(-1.00000000000000))*(r22)*(x9151)))+(((IkReal(-0.374290000000000))*(cj5)*(r22)))+(pz)+(((IkReal(-1.00000000000000))*(x9137)*(x9141)))+(((IkReal(-1.00000000000000))*(x9137)*(x9142))));
evalcond[3]=((((IkReal(-1.00000000000000))*(sj5)*(x9132)*(x9153)))+(((r12)*(x9139)))+(((r02)*(x9147)))+(((IkReal(-1.00000000000000))*(sj5)*(x9130)*(x9150)))+(((IkReal(-1.00000000000000))*(r01)*(x9130)*(x9148)))+(((IkReal(-1.00000000000000))*(r11)*(x9143)*(x9148))));
evalcond[4]=((((IkReal(-1.00000000000000))*(r10)*(sj6)*(x9130)*(x9133)))+(((x9135)*(x9154)))+(((sj0)*(x9133)*(x9149)))+(((IkReal(-1.00000000000000))*(r12)*(x9130)*(x9135)))+(((IkReal(-1.00000000000000))*(r11)*(x9130)*(x9131)))+(((cj4)*(r10)*(x9136)))+(((r01)*(sj0)*(x9131)))+(((IkReal(-1.00000000000000))*(x9130)*(x9133)*(x9152)))+(((r00)*(x9132)*(x9133)))+(((IkReal(-1.00000000000000))*(r00)*(x9143)*(x9145))));
evalcond[5]=((IkReal(-1.00000000000000))+(((IkReal(-1.00000000000000))*(x9130)*(x9133)*(x9150)))+(((cj4)*(r00)*(x9136)))+(((IkReal(-1.00000000000000))*(r01)*(x9130)*(x9131)))+(((IkReal(-1.00000000000000))*(x9133)*(x9143)*(x9152)))+(((IkReal(-1.00000000000000))*(r11)*(x9131)*(x9143)))+(((IkReal(-1.00000000000000))*(x9130)*(x9133)*(x9149)))+(((IkReal(-1.00000000000000))*(x9132)*(x9133)*(x9153)))+(((IkReal(-1.00000000000000))*(x9135)*(x9156)))+(((IkReal(-1.00000000000000))*(r02)*(x9130)*(x9135)))+(((r10)*(sj0)*(x9145))));
evalcond[6]=((IkReal(0.0690000000000000))+(((x9146)*(x9147)))+(((cj0)*(r12)*(x9151)))+(((IkReal(-1.00000000000000))*(r11)*(x9134)*(x9136)))+(((sj0)*(x9134)*(x9149)))+(((IkReal(-1.00000000000000))*(sj0)*(x9137)*(x9149)))+(((r00)*(x9132)*(x9134)))+(((IkReal(-1.00000000000000))*(x9151)*(x9154)))+(((IkReal(-1.00000000000000))*(r00)*(x9132)*(x9137)))+(((IkReal(-1.00000000000000))*(x9139)*(x9140)))+(((IkReal(-1.00000000000000))*(r10)*(x9134)*(x9144)))+(((IkReal(-1.00000000000000))*(py)*(x9130)))+(((r11)*(x9136)*(x9137)))+(((px)*(sj0)))+(((r10)*(x9137)*(x9144))));
evalcond[7]=((((r01)*(sj4)*(x9144)))+(((IkReal(-1.00000000000000))*(cj5)*(r01)*(x9130)*(x9145)))+(((IkReal(-1.00000000000000))*(r11)*(x9139)*(x9145)))+(((IkReal(-1.00000000000000))*(r10)*(x9143)*(x9155)))+(((IkReal(-1.00000000000000))*(r00)*(x9130)*(x9155)))+(((IkReal(-1.00000000000000))*(r02)*(x9130)*(x9138)))+(((IkReal(-1.00000000000000))*(x9131)*(x9139)*(x9153)))+(((r11)*(sj4)*(x9132)))+(((IkReal(-1.00000000000000))*(cj5)*(r00)*(x9130)*(x9131)))+(((IkReal(-1.00000000000000))*(x9138)*(x9156))));
evalcond[8]=((IkReal(0.0690000000000000))+(((r10)*(x9132)*(x9137)))+(((IkReal(-1.00000000000000))*(px)*(x9130)))+(((r00)*(x9137)*(x9144)))+(((x9139)*(x9146)))+(((r01)*(x9136)*(x9137)))+(((IkReal(-1.00000000000000))*(r10)*(x9132)*(x9134)))+(((IkReal(-1.00000000000000))*(r00)*(x9134)*(x9144)))+(((sj0)*(x9137)*(x9152)))+(((x9140)*(x9147)))+(((IkReal(-1.00000000000000))*(sj0)*(x9134)*(x9152)))+(((IkReal(-1.00000000000000))*(py)*(x9143)))+(((cj0)*(r02)*(x9151)))+(((r12)*(sj0)*(x9151)))+(((IkReal(-1.00000000000000))*(r01)*(x9134)*(x9136))));
if( IKabs(evalcond[0]) < 0.0000010000000000  && IKabs(evalcond[1]) < 0.0000010000000000  && IKabs(evalcond[2]) < 0.0000010000000000  && IKabs(evalcond[3]) < 0.0000010000000000  && IKabs(evalcond[4]) < 0.0000010000000000  && IKabs(evalcond[5]) < 0.0000010000000000  && IKabs(evalcond[6]) < 0.0000010000000000  && IKabs(evalcond[7]) < 0.0000010000000000  && IKabs(evalcond[8]) < 0.0000010000000000  )
{
{
IkReal j3array[1], cj3array[1], sj3array[1];
bool j3valid[1]={false};
_nj3 = 1;
IkReal x9157=((IkReal(1.00000000000000))*(sj5));
IkReal x9158=((cj6)*(r21));
IkReal x9159=((r20)*(sj6));
IkReal x9160=((IkReal(1.00000000000000))*(cj4)*(cj5));
if( IKabs(((((IkReal(-1.00000000000000))*(x9158)*(x9160)))+(((IkReal(-1.00000000000000))*(x9159)*(x9160)))+(((IkReal(-1.00000000000000))*(cj4)*(r22)*(x9157)))+(((r21)*(sj4)*(sj6)))+(((IkReal(-1.00000000000000))*(cj6)*(r20)*(sj4))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(((((IkReal(-1.00000000000000))*(x9157)*(x9159)))+(((IkReal(-1.00000000000000))*(x9157)*(x9158)))+(((cj5)*(r22))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(IKsqr(((((IkReal(-1.00000000000000))*(x9158)*(x9160)))+(((IkReal(-1.00000000000000))*(x9159)*(x9160)))+(((IkReal(-1.00000000000000))*(cj4)*(r22)*(x9157)))+(((r21)*(sj4)*(sj6)))+(((IkReal(-1.00000000000000))*(cj6)*(r20)*(sj4)))))+IKsqr(((((IkReal(-1.00000000000000))*(x9157)*(x9159)))+(((IkReal(-1.00000000000000))*(x9157)*(x9158)))+(((cj5)*(r22)))))-1) <= IKFAST_SINCOS_THRESH )
    continue;
j3array[0]=IKatan2(((((IkReal(-1.00000000000000))*(x9158)*(x9160)))+(((IkReal(-1.00000000000000))*(x9159)*(x9160)))+(((IkReal(-1.00000000000000))*(cj4)*(r22)*(x9157)))+(((r21)*(sj4)*(sj6)))+(((IkReal(-1.00000000000000))*(cj6)*(r20)*(sj4)))), ((((IkReal(-1.00000000000000))*(x9157)*(x9159)))+(((IkReal(-1.00000000000000))*(x9157)*(x9158)))+(((cj5)*(r22)))));
sj3array[0]=IKsin(j3array[0]);
cj3array[0]=IKcos(j3array[0]);
if( j3array[0] > IKPI )
{
    j3array[0]-=IK2PI;
}
else if( j3array[0] < -IKPI )
{    j3array[0]+=IK2PI;
}
j3valid[0] = true;
for(int ij3 = 0; ij3 < 1; ++ij3)
{
if( !j3valid[ij3] )
{
    continue;
}
_ij3[0] = ij3; _ij3[1] = -1;
for(int iij3 = ij3+1; iij3 < 1; ++iij3)
{
if( j3valid[iij3] && IKabs(cj3array[ij3]-cj3array[iij3]) < IKFAST_SOLUTION_THRESH && IKabs(sj3array[ij3]-sj3array[iij3]) < IKFAST_SOLUTION_THRESH )
{
    j3valid[iij3]=false; _ij3[1] = iij3; break; 
}
}
j3 = j3array[ij3]; cj3 = cj3array[ij3]; sj3 = sj3array[ij3];
{
IkReal evalcond[4];
IkReal x9161=IKsin(j3);
IkReal x9162=IKcos(j3);
IkReal x9163=((sj0)*(sj5));
IkReal x9164=((r00)*(sj6));
IkReal x9165=((cj6)*(r01));
IkReal x9166=((cj5)*(sj0));
IkReal x9167=((cj0)*(cj5));
IkReal x9168=((cj6)*(sj4));
IkReal x9169=((sj4)*(sj6));
IkReal x9170=((cj0)*(r11));
IkReal x9171=((cj4)*(cj6));
IkReal x9172=((cj4)*(sj6));
IkReal x9173=((IkReal(1.00000000000000))*(cj0));
IkReal x9174=((cj4)*(sj5));
IkReal x9175=((sj5)*(sj6));
IkReal x9176=((cj6)*(sj5));
evalcond[0]=((((r20)*(x9175)))+(((IkReal(-1.00000000000000))*(cj5)*(r22)))+(((r21)*(x9176)))+(x9162));
evalcond[1]=((((cj5)*(r21)*(x9171)))+(((r22)*(x9174)))+(((r20)*(x9168)))+(x9161)+(((cj5)*(r20)*(x9172)))+(((IkReal(-1.00000000000000))*(r21)*(x9169))));
evalcond[2]=((((x9163)*(x9164)))+(((x9163)*(x9165)))+(((IkReal(-1.00000000000000))*(r10)*(x9173)*(x9175)))+(((r12)*(x9167)))+(((IkReal(-1.00000000000000))*(x9161)))+(((IkReal(-1.00000000000000))*(r02)*(x9166)))+(((IkReal(-1.00000000000000))*(x9170)*(x9176))));
evalcond[3]=((((IkReal(-1.00000000000000))*(r01)*(sj0)*(x9169)))+(((IkReal(-1.00000000000000))*(r11)*(x9167)*(x9171)))+(((IkReal(-1.00000000000000))*(r10)*(x9168)*(x9173)))+(((x9169)*(x9170)))+(((cj4)*(x9164)*(x9166)))+(((cj4)*(r02)*(x9163)))+(((r00)*(sj0)*(x9168)))+(((IkReal(-1.00000000000000))*(r12)*(x9173)*(x9174)))+(((IkReal(-1.00000000000000))*(r10)*(x9167)*(x9172)))+(((cj4)*(x9165)*(x9166)))+(x9162));
if( IKabs(evalcond[0]) > 0.000001  || IKabs(evalcond[1]) > 0.000001  || IKabs(evalcond[2]) > 0.000001  || IKabs(evalcond[3]) > 0.000001  )
{
continue;
}
}

{
std::vector<IkSingleDOFSolutionBase<IkReal> > vinfos(7);
vinfos[0].jointtype = 1;
vinfos[0].foffset = j0;
vinfos[0].indices[0] = _ij0[0];
vinfos[0].indices[1] = _ij0[1];
vinfos[0].maxsolutions = _nj0;
vinfos[1].jointtype = 1;
vinfos[1].foffset = j1;
vinfos[1].indices[0] = _ij1[0];
vinfos[1].indices[1] = _ij1[1];
vinfos[1].maxsolutions = _nj1;
vinfos[2].jointtype = 1;
vinfos[2].foffset = j2;
vinfos[2].indices[0] = _ij2[0];
vinfos[2].indices[1] = _ij2[1];
vinfos[2].maxsolutions = _nj2;
vinfos[3].jointtype = 1;
vinfos[3].foffset = j3;
vinfos[3].indices[0] = _ij3[0];
vinfos[3].indices[1] = _ij3[1];
vinfos[3].maxsolutions = _nj3;
vinfos[4].jointtype = 1;
vinfos[4].foffset = j4;
vinfos[4].indices[0] = _ij4[0];
vinfos[4].indices[1] = _ij4[1];
vinfos[4].maxsolutions = _nj4;
vinfos[5].jointtype = 1;
vinfos[5].foffset = j5;
vinfos[5].indices[0] = _ij5[0];
vinfos[5].indices[1] = _ij5[1];
vinfos[5].maxsolutions = _nj5;
vinfos[6].jointtype = 1;
vinfos[6].foffset = j6;
vinfos[6].indices[0] = _ij6[0];
vinfos[6].indices[1] = _ij6[1];
vinfos[6].maxsolutions = _nj6;
std::vector<int> vfree(0);
solutions.AddSolution(vinfos,vfree);
}
}
}

} else
{
IkReal x9177=((IkReal(1.00000000000000))*(cj0));
IkReal x9178=((cj4)*(sj6));
IkReal x9179=((sj0)*(sj4));
IkReal x9180=((cj5)*(sj6));
IkReal x9181=((sj4)*(sj5));
IkReal x9182=((r12)*(sj5));
IkReal x9183=((IkReal(0.374290000000000))*(cj5));
IkReal x9184=((r02)*(sj0));
IkReal x9185=((r20)*(sj4));
IkReal x9186=((IkReal(1.00000000000000))*(sj0));
IkReal x9187=((IkReal(1.00000000000000))*(cj5));
IkReal x9188=((cj0)*(r10));
IkReal x9189=((cj4)*(cj6));
IkReal x9190=((r00)*(sj0));
IkReal x9191=((cj6)*(r21));
IkReal x9192=((IkReal(0.374290000000000))*(sj5));
IkReal x9193=((cj0)*(r00));
IkReal x9194=((IkReal(0.0100000000000000))*(sj5));
IkReal x9195=((cj0)*(r02));
IkReal x9196=((cj5)*(sj4));
IkReal x9197=((cj6)*(r01));
IkReal x9198=((cj6)*(r11));
IkReal x9199=((r01)*(sj0));
IkReal x9200=((r10)*(sj0));
IkReal x9201=((IkReal(0.0100000000000000))*(cj5)*(cj6));
IkReal x9202=((sj6)*(x9192));
IkReal x9203=((cj0)*(cj6)*(x9192));
evalcond[0]=((IkReal(-3.14159265358979))+(IKfmod(((IkReal(3.14159265358979))+(j1)), IkReal(6.28318530717959))));
evalcond[1]=((((IkReal(-1.00000000000000))*(r22)*(x9187)))+(((r20)*(sj5)*(sj6)))+(((sj5)*(x9191))));
evalcond[2]=((IkReal(-1.00000000000000))+(((r22)*(x9181)))+(((r21)*(x9178)))+(((IkReal(-1.00000000000000))*(r20)*(x9189)))+(((x9180)*(x9185)))+(((x9191)*(x9196))));
evalcond[3]=((((IkReal(-1.00000000000000))*(r22)*(x9183)))+(((IkReal(-0.0100000000000000))*(cj5)*(x9191)))+(((IkReal(-1.00000000000000))*(r22)*(x9194)))+(((IkReal(-0.0100000000000000))*(r20)*(x9180)))+(pz)+(((x9191)*(x9192)))+(((r20)*(x9202))));
evalcond[4]=((((cj5)*(r21)*(x9189)))+(((IkReal(-1.00000000000000))*(r21)*(sj4)*(sj6)))+(((cj5)*(r20)*(x9178)))+(((cj4)*(r22)*(sj5)))+(((cj6)*(x9185))));
evalcond[5]=((((IkReal(-1.00000000000000))*(r11)*(x9177)*(x9178)))+(((IkReal(-1.00000000000000))*(r12)*(x9177)*(x9181)))+(((r02)*(sj5)*(x9179)))+(((IkReal(-1.00000000000000))*(r10)*(sj4)*(x9177)*(x9180)))+(((cj5)*(x9179)*(x9197)))+(((x9178)*(x9199)))+(((r00)*(x9179)*(x9180)))+(((x9188)*(x9189)))+(((IkReal(-1.00000000000000))*(x9177)*(x9196)*(x9198)))+(((IkReal(-1.00000000000000))*(r00)*(x9186)*(x9189))));
evalcond[6]=((((IkReal(-1.00000000000000))*(x9179)*(x9182)))+(((IkReal(-1.00000000000000))*(r01)*(x9177)*(x9178)))+(((IkReal(-1.00000000000000))*(r00)*(sj4)*(x9177)*(x9180)))+(((IkReal(-1.00000000000000))*(r10)*(x9179)*(x9180)))+(((IkReal(-1.00000000000000))*(r02)*(x9177)*(x9181)))+(((IkReal(-1.00000000000000))*(x9177)*(x9196)*(x9197)))+(((IkReal(-1.00000000000000))*(x9179)*(x9187)*(x9198)))+(((x9189)*(x9200)))+(((x9189)*(x9193)))+(((IkReal(-1.00000000000000))*(r11)*(x9178)*(x9186))));
evalcond[7]=((IkReal(0.0690000000000000))+(((IkReal(0.0100000000000000))*(cj0)*(x9182)))+(((cj0)*(r12)*(x9183)))+(((IkReal(0.0100000000000000))*(cj0)*(cj5)*(x9198)))+(((IkReal(-1.00000000000000))*(x9183)*(x9184)))+(((IkReal(-1.00000000000000))*(x9188)*(x9202)))+(((IkReal(-0.0100000000000000))*(cj5)*(sj0)*(x9197)))+(((IkReal(-1.00000000000000))*(py)*(x9177)))+(((IkReal(-1.00000000000000))*(cj0)*(x9192)*(x9198)))+(((x9190)*(x9202)))+(((IkReal(0.0100000000000000))*(x9180)*(x9188)))+(((sj0)*(x9192)*(x9197)))+(((IkReal(-0.0100000000000000))*(x9180)*(x9190)))+(((px)*(sj0)))+(((IkReal(-1.00000000000000))*(x9184)*(x9194))));
evalcond[8]=((IkReal(0.433420000000000))+(((IkReal(-1.00000000000000))*(x9193)*(x9202)))+(((IkReal(0.0100000000000000))*(x9180)*(x9193)))+(((r12)*(sj0)*(x9183)))+(((IkReal(0.0100000000000000))*(cj5)*(sj0)*(x9198)))+(((IkReal(-1.00000000000000))*(cj0)*(x9192)*(x9197)))+(((x9194)*(x9195)))+(((IkReal(-1.00000000000000))*(sj0)*(x9192)*(x9198)))+(((IkReal(-1.00000000000000))*(px)*(x9177)))+(((IkReal(0.0100000000000000))*(sj0)*(x9182)))+(((IkReal(-1.00000000000000))*(x9200)*(x9202)))+(((IkReal(0.0100000000000000))*(x9180)*(x9200)))+(((x9183)*(x9195)))+(((IkReal(0.0100000000000000))*(cj0)*(cj5)*(x9197)))+(((IkReal(-1.00000000000000))*(py)*(x9186))));
if( IKabs(evalcond[0]) < 0.0000010000000000  && IKabs(evalcond[1]) < 0.0000010000000000  && IKabs(evalcond[2]) < 0.0000010000000000  && IKabs(evalcond[3]) < 0.0000010000000000  && IKabs(evalcond[4]) < 0.0000010000000000  && IKabs(evalcond[5]) < 0.0000010000000000  && IKabs(evalcond[6]) < 0.0000010000000000  && IKabs(evalcond[7]) < 0.0000010000000000  && IKabs(evalcond[8]) < 0.0000010000000000  )
{
{
IkReal j3array[1], cj3array[1], sj3array[1];
bool j3valid[1]={false};
_nj3 = 1;
IkReal x9204=((cj0)*(cj5));
IkReal x9205=((IkReal(1.00000000000000))*(cj0));
IkReal x9206=((cj6)*(r11));
IkReal x9207=((r10)*(sj6));
IkReal x9208=((cj5)*(sj0));
IkReal x9209=((r00)*(sj5)*(sj6));
IkReal x9210=((cj6)*(r01)*(sj5));
IkReal x9211=((IkReal(1.00000000000000))*(sj0)*(sj5));
if( IKabs(((((r12)*(x9204)))+(((IkReal(-1.00000000000000))*(sj5)*(x9205)*(x9206)))+(((IkReal(-1.00000000000000))*(r02)*(x9208)))+(((IkReal(-1.00000000000000))*(sj5)*(x9205)*(x9207)))+(((sj0)*(x9209)))+(((sj0)*(x9210))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(((((r02)*(x9204)))+(((IkReal(-1.00000000000000))*(x9205)*(x9209)))+(((IkReal(-1.00000000000000))*(x9207)*(x9211)))+(((IkReal(-1.00000000000000))*(x9205)*(x9210)))+(((r12)*(x9208)))+(((IkReal(-1.00000000000000))*(x9206)*(x9211))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(IKsqr(((((r12)*(x9204)))+(((IkReal(-1.00000000000000))*(sj5)*(x9205)*(x9206)))+(((IkReal(-1.00000000000000))*(r02)*(x9208)))+(((IkReal(-1.00000000000000))*(sj5)*(x9205)*(x9207)))+(((sj0)*(x9209)))+(((sj0)*(x9210)))))+IKsqr(((((r02)*(x9204)))+(((IkReal(-1.00000000000000))*(x9205)*(x9209)))+(((IkReal(-1.00000000000000))*(x9207)*(x9211)))+(((IkReal(-1.00000000000000))*(x9205)*(x9210)))+(((r12)*(x9208)))+(((IkReal(-1.00000000000000))*(x9206)*(x9211)))))-1) <= IKFAST_SINCOS_THRESH )
    continue;
j3array[0]=IKatan2(((((r12)*(x9204)))+(((IkReal(-1.00000000000000))*(sj5)*(x9205)*(x9206)))+(((IkReal(-1.00000000000000))*(r02)*(x9208)))+(((IkReal(-1.00000000000000))*(sj5)*(x9205)*(x9207)))+(((sj0)*(x9209)))+(((sj0)*(x9210)))), ((((r02)*(x9204)))+(((IkReal(-1.00000000000000))*(x9205)*(x9209)))+(((IkReal(-1.00000000000000))*(x9207)*(x9211)))+(((IkReal(-1.00000000000000))*(x9205)*(x9210)))+(((r12)*(x9208)))+(((IkReal(-1.00000000000000))*(x9206)*(x9211)))));
sj3array[0]=IKsin(j3array[0]);
cj3array[0]=IKcos(j3array[0]);
if( j3array[0] > IKPI )
{
    j3array[0]-=IK2PI;
}
else if( j3array[0] < -IKPI )
{    j3array[0]+=IK2PI;
}
j3valid[0] = true;
for(int ij3 = 0; ij3 < 1; ++ij3)
{
if( !j3valid[ij3] )
{
    continue;
}
_ij3[0] = ij3; _ij3[1] = -1;
for(int iij3 = ij3+1; iij3 < 1; ++iij3)
{
if( j3valid[iij3] && IKabs(cj3array[ij3]-cj3array[iij3]) < IKFAST_SOLUTION_THRESH && IKabs(sj3array[ij3]-sj3array[iij3]) < IKFAST_SOLUTION_THRESH )
{
    j3valid[iij3]=false; _ij3[1] = iij3; break; 
}
}
j3 = j3array[ij3]; cj3 = cj3array[ij3]; sj3 = sj3array[ij3];
{
IkReal evalcond[4];
IkReal x9212=IKcos(j3);
IkReal x9213=((sj0)*(sj5));
IkReal x9214=((r00)*(sj6));
IkReal x9215=((cj6)*(sj0));
IkReal x9216=((IkReal(1.00000000000000))*(cj4));
IkReal x9217=((r00)*(sj4));
IkReal x9218=((cj0)*(cj5));
IkReal x9219=((cj5)*(sj0));
IkReal x9220=((cj6)*(r11));
IkReal x9221=((r10)*(sj6));
IkReal x9222=((cj0)*(sj5));
IkReal x9223=((r10)*(sj4));
IkReal x9224=((IkReal(1.00000000000000))*(IKsin(j3)));
IkReal x9225=((cj4)*(cj5)*(r01));
IkReal x9226=((IkReal(1.00000000000000))*(cj0)*(cj6));
IkReal x9227=((cj0)*(sj4)*(sj6));
IkReal x9228=((sj0)*(sj4)*(sj6));
evalcond[0]=((((IkReal(-1.00000000000000))*(r02)*(x9219)))+(((IkReal(-1.00000000000000))*(x9221)*(x9222)))+(((x9213)*(x9214)))+(((IkReal(-1.00000000000000))*(x9220)*(x9222)))+(((cj6)*(r01)*(x9213)))+(((r12)*(x9218)))+(((IkReal(-1.00000000000000))*(x9224))));
evalcond[1]=((((IkReal(-1.00000000000000))*(cj6)*(r01)*(x9222)))+(((IkReal(-1.00000000000000))*(x9213)*(x9221)))+(((IkReal(-1.00000000000000))*(x9213)*(x9220)))+(((r12)*(x9219)))+(((IkReal(-1.00000000000000))*(x9214)*(x9222)))+(((IkReal(-1.00000000000000))*(x9212)))+(((r02)*(x9218))));
evalcond[2]=((((IkReal(-1.00000000000000))*(r12)*(x9216)*(x9222)))+(x9212)+(((cj4)*(r02)*(x9213)))+(((IkReal(-1.00000000000000))*(x9223)*(x9226)))+(((x9215)*(x9217)))+(((x9215)*(x9225)))+(((IkReal(-1.00000000000000))*(x9216)*(x9218)*(x9221)))+(((r11)*(x9227)))+(((IkReal(-1.00000000000000))*(r01)*(x9228)))+(((cj4)*(x9214)*(x9219)))+(((IkReal(-1.00000000000000))*(x9216)*(x9218)*(x9220))));
evalcond[3]=((((IkReal(-1.00000000000000))*(x9216)*(x9219)*(x9221)))+(((r01)*(x9227)))+(((r11)*(x9228)))+(((IkReal(-1.00000000000000))*(r02)*(x9216)*(x9222)))+(((IkReal(-1.00000000000000))*(cj5)*(r11)*(x9215)*(x9216)))+(((IkReal(-1.00000000000000))*(x9217)*(x9226)))+(((IkReal(-1.00000000000000))*(x9214)*(x9216)*(x9218)))+(((IkReal(-1.00000000000000))*(cj6)*(r01)*(x9216)*(x9218)))+(((IkReal(-1.00000000000000))*(r12)*(x9213)*(x9216)))+(((IkReal(-1.00000000000000))*(x9224)))+(((IkReal(-1.00000000000000))*(x9215)*(x9223))));
if( IKabs(evalcond[0]) > 0.000001  || IKabs(evalcond[1]) > 0.000001  || IKabs(evalcond[2]) > 0.000001  || IKabs(evalcond[3]) > 0.000001  )
{
continue;
}
}

{
std::vector<IkSingleDOFSolutionBase<IkReal> > vinfos(7);
vinfos[0].jointtype = 1;
vinfos[0].foffset = j0;
vinfos[0].indices[0] = _ij0[0];
vinfos[0].indices[1] = _ij0[1];
vinfos[0].maxsolutions = _nj0;
vinfos[1].jointtype = 1;
vinfos[1].foffset = j1;
vinfos[1].indices[0] = _ij1[0];
vinfos[1].indices[1] = _ij1[1];
vinfos[1].maxsolutions = _nj1;
vinfos[2].jointtype = 1;
vinfos[2].foffset = j2;
vinfos[2].indices[0] = _ij2[0];
vinfos[2].indices[1] = _ij2[1];
vinfos[2].maxsolutions = _nj2;
vinfos[3].jointtype = 1;
vinfos[3].foffset = j3;
vinfos[3].indices[0] = _ij3[0];
vinfos[3].indices[1] = _ij3[1];
vinfos[3].maxsolutions = _nj3;
vinfos[4].jointtype = 1;
vinfos[4].foffset = j4;
vinfos[4].indices[0] = _ij4[0];
vinfos[4].indices[1] = _ij4[1];
vinfos[4].maxsolutions = _nj4;
vinfos[5].jointtype = 1;
vinfos[5].foffset = j5;
vinfos[5].indices[0] = _ij5[0];
vinfos[5].indices[1] = _ij5[1];
vinfos[5].maxsolutions = _nj5;
vinfos[6].jointtype = 1;
vinfos[6].foffset = j6;
vinfos[6].indices[0] = _ij6[0];
vinfos[6].indices[1] = _ij6[1];
vinfos[6].maxsolutions = _nj6;
std::vector<int> vfree(0);
solutions.AddSolution(vinfos,vfree);
}
}
}

} else
{
IkReal x9229=((IkReal(1.00000000000000))*(cj0));
IkReal x9230=((cj4)*(sj6));
IkReal x9231=((sj0)*(sj4));
IkReal x9232=((cj5)*(sj6));
IkReal x9233=((sj4)*(sj5));
IkReal x9234=((r12)*(sj5));
IkReal x9235=((IkReal(0.374290000000000))*(cj5));
IkReal x9236=((r02)*(sj0));
IkReal x9237=((r20)*(sj4));
IkReal x9238=((IkReal(1.00000000000000))*(sj0));
IkReal x9239=((IkReal(1.00000000000000))*(cj5));
IkReal x9240=((cj0)*(r10));
IkReal x9241=((cj4)*(cj6));
IkReal x9242=((r00)*(sj0));
IkReal x9243=((cj6)*(r21));
IkReal x9244=((IkReal(0.374290000000000))*(sj5));
IkReal x9245=((cj0)*(r00));
IkReal x9246=((IkReal(0.0100000000000000))*(sj5));
IkReal x9247=((cj0)*(r02));
IkReal x9248=((cj5)*(sj4));
IkReal x9249=((cj6)*(r01));
IkReal x9250=((cj6)*(r11));
IkReal x9251=((r01)*(sj0));
IkReal x9252=((r10)*(sj0));
IkReal x9253=((IkReal(0.0100000000000000))*(cj5)*(cj6));
IkReal x9254=((sj6)*(x9244));
IkReal x9255=((cj0)*(cj6)*(x9244));
evalcond[0]=((IkReal(-3.14159265358979))+(IKfmod(j1, IkReal(6.28318530717959))));
evalcond[1]=((((sj5)*(x9243)))+(((IkReal(-1.00000000000000))*(r22)*(x9239)))+(((r20)*(sj5)*(sj6))));
evalcond[2]=((IkReal(1.00000000000000))+(((r21)*(x9230)))+(((IkReal(-1.00000000000000))*(r20)*(x9241)))+(((x9232)*(x9237)))+(((r22)*(x9233)))+(((x9243)*(x9248))));
evalcond[3]=((((IkReal(-1.00000000000000))*(r22)*(x9246)))+(((IkReal(-1.00000000000000))*(r22)*(x9235)))+(((IkReal(-0.0100000000000000))*(cj5)*(x9243)))+(pz)+(((IkReal(-0.0100000000000000))*(r20)*(x9232)))+(((r20)*(x9254)))+(((x9243)*(x9244))));
evalcond[4]=((((cj6)*(x9237)))+(((IkReal(-1.00000000000000))*(r21)*(sj4)*(sj6)))+(((cj4)*(r22)*(sj5)))+(((cj5)*(r20)*(x9230)))+(((cj5)*(r21)*(x9241))));
evalcond[5]=((((IkReal(-1.00000000000000))*(r12)*(x9229)*(x9233)))+(((x9230)*(x9251)))+(((cj5)*(x9231)*(x9249)))+(((x9240)*(x9241)))+(((IkReal(-1.00000000000000))*(r10)*(sj4)*(x9229)*(x9232)))+(((IkReal(-1.00000000000000))*(x9229)*(x9248)*(x9250)))+(((r02)*(sj5)*(x9231)))+(((IkReal(-1.00000000000000))*(r00)*(x9238)*(x9241)))+(((r00)*(x9231)*(x9232)))+(((IkReal(-1.00000000000000))*(r11)*(x9229)*(x9230))));
evalcond[6]=((((IkReal(-1.00000000000000))*(r00)*(sj4)*(x9229)*(x9232)))+(((IkReal(-1.00000000000000))*(x9231)*(x9234)))+(((IkReal(-1.00000000000000))*(r10)*(x9231)*(x9232)))+(((x9241)*(x9252)))+(((x9241)*(x9245)))+(((IkReal(-1.00000000000000))*(x9231)*(x9239)*(x9250)))+(((IkReal(-1.00000000000000))*(r01)*(x9229)*(x9230)))+(((IkReal(-1.00000000000000))*(r02)*(x9229)*(x9233)))+(((IkReal(-1.00000000000000))*(r11)*(x9230)*(x9238)))+(((IkReal(-1.00000000000000))*(x9229)*(x9248)*(x9249))));
evalcond[7]=((IkReal(0.0690000000000000))+(((IkReal(0.0100000000000000))*(cj0)*(x9234)))+(((sj0)*(x9244)*(x9249)))+(((cj0)*(r12)*(x9235)))+(((IkReal(-1.00000000000000))*(x9236)*(x9246)))+(((IkReal(-1.00000000000000))*(x9235)*(x9236)))+(((IkReal(0.0100000000000000))*(x9232)*(x9240)))+(((x9242)*(x9254)))+(((IkReal(-0.0100000000000000))*(x9232)*(x9242)))+(((IkReal(-1.00000000000000))*(py)*(x9229)))+(((IkReal(-1.00000000000000))*(cj0)*(x9244)*(x9250)))+(((IkReal(0.0100000000000000))*(cj0)*(cj5)*(x9250)))+(((IkReal(-1.00000000000000))*(x9240)*(x9254)))+(((px)*(sj0)))+(((IkReal(-0.0100000000000000))*(cj5)*(sj0)*(x9249))));
evalcond[8]=((IkReal(-0.295420000000000))+(((IkReal(-1.00000000000000))*(cj0)*(x9244)*(x9249)))+(((IkReal(0.0100000000000000))*(x9232)*(x9245)))+(((x9235)*(x9247)))+(((IkReal(0.0100000000000000))*(cj5)*(sj0)*(x9250)))+(((IkReal(-1.00000000000000))*(px)*(x9229)))+(((IkReal(-1.00000000000000))*(py)*(x9238)))+(((IkReal(-1.00000000000000))*(x9245)*(x9254)))+(((IkReal(-1.00000000000000))*(sj0)*(x9244)*(x9250)))+(((x9246)*(x9247)))+(((IkReal(0.0100000000000000))*(cj0)*(cj5)*(x9249)))+(((r12)*(sj0)*(x9235)))+(((IkReal(0.0100000000000000))*(x9232)*(x9252)))+(((IkReal(-1.00000000000000))*(x9252)*(x9254)))+(((IkReal(0.0100000000000000))*(sj0)*(x9234))));
if( IKabs(evalcond[0]) < 0.0000010000000000  && IKabs(evalcond[1]) < 0.0000010000000000  && IKabs(evalcond[2]) < 0.0000010000000000  && IKabs(evalcond[3]) < 0.0000010000000000  && IKabs(evalcond[4]) < 0.0000010000000000  && IKabs(evalcond[5]) < 0.0000010000000000  && IKabs(evalcond[6]) < 0.0000010000000000  && IKabs(evalcond[7]) < 0.0000010000000000  && IKabs(evalcond[8]) < 0.0000010000000000  )
{
{
IkReal j3array[1], cj3array[1], sj3array[1];
bool j3valid[1]={false};
_nj3 = 1;
IkReal x9256=((sj0)*(sj5));
IkReal x9257=((r00)*(sj6));
IkReal x9258=((IkReal(1.00000000000000))*(cj5));
IkReal x9259=((cj6)*(r11));
IkReal x9260=((cj6)*(r01));
IkReal x9261=((r10)*(sj6));
IkReal x9262=((cj0)*(sj5));
if( IKabs(((((IkReal(-1.00000000000000))*(x9259)*(x9262)))+(((IkReal(-1.00000000000000))*(x9261)*(x9262)))+(((cj0)*(cj5)*(r12)))+(((IkReal(-1.00000000000000))*(r02)*(sj0)*(x9258)))+(((x9256)*(x9257)))+(((x9256)*(x9260))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(((((IkReal(-1.00000000000000))*(cj0)*(r02)*(x9258)))+(((x9256)*(x9259)))+(((x9257)*(x9262)))+(((IkReal(-1.00000000000000))*(r12)*(sj0)*(x9258)))+(((x9256)*(x9261)))+(((x9260)*(x9262))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(IKsqr(((((IkReal(-1.00000000000000))*(x9259)*(x9262)))+(((IkReal(-1.00000000000000))*(x9261)*(x9262)))+(((cj0)*(cj5)*(r12)))+(((IkReal(-1.00000000000000))*(r02)*(sj0)*(x9258)))+(((x9256)*(x9257)))+(((x9256)*(x9260)))))+IKsqr(((((IkReal(-1.00000000000000))*(cj0)*(r02)*(x9258)))+(((x9256)*(x9259)))+(((x9257)*(x9262)))+(((IkReal(-1.00000000000000))*(r12)*(sj0)*(x9258)))+(((x9256)*(x9261)))+(((x9260)*(x9262)))))-1) <= IKFAST_SINCOS_THRESH )
    continue;
j3array[0]=IKatan2(((((IkReal(-1.00000000000000))*(x9259)*(x9262)))+(((IkReal(-1.00000000000000))*(x9261)*(x9262)))+(((cj0)*(cj5)*(r12)))+(((IkReal(-1.00000000000000))*(r02)*(sj0)*(x9258)))+(((x9256)*(x9257)))+(((x9256)*(x9260)))), ((((IkReal(-1.00000000000000))*(cj0)*(r02)*(x9258)))+(((x9256)*(x9259)))+(((x9257)*(x9262)))+(((IkReal(-1.00000000000000))*(r12)*(sj0)*(x9258)))+(((x9256)*(x9261)))+(((x9260)*(x9262)))));
sj3array[0]=IKsin(j3array[0]);
cj3array[0]=IKcos(j3array[0]);
if( j3array[0] > IKPI )
{
    j3array[0]-=IK2PI;
}
else if( j3array[0] < -IKPI )
{    j3array[0]+=IK2PI;
}
j3valid[0] = true;
for(int ij3 = 0; ij3 < 1; ++ij3)
{
if( !j3valid[ij3] )
{
    continue;
}
_ij3[0] = ij3; _ij3[1] = -1;
for(int iij3 = ij3+1; iij3 < 1; ++iij3)
{
if( j3valid[iij3] && IKabs(cj3array[ij3]-cj3array[iij3]) < IKFAST_SOLUTION_THRESH && IKabs(sj3array[ij3]-sj3array[iij3]) < IKFAST_SOLUTION_THRESH )
{
    j3valid[iij3]=false; _ij3[1] = iij3; break; 
}
}
j3 = j3array[ij3]; cj3 = cj3array[ij3]; sj3 = sj3array[ij3];
{
IkReal evalcond[4];
IkReal x9263=IKcos(j3);
IkReal x9264=IKsin(j3);
IkReal x9265=((sj0)*(sj5));
IkReal x9266=((r00)*(sj6));
IkReal x9267=((cj6)*(sj0));
IkReal x9268=((IkReal(1.00000000000000))*(cj4));
IkReal x9269=((r00)*(sj4));
IkReal x9270=((cj0)*(cj5));
IkReal x9271=((cj5)*(sj0));
IkReal x9272=((cj6)*(r11));
IkReal x9273=((r10)*(sj6));
IkReal x9274=((cj0)*(sj5));
IkReal x9275=((r10)*(sj4));
IkReal x9276=((cj4)*(cj5)*(r01));
IkReal x9277=((IkReal(1.00000000000000))*(cj0)*(cj6));
IkReal x9278=((cj0)*(sj4)*(sj6));
IkReal x9279=((sj0)*(sj4)*(sj6));
evalcond[0]=((((IkReal(-1.00000000000000))*(x9273)*(x9274)))+(((cj6)*(r01)*(x9265)))+(((IkReal(-1.00000000000000))*(r02)*(x9271)))+(((IkReal(-1.00000000000000))*(x9264)))+(((IkReal(-1.00000000000000))*(x9272)*(x9274)))+(((x9265)*(x9266)))+(((r12)*(x9270))));
evalcond[1]=((((r02)*(x9270)))+(((IkReal(-1.00000000000000))*(x9265)*(x9272)))+(x9263)+(((r12)*(x9271)))+(((IkReal(-1.00000000000000))*(cj6)*(r01)*(x9274)))+(((IkReal(-1.00000000000000))*(x9266)*(x9274)))+(((IkReal(-1.00000000000000))*(x9265)*(x9273))));
evalcond[2]=((((cj4)*(r02)*(x9265)))+(((x9267)*(x9269)))+(x9263)+(((r11)*(x9278)))+(((IkReal(-1.00000000000000))*(x9268)*(x9270)*(x9273)))+(((x9267)*(x9276)))+(((IkReal(-1.00000000000000))*(x9268)*(x9270)*(x9272)))+(((IkReal(-1.00000000000000))*(x9275)*(x9277)))+(((cj4)*(x9266)*(x9271)))+(((IkReal(-1.00000000000000))*(r12)*(x9268)*(x9274)))+(((IkReal(-1.00000000000000))*(r01)*(x9279))));
evalcond[3]=((((r11)*(x9279)))+(((IkReal(-1.00000000000000))*(x9267)*(x9275)))+(x9264)+(((IkReal(-1.00000000000000))*(x9268)*(x9271)*(x9273)))+(((r01)*(x9278)))+(((IkReal(-1.00000000000000))*(x9266)*(x9268)*(x9270)))+(((IkReal(-1.00000000000000))*(x9269)*(x9277)))+(((IkReal(-1.00000000000000))*(r12)*(x9265)*(x9268)))+(((IkReal(-1.00000000000000))*(cj5)*(r11)*(x9267)*(x9268)))+(((IkReal(-1.00000000000000))*(cj6)*(r01)*(x9268)*(x9270)))+(((IkReal(-1.00000000000000))*(r02)*(x9268)*(x9274))));
if( IKabs(evalcond[0]) > 0.000001  || IKabs(evalcond[1]) > 0.000001  || IKabs(evalcond[2]) > 0.000001  || IKabs(evalcond[3]) > 0.000001  )
{
continue;
}
}

{
std::vector<IkSingleDOFSolutionBase<IkReal> > vinfos(7);
vinfos[0].jointtype = 1;
vinfos[0].foffset = j0;
vinfos[0].indices[0] = _ij0[0];
vinfos[0].indices[1] = _ij0[1];
vinfos[0].maxsolutions = _nj0;
vinfos[1].jointtype = 1;
vinfos[1].foffset = j1;
vinfos[1].indices[0] = _ij1[0];
vinfos[1].indices[1] = _ij1[1];
vinfos[1].maxsolutions = _nj1;
vinfos[2].jointtype = 1;
vinfos[2].foffset = j2;
vinfos[2].indices[0] = _ij2[0];
vinfos[2].indices[1] = _ij2[1];
vinfos[2].maxsolutions = _nj2;
vinfos[3].jointtype = 1;
vinfos[3].foffset = j3;
vinfos[3].indices[0] = _ij3[0];
vinfos[3].indices[1] = _ij3[1];
vinfos[3].maxsolutions = _nj3;
vinfos[4].jointtype = 1;
vinfos[4].foffset = j4;
vinfos[4].indices[0] = _ij4[0];
vinfos[4].indices[1] = _ij4[1];
vinfos[4].maxsolutions = _nj4;
vinfos[5].jointtype = 1;
vinfos[5].foffset = j5;
vinfos[5].indices[0] = _ij5[0];
vinfos[5].indices[1] = _ij5[1];
vinfos[5].maxsolutions = _nj5;
vinfos[6].jointtype = 1;
vinfos[6].foffset = j6;
vinfos[6].indices[0] = _ij6[0];
vinfos[6].indices[1] = _ij6[1];
vinfos[6].maxsolutions = _nj6;
std::vector<int> vfree(0);
solutions.AddSolution(vinfos,vfree);
}
}
}

} else
{
if( 1 )
{
continue;

} else
{
}
}
}
}
}
}

} else
{
{
IkReal j3array[1], cj3array[1], sj3array[1];
bool j3valid[1]={false};
_nj3 = 1;
IkReal x9280=((cj0)*(cj5));
IkReal x9281=((IkReal(1.00000000000000))*(cj0));
IkReal x9282=((cj6)*(r11));
IkReal x9283=((r10)*(sj6));
IkReal x9284=((cj5)*(sj0));
IkReal x9285=((r00)*(sj5)*(sj6));
IkReal x9286=((cj6)*(r01)*(sj5));
IkReal x9287=((IkReal(1.00000000000000))*(sj0)*(sj5));
if( IKabs(((((sj0)*(x9286)))+(((r12)*(x9280)))+(((IkReal(-1.00000000000000))*(r02)*(x9284)))+(((IkReal(-1.00000000000000))*(sj5)*(x9281)*(x9283)))+(((IkReal(-1.00000000000000))*(sj5)*(x9281)*(x9282)))+(((sj0)*(x9285))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(((((IKabs(cj1) != 0)?((IkReal)1/(cj1)):(IkReal)1.0e30))*(((((r02)*(x9280)))+(((IkReal(-1.00000000000000))*(x9283)*(x9287)))+(((r12)*(x9284)))+(((IkReal(-1.00000000000000))*(x9281)*(x9286)))+(((IkReal(-1.00000000000000))*(x9281)*(x9285)))+(((IkReal(-1.00000000000000))*(x9282)*(x9287))))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(IKsqr(((((sj0)*(x9286)))+(((r12)*(x9280)))+(((IkReal(-1.00000000000000))*(r02)*(x9284)))+(((IkReal(-1.00000000000000))*(sj5)*(x9281)*(x9283)))+(((IkReal(-1.00000000000000))*(sj5)*(x9281)*(x9282)))+(((sj0)*(x9285)))))+IKsqr(((((IKabs(cj1) != 0)?((IkReal)1/(cj1)):(IkReal)1.0e30))*(((((r02)*(x9280)))+(((IkReal(-1.00000000000000))*(x9283)*(x9287)))+(((r12)*(x9284)))+(((IkReal(-1.00000000000000))*(x9281)*(x9286)))+(((IkReal(-1.00000000000000))*(x9281)*(x9285)))+(((IkReal(-1.00000000000000))*(x9282)*(x9287)))))))-1) <= IKFAST_SINCOS_THRESH )
    continue;
j3array[0]=IKatan2(((((sj0)*(x9286)))+(((r12)*(x9280)))+(((IkReal(-1.00000000000000))*(r02)*(x9284)))+(((IkReal(-1.00000000000000))*(sj5)*(x9281)*(x9283)))+(((IkReal(-1.00000000000000))*(sj5)*(x9281)*(x9282)))+(((sj0)*(x9285)))), ((((IKabs(cj1) != 0)?((IkReal)1/(cj1)):(IkReal)1.0e30))*(((((r02)*(x9280)))+(((IkReal(-1.00000000000000))*(x9283)*(x9287)))+(((r12)*(x9284)))+(((IkReal(-1.00000000000000))*(x9281)*(x9286)))+(((IkReal(-1.00000000000000))*(x9281)*(x9285)))+(((IkReal(-1.00000000000000))*(x9282)*(x9287)))))));
sj3array[0]=IKsin(j3array[0]);
cj3array[0]=IKcos(j3array[0]);
if( j3array[0] > IKPI )
{
    j3array[0]-=IK2PI;
}
else if( j3array[0] < -IKPI )
{    j3array[0]+=IK2PI;
}
j3valid[0] = true;
for(int ij3 = 0; ij3 < 1; ++ij3)
{
if( !j3valid[ij3] )
{
    continue;
}
_ij3[0] = ij3; _ij3[1] = -1;
for(int iij3 = ij3+1; iij3 < 1; ++iij3)
{
if( j3valid[iij3] && IKabs(cj3array[ij3]-cj3array[iij3]) < IKFAST_SOLUTION_THRESH && IKabs(sj3array[ij3]-sj3array[iij3]) < IKFAST_SOLUTION_THRESH )
{
    j3valid[iij3]=false; _ij3[1] = iij3; break; 
}
}
j3 = j3array[ij3]; cj3 = cj3array[ij3]; sj3 = sj3array[ij3];
{
IkReal evalcond[6];
IkReal x9288=IKsin(j3);
IkReal x9289=IKcos(j3);
IkReal x9290=((sj0)*(sj5));
IkReal x9291=((r00)*(sj6));
IkReal x9292=((cj6)*(r01));
IkReal x9293=((cj4)*(cj5));
IkReal x9294=((IkReal(1.00000000000000))*(cj0));
IkReal x9295=((cj5)*(r12));
IkReal x9296=((IkReal(1.00000000000000))*(sj0));
IkReal x9297=((cj6)*(r11));
IkReal x9298=((cj5)*(r02));
IkReal x9299=((IkReal(1.00000000000000))*(cj1));
IkReal x9300=((cj6)*(sj4));
IkReal x9301=((cj6)*(r21));
IkReal x9302=((r20)*(sj6));
IkReal x9303=((r10)*(sj6));
IkReal x9304=((sj4)*(sj6));
IkReal x9305=((cj4)*(r02));
IkReal x9306=((IkReal(1.00000000000000))*(cj4)*(r12));
IkReal x9307=((IkReal(1.00000000000000))*(x9288));
IkReal x9308=((cj0)*(x9304));
evalcond[0]=((((sj5)*(x9301)))+(((IkReal(-1.00000000000000))*(cj5)*(r22)))+(((IkReal(-1.00000000000000))*(sj1)*(x9289)))+(((sj5)*(x9302))));
evalcond[1]=((((x9293)*(x9301)))+(((IkReal(-1.00000000000000))*(sj1)*(x9307)))+(((r20)*(x9300)))+(((x9293)*(x9302)))+(((cj4)*(r22)*(sj5)))+(((IkReal(-1.00000000000000))*(r21)*(x9304))));
evalcond[2]=((((IkReal(-1.00000000000000))*(sj5)*(x9294)*(x9297)))+(((IkReal(-1.00000000000000))*(x9296)*(x9298)))+(((cj0)*(x9295)))+(((x9290)*(x9291)))+(((IkReal(-1.00000000000000))*(sj5)*(x9294)*(x9303)))+(((x9290)*(x9292)))+(((IkReal(-1.00000000000000))*(x9307))));
evalcond[3]=((((IkReal(-1.00000000000000))*(x9289)*(x9299)))+(((cj0)*(x9298)))+(((sj0)*(x9295)))+(((IkReal(-1.00000000000000))*(sj5)*(x9292)*(x9294)))+(((IkReal(-1.00000000000000))*(x9290)*(x9303)))+(((IkReal(-1.00000000000000))*(x9290)*(x9297)))+(((IkReal(-1.00000000000000))*(sj5)*(x9291)*(x9294))));
evalcond[4]=((((sj0)*(x9291)*(x9293)))+(((IkReal(-1.00000000000000))*(x9293)*(x9294)*(x9297)))+(((IkReal(-1.00000000000000))*(cj4)*(r12)*(sj5)*(x9294)))+(((r00)*(sj0)*(x9300)))+(((sj0)*(x9292)*(x9293)))+(((IkReal(-1.00000000000000))*(r10)*(x9294)*(x9300)))+(((x9290)*(x9305)))+(((r11)*(x9308)))+(((IkReal(-1.00000000000000))*(x9293)*(x9294)*(x9303)))+(x9289)+(((IkReal(-1.00000000000000))*(r01)*(x9296)*(x9304))));
evalcond[5]=((((IkReal(-1.00000000000000))*(x9291)*(x9293)*(x9294)))+(((r11)*(sj0)*(x9304)))+(((IkReal(-1.00000000000000))*(x9288)*(x9299)))+(((IkReal(-1.00000000000000))*(x9293)*(x9296)*(x9303)))+(((IkReal(-1.00000000000000))*(x9293)*(x9296)*(x9297)))+(((IkReal(-1.00000000000000))*(x9290)*(x9306)))+(((IkReal(-1.00000000000000))*(sj5)*(x9294)*(x9305)))+(((IkReal(-1.00000000000000))*(x9292)*(x9293)*(x9294)))+(((IkReal(-1.00000000000000))*(r00)*(x9294)*(x9300)))+(((IkReal(-1.00000000000000))*(r10)*(x9296)*(x9300)))+(((r01)*(x9308))));
if( IKabs(evalcond[0]) > 0.000001  || IKabs(evalcond[1]) > 0.000001  || IKabs(evalcond[2]) > 0.000001  || IKabs(evalcond[3]) > 0.000001  || IKabs(evalcond[4]) > 0.000001  || IKabs(evalcond[5]) > 0.000001  )
{
continue;
}
}

{
std::vector<IkSingleDOFSolutionBase<IkReal> > vinfos(7);
vinfos[0].jointtype = 1;
vinfos[0].foffset = j0;
vinfos[0].indices[0] = _ij0[0];
vinfos[0].indices[1] = _ij0[1];
vinfos[0].maxsolutions = _nj0;
vinfos[1].jointtype = 1;
vinfos[1].foffset = j1;
vinfos[1].indices[0] = _ij1[0];
vinfos[1].indices[1] = _ij1[1];
vinfos[1].maxsolutions = _nj1;
vinfos[2].jointtype = 1;
vinfos[2].foffset = j2;
vinfos[2].indices[0] = _ij2[0];
vinfos[2].indices[1] = _ij2[1];
vinfos[2].maxsolutions = _nj2;
vinfos[3].jointtype = 1;
vinfos[3].foffset = j3;
vinfos[3].indices[0] = _ij3[0];
vinfos[3].indices[1] = _ij3[1];
vinfos[3].maxsolutions = _nj3;
vinfos[4].jointtype = 1;
vinfos[4].foffset = j4;
vinfos[4].indices[0] = _ij4[0];
vinfos[4].indices[1] = _ij4[1];
vinfos[4].maxsolutions = _nj4;
vinfos[5].jointtype = 1;
vinfos[5].foffset = j5;
vinfos[5].indices[0] = _ij5[0];
vinfos[5].indices[1] = _ij5[1];
vinfos[5].maxsolutions = _nj5;
vinfos[6].jointtype = 1;
vinfos[6].foffset = j6;
vinfos[6].indices[0] = _ij6[0];
vinfos[6].indices[1] = _ij6[1];
vinfos[6].maxsolutions = _nj6;
std::vector<int> vfree(0);
solutions.AddSolution(vinfos,vfree);
}
}
}

}

}

} else
{
{
IkReal j3array[1], cj3array[1], sj3array[1];
bool j3valid[1]={false};
_nj3 = 1;
IkReal x9309=((sj5)*(sj6));
IkReal x9310=((cj6)*(sj5));
IkReal x9311=((IkReal(1.00000000000000))*(cj0));
IkReal x9312=((IkReal(1.00000000000000))*(cj5));
if( IKabs(((((r01)*(sj0)*(x9310)))+(((IkReal(-1.00000000000000))*(r11)*(x9310)*(x9311)))+(((r00)*(sj0)*(x9309)))+(((IkReal(-1.00000000000000))*(r10)*(x9309)*(x9311)))+(((cj0)*(cj5)*(r12)))+(((IkReal(-1.00000000000000))*(r02)*(sj0)*(x9312))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(((((IKabs(sj1) != 0)?((IkReal)1/(sj1)):(IkReal)1.0e30))*(((((r21)*(x9310)))+(((IkReal(-1.00000000000000))*(r22)*(x9312)))+(((r20)*(x9309))))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(IKsqr(((((r01)*(sj0)*(x9310)))+(((IkReal(-1.00000000000000))*(r11)*(x9310)*(x9311)))+(((r00)*(sj0)*(x9309)))+(((IkReal(-1.00000000000000))*(r10)*(x9309)*(x9311)))+(((cj0)*(cj5)*(r12)))+(((IkReal(-1.00000000000000))*(r02)*(sj0)*(x9312)))))+IKsqr(((((IKabs(sj1) != 0)?((IkReal)1/(sj1)):(IkReal)1.0e30))*(((((r21)*(x9310)))+(((IkReal(-1.00000000000000))*(r22)*(x9312)))+(((r20)*(x9309)))))))-1) <= IKFAST_SINCOS_THRESH )
    continue;
j3array[0]=IKatan2(((((r01)*(sj0)*(x9310)))+(((IkReal(-1.00000000000000))*(r11)*(x9310)*(x9311)))+(((r00)*(sj0)*(x9309)))+(((IkReal(-1.00000000000000))*(r10)*(x9309)*(x9311)))+(((cj0)*(cj5)*(r12)))+(((IkReal(-1.00000000000000))*(r02)*(sj0)*(x9312)))), ((((IKabs(sj1) != 0)?((IkReal)1/(sj1)):(IkReal)1.0e30))*(((((r21)*(x9310)))+(((IkReal(-1.00000000000000))*(r22)*(x9312)))+(((r20)*(x9309)))))));
sj3array[0]=IKsin(j3array[0]);
cj3array[0]=IKcos(j3array[0]);
if( j3array[0] > IKPI )
{
    j3array[0]-=IK2PI;
}
else if( j3array[0] < -IKPI )
{    j3array[0]+=IK2PI;
}
j3valid[0] = true;
for(int ij3 = 0; ij3 < 1; ++ij3)
{
if( !j3valid[ij3] )
{
    continue;
}
_ij3[0] = ij3; _ij3[1] = -1;
for(int iij3 = ij3+1; iij3 < 1; ++iij3)
{
if( j3valid[iij3] && IKabs(cj3array[ij3]-cj3array[iij3]) < IKFAST_SOLUTION_THRESH && IKabs(sj3array[ij3]-sj3array[iij3]) < IKFAST_SOLUTION_THRESH )
{
    j3valid[iij3]=false; _ij3[1] = iij3; break; 
}
}
j3 = j3array[ij3]; cj3 = cj3array[ij3]; sj3 = sj3array[ij3];
{
IkReal evalcond[6];
IkReal x9313=IKsin(j3);
IkReal x9314=IKcos(j3);
IkReal x9315=((sj0)*(sj5));
IkReal x9316=((r00)*(sj6));
IkReal x9317=((cj6)*(r01));
IkReal x9318=((cj4)*(cj5));
IkReal x9319=((IkReal(1.00000000000000))*(cj0));
IkReal x9320=((cj5)*(r12));
IkReal x9321=((IkReal(1.00000000000000))*(sj0));
IkReal x9322=((cj6)*(r11));
IkReal x9323=((cj5)*(r02));
IkReal x9324=((IkReal(1.00000000000000))*(cj1));
IkReal x9325=((cj6)*(sj4));
IkReal x9326=((cj6)*(r21));
IkReal x9327=((r20)*(sj6));
IkReal x9328=((r10)*(sj6));
IkReal x9329=((sj4)*(sj6));
IkReal x9330=((cj4)*(r02));
IkReal x9331=((IkReal(1.00000000000000))*(cj4)*(r12));
IkReal x9332=((IkReal(1.00000000000000))*(x9313));
IkReal x9333=((cj0)*(x9329));
evalcond[0]=((((IkReal(-1.00000000000000))*(sj1)*(x9314)))+(((IkReal(-1.00000000000000))*(cj5)*(r22)))+(((sj5)*(x9326)))+(((sj5)*(x9327))));
evalcond[1]=((((x9318)*(x9327)))+(((cj4)*(r22)*(sj5)))+(((IkReal(-1.00000000000000))*(r21)*(x9329)))+(((r20)*(x9325)))+(((x9318)*(x9326)))+(((IkReal(-1.00000000000000))*(sj1)*(x9332))));
evalcond[2]=((((IkReal(-1.00000000000000))*(x9332)))+(((x9315)*(x9317)))+(((IkReal(-1.00000000000000))*(sj5)*(x9319)*(x9322)))+(((x9315)*(x9316)))+(((IkReal(-1.00000000000000))*(sj5)*(x9319)*(x9328)))+(((IkReal(-1.00000000000000))*(x9321)*(x9323)))+(((cj0)*(x9320))));
evalcond[3]=((((IkReal(-1.00000000000000))*(x9314)*(x9324)))+(((IkReal(-1.00000000000000))*(sj5)*(x9316)*(x9319)))+(((IkReal(-1.00000000000000))*(x9315)*(x9322)))+(((IkReal(-1.00000000000000))*(x9315)*(x9328)))+(((sj0)*(x9320)))+(((IkReal(-1.00000000000000))*(sj5)*(x9317)*(x9319)))+(((cj0)*(x9323))));
evalcond[4]=((((IkReal(-1.00000000000000))*(r01)*(x9321)*(x9329)))+(((IkReal(-1.00000000000000))*(cj4)*(r12)*(sj5)*(x9319)))+(((r11)*(x9333)))+(((sj0)*(x9316)*(x9318)))+(((IkReal(-1.00000000000000))*(x9318)*(x9319)*(x9322)))+(((IkReal(-1.00000000000000))*(x9318)*(x9319)*(x9328)))+(((IkReal(-1.00000000000000))*(r10)*(x9319)*(x9325)))+(((sj0)*(x9317)*(x9318)))+(((r00)*(sj0)*(x9325)))+(((x9315)*(x9330)))+(x9314));
evalcond[5]=((((r11)*(sj0)*(x9329)))+(((IkReal(-1.00000000000000))*(x9318)*(x9321)*(x9322)))+(((IkReal(-1.00000000000000))*(r10)*(x9321)*(x9325)))+(((IkReal(-1.00000000000000))*(x9317)*(x9318)*(x9319)))+(((IkReal(-1.00000000000000))*(sj5)*(x9319)*(x9330)))+(((IkReal(-1.00000000000000))*(x9315)*(x9331)))+(((IkReal(-1.00000000000000))*(r00)*(x9319)*(x9325)))+(((IkReal(-1.00000000000000))*(x9313)*(x9324)))+(((IkReal(-1.00000000000000))*(x9316)*(x9318)*(x9319)))+(((r01)*(x9333)))+(((IkReal(-1.00000000000000))*(x9318)*(x9321)*(x9328))));
if( IKabs(evalcond[0]) > 0.000001  || IKabs(evalcond[1]) > 0.000001  || IKabs(evalcond[2]) > 0.000001  || IKabs(evalcond[3]) > 0.000001  || IKabs(evalcond[4]) > 0.000001  || IKabs(evalcond[5]) > 0.000001  )
{
continue;
}
}

{
std::vector<IkSingleDOFSolutionBase<IkReal> > vinfos(7);
vinfos[0].jointtype = 1;
vinfos[0].foffset = j0;
vinfos[0].indices[0] = _ij0[0];
vinfos[0].indices[1] = _ij0[1];
vinfos[0].maxsolutions = _nj0;
vinfos[1].jointtype = 1;
vinfos[1].foffset = j1;
vinfos[1].indices[0] = _ij1[0];
vinfos[1].indices[1] = _ij1[1];
vinfos[1].maxsolutions = _nj1;
vinfos[2].jointtype = 1;
vinfos[2].foffset = j2;
vinfos[2].indices[0] = _ij2[0];
vinfos[2].indices[1] = _ij2[1];
vinfos[2].maxsolutions = _nj2;
vinfos[3].jointtype = 1;
vinfos[3].foffset = j3;
vinfos[3].indices[0] = _ij3[0];
vinfos[3].indices[1] = _ij3[1];
vinfos[3].maxsolutions = _nj3;
vinfos[4].jointtype = 1;
vinfos[4].foffset = j4;
vinfos[4].indices[0] = _ij4[0];
vinfos[4].indices[1] = _ij4[1];
vinfos[4].maxsolutions = _nj4;
vinfos[5].jointtype = 1;
vinfos[5].foffset = j5;
vinfos[5].indices[0] = _ij5[0];
vinfos[5].indices[1] = _ij5[1];
vinfos[5].maxsolutions = _nj5;
vinfos[6].jointtype = 1;
vinfos[6].foffset = j6;
vinfos[6].indices[0] = _ij6[0];
vinfos[6].indices[1] = _ij6[1];
vinfos[6].maxsolutions = _nj6;
std::vector<int> vfree(0);
solutions.AddSolution(vinfos,vfree);
}
}
}

}

}

} else
{
{
IkReal j3array[1], cj3array[1], sj3array[1];
bool j3valid[1]={false};
_nj3 = 1;
IkReal x9334=((r20)*(sj6));
IkReal x9335=((cj4)*(cj5));
IkReal x9336=((cj6)*(r21));
if( IKabs(((gconst17)*(((((IkReal(-1.00000000000000))*(r21)*(sj4)*(sj6)))+(((x9334)*(x9335)))+(((cj6)*(r20)*(sj4)))+(((cj4)*(r22)*(sj5)))+(((x9335)*(x9336))))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(((gconst17)*(((((sj5)*(x9336)))+(((IkReal(-1.00000000000000))*(cj5)*(r22)))+(((sj5)*(x9334))))))) < IKFAST_ATAN2_MAGTHRESH )
    continue;
j3array[0]=IKatan2(((gconst17)*(((((IkReal(-1.00000000000000))*(r21)*(sj4)*(sj6)))+(((x9334)*(x9335)))+(((cj6)*(r20)*(sj4)))+(((cj4)*(r22)*(sj5)))+(((x9335)*(x9336)))))), ((gconst17)*(((((sj5)*(x9336)))+(((IkReal(-1.00000000000000))*(cj5)*(r22)))+(((sj5)*(x9334)))))));
sj3array[0]=IKsin(j3array[0]);
cj3array[0]=IKcos(j3array[0]);
if( j3array[0] > IKPI )
{
    j3array[0]-=IK2PI;
}
else if( j3array[0] < -IKPI )
{    j3array[0]+=IK2PI;
}
j3valid[0] = true;
for(int ij3 = 0; ij3 < 1; ++ij3)
{
if( !j3valid[ij3] )
{
    continue;
}
_ij3[0] = ij3; _ij3[1] = -1;
for(int iij3 = ij3+1; iij3 < 1; ++iij3)
{
if( j3valid[iij3] && IKabs(cj3array[ij3]-cj3array[iij3]) < IKFAST_SOLUTION_THRESH && IKabs(sj3array[ij3]-sj3array[iij3]) < IKFAST_SOLUTION_THRESH )
{
    j3valid[iij3]=false; _ij3[1] = iij3; break; 
}
}
j3 = j3array[ij3]; cj3 = cj3array[ij3]; sj3 = sj3array[ij3];
{
IkReal evalcond[6];
IkReal x9337=IKsin(j3);
IkReal x9338=IKcos(j3);
IkReal x9339=((sj0)*(sj5));
IkReal x9340=((r00)*(sj6));
IkReal x9341=((cj6)*(r01));
IkReal x9342=((cj4)*(cj5));
IkReal x9343=((IkReal(1.00000000000000))*(cj0));
IkReal x9344=((cj5)*(r12));
IkReal x9345=((IkReal(1.00000000000000))*(sj0));
IkReal x9346=((cj6)*(r11));
IkReal x9347=((cj5)*(r02));
IkReal x9348=((IkReal(1.00000000000000))*(cj1));
IkReal x9349=((cj6)*(sj4));
IkReal x9350=((cj6)*(r21));
IkReal x9351=((r20)*(sj6));
IkReal x9352=((r10)*(sj6));
IkReal x9353=((sj4)*(sj6));
IkReal x9354=((cj4)*(r02));
IkReal x9355=((IkReal(1.00000000000000))*(cj4)*(r12));
IkReal x9356=((IkReal(1.00000000000000))*(x9337));
IkReal x9357=((cj0)*(x9353));
evalcond[0]=((((sj5)*(x9350)))+(((sj5)*(x9351)))+(((IkReal(-1.00000000000000))*(cj5)*(r22)))+(((IkReal(-1.00000000000000))*(sj1)*(x9338))));
evalcond[1]=((((x9342)*(x9350)))+(((r20)*(x9349)))+(((cj4)*(r22)*(sj5)))+(((x9342)*(x9351)))+(((IkReal(-1.00000000000000))*(sj1)*(x9356)))+(((IkReal(-1.00000000000000))*(r21)*(x9353))));
evalcond[2]=((((x9339)*(x9341)))+(((IkReal(-1.00000000000000))*(x9345)*(x9347)))+(((IkReal(-1.00000000000000))*(sj5)*(x9343)*(x9352)))+(((IkReal(-1.00000000000000))*(sj5)*(x9343)*(x9346)))+(((IkReal(-1.00000000000000))*(x9356)))+(((cj0)*(x9344)))+(((x9339)*(x9340))));
evalcond[3]=((((IkReal(-1.00000000000000))*(x9339)*(x9352)))+(((sj0)*(x9344)))+(((IkReal(-1.00000000000000))*(x9339)*(x9346)))+(((IkReal(-1.00000000000000))*(sj5)*(x9340)*(x9343)))+(((cj0)*(x9347)))+(((IkReal(-1.00000000000000))*(sj5)*(x9341)*(x9343)))+(((IkReal(-1.00000000000000))*(x9338)*(x9348))));
evalcond[4]=((((IkReal(-1.00000000000000))*(cj4)*(r12)*(sj5)*(x9343)))+(x9338)+(((IkReal(-1.00000000000000))*(x9342)*(x9343)*(x9346)))+(((sj0)*(x9341)*(x9342)))+(((IkReal(-1.00000000000000))*(r01)*(x9345)*(x9353)))+(((r00)*(sj0)*(x9349)))+(((IkReal(-1.00000000000000))*(x9342)*(x9343)*(x9352)))+(((sj0)*(x9340)*(x9342)))+(((x9339)*(x9354)))+(((r11)*(x9357)))+(((IkReal(-1.00000000000000))*(r10)*(x9343)*(x9349))));
evalcond[5]=((((IkReal(-1.00000000000000))*(x9342)*(x9345)*(x9352)))+(((IkReal(-1.00000000000000))*(x9341)*(x9342)*(x9343)))+(((IkReal(-1.00000000000000))*(r00)*(x9343)*(x9349)))+(((IkReal(-1.00000000000000))*(x9342)*(x9345)*(x9346)))+(((IkReal(-1.00000000000000))*(x9337)*(x9348)))+(((r11)*(sj0)*(x9353)))+(((r01)*(x9357)))+(((IkReal(-1.00000000000000))*(r10)*(x9345)*(x9349)))+(((IkReal(-1.00000000000000))*(x9339)*(x9355)))+(((IkReal(-1.00000000000000))*(x9340)*(x9342)*(x9343)))+(((IkReal(-1.00000000000000))*(sj5)*(x9343)*(x9354))));
if( IKabs(evalcond[0]) > 0.000001  || IKabs(evalcond[1]) > 0.000001  || IKabs(evalcond[2]) > 0.000001  || IKabs(evalcond[3]) > 0.000001  || IKabs(evalcond[4]) > 0.000001  || IKabs(evalcond[5]) > 0.000001  )
{
continue;
}
}

{
std::vector<IkSingleDOFSolutionBase<IkReal> > vinfos(7);
vinfos[0].jointtype = 1;
vinfos[0].foffset = j0;
vinfos[0].indices[0] = _ij0[0];
vinfos[0].indices[1] = _ij0[1];
vinfos[0].maxsolutions = _nj0;
vinfos[1].jointtype = 1;
vinfos[1].foffset = j1;
vinfos[1].indices[0] = _ij1[0];
vinfos[1].indices[1] = _ij1[1];
vinfos[1].maxsolutions = _nj1;
vinfos[2].jointtype = 1;
vinfos[2].foffset = j2;
vinfos[2].indices[0] = _ij2[0];
vinfos[2].indices[1] = _ij2[1];
vinfos[2].maxsolutions = _nj2;
vinfos[3].jointtype = 1;
vinfos[3].foffset = j3;
vinfos[3].indices[0] = _ij3[0];
vinfos[3].indices[1] = _ij3[1];
vinfos[3].maxsolutions = _nj3;
vinfos[4].jointtype = 1;
vinfos[4].foffset = j4;
vinfos[4].indices[0] = _ij4[0];
vinfos[4].indices[1] = _ij4[1];
vinfos[4].maxsolutions = _nj4;
vinfos[5].jointtype = 1;
vinfos[5].foffset = j5;
vinfos[5].indices[0] = _ij5[0];
vinfos[5].indices[1] = _ij5[1];
vinfos[5].maxsolutions = _nj5;
vinfos[6].jointtype = 1;
vinfos[6].foffset = j6;
vinfos[6].indices[0] = _ij6[0];
vinfos[6].indices[1] = _ij6[1];
vinfos[6].maxsolutions = _nj6;
std::vector<int> vfree(0);
solutions.AddSolution(vinfos,vfree);
}
}
}

}

}
}
}

}

}

} else
{
{
IkReal j4array[1], cj4array[1], sj4array[1];
bool j4valid[1]={false};
_nj4 = 1;
IkReal x9358=((cj1)*(sj6));
IkReal x9359=((r01)*(sj0));
IkReal x9360=((cj0)*(r11));
IkReal x9361=((cj1)*(cj6));
IkReal x9362=((cj0)*(r10));
IkReal x9363=((IkReal(1.00000000000000))*(sj0));
IkReal x9364=((cj1)*(sj5));
if( IKabs(((gconst13)*(((((IkReal(-1.00000000000000))*(r00)*(x9361)*(x9363)))+(((x9361)*(x9362)))+(((x9358)*(x9359)))+(((IkReal(-1.00000000000000))*(x9358)*(x9360))))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(((gconst13)*(((((IkReal(-1.00000000000000))*(cj5)*(x9359)*(x9361)))+(((IkReal(-1.00000000000000))*(cj5)*(r00)*(x9358)*(x9363)))+(((cj5)*(x9358)*(x9362)))+(((cj5)*(x9360)*(x9361)))+(((cj0)*(r12)*(x9364)))+(((IkReal(-1.00000000000000))*(r02)*(x9363)*(x9364))))))) < IKFAST_ATAN2_MAGTHRESH )
    continue;
j4array[0]=IKatan2(((gconst13)*(((((IkReal(-1.00000000000000))*(r00)*(x9361)*(x9363)))+(((x9361)*(x9362)))+(((x9358)*(x9359)))+(((IkReal(-1.00000000000000))*(x9358)*(x9360)))))), ((gconst13)*(((((IkReal(-1.00000000000000))*(cj5)*(x9359)*(x9361)))+(((IkReal(-1.00000000000000))*(cj5)*(r00)*(x9358)*(x9363)))+(((cj5)*(x9358)*(x9362)))+(((cj5)*(x9360)*(x9361)))+(((cj0)*(r12)*(x9364)))+(((IkReal(-1.00000000000000))*(r02)*(x9363)*(x9364)))))));
sj4array[0]=IKsin(j4array[0]);
cj4array[0]=IKcos(j4array[0]);
if( j4array[0] > IKPI )
{
    j4array[0]-=IK2PI;
}
else if( j4array[0] < -IKPI )
{    j4array[0]+=IK2PI;
}
j4valid[0] = true;
for(int ij4 = 0; ij4 < 1; ++ij4)
{
if( !j4valid[ij4] )
{
    continue;
}
_ij4[0] = ij4; _ij4[1] = -1;
for(int iij4 = ij4+1; iij4 < 1; ++iij4)
{
if( j4valid[iij4] && IKabs(cj4array[ij4]-cj4array[iij4]) < IKFAST_SOLUTION_THRESH && IKabs(sj4array[ij4]-sj4array[iij4]) < IKFAST_SOLUTION_THRESH )
{
    j4valid[iij4]=false; _ij4[1] = iij4; break; 
}
}
j4 = j4array[ij4]; cj4 = cj4array[ij4]; sj4 = sj4array[ij4];
{
IkReal evalcond[3];
IkReal x9365=IKsin(j4);
IkReal x9366=IKcos(j4);
IkReal x9367=((r00)*(sj6));
IkReal x9368=((cj6)*(r01));
IkReal x9369=((IkReal(1.00000000000000))*(cj0));
IkReal x9370=((IkReal(1.00000000000000))*(sj0));
IkReal x9371=((r10)*(sj6));
IkReal x9372=((sj5)*(x9365));
IkReal x9373=((IkReal(1.00000000000000))*(cj6)*(r11));
IkReal x9374=((cj5)*(x9365));
IkReal x9375=((cj6)*(x9366));
IkReal x9376=((sj0)*(x9374));
IkReal x9377=((r01)*(sj6)*(x9366));
IkReal x9378=((r11)*(sj6)*(x9366));
evalcond[0]=((((r20)*(sj6)*(x9374)))+(((IkReal(-1.00000000000000))*(r20)*(x9375)))+(((IkReal(-1.00000000000000))*(cj1)))+(((cj6)*(r21)*(x9374)))+(((r21)*(sj6)*(x9366)))+(((r22)*(x9372))));
evalcond[1]=((((IkReal(-1.00000000000000))*(x9369)*(x9371)*(x9374)))+(((IkReal(-1.00000000000000))*(cj6)*(r11)*(x9369)*(x9374)))+(((IkReal(-1.00000000000000))*(x9369)*(x9378)))+(((x9367)*(x9376)))+(((cj0)*(r10)*(x9375)))+(((IkReal(-1.00000000000000))*(r00)*(x9370)*(x9375)))+(((r02)*(sj0)*(x9372)))+(((sj0)*(x9377)))+(((IkReal(-1.00000000000000))*(r12)*(x9369)*(x9372)))+(((x9368)*(x9376))));
evalcond[2]=((((r10)*(sj0)*(x9375)))+(sj1)+(((IkReal(-1.00000000000000))*(x9369)*(x9377)))+(((IkReal(-1.00000000000000))*(cj6)*(r11)*(x9370)*(x9374)))+(((IkReal(-1.00000000000000))*(x9370)*(x9371)*(x9374)))+(((IkReal(-1.00000000000000))*(r12)*(x9370)*(x9372)))+(((IkReal(-1.00000000000000))*(r02)*(x9369)*(x9372)))+(((IkReal(-1.00000000000000))*(x9367)*(x9369)*(x9374)))+(((cj0)*(r00)*(x9375)))+(((IkReal(-1.00000000000000))*(x9368)*(x9369)*(x9374)))+(((IkReal(-1.00000000000000))*(x9370)*(x9378))));
if( IKabs(evalcond[0]) > 0.000001  || IKabs(evalcond[1]) > 0.000001  || IKabs(evalcond[2]) > 0.000001  )
{
continue;
}
}

{
IkReal dummyeval[1];
IkReal gconst17;
gconst17=IKsign(sj1);
dummyeval[0]=sj1;
if( IKabs(dummyeval[0]) < 0.0000010000000000  )
{
{
IkReal dummyeval[1];
dummyeval[0]=sj1;
if( IKabs(dummyeval[0]) < 0.0000010000000000  )
{
{
IkReal dummyeval[1];
dummyeval[0]=cj1;
if( IKabs(dummyeval[0]) < 0.0000010000000000  )
{
{
IkReal evalcond[9];
IkReal x9379=((IkReal(1.00000000000000))*(cj0));
IkReal x9380=((cj4)*(sj6));
IkReal x9381=((sj0)*(sj6));
IkReal x9382=((cj5)*(sj4));
IkReal x9383=((IkReal(0.374290000000000))*(sj5));
IkReal x9384=((sj4)*(sj5));
IkReal x9385=((cj0)*(cj6));
IkReal x9386=((IkReal(0.0100000000000000))*(cj5));
IkReal x9387=((cj4)*(sj5));
IkReal x9388=((cj5)*(sj0));
IkReal x9389=((IkReal(0.374290000000000))*(r02));
IkReal x9390=((r20)*(sj6));
IkReal x9391=((cj6)*(r21));
IkReal x9392=((IkReal(1.00000000000000))*(sj0));
IkReal x9393=((cj0)*(sj6));
IkReal x9394=((cj4)*(cj6));
IkReal x9395=((IkReal(0.374290000000000))*(r12));
IkReal x9396=((cj0)*(cj5));
IkReal x9397=((cj6)*(sj5));
IkReal x9398=((cj6)*(r01));
IkReal x9399=((r00)*(sj6));
IkReal x9400=((IkReal(0.0100000000000000))*(sj5));
IkReal x9401=((cj6)*(r11));
IkReal x9402=((IkReal(1.00000000000000))*(r10));
IkReal x9403=((r02)*(sj0));
IkReal x9404=((cj6)*(sj4));
IkReal x9405=((r12)*(x9392));
evalcond[0]=((IkReal(-3.14159265358979))+(IKfmod(((IkReal(1.57079632679490))+(j1)), IkReal(6.28318530717959))));
evalcond[1]=((((IkReal(-1.00000000000000))*(r20)*(x9394)))+(((x9382)*(x9390)))+(((r22)*(x9384)))+(((x9382)*(x9391)))+(((r21)*(x9380))));
evalcond[2]=((IkReal(0.364420000000000))+(((x9383)*(x9391)))+(((IkReal(-0.374290000000000))*(cj5)*(r22)))+(((IkReal(-1.00000000000000))*(r22)*(x9400)))+(((IkReal(-1.00000000000000))*(x9386)*(x9391)))+(pz)+(((x9383)*(x9390)))+(((IkReal(-1.00000000000000))*(x9386)*(x9390))));
evalcond[3]=((((IkReal(-1.00000000000000))*(r11)*(x9392)*(x9397)))+(((IkReal(-1.00000000000000))*(sj5)*(x9381)*(x9402)))+(((IkReal(-1.00000000000000))*(sj5)*(x9379)*(x9399)))+(((r12)*(x9388)))+(((IkReal(-1.00000000000000))*(r01)*(x9379)*(x9397)))+(((r02)*(x9396))));
evalcond[4]=((((r01)*(sj0)*(x9380)))+(((x9384)*(x9403)))+(((cj4)*(r10)*(x9385)))+(((r00)*(x9381)*(x9382)))+(((IkReal(-1.00000000000000))*(x9379)*(x9382)*(x9401)))+(((sj0)*(x9382)*(x9398)))+(((IkReal(-1.00000000000000))*(r00)*(x9392)*(x9394)))+(((IkReal(-1.00000000000000))*(r11)*(x9379)*(x9380)))+(((IkReal(-1.00000000000000))*(r12)*(x9379)*(x9384)))+(((IkReal(-1.00000000000000))*(r10)*(sj6)*(x9379)*(x9382))));
evalcond[5]=((IkReal(1.00000000000000))+(((IkReal(-1.00000000000000))*(x9379)*(x9382)*(x9399)))+(((IkReal(-1.00000000000000))*(x9381)*(x9382)*(x9402)))+(((IkReal(-1.00000000000000))*(r11)*(x9380)*(x9392)))+(((r10)*(sj0)*(x9394)))+(((IkReal(-1.00000000000000))*(r02)*(x9379)*(x9384)))+(((cj4)*(r00)*(x9385)))+(((IkReal(-1.00000000000000))*(x9382)*(x9392)*(x9401)))+(((IkReal(-1.00000000000000))*(x9384)*(x9405)))+(((IkReal(-1.00000000000000))*(r01)*(x9379)*(x9380)))+(((IkReal(-1.00000000000000))*(x9379)*(x9382)*(x9398))));
evalcond[6]=((IkReal(0.0690000000000000))+(((IkReal(-1.00000000000000))*(sj0)*(x9386)*(x9398)))+(((IkReal(-1.00000000000000))*(r10)*(x9383)*(x9393)))+(((IkReal(-1.00000000000000))*(r11)*(x9383)*(x9385)))+(((cj0)*(r12)*(x9400)))+(((sj0)*(x9383)*(x9398)))+(((r10)*(x9386)*(x9393)))+(((r00)*(x9381)*(x9383)))+(((IkReal(-1.00000000000000))*(x9400)*(x9403)))+(((IkReal(-1.00000000000000))*(py)*(x9379)))+(((IkReal(-1.00000000000000))*(r00)*(x9381)*(x9386)))+(((px)*(sj0)))+(((IkReal(-1.00000000000000))*(x9388)*(x9389)))+(((x9395)*(x9396)))+(((r11)*(x9385)*(x9386))));
evalcond[7]=((((IkReal(-1.00000000000000))*(r00)*(x9379)*(x9404)))+(((IkReal(-1.00000000000000))*(r10)*(x9392)*(x9404)))+(((IkReal(-1.00000000000000))*(cj5)*(r01)*(x9379)*(x9394)))+(((IkReal(-1.00000000000000))*(x9387)*(x9405)))+(((IkReal(-1.00000000000000))*(r02)*(x9379)*(x9387)))+(((r01)*(sj4)*(x9393)))+(((IkReal(-1.00000000000000))*(r11)*(x9388)*(x9394)))+(((IkReal(-1.00000000000000))*(x9380)*(x9388)*(x9402)))+(((r11)*(sj4)*(x9381)))+(((IkReal(-1.00000000000000))*(cj5)*(r00)*(x9379)*(x9380))));
evalcond[8]=((IkReal(0.0690000000000000))+(((x9389)*(x9396)))+(((IkReal(-1.00000000000000))*(r00)*(x9383)*(x9393)))+(((r12)*(sj0)*(x9400)))+(((IkReal(-1.00000000000000))*(r10)*(x9381)*(x9383)))+(((r10)*(x9381)*(x9386)))+(((IkReal(-1.00000000000000))*(r01)*(x9383)*(x9385)))+(((IkReal(-1.00000000000000))*(sj0)*(x9383)*(x9401)))+(((r00)*(x9386)*(x9393)))+(((sj0)*(x9386)*(x9401)))+(((r01)*(x9385)*(x9386)))+(((IkReal(-1.00000000000000))*(px)*(x9379)))+(((x9388)*(x9395)))+(((cj0)*(r02)*(x9400)))+(((IkReal(-1.00000000000000))*(py)*(x9392))));
if( IKabs(evalcond[0]) < 0.0000010000000000  && IKabs(evalcond[1]) < 0.0000010000000000  && IKabs(evalcond[2]) < 0.0000010000000000  && IKabs(evalcond[3]) < 0.0000010000000000  && IKabs(evalcond[4]) < 0.0000010000000000  && IKabs(evalcond[5]) < 0.0000010000000000  && IKabs(evalcond[6]) < 0.0000010000000000  && IKabs(evalcond[7]) < 0.0000010000000000  && IKabs(evalcond[8]) < 0.0000010000000000  )
{
{
IkReal j3array[1], cj3array[1], sj3array[1];
bool j3valid[1]={false};
_nj3 = 1;
IkReal x9406=((r20)*(sj6));
IkReal x9407=((cj4)*(cj5));
IkReal x9408=((cj6)*(r21));
if( IKabs(((((IkReal(-1.00000000000000))*(r21)*(sj4)*(sj6)))+(((cj6)*(r20)*(sj4)))+(((x9406)*(x9407)))+(((cj4)*(r22)*(sj5)))+(((x9407)*(x9408))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(((((IkReal(-1.00000000000000))*(cj5)*(r22)))+(((sj5)*(x9406)))+(((sj5)*(x9408))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(IKsqr(((((IkReal(-1.00000000000000))*(r21)*(sj4)*(sj6)))+(((cj6)*(r20)*(sj4)))+(((x9406)*(x9407)))+(((cj4)*(r22)*(sj5)))+(((x9407)*(x9408)))))+IKsqr(((((IkReal(-1.00000000000000))*(cj5)*(r22)))+(((sj5)*(x9406)))+(((sj5)*(x9408)))))-1) <= IKFAST_SINCOS_THRESH )
    continue;
j3array[0]=IKatan2(((((IkReal(-1.00000000000000))*(r21)*(sj4)*(sj6)))+(((cj6)*(r20)*(sj4)))+(((x9406)*(x9407)))+(((cj4)*(r22)*(sj5)))+(((x9407)*(x9408)))), ((((IkReal(-1.00000000000000))*(cj5)*(r22)))+(((sj5)*(x9406)))+(((sj5)*(x9408)))));
sj3array[0]=IKsin(j3array[0]);
cj3array[0]=IKcos(j3array[0]);
if( j3array[0] > IKPI )
{
    j3array[0]-=IK2PI;
}
else if( j3array[0] < -IKPI )
{    j3array[0]+=IK2PI;
}
j3valid[0] = true;
for(int ij3 = 0; ij3 < 1; ++ij3)
{
if( !j3valid[ij3] )
{
    continue;
}
_ij3[0] = ij3; _ij3[1] = -1;
for(int iij3 = ij3+1; iij3 < 1; ++iij3)
{
if( j3valid[iij3] && IKabs(cj3array[ij3]-cj3array[iij3]) < IKFAST_SOLUTION_THRESH && IKabs(sj3array[ij3]-sj3array[iij3]) < IKFAST_SOLUTION_THRESH )
{
    j3valid[iij3]=false; _ij3[1] = iij3; break; 
}
}
j3 = j3array[ij3]; cj3 = cj3array[ij3]; sj3 = sj3array[ij3];
{
IkReal evalcond[4];
IkReal x9409=IKcos(j3);
IkReal x9410=((sj0)*(sj5));
IkReal x9411=((r00)*(sj6));
IkReal x9412=((cj6)*(r01));
IkReal x9413=((cj5)*(sj0));
IkReal x9414=((cj0)*(cj5));
IkReal x9415=((cj6)*(sj4));
IkReal x9416=((sj4)*(sj6));
IkReal x9417=((cj0)*(r11));
IkReal x9418=((cj4)*(cj6));
IkReal x9419=((cj4)*(sj6));
IkReal x9420=((IkReal(1.00000000000000))*(cj0));
IkReal x9421=((cj4)*(sj5));
IkReal x9422=((sj5)*(sj6));
IkReal x9423=((cj6)*(sj5));
IkReal x9424=((IkReal(1.00000000000000))*(IKsin(j3)));
evalcond[0]=((((r20)*(x9422)))+(((r21)*(x9423)))+(((IkReal(-1.00000000000000))*(x9409)))+(((IkReal(-1.00000000000000))*(cj5)*(r22))));
evalcond[1]=((((cj5)*(r20)*(x9419)))+(((r22)*(x9421)))+(((IkReal(-1.00000000000000))*(r21)*(x9416)))+(((IkReal(-1.00000000000000))*(x9424)))+(((cj5)*(r21)*(x9418)))+(((r20)*(x9415))));
evalcond[2]=((((r12)*(x9414)))+(((x9410)*(x9411)))+(((IkReal(-1.00000000000000))*(x9417)*(x9423)))+(((IkReal(-1.00000000000000))*(r10)*(x9420)*(x9422)))+(((IkReal(-1.00000000000000))*(x9424)))+(((x9410)*(x9412)))+(((IkReal(-1.00000000000000))*(r02)*(x9413))));
evalcond[3]=((x9409)+(((cj4)*(x9412)*(x9413)))+(((IkReal(-1.00000000000000))*(r11)*(x9414)*(x9418)))+(((cj4)*(r02)*(x9410)))+(((x9416)*(x9417)))+(((IkReal(-1.00000000000000))*(r10)*(x9415)*(x9420)))+(((IkReal(-1.00000000000000))*(r01)*(sj0)*(x9416)))+(((cj4)*(x9411)*(x9413)))+(((r00)*(sj0)*(x9415)))+(((IkReal(-1.00000000000000))*(r12)*(x9420)*(x9421)))+(((IkReal(-1.00000000000000))*(r10)*(x9414)*(x9419))));
if( IKabs(evalcond[0]) > 0.000001  || IKabs(evalcond[1]) > 0.000001  || IKabs(evalcond[2]) > 0.000001  || IKabs(evalcond[3]) > 0.000001  )
{
continue;
}
}

{
std::vector<IkSingleDOFSolutionBase<IkReal> > vinfos(7);
vinfos[0].jointtype = 1;
vinfos[0].foffset = j0;
vinfos[0].indices[0] = _ij0[0];
vinfos[0].indices[1] = _ij0[1];
vinfos[0].maxsolutions = _nj0;
vinfos[1].jointtype = 1;
vinfos[1].foffset = j1;
vinfos[1].indices[0] = _ij1[0];
vinfos[1].indices[1] = _ij1[1];
vinfos[1].maxsolutions = _nj1;
vinfos[2].jointtype = 1;
vinfos[2].foffset = j2;
vinfos[2].indices[0] = _ij2[0];
vinfos[2].indices[1] = _ij2[1];
vinfos[2].maxsolutions = _nj2;
vinfos[3].jointtype = 1;
vinfos[3].foffset = j3;
vinfos[3].indices[0] = _ij3[0];
vinfos[3].indices[1] = _ij3[1];
vinfos[3].maxsolutions = _nj3;
vinfos[4].jointtype = 1;
vinfos[4].foffset = j4;
vinfos[4].indices[0] = _ij4[0];
vinfos[4].indices[1] = _ij4[1];
vinfos[4].maxsolutions = _nj4;
vinfos[5].jointtype = 1;
vinfos[5].foffset = j5;
vinfos[5].indices[0] = _ij5[0];
vinfos[5].indices[1] = _ij5[1];
vinfos[5].maxsolutions = _nj5;
vinfos[6].jointtype = 1;
vinfos[6].foffset = j6;
vinfos[6].indices[0] = _ij6[0];
vinfos[6].indices[1] = _ij6[1];
vinfos[6].maxsolutions = _nj6;
std::vector<int> vfree(0);
solutions.AddSolution(vinfos,vfree);
}
}
}

} else
{
IkReal x9425=((IkReal(1.00000000000000))*(cj0));
IkReal x9426=((cj4)*(sj6));
IkReal x9427=((sj0)*(sj6));
IkReal x9428=((cj5)*(sj4));
IkReal x9429=((IkReal(0.374290000000000))*(sj5));
IkReal x9430=((sj4)*(sj5));
IkReal x9431=((cj0)*(cj6));
IkReal x9432=((IkReal(0.0100000000000000))*(cj5));
IkReal x9433=((cj4)*(sj5));
IkReal x9434=((cj5)*(sj0));
IkReal x9435=((IkReal(0.374290000000000))*(r02));
IkReal x9436=((r20)*(sj6));
IkReal x9437=((cj6)*(r21));
IkReal x9438=((IkReal(1.00000000000000))*(sj0));
IkReal x9439=((cj0)*(sj6));
IkReal x9440=((cj4)*(cj6));
IkReal x9441=((IkReal(0.374290000000000))*(r12));
IkReal x9442=((cj0)*(cj5));
IkReal x9443=((cj6)*(sj5));
IkReal x9444=((cj6)*(r01));
IkReal x9445=((r00)*(sj6));
IkReal x9446=((IkReal(0.0100000000000000))*(sj5));
IkReal x9447=((cj6)*(r11));
IkReal x9448=((IkReal(1.00000000000000))*(r10));
IkReal x9449=((r02)*(sj0));
IkReal x9450=((cj6)*(sj4));
IkReal x9451=((r12)*(x9438));
evalcond[0]=((IkReal(-3.14159265358979))+(IKfmod(((IkReal(4.71238898038469))+(j1)), IkReal(6.28318530717959))));
evalcond[1]=((((x9428)*(x9437)))+(((IkReal(-1.00000000000000))*(r20)*(x9440)))+(((x9428)*(x9436)))+(((r21)*(x9426)))+(((r22)*(x9430))));
evalcond[2]=((IkReal(-0.364420000000000))+(((x9429)*(x9437)))+(((IkReal(-1.00000000000000))*(r22)*(x9446)))+(((IkReal(-0.374290000000000))*(cj5)*(r22)))+(((IkReal(-1.00000000000000))*(x9432)*(x9437)))+(pz)+(((IkReal(-1.00000000000000))*(x9432)*(x9436)))+(((x9429)*(x9436))));
evalcond[3]=((((IkReal(-1.00000000000000))*(r11)*(x9438)*(x9443)))+(((r12)*(x9434)))+(((IkReal(-1.00000000000000))*(r01)*(x9425)*(x9443)))+(((r02)*(x9442)))+(((IkReal(-1.00000000000000))*(sj5)*(x9427)*(x9448)))+(((IkReal(-1.00000000000000))*(sj5)*(x9425)*(x9445))));
evalcond[4]=((((IkReal(-1.00000000000000))*(x9425)*(x9428)*(x9447)))+(((r00)*(x9427)*(x9428)))+(((IkReal(-1.00000000000000))*(r10)*(sj6)*(x9425)*(x9428)))+(((x9430)*(x9449)))+(((IkReal(-1.00000000000000))*(r12)*(x9425)*(x9430)))+(((sj0)*(x9428)*(x9444)))+(((IkReal(-1.00000000000000))*(r11)*(x9425)*(x9426)))+(((IkReal(-1.00000000000000))*(r00)*(x9438)*(x9440)))+(((r01)*(sj0)*(x9426)))+(((cj4)*(r10)*(x9431))));
evalcond[5]=((IkReal(-1.00000000000000))+(((cj4)*(r00)*(x9431)))+(((IkReal(-1.00000000000000))*(r11)*(x9426)*(x9438)))+(((IkReal(-1.00000000000000))*(x9425)*(x9428)*(x9445)))+(((IkReal(-1.00000000000000))*(x9427)*(x9428)*(x9448)))+(((IkReal(-1.00000000000000))*(r01)*(x9425)*(x9426)))+(((r10)*(sj0)*(x9440)))+(((IkReal(-1.00000000000000))*(x9428)*(x9438)*(x9447)))+(((IkReal(-1.00000000000000))*(r02)*(x9425)*(x9430)))+(((IkReal(-1.00000000000000))*(x9430)*(x9451)))+(((IkReal(-1.00000000000000))*(x9425)*(x9428)*(x9444))));
evalcond[6]=((IkReal(0.0690000000000000))+(((cj0)*(r12)*(x9446)))+(((IkReal(-1.00000000000000))*(r00)*(x9427)*(x9432)))+(((r10)*(x9432)*(x9439)))+(((x9441)*(x9442)))+(((IkReal(-1.00000000000000))*(sj0)*(x9432)*(x9444)))+(((IkReal(-1.00000000000000))*(r10)*(x9429)*(x9439)))+(((IkReal(-1.00000000000000))*(x9434)*(x9435)))+(((r00)*(x9427)*(x9429)))+(((IkReal(-1.00000000000000))*(r11)*(x9429)*(x9431)))+(((px)*(sj0)))+(((IkReal(-1.00000000000000))*(x9446)*(x9449)))+(((sj0)*(x9429)*(x9444)))+(((IkReal(-1.00000000000000))*(py)*(x9425)))+(((r11)*(x9431)*(x9432))));
evalcond[7]=((((IkReal(-1.00000000000000))*(r11)*(x9434)*(x9440)))+(((IkReal(-1.00000000000000))*(r00)*(x9425)*(x9450)))+(((r11)*(sj4)*(x9427)))+(((IkReal(-1.00000000000000))*(x9426)*(x9434)*(x9448)))+(((IkReal(-1.00000000000000))*(r10)*(x9438)*(x9450)))+(((IkReal(-1.00000000000000))*(x9433)*(x9451)))+(((IkReal(-1.00000000000000))*(r02)*(x9425)*(x9433)))+(((IkReal(-1.00000000000000))*(cj5)*(r00)*(x9425)*(x9426)))+(((IkReal(-1.00000000000000))*(cj5)*(r01)*(x9425)*(x9440)))+(((r01)*(sj4)*(x9439))));
evalcond[8]=((IkReal(0.0690000000000000))+(((IkReal(-1.00000000000000))*(r00)*(x9429)*(x9439)))+(((r00)*(x9432)*(x9439)))+(((r12)*(sj0)*(x9446)))+(((IkReal(-1.00000000000000))*(r01)*(x9429)*(x9431)))+(((IkReal(-1.00000000000000))*(r10)*(x9427)*(x9429)))+(((x9435)*(x9442)))+(((cj0)*(r02)*(x9446)))+(((r10)*(x9427)*(x9432)))+(((IkReal(-1.00000000000000))*(px)*(x9425)))+(((r01)*(x9431)*(x9432)))+(((x9434)*(x9441)))+(((IkReal(-1.00000000000000))*(sj0)*(x9429)*(x9447)))+(((IkReal(-1.00000000000000))*(py)*(x9438)))+(((sj0)*(x9432)*(x9447))));
if( IKabs(evalcond[0]) < 0.0000010000000000  && IKabs(evalcond[1]) < 0.0000010000000000  && IKabs(evalcond[2]) < 0.0000010000000000  && IKabs(evalcond[3]) < 0.0000010000000000  && IKabs(evalcond[4]) < 0.0000010000000000  && IKabs(evalcond[5]) < 0.0000010000000000  && IKabs(evalcond[6]) < 0.0000010000000000  && IKabs(evalcond[7]) < 0.0000010000000000  && IKabs(evalcond[8]) < 0.0000010000000000  )
{
{
IkReal j3array[1], cj3array[1], sj3array[1];
bool j3valid[1]={false};
_nj3 = 1;
IkReal x9452=((IkReal(1.00000000000000))*(sj5));
IkReal x9453=((cj6)*(r21));
IkReal x9454=((r20)*(sj6));
IkReal x9455=((IkReal(1.00000000000000))*(cj4)*(cj5));
if( IKabs(((((IkReal(-1.00000000000000))*(x9454)*(x9455)))+(((IkReal(-1.00000000000000))*(cj4)*(r22)*(x9452)))+(((r21)*(sj4)*(sj6)))+(((IkReal(-1.00000000000000))*(x9453)*(x9455)))+(((IkReal(-1.00000000000000))*(cj6)*(r20)*(sj4))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(((((IkReal(-1.00000000000000))*(x9452)*(x9453)))+(((IkReal(-1.00000000000000))*(x9452)*(x9454)))+(((cj5)*(r22))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(IKsqr(((((IkReal(-1.00000000000000))*(x9454)*(x9455)))+(((IkReal(-1.00000000000000))*(cj4)*(r22)*(x9452)))+(((r21)*(sj4)*(sj6)))+(((IkReal(-1.00000000000000))*(x9453)*(x9455)))+(((IkReal(-1.00000000000000))*(cj6)*(r20)*(sj4)))))+IKsqr(((((IkReal(-1.00000000000000))*(x9452)*(x9453)))+(((IkReal(-1.00000000000000))*(x9452)*(x9454)))+(((cj5)*(r22)))))-1) <= IKFAST_SINCOS_THRESH )
    continue;
j3array[0]=IKatan2(((((IkReal(-1.00000000000000))*(x9454)*(x9455)))+(((IkReal(-1.00000000000000))*(cj4)*(r22)*(x9452)))+(((r21)*(sj4)*(sj6)))+(((IkReal(-1.00000000000000))*(x9453)*(x9455)))+(((IkReal(-1.00000000000000))*(cj6)*(r20)*(sj4)))), ((((IkReal(-1.00000000000000))*(x9452)*(x9453)))+(((IkReal(-1.00000000000000))*(x9452)*(x9454)))+(((cj5)*(r22)))));
sj3array[0]=IKsin(j3array[0]);
cj3array[0]=IKcos(j3array[0]);
if( j3array[0] > IKPI )
{
    j3array[0]-=IK2PI;
}
else if( j3array[0] < -IKPI )
{    j3array[0]+=IK2PI;
}
j3valid[0] = true;
for(int ij3 = 0; ij3 < 1; ++ij3)
{
if( !j3valid[ij3] )
{
    continue;
}
_ij3[0] = ij3; _ij3[1] = -1;
for(int iij3 = ij3+1; iij3 < 1; ++iij3)
{
if( j3valid[iij3] && IKabs(cj3array[ij3]-cj3array[iij3]) < IKFAST_SOLUTION_THRESH && IKabs(sj3array[ij3]-sj3array[iij3]) < IKFAST_SOLUTION_THRESH )
{
    j3valid[iij3]=false; _ij3[1] = iij3; break; 
}
}
j3 = j3array[ij3]; cj3 = cj3array[ij3]; sj3 = sj3array[ij3];
{
IkReal evalcond[4];
IkReal x9456=IKsin(j3);
IkReal x9457=IKcos(j3);
IkReal x9458=((sj0)*(sj5));
IkReal x9459=((r00)*(sj6));
IkReal x9460=((cj6)*(r01));
IkReal x9461=((cj5)*(sj0));
IkReal x9462=((cj0)*(cj5));
IkReal x9463=((cj6)*(sj4));
IkReal x9464=((sj4)*(sj6));
IkReal x9465=((cj0)*(r11));
IkReal x9466=((cj4)*(cj6));
IkReal x9467=((cj4)*(sj6));
IkReal x9468=((IkReal(1.00000000000000))*(cj0));
IkReal x9469=((cj4)*(sj5));
IkReal x9470=((sj5)*(sj6));
IkReal x9471=((cj6)*(sj5));
evalcond[0]=((((r20)*(x9470)))+(((IkReal(-1.00000000000000))*(cj5)*(r22)))+(((r21)*(x9471)))+(x9457));
evalcond[1]=((((r22)*(x9469)))+(((cj5)*(r21)*(x9466)))+(x9456)+(((cj5)*(r20)*(x9467)))+(((r20)*(x9463)))+(((IkReal(-1.00000000000000))*(r21)*(x9464))));
evalcond[2]=((((x9458)*(x9459)))+(((x9458)*(x9460)))+(((IkReal(-1.00000000000000))*(x9465)*(x9471)))+(((r12)*(x9462)))+(((IkReal(-1.00000000000000))*(x9456)))+(((IkReal(-1.00000000000000))*(r10)*(x9468)*(x9470)))+(((IkReal(-1.00000000000000))*(r02)*(x9461))));
evalcond[3]=((((IkReal(-1.00000000000000))*(r11)*(x9462)*(x9466)))+(((cj4)*(r02)*(x9458)))+(((x9464)*(x9465)))+(((cj4)*(x9460)*(x9461)))+(((IkReal(-1.00000000000000))*(r01)*(sj0)*(x9464)))+(((IkReal(-1.00000000000000))*(r10)*(x9463)*(x9468)))+(((IkReal(-1.00000000000000))*(r10)*(x9462)*(x9467)))+(((IkReal(-1.00000000000000))*(r12)*(x9468)*(x9469)))+(((r00)*(sj0)*(x9463)))+(x9457)+(((cj4)*(x9459)*(x9461))));
if( IKabs(evalcond[0]) > 0.000001  || IKabs(evalcond[1]) > 0.000001  || IKabs(evalcond[2]) > 0.000001  || IKabs(evalcond[3]) > 0.000001  )
{
continue;
}
}

{
std::vector<IkSingleDOFSolutionBase<IkReal> > vinfos(7);
vinfos[0].jointtype = 1;
vinfos[0].foffset = j0;
vinfos[0].indices[0] = _ij0[0];
vinfos[0].indices[1] = _ij0[1];
vinfos[0].maxsolutions = _nj0;
vinfos[1].jointtype = 1;
vinfos[1].foffset = j1;
vinfos[1].indices[0] = _ij1[0];
vinfos[1].indices[1] = _ij1[1];
vinfos[1].maxsolutions = _nj1;
vinfos[2].jointtype = 1;
vinfos[2].foffset = j2;
vinfos[2].indices[0] = _ij2[0];
vinfos[2].indices[1] = _ij2[1];
vinfos[2].maxsolutions = _nj2;
vinfos[3].jointtype = 1;
vinfos[3].foffset = j3;
vinfos[3].indices[0] = _ij3[0];
vinfos[3].indices[1] = _ij3[1];
vinfos[3].maxsolutions = _nj3;
vinfos[4].jointtype = 1;
vinfos[4].foffset = j4;
vinfos[4].indices[0] = _ij4[0];
vinfos[4].indices[1] = _ij4[1];
vinfos[4].maxsolutions = _nj4;
vinfos[5].jointtype = 1;
vinfos[5].foffset = j5;
vinfos[5].indices[0] = _ij5[0];
vinfos[5].indices[1] = _ij5[1];
vinfos[5].maxsolutions = _nj5;
vinfos[6].jointtype = 1;
vinfos[6].foffset = j6;
vinfos[6].indices[0] = _ij6[0];
vinfos[6].indices[1] = _ij6[1];
vinfos[6].maxsolutions = _nj6;
std::vector<int> vfree(0);
solutions.AddSolution(vinfos,vfree);
}
}
}

} else
{
IkReal x9472=((IkReal(1.00000000000000))*(cj0));
IkReal x9473=((cj4)*(sj6));
IkReal x9474=((sj0)*(sj4));
IkReal x9475=((cj5)*(sj6));
IkReal x9476=((sj4)*(sj5));
IkReal x9477=((r12)*(sj5));
IkReal x9478=((IkReal(0.374290000000000))*(cj5));
IkReal x9479=((r02)*(sj0));
IkReal x9480=((r20)*(sj4));
IkReal x9481=((IkReal(1.00000000000000))*(sj0));
IkReal x9482=((IkReal(1.00000000000000))*(cj5));
IkReal x9483=((cj0)*(r10));
IkReal x9484=((cj4)*(cj6));
IkReal x9485=((r00)*(sj0));
IkReal x9486=((cj6)*(r21));
IkReal x9487=((IkReal(0.374290000000000))*(sj5));
IkReal x9488=((cj0)*(r00));
IkReal x9489=((IkReal(0.0100000000000000))*(sj5));
IkReal x9490=((cj0)*(r02));
IkReal x9491=((cj5)*(sj4));
IkReal x9492=((cj6)*(r01));
IkReal x9493=((cj6)*(r11));
IkReal x9494=((r01)*(sj0));
IkReal x9495=((r10)*(sj0));
IkReal x9496=((IkReal(0.0100000000000000))*(cj5)*(cj6));
IkReal x9497=((sj6)*(x9487));
IkReal x9498=((cj0)*(cj6)*(x9487));
evalcond[0]=((IkReal(-3.14159265358979))+(IKfmod(((IkReal(3.14159265358979))+(j1)), IkReal(6.28318530717959))));
evalcond[1]=((((sj5)*(x9486)))+(((r20)*(sj5)*(sj6)))+(((IkReal(-1.00000000000000))*(r22)*(x9482))));
evalcond[2]=((IkReal(-1.00000000000000))+(((IkReal(-1.00000000000000))*(r20)*(x9484)))+(((r22)*(x9476)))+(((r21)*(x9473)))+(((x9486)*(x9491)))+(((x9475)*(x9480))));
evalcond[3]=((((IkReal(-1.00000000000000))*(r22)*(x9489)))+(((IkReal(-0.0100000000000000))*(cj5)*(x9486)))+(((r20)*(x9497)))+(((IkReal(-1.00000000000000))*(r22)*(x9478)))+(((x9486)*(x9487)))+(pz)+(((IkReal(-0.0100000000000000))*(r20)*(x9475))));
evalcond[4]=((((IkReal(-1.00000000000000))*(r21)*(sj4)*(sj6)))+(((cj6)*(x9480)))+(((cj5)*(r20)*(x9473)))+(((cj4)*(r22)*(sj5)))+(((cj5)*(r21)*(x9484))));
evalcond[5]=((((x9483)*(x9484)))+(((IkReal(-1.00000000000000))*(r10)*(sj4)*(x9472)*(x9475)))+(((r02)*(sj5)*(x9474)))+(((IkReal(-1.00000000000000))*(r00)*(x9481)*(x9484)))+(((r00)*(x9474)*(x9475)))+(((IkReal(-1.00000000000000))*(r11)*(x9472)*(x9473)))+(((x9473)*(x9494)))+(((cj5)*(x9474)*(x9492)))+(((IkReal(-1.00000000000000))*(x9472)*(x9491)*(x9493)))+(((IkReal(-1.00000000000000))*(r12)*(x9472)*(x9476))));
evalcond[6]=((((IkReal(-1.00000000000000))*(x9472)*(x9491)*(x9492)))+(((IkReal(-1.00000000000000))*(x9474)*(x9482)*(x9493)))+(((x9484)*(x9495)))+(((IkReal(-1.00000000000000))*(r01)*(x9472)*(x9473)))+(((IkReal(-1.00000000000000))*(r11)*(x9473)*(x9481)))+(((IkReal(-1.00000000000000))*(r00)*(sj4)*(x9472)*(x9475)))+(((IkReal(-1.00000000000000))*(r02)*(x9472)*(x9476)))+(((IkReal(-1.00000000000000))*(r10)*(x9474)*(x9475)))+(((IkReal(-1.00000000000000))*(x9474)*(x9477)))+(((x9484)*(x9488))));
evalcond[7]=((IkReal(0.0690000000000000))+(((IkReal(0.0100000000000000))*(cj0)*(cj5)*(x9493)))+(((IkReal(-0.0100000000000000))*(cj5)*(sj0)*(x9492)))+(((IkReal(0.0100000000000000))*(x9475)*(x9483)))+(((IkReal(-1.00000000000000))*(x9478)*(x9479)))+(((IkReal(-1.00000000000000))*(cj0)*(x9487)*(x9493)))+(((IkReal(-1.00000000000000))*(py)*(x9472)))+(((IkReal(-1.00000000000000))*(x9479)*(x9489)))+(((px)*(sj0)))+(((IkReal(-0.0100000000000000))*(x9475)*(x9485)))+(((IkReal(-1.00000000000000))*(x9483)*(x9497)))+(((x9485)*(x9497)))+(((IkReal(0.0100000000000000))*(cj0)*(x9477)))+(((sj0)*(x9487)*(x9492)))+(((cj0)*(r12)*(x9478))));
evalcond[8]=((IkReal(0.433420000000000))+(((IkReal(-1.00000000000000))*(py)*(x9481)))+(((IkReal(-1.00000000000000))*(sj0)*(x9487)*(x9493)))+(((IkReal(0.0100000000000000))*(cj5)*(sj0)*(x9493)))+(((IkReal(-1.00000000000000))*(x9488)*(x9497)))+(((IkReal(0.0100000000000000))*(cj0)*(cj5)*(x9492)))+(((IkReal(0.0100000000000000))*(sj0)*(x9477)))+(((IkReal(0.0100000000000000))*(x9475)*(x9495)))+(((IkReal(0.0100000000000000))*(x9475)*(x9488)))+(((x9489)*(x9490)))+(((r12)*(sj0)*(x9478)))+(((IkReal(-1.00000000000000))*(x9495)*(x9497)))+(((IkReal(-1.00000000000000))*(px)*(x9472)))+(((x9478)*(x9490)))+(((IkReal(-1.00000000000000))*(cj0)*(x9487)*(x9492))));
if( IKabs(evalcond[0]) < 0.0000010000000000  && IKabs(evalcond[1]) < 0.0000010000000000  && IKabs(evalcond[2]) < 0.0000010000000000  && IKabs(evalcond[3]) < 0.0000010000000000  && IKabs(evalcond[4]) < 0.0000010000000000  && IKabs(evalcond[5]) < 0.0000010000000000  && IKabs(evalcond[6]) < 0.0000010000000000  && IKabs(evalcond[7]) < 0.0000010000000000  && IKabs(evalcond[8]) < 0.0000010000000000  )
{
{
IkReal j3array[1], cj3array[1], sj3array[1];
bool j3valid[1]={false};
_nj3 = 1;
IkReal x9499=((cj0)*(cj5));
IkReal x9500=((IkReal(1.00000000000000))*(cj0));
IkReal x9501=((cj6)*(r11));
IkReal x9502=((r10)*(sj6));
IkReal x9503=((cj5)*(sj0));
IkReal x9504=((r00)*(sj5)*(sj6));
IkReal x9505=((cj6)*(r01)*(sj5));
IkReal x9506=((IkReal(1.00000000000000))*(sj0)*(sj5));
if( IKabs(((((IkReal(-1.00000000000000))*(r02)*(x9503)))+(((r12)*(x9499)))+(((IkReal(-1.00000000000000))*(sj5)*(x9500)*(x9501)))+(((sj0)*(x9504)))+(((IkReal(-1.00000000000000))*(sj5)*(x9500)*(x9502)))+(((sj0)*(x9505))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(((((r02)*(x9499)))+(((r12)*(x9503)))+(((IkReal(-1.00000000000000))*(x9500)*(x9505)))+(((IkReal(-1.00000000000000))*(x9500)*(x9504)))+(((IkReal(-1.00000000000000))*(x9501)*(x9506)))+(((IkReal(-1.00000000000000))*(x9502)*(x9506))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(IKsqr(((((IkReal(-1.00000000000000))*(r02)*(x9503)))+(((r12)*(x9499)))+(((IkReal(-1.00000000000000))*(sj5)*(x9500)*(x9501)))+(((sj0)*(x9504)))+(((IkReal(-1.00000000000000))*(sj5)*(x9500)*(x9502)))+(((sj0)*(x9505)))))+IKsqr(((((r02)*(x9499)))+(((r12)*(x9503)))+(((IkReal(-1.00000000000000))*(x9500)*(x9505)))+(((IkReal(-1.00000000000000))*(x9500)*(x9504)))+(((IkReal(-1.00000000000000))*(x9501)*(x9506)))+(((IkReal(-1.00000000000000))*(x9502)*(x9506)))))-1) <= IKFAST_SINCOS_THRESH )
    continue;
j3array[0]=IKatan2(((((IkReal(-1.00000000000000))*(r02)*(x9503)))+(((r12)*(x9499)))+(((IkReal(-1.00000000000000))*(sj5)*(x9500)*(x9501)))+(((sj0)*(x9504)))+(((IkReal(-1.00000000000000))*(sj5)*(x9500)*(x9502)))+(((sj0)*(x9505)))), ((((r02)*(x9499)))+(((r12)*(x9503)))+(((IkReal(-1.00000000000000))*(x9500)*(x9505)))+(((IkReal(-1.00000000000000))*(x9500)*(x9504)))+(((IkReal(-1.00000000000000))*(x9501)*(x9506)))+(((IkReal(-1.00000000000000))*(x9502)*(x9506)))));
sj3array[0]=IKsin(j3array[0]);
cj3array[0]=IKcos(j3array[0]);
if( j3array[0] > IKPI )
{
    j3array[0]-=IK2PI;
}
else if( j3array[0] < -IKPI )
{    j3array[0]+=IK2PI;
}
j3valid[0] = true;
for(int ij3 = 0; ij3 < 1; ++ij3)
{
if( !j3valid[ij3] )
{
    continue;
}
_ij3[0] = ij3; _ij3[1] = -1;
for(int iij3 = ij3+1; iij3 < 1; ++iij3)
{
if( j3valid[iij3] && IKabs(cj3array[ij3]-cj3array[iij3]) < IKFAST_SOLUTION_THRESH && IKabs(sj3array[ij3]-sj3array[iij3]) < IKFAST_SOLUTION_THRESH )
{
    j3valid[iij3]=false; _ij3[1] = iij3; break; 
}
}
j3 = j3array[ij3]; cj3 = cj3array[ij3]; sj3 = sj3array[ij3];
{
IkReal evalcond[4];
IkReal x9507=IKcos(j3);
IkReal x9508=((sj0)*(sj5));
IkReal x9509=((r00)*(sj6));
IkReal x9510=((cj6)*(sj0));
IkReal x9511=((IkReal(1.00000000000000))*(cj4));
IkReal x9512=((r00)*(sj4));
IkReal x9513=((cj0)*(cj5));
IkReal x9514=((cj5)*(sj0));
IkReal x9515=((cj6)*(r11));
IkReal x9516=((r10)*(sj6));
IkReal x9517=((cj0)*(sj5));
IkReal x9518=((r10)*(sj4));
IkReal x9519=((IkReal(1.00000000000000))*(IKsin(j3)));
IkReal x9520=((cj4)*(cj5)*(r01));
IkReal x9521=((IkReal(1.00000000000000))*(cj0)*(cj6));
IkReal x9522=((cj0)*(sj4)*(sj6));
IkReal x9523=((sj0)*(sj4)*(sj6));
evalcond[0]=((((IkReal(-1.00000000000000))*(x9515)*(x9517)))+(((IkReal(-1.00000000000000))*(x9516)*(x9517)))+(((cj6)*(r01)*(x9508)))+(((IkReal(-1.00000000000000))*(r02)*(x9514)))+(((r12)*(x9513)))+(((x9508)*(x9509)))+(((IkReal(-1.00000000000000))*(x9519))));
evalcond[1]=((((IkReal(-1.00000000000000))*(x9508)*(x9515)))+(((IkReal(-1.00000000000000))*(x9507)))+(((r02)*(x9513)))+(((IkReal(-1.00000000000000))*(x9509)*(x9517)))+(((r12)*(x9514)))+(((IkReal(-1.00000000000000))*(cj6)*(r01)*(x9517)))+(((IkReal(-1.00000000000000))*(x9508)*(x9516))));
evalcond[2]=((((IkReal(-1.00000000000000))*(x9511)*(x9513)*(x9515)))+(((cj4)*(r02)*(x9508)))+(((r11)*(x9522)))+(((IkReal(-1.00000000000000))*(x9518)*(x9521)))+(((x9510)*(x9520)))+(((cj4)*(x9509)*(x9514)))+(((IkReal(-1.00000000000000))*(r01)*(x9523)))+(((IkReal(-1.00000000000000))*(r12)*(x9511)*(x9517)))+(((IkReal(-1.00000000000000))*(x9511)*(x9513)*(x9516)))+(x9507)+(((x9510)*(x9512))));
evalcond[3]=((((r01)*(x9522)))+(((IkReal(-1.00000000000000))*(x9510)*(x9518)))+(((IkReal(-1.00000000000000))*(x9509)*(x9511)*(x9513)))+(((IkReal(-1.00000000000000))*(x9512)*(x9521)))+(((IkReal(-1.00000000000000))*(r02)*(x9511)*(x9517)))+(((IkReal(-1.00000000000000))*(cj6)*(r01)*(x9511)*(x9513)))+(((r11)*(x9523)))+(((IkReal(-1.00000000000000))*(x9511)*(x9514)*(x9516)))+(((IkReal(-1.00000000000000))*(cj5)*(r11)*(x9510)*(x9511)))+(((IkReal(-1.00000000000000))*(x9519)))+(((IkReal(-1.00000000000000))*(r12)*(x9508)*(x9511))));
if( IKabs(evalcond[0]) > 0.000001  || IKabs(evalcond[1]) > 0.000001  || IKabs(evalcond[2]) > 0.000001  || IKabs(evalcond[3]) > 0.000001  )
{
continue;
}
}

{
std::vector<IkSingleDOFSolutionBase<IkReal> > vinfos(7);
vinfos[0].jointtype = 1;
vinfos[0].foffset = j0;
vinfos[0].indices[0] = _ij0[0];
vinfos[0].indices[1] = _ij0[1];
vinfos[0].maxsolutions = _nj0;
vinfos[1].jointtype = 1;
vinfos[1].foffset = j1;
vinfos[1].indices[0] = _ij1[0];
vinfos[1].indices[1] = _ij1[1];
vinfos[1].maxsolutions = _nj1;
vinfos[2].jointtype = 1;
vinfos[2].foffset = j2;
vinfos[2].indices[0] = _ij2[0];
vinfos[2].indices[1] = _ij2[1];
vinfos[2].maxsolutions = _nj2;
vinfos[3].jointtype = 1;
vinfos[3].foffset = j3;
vinfos[3].indices[0] = _ij3[0];
vinfos[3].indices[1] = _ij3[1];
vinfos[3].maxsolutions = _nj3;
vinfos[4].jointtype = 1;
vinfos[4].foffset = j4;
vinfos[4].indices[0] = _ij4[0];
vinfos[4].indices[1] = _ij4[1];
vinfos[4].maxsolutions = _nj4;
vinfos[5].jointtype = 1;
vinfos[5].foffset = j5;
vinfos[5].indices[0] = _ij5[0];
vinfos[5].indices[1] = _ij5[1];
vinfos[5].maxsolutions = _nj5;
vinfos[6].jointtype = 1;
vinfos[6].foffset = j6;
vinfos[6].indices[0] = _ij6[0];
vinfos[6].indices[1] = _ij6[1];
vinfos[6].maxsolutions = _nj6;
std::vector<int> vfree(0);
solutions.AddSolution(vinfos,vfree);
}
}
}

} else
{
IkReal x9524=((IkReal(1.00000000000000))*(cj0));
IkReal x9525=((cj4)*(sj6));
IkReal x9526=((sj0)*(sj4));
IkReal x9527=((cj5)*(sj6));
IkReal x9528=((sj4)*(sj5));
IkReal x9529=((r12)*(sj5));
IkReal x9530=((IkReal(0.374290000000000))*(cj5));
IkReal x9531=((r02)*(sj0));
IkReal x9532=((r20)*(sj4));
IkReal x9533=((IkReal(1.00000000000000))*(sj0));
IkReal x9534=((IkReal(1.00000000000000))*(cj5));
IkReal x9535=((cj0)*(r10));
IkReal x9536=((cj4)*(cj6));
IkReal x9537=((r00)*(sj0));
IkReal x9538=((cj6)*(r21));
IkReal x9539=((IkReal(0.374290000000000))*(sj5));
IkReal x9540=((cj0)*(r00));
IkReal x9541=((IkReal(0.0100000000000000))*(sj5));
IkReal x9542=((cj0)*(r02));
IkReal x9543=((cj5)*(sj4));
IkReal x9544=((cj6)*(r01));
IkReal x9545=((cj6)*(r11));
IkReal x9546=((r01)*(sj0));
IkReal x9547=((r10)*(sj0));
IkReal x9548=((IkReal(0.0100000000000000))*(cj5)*(cj6));
IkReal x9549=((sj6)*(x9539));
IkReal x9550=((cj0)*(cj6)*(x9539));
evalcond[0]=((IkReal(-3.14159265358979))+(IKfmod(j1, IkReal(6.28318530717959))));
evalcond[1]=((((sj5)*(x9538)))+(((IkReal(-1.00000000000000))*(r22)*(x9534)))+(((r20)*(sj5)*(sj6))));
evalcond[2]=((IkReal(1.00000000000000))+(((r22)*(x9528)))+(((r21)*(x9525)))+(((x9527)*(x9532)))+(((x9538)*(x9543)))+(((IkReal(-1.00000000000000))*(r20)*(x9536))));
evalcond[3]=((((r20)*(x9549)))+(((IkReal(-0.0100000000000000))*(cj5)*(x9538)))+(((IkReal(-0.0100000000000000))*(r20)*(x9527)))+(((x9538)*(x9539)))+(((IkReal(-1.00000000000000))*(r22)*(x9541)))+(pz)+(((IkReal(-1.00000000000000))*(r22)*(x9530))));
evalcond[4]=((((IkReal(-1.00000000000000))*(r21)*(sj4)*(sj6)))+(((cj5)*(r21)*(x9536)))+(((cj4)*(r22)*(sj5)))+(((cj5)*(r20)*(x9525)))+(((cj6)*(x9532))));
evalcond[5]=((((IkReal(-1.00000000000000))*(r00)*(x9533)*(x9536)))+(((x9525)*(x9546)))+(((x9535)*(x9536)))+(((IkReal(-1.00000000000000))*(r11)*(x9524)*(x9525)))+(((r00)*(x9526)*(x9527)))+(((cj5)*(x9526)*(x9544)))+(((r02)*(sj5)*(x9526)))+(((IkReal(-1.00000000000000))*(r12)*(x9524)*(x9528)))+(((IkReal(-1.00000000000000))*(x9524)*(x9543)*(x9545)))+(((IkReal(-1.00000000000000))*(r10)*(sj4)*(x9524)*(x9527))));
evalcond[6]=((((IkReal(-1.00000000000000))*(x9526)*(x9534)*(x9545)))+(((IkReal(-1.00000000000000))*(x9524)*(x9543)*(x9544)))+(((IkReal(-1.00000000000000))*(x9526)*(x9529)))+(((IkReal(-1.00000000000000))*(r00)*(sj4)*(x9524)*(x9527)))+(((IkReal(-1.00000000000000))*(r11)*(x9525)*(x9533)))+(((IkReal(-1.00000000000000))*(r01)*(x9524)*(x9525)))+(((x9536)*(x9540)))+(((x9536)*(x9547)))+(((IkReal(-1.00000000000000))*(r10)*(x9526)*(x9527)))+(((IkReal(-1.00000000000000))*(r02)*(x9524)*(x9528))));
evalcond[7]=((IkReal(0.0690000000000000))+(((IkReal(-1.00000000000000))*(x9535)*(x9549)))+(((sj0)*(x9539)*(x9544)))+(((IkReal(-0.0100000000000000))*(x9527)*(x9537)))+(((x9537)*(x9549)))+(((IkReal(-1.00000000000000))*(cj0)*(x9539)*(x9545)))+(((IkReal(0.0100000000000000))*(cj0)*(cj5)*(x9545)))+(((IkReal(-1.00000000000000))*(x9531)*(x9541)))+(((IkReal(0.0100000000000000))*(cj0)*(x9529)))+(((IkReal(-1.00000000000000))*(x9530)*(x9531)))+(((IkReal(0.0100000000000000))*(x9527)*(x9535)))+(((cj0)*(r12)*(x9530)))+(((px)*(sj0)))+(((IkReal(-0.0100000000000000))*(cj5)*(sj0)*(x9544)))+(((IkReal(-1.00000000000000))*(py)*(x9524))));
evalcond[8]=((IkReal(-0.295420000000000))+(((IkReal(-1.00000000000000))*(cj0)*(x9539)*(x9544)))+(((IkReal(0.0100000000000000))*(cj5)*(sj0)*(x9545)))+(((x9541)*(x9542)))+(((IkReal(0.0100000000000000))*(x9527)*(x9540)))+(((IkReal(-1.00000000000000))*(px)*(x9524)))+(((IkReal(0.0100000000000000))*(sj0)*(x9529)))+(((IkReal(-1.00000000000000))*(x9540)*(x9549)))+(((r12)*(sj0)*(x9530)))+(((IkReal(-1.00000000000000))*(x9547)*(x9549)))+(((IkReal(-1.00000000000000))*(py)*(x9533)))+(((x9530)*(x9542)))+(((IkReal(0.0100000000000000))*(x9527)*(x9547)))+(((IkReal(0.0100000000000000))*(cj0)*(cj5)*(x9544)))+(((IkReal(-1.00000000000000))*(sj0)*(x9539)*(x9545))));
if( IKabs(evalcond[0]) < 0.0000010000000000  && IKabs(evalcond[1]) < 0.0000010000000000  && IKabs(evalcond[2]) < 0.0000010000000000  && IKabs(evalcond[3]) < 0.0000010000000000  && IKabs(evalcond[4]) < 0.0000010000000000  && IKabs(evalcond[5]) < 0.0000010000000000  && IKabs(evalcond[6]) < 0.0000010000000000  && IKabs(evalcond[7]) < 0.0000010000000000  && IKabs(evalcond[8]) < 0.0000010000000000  )
{
{
IkReal j3array[1], cj3array[1], sj3array[1];
bool j3valid[1]={false};
_nj3 = 1;
IkReal x9551=((sj0)*(sj5));
IkReal x9552=((r00)*(sj6));
IkReal x9553=((IkReal(1.00000000000000))*(cj5));
IkReal x9554=((cj6)*(r11));
IkReal x9555=((cj6)*(r01));
IkReal x9556=((r10)*(sj6));
IkReal x9557=((cj0)*(sj5));
if( IKabs(((((x9551)*(x9555)))+(((IkReal(-1.00000000000000))*(x9556)*(x9557)))+(((IkReal(-1.00000000000000))*(r02)*(sj0)*(x9553)))+(((x9551)*(x9552)))+(((cj0)*(cj5)*(r12)))+(((IkReal(-1.00000000000000))*(x9554)*(x9557))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(((((x9552)*(x9557)))+(((x9555)*(x9557)))+(((IkReal(-1.00000000000000))*(cj0)*(r02)*(x9553)))+(((x9551)*(x9554)))+(((IkReal(-1.00000000000000))*(r12)*(sj0)*(x9553)))+(((x9551)*(x9556))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(IKsqr(((((x9551)*(x9555)))+(((IkReal(-1.00000000000000))*(x9556)*(x9557)))+(((IkReal(-1.00000000000000))*(r02)*(sj0)*(x9553)))+(((x9551)*(x9552)))+(((cj0)*(cj5)*(r12)))+(((IkReal(-1.00000000000000))*(x9554)*(x9557)))))+IKsqr(((((x9552)*(x9557)))+(((x9555)*(x9557)))+(((IkReal(-1.00000000000000))*(cj0)*(r02)*(x9553)))+(((x9551)*(x9554)))+(((IkReal(-1.00000000000000))*(r12)*(sj0)*(x9553)))+(((x9551)*(x9556)))))-1) <= IKFAST_SINCOS_THRESH )
    continue;
j3array[0]=IKatan2(((((x9551)*(x9555)))+(((IkReal(-1.00000000000000))*(x9556)*(x9557)))+(((IkReal(-1.00000000000000))*(r02)*(sj0)*(x9553)))+(((x9551)*(x9552)))+(((cj0)*(cj5)*(r12)))+(((IkReal(-1.00000000000000))*(x9554)*(x9557)))), ((((x9552)*(x9557)))+(((x9555)*(x9557)))+(((IkReal(-1.00000000000000))*(cj0)*(r02)*(x9553)))+(((x9551)*(x9554)))+(((IkReal(-1.00000000000000))*(r12)*(sj0)*(x9553)))+(((x9551)*(x9556)))));
sj3array[0]=IKsin(j3array[0]);
cj3array[0]=IKcos(j3array[0]);
if( j3array[0] > IKPI )
{
    j3array[0]-=IK2PI;
}
else if( j3array[0] < -IKPI )
{    j3array[0]+=IK2PI;
}
j3valid[0] = true;
for(int ij3 = 0; ij3 < 1; ++ij3)
{
if( !j3valid[ij3] )
{
    continue;
}
_ij3[0] = ij3; _ij3[1] = -1;
for(int iij3 = ij3+1; iij3 < 1; ++iij3)
{
if( j3valid[iij3] && IKabs(cj3array[ij3]-cj3array[iij3]) < IKFAST_SOLUTION_THRESH && IKabs(sj3array[ij3]-sj3array[iij3]) < IKFAST_SOLUTION_THRESH )
{
    j3valid[iij3]=false; _ij3[1] = iij3; break; 
}
}
j3 = j3array[ij3]; cj3 = cj3array[ij3]; sj3 = sj3array[ij3];
{
IkReal evalcond[4];
IkReal x9558=IKcos(j3);
IkReal x9559=IKsin(j3);
IkReal x9560=((sj0)*(sj5));
IkReal x9561=((r00)*(sj6));
IkReal x9562=((cj6)*(sj0));
IkReal x9563=((IkReal(1.00000000000000))*(cj4));
IkReal x9564=((r00)*(sj4));
IkReal x9565=((cj0)*(cj5));
IkReal x9566=((cj5)*(sj0));
IkReal x9567=((cj6)*(r11));
IkReal x9568=((r10)*(sj6));
IkReal x9569=((cj0)*(sj5));
IkReal x9570=((r10)*(sj4));
IkReal x9571=((cj4)*(cj5)*(r01));
IkReal x9572=((IkReal(1.00000000000000))*(cj0)*(cj6));
IkReal x9573=((cj0)*(sj4)*(sj6));
IkReal x9574=((sj0)*(sj4)*(sj6));
evalcond[0]=((((r12)*(x9565)))+(((IkReal(-1.00000000000000))*(x9559)))+(((IkReal(-1.00000000000000))*(x9568)*(x9569)))+(((x9560)*(x9561)))+(((IkReal(-1.00000000000000))*(r02)*(x9566)))+(((IkReal(-1.00000000000000))*(x9567)*(x9569)))+(((cj6)*(r01)*(x9560))));
evalcond[1]=((((IkReal(-1.00000000000000))*(x9560)*(x9567)))+(((r12)*(x9566)))+(((r02)*(x9565)))+(((IkReal(-1.00000000000000))*(x9561)*(x9569)))+(x9558)+(((IkReal(-1.00000000000000))*(cj6)*(r01)*(x9569)))+(((IkReal(-1.00000000000000))*(x9560)*(x9568))));
evalcond[2]=((((IkReal(-1.00000000000000))*(r01)*(x9574)))+(((IkReal(-1.00000000000000))*(x9570)*(x9572)))+(((IkReal(-1.00000000000000))*(x9563)*(x9565)*(x9568)))+(x9558)+(((cj4)*(x9561)*(x9566)))+(((x9562)*(x9571)))+(((r11)*(x9573)))+(((cj4)*(r02)*(x9560)))+(((IkReal(-1.00000000000000))*(x9563)*(x9565)*(x9567)))+(((x9562)*(x9564)))+(((IkReal(-1.00000000000000))*(r12)*(x9563)*(x9569))));
evalcond[3]=((((r01)*(x9573)))+(((IkReal(-1.00000000000000))*(x9564)*(x9572)))+(((IkReal(-1.00000000000000))*(x9563)*(x9566)*(x9568)))+(((r11)*(x9574)))+(((IkReal(-1.00000000000000))*(r02)*(x9563)*(x9569)))+(((IkReal(-1.00000000000000))*(cj5)*(r11)*(x9562)*(x9563)))+(x9559)+(((IkReal(-1.00000000000000))*(x9562)*(x9570)))+(((IkReal(-1.00000000000000))*(r12)*(x9560)*(x9563)))+(((IkReal(-1.00000000000000))*(x9561)*(x9563)*(x9565)))+(((IkReal(-1.00000000000000))*(cj6)*(r01)*(x9563)*(x9565))));
if( IKabs(evalcond[0]) > 0.000001  || IKabs(evalcond[1]) > 0.000001  || IKabs(evalcond[2]) > 0.000001  || IKabs(evalcond[3]) > 0.000001  )
{
continue;
}
}

{
std::vector<IkSingleDOFSolutionBase<IkReal> > vinfos(7);
vinfos[0].jointtype = 1;
vinfos[0].foffset = j0;
vinfos[0].indices[0] = _ij0[0];
vinfos[0].indices[1] = _ij0[1];
vinfos[0].maxsolutions = _nj0;
vinfos[1].jointtype = 1;
vinfos[1].foffset = j1;
vinfos[1].indices[0] = _ij1[0];
vinfos[1].indices[1] = _ij1[1];
vinfos[1].maxsolutions = _nj1;
vinfos[2].jointtype = 1;
vinfos[2].foffset = j2;
vinfos[2].indices[0] = _ij2[0];
vinfos[2].indices[1] = _ij2[1];
vinfos[2].maxsolutions = _nj2;
vinfos[3].jointtype = 1;
vinfos[3].foffset = j3;
vinfos[3].indices[0] = _ij3[0];
vinfos[3].indices[1] = _ij3[1];
vinfos[3].maxsolutions = _nj3;
vinfos[4].jointtype = 1;
vinfos[4].foffset = j4;
vinfos[4].indices[0] = _ij4[0];
vinfos[4].indices[1] = _ij4[1];
vinfos[4].maxsolutions = _nj4;
vinfos[5].jointtype = 1;
vinfos[5].foffset = j5;
vinfos[5].indices[0] = _ij5[0];
vinfos[5].indices[1] = _ij5[1];
vinfos[5].maxsolutions = _nj5;
vinfos[6].jointtype = 1;
vinfos[6].foffset = j6;
vinfos[6].indices[0] = _ij6[0];
vinfos[6].indices[1] = _ij6[1];
vinfos[6].maxsolutions = _nj6;
std::vector<int> vfree(0);
solutions.AddSolution(vinfos,vfree);
}
}
}

} else
{
if( 1 )
{
continue;

} else
{
}
}
}
}
}
}

} else
{
{
IkReal j3array[1], cj3array[1], sj3array[1];
bool j3valid[1]={false};
_nj3 = 1;
IkReal x9575=((cj0)*(cj5));
IkReal x9576=((IkReal(1.00000000000000))*(cj0));
IkReal x9577=((cj6)*(r11));
IkReal x9578=((r10)*(sj6));
IkReal x9579=((cj5)*(sj0));
IkReal x9580=((r00)*(sj5)*(sj6));
IkReal x9581=((cj6)*(r01)*(sj5));
IkReal x9582=((IkReal(1.00000000000000))*(sj0)*(sj5));
if( IKabs(((((IkReal(-1.00000000000000))*(r02)*(x9579)))+(((sj0)*(x9581)))+(((IkReal(-1.00000000000000))*(sj5)*(x9576)*(x9577)))+(((r12)*(x9575)))+(((IkReal(-1.00000000000000))*(sj5)*(x9576)*(x9578)))+(((sj0)*(x9580))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(((((IKabs(cj1) != 0)?((IkReal)1/(cj1)):(IkReal)1.0e30))*(((((IkReal(-1.00000000000000))*(x9576)*(x9580)))+(((IkReal(-1.00000000000000))*(x9576)*(x9581)))+(((IkReal(-1.00000000000000))*(x9577)*(x9582)))+(((r02)*(x9575)))+(((IkReal(-1.00000000000000))*(x9578)*(x9582)))+(((r12)*(x9579))))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(IKsqr(((((IkReal(-1.00000000000000))*(r02)*(x9579)))+(((sj0)*(x9581)))+(((IkReal(-1.00000000000000))*(sj5)*(x9576)*(x9577)))+(((r12)*(x9575)))+(((IkReal(-1.00000000000000))*(sj5)*(x9576)*(x9578)))+(((sj0)*(x9580)))))+IKsqr(((((IKabs(cj1) != 0)?((IkReal)1/(cj1)):(IkReal)1.0e30))*(((((IkReal(-1.00000000000000))*(x9576)*(x9580)))+(((IkReal(-1.00000000000000))*(x9576)*(x9581)))+(((IkReal(-1.00000000000000))*(x9577)*(x9582)))+(((r02)*(x9575)))+(((IkReal(-1.00000000000000))*(x9578)*(x9582)))+(((r12)*(x9579)))))))-1) <= IKFAST_SINCOS_THRESH )
    continue;
j3array[0]=IKatan2(((((IkReal(-1.00000000000000))*(r02)*(x9579)))+(((sj0)*(x9581)))+(((IkReal(-1.00000000000000))*(sj5)*(x9576)*(x9577)))+(((r12)*(x9575)))+(((IkReal(-1.00000000000000))*(sj5)*(x9576)*(x9578)))+(((sj0)*(x9580)))), ((((IKabs(cj1) != 0)?((IkReal)1/(cj1)):(IkReal)1.0e30))*(((((IkReal(-1.00000000000000))*(x9576)*(x9580)))+(((IkReal(-1.00000000000000))*(x9576)*(x9581)))+(((IkReal(-1.00000000000000))*(x9577)*(x9582)))+(((r02)*(x9575)))+(((IkReal(-1.00000000000000))*(x9578)*(x9582)))+(((r12)*(x9579)))))));
sj3array[0]=IKsin(j3array[0]);
cj3array[0]=IKcos(j3array[0]);
if( j3array[0] > IKPI )
{
    j3array[0]-=IK2PI;
}
else if( j3array[0] < -IKPI )
{    j3array[0]+=IK2PI;
}
j3valid[0] = true;
for(int ij3 = 0; ij3 < 1; ++ij3)
{
if( !j3valid[ij3] )
{
    continue;
}
_ij3[0] = ij3; _ij3[1] = -1;
for(int iij3 = ij3+1; iij3 < 1; ++iij3)
{
if( j3valid[iij3] && IKabs(cj3array[ij3]-cj3array[iij3]) < IKFAST_SOLUTION_THRESH && IKabs(sj3array[ij3]-sj3array[iij3]) < IKFAST_SOLUTION_THRESH )
{
    j3valid[iij3]=false; _ij3[1] = iij3; break; 
}
}
j3 = j3array[ij3]; cj3 = cj3array[ij3]; sj3 = sj3array[ij3];
{
IkReal evalcond[6];
IkReal x9583=IKsin(j3);
IkReal x9584=IKcos(j3);
IkReal x9585=((sj0)*(sj5));
IkReal x9586=((r00)*(sj6));
IkReal x9587=((cj6)*(r01));
IkReal x9588=((cj4)*(cj5));
IkReal x9589=((IkReal(1.00000000000000))*(cj0));
IkReal x9590=((cj5)*(r12));
IkReal x9591=((IkReal(1.00000000000000))*(sj0));
IkReal x9592=((cj6)*(r11));
IkReal x9593=((cj5)*(r02));
IkReal x9594=((IkReal(1.00000000000000))*(cj1));
IkReal x9595=((cj6)*(sj4));
IkReal x9596=((cj6)*(r21));
IkReal x9597=((r20)*(sj6));
IkReal x9598=((r10)*(sj6));
IkReal x9599=((sj4)*(sj6));
IkReal x9600=((cj4)*(r02));
IkReal x9601=((IkReal(1.00000000000000))*(cj4)*(r12));
IkReal x9602=((IkReal(1.00000000000000))*(x9583));
IkReal x9603=((cj0)*(x9599));
evalcond[0]=((((sj5)*(x9596)))+(((IkReal(-1.00000000000000))*(cj5)*(r22)))+(((IkReal(-1.00000000000000))*(sj1)*(x9584)))+(((sj5)*(x9597))));
evalcond[1]=((((IkReal(-1.00000000000000))*(r21)*(x9599)))+(((cj4)*(r22)*(sj5)))+(((r20)*(x9595)))+(((IkReal(-1.00000000000000))*(sj1)*(x9602)))+(((x9588)*(x9597)))+(((x9588)*(x9596))));
evalcond[2]=((((x9585)*(x9586)))+(((IkReal(-1.00000000000000))*(x9602)))+(((IkReal(-1.00000000000000))*(sj5)*(x9589)*(x9592)))+(((IkReal(-1.00000000000000))*(sj5)*(x9589)*(x9598)))+(((cj0)*(x9590)))+(((IkReal(-1.00000000000000))*(x9591)*(x9593)))+(((x9585)*(x9587))));
evalcond[3]=((((IkReal(-1.00000000000000))*(x9585)*(x9592)))+(((IkReal(-1.00000000000000))*(x9584)*(x9594)))+(((IkReal(-1.00000000000000))*(sj5)*(x9587)*(x9589)))+(((IkReal(-1.00000000000000))*(sj5)*(x9586)*(x9589)))+(((IkReal(-1.00000000000000))*(x9585)*(x9598)))+(((sj0)*(x9590)))+(((cj0)*(x9593))));
evalcond[4]=((((r00)*(sj0)*(x9595)))+(((IkReal(-1.00000000000000))*(x9588)*(x9589)*(x9592)))+(((IkReal(-1.00000000000000))*(r01)*(x9591)*(x9599)))+(((r11)*(x9603)))+(x9584)+(((IkReal(-1.00000000000000))*(x9588)*(x9589)*(x9598)))+(((sj0)*(x9586)*(x9588)))+(((IkReal(-1.00000000000000))*(r10)*(x9589)*(x9595)))+(((sj0)*(x9587)*(x9588)))+(((x9585)*(x9600)))+(((IkReal(-1.00000000000000))*(cj4)*(r12)*(sj5)*(x9589))));
evalcond[5]=((((IkReal(-1.00000000000000))*(x9585)*(x9601)))+(((IkReal(-1.00000000000000))*(x9587)*(x9588)*(x9589)))+(((IkReal(-1.00000000000000))*(r00)*(x9589)*(x9595)))+(((IkReal(-1.00000000000000))*(x9583)*(x9594)))+(((r11)*(sj0)*(x9599)))+(((r01)*(x9603)))+(((IkReal(-1.00000000000000))*(r10)*(x9591)*(x9595)))+(((IkReal(-1.00000000000000))*(x9586)*(x9588)*(x9589)))+(((IkReal(-1.00000000000000))*(x9588)*(x9591)*(x9592)))+(((IkReal(-1.00000000000000))*(sj5)*(x9589)*(x9600)))+(((IkReal(-1.00000000000000))*(x9588)*(x9591)*(x9598))));
if( IKabs(evalcond[0]) > 0.000001  || IKabs(evalcond[1]) > 0.000001  || IKabs(evalcond[2]) > 0.000001  || IKabs(evalcond[3]) > 0.000001  || IKabs(evalcond[4]) > 0.000001  || IKabs(evalcond[5]) > 0.000001  )
{
continue;
}
}

{
std::vector<IkSingleDOFSolutionBase<IkReal> > vinfos(7);
vinfos[0].jointtype = 1;
vinfos[0].foffset = j0;
vinfos[0].indices[0] = _ij0[0];
vinfos[0].indices[1] = _ij0[1];
vinfos[0].maxsolutions = _nj0;
vinfos[1].jointtype = 1;
vinfos[1].foffset = j1;
vinfos[1].indices[0] = _ij1[0];
vinfos[1].indices[1] = _ij1[1];
vinfos[1].maxsolutions = _nj1;
vinfos[2].jointtype = 1;
vinfos[2].foffset = j2;
vinfos[2].indices[0] = _ij2[0];
vinfos[2].indices[1] = _ij2[1];
vinfos[2].maxsolutions = _nj2;
vinfos[3].jointtype = 1;
vinfos[3].foffset = j3;
vinfos[3].indices[0] = _ij3[0];
vinfos[3].indices[1] = _ij3[1];
vinfos[3].maxsolutions = _nj3;
vinfos[4].jointtype = 1;
vinfos[4].foffset = j4;
vinfos[4].indices[0] = _ij4[0];
vinfos[4].indices[1] = _ij4[1];
vinfos[4].maxsolutions = _nj4;
vinfos[5].jointtype = 1;
vinfos[5].foffset = j5;
vinfos[5].indices[0] = _ij5[0];
vinfos[5].indices[1] = _ij5[1];
vinfos[5].maxsolutions = _nj5;
vinfos[6].jointtype = 1;
vinfos[6].foffset = j6;
vinfos[6].indices[0] = _ij6[0];
vinfos[6].indices[1] = _ij6[1];
vinfos[6].maxsolutions = _nj6;
std::vector<int> vfree(0);
solutions.AddSolution(vinfos,vfree);
}
}
}

}

}

} else
{
{
IkReal j3array[1], cj3array[1], sj3array[1];
bool j3valid[1]={false};
_nj3 = 1;
IkReal x9604=((sj5)*(sj6));
IkReal x9605=((cj6)*(sj5));
IkReal x9606=((IkReal(1.00000000000000))*(cj0));
IkReal x9607=((IkReal(1.00000000000000))*(cj5));
if( IKabs(((((r01)*(sj0)*(x9605)))+(((r00)*(sj0)*(x9604)))+(((IkReal(-1.00000000000000))*(r10)*(x9604)*(x9606)))+(((IkReal(-1.00000000000000))*(r02)*(sj0)*(x9607)))+(((cj0)*(cj5)*(r12)))+(((IkReal(-1.00000000000000))*(r11)*(x9605)*(x9606))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(((((IKabs(sj1) != 0)?((IkReal)1/(sj1)):(IkReal)1.0e30))*(((((IkReal(-1.00000000000000))*(r22)*(x9607)))+(((r21)*(x9605)))+(((r20)*(x9604))))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(IKsqr(((((r01)*(sj0)*(x9605)))+(((r00)*(sj0)*(x9604)))+(((IkReal(-1.00000000000000))*(r10)*(x9604)*(x9606)))+(((IkReal(-1.00000000000000))*(r02)*(sj0)*(x9607)))+(((cj0)*(cj5)*(r12)))+(((IkReal(-1.00000000000000))*(r11)*(x9605)*(x9606)))))+IKsqr(((((IKabs(sj1) != 0)?((IkReal)1/(sj1)):(IkReal)1.0e30))*(((((IkReal(-1.00000000000000))*(r22)*(x9607)))+(((r21)*(x9605)))+(((r20)*(x9604)))))))-1) <= IKFAST_SINCOS_THRESH )
    continue;
j3array[0]=IKatan2(((((r01)*(sj0)*(x9605)))+(((r00)*(sj0)*(x9604)))+(((IkReal(-1.00000000000000))*(r10)*(x9604)*(x9606)))+(((IkReal(-1.00000000000000))*(r02)*(sj0)*(x9607)))+(((cj0)*(cj5)*(r12)))+(((IkReal(-1.00000000000000))*(r11)*(x9605)*(x9606)))), ((((IKabs(sj1) != 0)?((IkReal)1/(sj1)):(IkReal)1.0e30))*(((((IkReal(-1.00000000000000))*(r22)*(x9607)))+(((r21)*(x9605)))+(((r20)*(x9604)))))));
sj3array[0]=IKsin(j3array[0]);
cj3array[0]=IKcos(j3array[0]);
if( j3array[0] > IKPI )
{
    j3array[0]-=IK2PI;
}
else if( j3array[0] < -IKPI )
{    j3array[0]+=IK2PI;
}
j3valid[0] = true;
for(int ij3 = 0; ij3 < 1; ++ij3)
{
if( !j3valid[ij3] )
{
    continue;
}
_ij3[0] = ij3; _ij3[1] = -1;
for(int iij3 = ij3+1; iij3 < 1; ++iij3)
{
if( j3valid[iij3] && IKabs(cj3array[ij3]-cj3array[iij3]) < IKFAST_SOLUTION_THRESH && IKabs(sj3array[ij3]-sj3array[iij3]) < IKFAST_SOLUTION_THRESH )
{
    j3valid[iij3]=false; _ij3[1] = iij3; break; 
}
}
j3 = j3array[ij3]; cj3 = cj3array[ij3]; sj3 = sj3array[ij3];
{
IkReal evalcond[6];
IkReal x9608=IKsin(j3);
IkReal x9609=IKcos(j3);
IkReal x9610=((sj0)*(sj5));
IkReal x9611=((r00)*(sj6));
IkReal x9612=((cj6)*(r01));
IkReal x9613=((cj4)*(cj5));
IkReal x9614=((IkReal(1.00000000000000))*(cj0));
IkReal x9615=((cj5)*(r12));
IkReal x9616=((IkReal(1.00000000000000))*(sj0));
IkReal x9617=((cj6)*(r11));
IkReal x9618=((cj5)*(r02));
IkReal x9619=((IkReal(1.00000000000000))*(cj1));
IkReal x9620=((cj6)*(sj4));
IkReal x9621=((cj6)*(r21));
IkReal x9622=((r20)*(sj6));
IkReal x9623=((r10)*(sj6));
IkReal x9624=((sj4)*(sj6));
IkReal x9625=((cj4)*(r02));
IkReal x9626=((IkReal(1.00000000000000))*(cj4)*(r12));
IkReal x9627=((IkReal(1.00000000000000))*(x9608));
IkReal x9628=((cj0)*(x9624));
evalcond[0]=((((sj5)*(x9621)))+(((IkReal(-1.00000000000000))*(cj5)*(r22)))+(((sj5)*(x9622)))+(((IkReal(-1.00000000000000))*(sj1)*(x9609))));
evalcond[1]=((((x9613)*(x9621)))+(((r20)*(x9620)))+(((cj4)*(r22)*(sj5)))+(((x9613)*(x9622)))+(((IkReal(-1.00000000000000))*(sj1)*(x9627)))+(((IkReal(-1.00000000000000))*(r21)*(x9624))));
evalcond[2]=((((IkReal(-1.00000000000000))*(x9616)*(x9618)))+(((x9610)*(x9611)))+(((IkReal(-1.00000000000000))*(sj5)*(x9614)*(x9617)))+(((cj0)*(x9615)))+(((IkReal(-1.00000000000000))*(sj5)*(x9614)*(x9623)))+(((x9610)*(x9612)))+(((IkReal(-1.00000000000000))*(x9627))));
evalcond[3]=((((IkReal(-1.00000000000000))*(x9609)*(x9619)))+(((cj0)*(x9618)))+(((IkReal(-1.00000000000000))*(sj5)*(x9611)*(x9614)))+(((IkReal(-1.00000000000000))*(sj5)*(x9612)*(x9614)))+(((IkReal(-1.00000000000000))*(x9610)*(x9623)))+(((sj0)*(x9615)))+(((IkReal(-1.00000000000000))*(x9610)*(x9617))));
evalcond[4]=((((x9610)*(x9625)))+(((sj0)*(x9611)*(x9613)))+(((r11)*(x9628)))+(((r00)*(sj0)*(x9620)))+(((IkReal(-1.00000000000000))*(cj4)*(r12)*(sj5)*(x9614)))+(((IkReal(-1.00000000000000))*(r01)*(x9616)*(x9624)))+(((IkReal(-1.00000000000000))*(x9613)*(x9614)*(x9617)))+(((IkReal(-1.00000000000000))*(r10)*(x9614)*(x9620)))+(((IkReal(-1.00000000000000))*(x9613)*(x9614)*(x9623)))+(((sj0)*(x9612)*(x9613)))+(x9609));
evalcond[5]=((((r11)*(sj0)*(x9624)))+(((IkReal(-1.00000000000000))*(r00)*(x9614)*(x9620)))+(((IkReal(-1.00000000000000))*(x9613)*(x9616)*(x9617)))+(((IkReal(-1.00000000000000))*(x9611)*(x9613)*(x9614)))+(((IkReal(-1.00000000000000))*(x9610)*(x9626)))+(((IkReal(-1.00000000000000))*(r10)*(x9616)*(x9620)))+(((IkReal(-1.00000000000000))*(x9613)*(x9616)*(x9623)))+(((r01)*(x9628)))+(((IkReal(-1.00000000000000))*(sj5)*(x9614)*(x9625)))+(((IkReal(-1.00000000000000))*(x9612)*(x9613)*(x9614)))+(((IkReal(-1.00000000000000))*(x9608)*(x9619))));
if( IKabs(evalcond[0]) > 0.000001  || IKabs(evalcond[1]) > 0.000001  || IKabs(evalcond[2]) > 0.000001  || IKabs(evalcond[3]) > 0.000001  || IKabs(evalcond[4]) > 0.000001  || IKabs(evalcond[5]) > 0.000001  )
{
continue;
}
}

{
std::vector<IkSingleDOFSolutionBase<IkReal> > vinfos(7);
vinfos[0].jointtype = 1;
vinfos[0].foffset = j0;
vinfos[0].indices[0] = _ij0[0];
vinfos[0].indices[1] = _ij0[1];
vinfos[0].maxsolutions = _nj0;
vinfos[1].jointtype = 1;
vinfos[1].foffset = j1;
vinfos[1].indices[0] = _ij1[0];
vinfos[1].indices[1] = _ij1[1];
vinfos[1].maxsolutions = _nj1;
vinfos[2].jointtype = 1;
vinfos[2].foffset = j2;
vinfos[2].indices[0] = _ij2[0];
vinfos[2].indices[1] = _ij2[1];
vinfos[2].maxsolutions = _nj2;
vinfos[3].jointtype = 1;
vinfos[3].foffset = j3;
vinfos[3].indices[0] = _ij3[0];
vinfos[3].indices[1] = _ij3[1];
vinfos[3].maxsolutions = _nj3;
vinfos[4].jointtype = 1;
vinfos[4].foffset = j4;
vinfos[4].indices[0] = _ij4[0];
vinfos[4].indices[1] = _ij4[1];
vinfos[4].maxsolutions = _nj4;
vinfos[5].jointtype = 1;
vinfos[5].foffset = j5;
vinfos[5].indices[0] = _ij5[0];
vinfos[5].indices[1] = _ij5[1];
vinfos[5].maxsolutions = _nj5;
vinfos[6].jointtype = 1;
vinfos[6].foffset = j6;
vinfos[6].indices[0] = _ij6[0];
vinfos[6].indices[1] = _ij6[1];
vinfos[6].maxsolutions = _nj6;
std::vector<int> vfree(0);
solutions.AddSolution(vinfos,vfree);
}
}
}

}

}

} else
{
{
IkReal j3array[1], cj3array[1], sj3array[1];
bool j3valid[1]={false};
_nj3 = 1;
IkReal x9629=((r20)*(sj6));
IkReal x9630=((cj4)*(cj5));
IkReal x9631=((cj6)*(r21));
if( IKabs(((gconst17)*(((((x9629)*(x9630)))+(((IkReal(-1.00000000000000))*(r21)*(sj4)*(sj6)))+(((x9630)*(x9631)))+(((cj6)*(r20)*(sj4)))+(((cj4)*(r22)*(sj5))))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(((gconst17)*(((((IkReal(-1.00000000000000))*(cj5)*(r22)))+(((sj5)*(x9629)))+(((sj5)*(x9631))))))) < IKFAST_ATAN2_MAGTHRESH )
    continue;
j3array[0]=IKatan2(((gconst17)*(((((x9629)*(x9630)))+(((IkReal(-1.00000000000000))*(r21)*(sj4)*(sj6)))+(((x9630)*(x9631)))+(((cj6)*(r20)*(sj4)))+(((cj4)*(r22)*(sj5)))))), ((gconst17)*(((((IkReal(-1.00000000000000))*(cj5)*(r22)))+(((sj5)*(x9629)))+(((sj5)*(x9631)))))));
sj3array[0]=IKsin(j3array[0]);
cj3array[0]=IKcos(j3array[0]);
if( j3array[0] > IKPI )
{
    j3array[0]-=IK2PI;
}
else if( j3array[0] < -IKPI )
{    j3array[0]+=IK2PI;
}
j3valid[0] = true;
for(int ij3 = 0; ij3 < 1; ++ij3)
{
if( !j3valid[ij3] )
{
    continue;
}
_ij3[0] = ij3; _ij3[1] = -1;
for(int iij3 = ij3+1; iij3 < 1; ++iij3)
{
if( j3valid[iij3] && IKabs(cj3array[ij3]-cj3array[iij3]) < IKFAST_SOLUTION_THRESH && IKabs(sj3array[ij3]-sj3array[iij3]) < IKFAST_SOLUTION_THRESH )
{
    j3valid[iij3]=false; _ij3[1] = iij3; break; 
}
}
j3 = j3array[ij3]; cj3 = cj3array[ij3]; sj3 = sj3array[ij3];
{
IkReal evalcond[6];
IkReal x9632=IKsin(j3);
IkReal x9633=IKcos(j3);
IkReal x9634=((sj0)*(sj5));
IkReal x9635=((r00)*(sj6));
IkReal x9636=((cj6)*(r01));
IkReal x9637=((cj4)*(cj5));
IkReal x9638=((IkReal(1.00000000000000))*(cj0));
IkReal x9639=((cj5)*(r12));
IkReal x9640=((IkReal(1.00000000000000))*(sj0));
IkReal x9641=((cj6)*(r11));
IkReal x9642=((cj5)*(r02));
IkReal x9643=((IkReal(1.00000000000000))*(cj1));
IkReal x9644=((cj6)*(sj4));
IkReal x9645=((cj6)*(r21));
IkReal x9646=((r20)*(sj6));
IkReal x9647=((r10)*(sj6));
IkReal x9648=((sj4)*(sj6));
IkReal x9649=((cj4)*(r02));
IkReal x9650=((IkReal(1.00000000000000))*(cj4)*(r12));
IkReal x9651=((IkReal(1.00000000000000))*(x9632));
IkReal x9652=((cj0)*(x9648));
evalcond[0]=((((IkReal(-1.00000000000000))*(sj1)*(x9633)))+(((sj5)*(x9646)))+(((sj5)*(x9645)))+(((IkReal(-1.00000000000000))*(cj5)*(r22))));
evalcond[1]=((((r20)*(x9644)))+(((cj4)*(r22)*(sj5)))+(((IkReal(-1.00000000000000))*(r21)*(x9648)))+(((x9637)*(x9645)))+(((IkReal(-1.00000000000000))*(sj1)*(x9651)))+(((x9637)*(x9646))));
evalcond[2]=((((x9634)*(x9636)))+(((IkReal(-1.00000000000000))*(x9640)*(x9642)))+(((IkReal(-1.00000000000000))*(x9651)))+(((x9634)*(x9635)))+(((IkReal(-1.00000000000000))*(sj5)*(x9638)*(x9641)))+(((cj0)*(x9639)))+(((IkReal(-1.00000000000000))*(sj5)*(x9638)*(x9647))));
evalcond[3]=((((IkReal(-1.00000000000000))*(sj5)*(x9636)*(x9638)))+(((sj0)*(x9639)))+(((IkReal(-1.00000000000000))*(sj5)*(x9635)*(x9638)))+(((IkReal(-1.00000000000000))*(x9634)*(x9647)))+(((IkReal(-1.00000000000000))*(x9633)*(x9643)))+(((IkReal(-1.00000000000000))*(x9634)*(x9641)))+(((cj0)*(x9642))));
evalcond[4]=((((IkReal(-1.00000000000000))*(x9637)*(x9638)*(x9641)))+(((IkReal(-1.00000000000000))*(x9637)*(x9638)*(x9647)))+(((IkReal(-1.00000000000000))*(r10)*(x9638)*(x9644)))+(((IkReal(-1.00000000000000))*(cj4)*(r12)*(sj5)*(x9638)))+(x9633)+(((sj0)*(x9636)*(x9637)))+(((x9634)*(x9649)))+(((r00)*(sj0)*(x9644)))+(((sj0)*(x9635)*(x9637)))+(((r11)*(x9652)))+(((IkReal(-1.00000000000000))*(r01)*(x9640)*(x9648))));
evalcond[5]=((((IkReal(-1.00000000000000))*(sj5)*(x9638)*(x9649)))+(((IkReal(-1.00000000000000))*(x9636)*(x9637)*(x9638)))+(((r01)*(x9652)))+(((IkReal(-1.00000000000000))*(x9637)*(x9640)*(x9641)))+(((IkReal(-1.00000000000000))*(x9634)*(x9650)))+(((IkReal(-1.00000000000000))*(x9637)*(x9640)*(x9647)))+(((IkReal(-1.00000000000000))*(x9635)*(x9637)*(x9638)))+(((IkReal(-1.00000000000000))*(x9632)*(x9643)))+(((IkReal(-1.00000000000000))*(r10)*(x9640)*(x9644)))+(((IkReal(-1.00000000000000))*(r00)*(x9638)*(x9644)))+(((r11)*(sj0)*(x9648))));
if( IKabs(evalcond[0]) > 0.000001  || IKabs(evalcond[1]) > 0.000001  || IKabs(evalcond[2]) > 0.000001  || IKabs(evalcond[3]) > 0.000001  || IKabs(evalcond[4]) > 0.000001  || IKabs(evalcond[5]) > 0.000001  )
{
continue;
}
}

{
std::vector<IkSingleDOFSolutionBase<IkReal> > vinfos(7);
vinfos[0].jointtype = 1;
vinfos[0].foffset = j0;
vinfos[0].indices[0] = _ij0[0];
vinfos[0].indices[1] = _ij0[1];
vinfos[0].maxsolutions = _nj0;
vinfos[1].jointtype = 1;
vinfos[1].foffset = j1;
vinfos[1].indices[0] = _ij1[0];
vinfos[1].indices[1] = _ij1[1];
vinfos[1].maxsolutions = _nj1;
vinfos[2].jointtype = 1;
vinfos[2].foffset = j2;
vinfos[2].indices[0] = _ij2[0];
vinfos[2].indices[1] = _ij2[1];
vinfos[2].maxsolutions = _nj2;
vinfos[3].jointtype = 1;
vinfos[3].foffset = j3;
vinfos[3].indices[0] = _ij3[0];
vinfos[3].indices[1] = _ij3[1];
vinfos[3].maxsolutions = _nj3;
vinfos[4].jointtype = 1;
vinfos[4].foffset = j4;
vinfos[4].indices[0] = _ij4[0];
vinfos[4].indices[1] = _ij4[1];
vinfos[4].maxsolutions = _nj4;
vinfos[5].jointtype = 1;
vinfos[5].foffset = j5;
vinfos[5].indices[0] = _ij5[0];
vinfos[5].indices[1] = _ij5[1];
vinfos[5].maxsolutions = _nj5;
vinfos[6].jointtype = 1;
vinfos[6].foffset = j6;
vinfos[6].indices[0] = _ij6[0];
vinfos[6].indices[1] = _ij6[1];
vinfos[6].maxsolutions = _nj6;
std::vector<int> vfree(0);
solutions.AddSolution(vinfos,vfree);
}
}
}

}

}
}
}

}

}

} else
{
IkReal x9653=((IkReal(0.374290000000000))*(sj5));
IkReal x9654=((cj0)*(sj6));
IkReal x9655=((IkReal(0.0100000000000000))*(sj5));
IkReal x9656=((cj0)*(r02));
IkReal x9657=((IkReal(0.0100000000000000))*(cj5));
IkReal x9658=((IkReal(1.00000000000000))*(py));
IkReal x9659=((r01)*(sj0));
IkReal x9660=((r20)*(sj6));
IkReal x9661=((r11)*(sj0));
IkReal x9662=((IkReal(0.374290000000000))*(cj5));
IkReal x9663=((cj0)*(r12));
IkReal x9664=((sj0)*(x9662));
IkReal x9665=((cj6)*(x9657));
IkReal x9666=((r10)*(sj0)*(sj6));
IkReal x9667=((r00)*(sj0)*(sj6));
IkReal x9668=((cj0)*(cj6)*(x9653));
evalcond[0]=((IkReal(-3.14159265358979))+(IKfmod(((IkReal(4.71238898038469))+(j2)), IkReal(6.28318530717959))));
evalcond[1]=((((IkReal(-1.00000000000000))*(x9657)*(x9660)))+(((IkReal(0.364420000000000))*(sj1)))+(((IkReal(-1.00000000000000))*(r22)*(x9655)))+(((IkReal(-1.00000000000000))*(r22)*(x9662)))+(pz)+(((IkReal(-1.00000000000000))*(r21)*(x9665)))+(((x9653)*(x9660)))+(((cj6)*(r21)*(x9653))));
evalcond[2]=((IkReal(-0.0690000000000000))+(((r10)*(x9654)*(x9657)))+(((cj0)*(r11)*(x9665)))+(((IkReal(-1.00000000000000))*(r02)*(sj0)*(x9655)))+(((IkReal(-1.00000000000000))*(cj0)*(x9658)))+(((IkReal(-1.00000000000000))*(x9657)*(x9667)))+(((IkReal(-1.00000000000000))*(r02)*(x9664)))+(((x9662)*(x9663)))+(((cj6)*(x9653)*(x9659)))+(((x9653)*(x9667)))+(((x9655)*(x9663)))+(((px)*(sj0)))+(((IkReal(-1.00000000000000))*(r11)*(x9668)))+(((IkReal(-1.00000000000000))*(x9659)*(x9665)))+(((IkReal(-1.00000000000000))*(r10)*(x9653)*(x9654))));
evalcond[3]=((IkReal(0.0690000000000000))+(((IkReal(-1.00000000000000))*(r00)*(x9653)*(x9654)))+(((IkReal(-1.00000000000000))*(cj0)*(px)))+(((x9655)*(x9656)))+(((IkReal(-1.00000000000000))*(x9653)*(x9666)))+(((x9656)*(x9662)))+(((cj0)*(r01)*(x9665)))+(((IkReal(-1.00000000000000))*(cj6)*(x9653)*(x9661)))+(((IkReal(-1.00000000000000))*(sj0)*(x9658)))+(((x9661)*(x9665)))+(((r12)*(sj0)*(x9655)))+(((x9657)*(x9666)))+(((IkReal(-1.00000000000000))*(r01)*(x9668)))+(((IkReal(0.364420000000000))*(cj1)))+(((r00)*(x9654)*(x9657)))+(((r12)*(x9664))));
if( IKabs(evalcond[0]) < 0.0000010000000000  && IKabs(evalcond[1]) < 0.0000010000000000  && IKabs(evalcond[2]) < 0.0000010000000000  && IKabs(evalcond[3]) < 0.0000010000000000  )
{
{
IkReal dummyeval[1];
IkReal gconst26;
IkReal x9669=(cj6)*(cj6);
IkReal x9670=(sj6)*(sj6);
IkReal x9671=((IkReal(1.00000000000000))*(r01));
IkReal x9672=((sj0)*(sj5));
IkReal x9673=((cj6)*(r22));
IkReal x9674=((r21)*(sj6));
IkReal x9675=((r00)*(r21));
IkReal x9676=((cj0)*(sj5));
IkReal x9677=((cj6)*(r20));
IkReal x9678=((r22)*(sj6));
IkReal x9679=((cj0)*(cj5));
IkReal x9680=((IkReal(1.00000000000000))*(r10));
IkReal x9681=((cj5)*(sj0));
IkReal x9682=((r20)*(x9670));
IkReal x9683=((x9669)*(x9681));
gconst26=IKsign(((((x9675)*(x9683)))+(((IkReal(-1.00000000000000))*(r02)*(x9672)*(x9677)))+(((IkReal(-1.00000000000000))*(r21)*(x9670)*(x9679)*(x9680)))+(((r02)*(x9672)*(x9674)))+(((IkReal(-1.00000000000000))*(x9671)*(x9672)*(x9678)))+(((r00)*(x9672)*(x9673)))+(((x9670)*(x9675)*(x9681)))+(((r11)*(r20)*(x9669)*(x9679)))+(((IkReal(-1.00000000000000))*(r12)*(x9674)*(x9676)))+(((IkReal(-1.00000000000000))*(r20)*(x9671)*(x9683)))+(((IkReal(-1.00000000000000))*(x9671)*(x9681)*(x9682)))+(((r12)*(x9676)*(x9677)))+(((r11)*(x9679)*(x9682)))+(((IkReal(-1.00000000000000))*(r21)*(x9669)*(x9679)*(x9680)))+(((r11)*(x9676)*(x9678)))+(((IkReal(-1.00000000000000))*(x9673)*(x9676)*(x9680)))));
IkReal x9684=(cj6)*(cj6);
IkReal x9685=(sj6)*(sj6);
IkReal x9686=((IkReal(1.00000000000000))*(r01));
IkReal x9687=((sj0)*(sj5));
IkReal x9688=((cj6)*(r22));
IkReal x9689=((r21)*(sj6));
IkReal x9690=((r00)*(r21));
IkReal x9691=((cj0)*(sj5));
IkReal x9692=((cj6)*(r20));
IkReal x9693=((r22)*(sj6));
IkReal x9694=((cj0)*(cj5));
IkReal x9695=((IkReal(1.00000000000000))*(r10));
IkReal x9696=((cj5)*(sj0));
IkReal x9697=((r20)*(x9685));
IkReal x9698=((x9684)*(x9696));
dummyeval[0]=((((r00)*(x9687)*(x9688)))+(((IkReal(-1.00000000000000))*(x9686)*(x9687)*(x9693)))+(((r11)*(x9694)*(x9697)))+(((IkReal(-1.00000000000000))*(r12)*(x9689)*(x9691)))+(((IkReal(-1.00000000000000))*(r20)*(x9686)*(x9698)))+(((IkReal(-1.00000000000000))*(x9686)*(x9696)*(x9697)))+(((r11)*(r20)*(x9684)*(x9694)))+(((IkReal(-1.00000000000000))*(r21)*(x9684)*(x9694)*(x9695)))+(((IkReal(-1.00000000000000))*(x9688)*(x9691)*(x9695)))+(((IkReal(-1.00000000000000))*(r21)*(x9685)*(x9694)*(x9695)))+(((x9690)*(x9698)))+(((r02)*(x9687)*(x9689)))+(((r11)*(x9691)*(x9693)))+(((r12)*(x9691)*(x9692)))+(((x9685)*(x9690)*(x9696)))+(((IkReal(-1.00000000000000))*(r02)*(x9687)*(x9692))));
if( IKabs(dummyeval[0]) < 0.0000010000000000  )
{
{
IkReal dummyeval[1];
IkReal gconst27;
IkReal x9699=(cj6)*(cj6);
IkReal x9700=(sj6)*(sj6);
IkReal x9701=((sj5)*(sj6));
IkReal x9702=((IkReal(1.00000000000000))*(cj0));
IkReal x9703=((cj6)*(sj5));
IkReal x9704=((r20)*(sj0));
IkReal x9705=((cj0)*(r20));
IkReal x9706=((r00)*(r21));
IkReal x9707=((r22)*(sj0));
IkReal x9708=((IkReal(1.00000000000000))*(r21)*(sj0));
IkReal x9709=((cj5)*(x9700));
IkReal x9710=((cj5)*(x9699));
gconst27=IKsign(((((IkReal(-1.00000000000000))*(r10)*(x9708)*(x9710)))+(((IkReal(-1.00000000000000))*(x9702)*(x9706)*(x9709)))+(((r02)*(x9703)*(x9705)))+(((IkReal(-1.00000000000000))*(r12)*(x9701)*(x9708)))+(((IkReal(-1.00000000000000))*(r02)*(r21)*(x9701)*(x9702)))+(((r01)*(x9705)*(x9709)))+(((r11)*(x9701)*(x9707)))+(((r12)*(x9703)*(x9704)))+(((r11)*(x9704)*(x9710)))+(((IkReal(-1.00000000000000))*(r10)*(x9703)*(x9707)))+(((IkReal(-1.00000000000000))*(x9702)*(x9706)*(x9710)))+(((IkReal(-1.00000000000000))*(r00)*(r22)*(x9702)*(x9703)))+(((r01)*(x9705)*(x9710)))+(((r11)*(x9704)*(x9709)))+(((IkReal(-1.00000000000000))*(r10)*(x9708)*(x9709)))+(((cj0)*(r01)*(r22)*(x9701)))));
IkReal x9711=(cj6)*(cj6);
IkReal x9712=(sj6)*(sj6);
IkReal x9713=((sj5)*(sj6));
IkReal x9714=((IkReal(1.00000000000000))*(cj0));
IkReal x9715=((cj6)*(sj5));
IkReal x9716=((r20)*(sj0));
IkReal x9717=((cj0)*(r20));
IkReal x9718=((r00)*(r21));
IkReal x9719=((r22)*(sj0));
IkReal x9720=((IkReal(1.00000000000000))*(r21)*(sj0));
IkReal x9721=((cj5)*(x9712));
IkReal x9722=((cj5)*(x9711));
dummyeval[0]=((((IkReal(-1.00000000000000))*(r00)*(r22)*(x9714)*(x9715)))+(((r02)*(x9715)*(x9717)))+(((IkReal(-1.00000000000000))*(r12)*(x9713)*(x9720)))+(((IkReal(-1.00000000000000))*(r10)*(x9715)*(x9719)))+(((r11)*(x9716)*(x9721)))+(((r11)*(x9716)*(x9722)))+(((r01)*(x9717)*(x9722)))+(((cj0)*(r01)*(r22)*(x9713)))+(((r11)*(x9713)*(x9719)))+(((r12)*(x9715)*(x9716)))+(((r01)*(x9717)*(x9721)))+(((IkReal(-1.00000000000000))*(x9714)*(x9718)*(x9721)))+(((IkReal(-1.00000000000000))*(r02)*(r21)*(x9713)*(x9714)))+(((IkReal(-1.00000000000000))*(r10)*(x9720)*(x9722)))+(((IkReal(-1.00000000000000))*(x9714)*(x9718)*(x9722)))+(((IkReal(-1.00000000000000))*(r10)*(x9720)*(x9721))));
if( IKabs(dummyeval[0]) < 0.0000010000000000  )
{
{
IkReal dummyeval[1];
dummyeval[0]=sj1;
if( IKabs(dummyeval[0]) < 0.0000010000000000  )
{
{
IkReal evalcond[5];
IkReal x9723=((cj5)*(r22));
IkReal x9724=((IkReal(0.374290000000000))*(sj5));
IkReal x9725=((cj0)*(sj6));
IkReal x9726=((cj6)*(r21));
IkReal x9727=((IkReal(0.0100000000000000))*(sj5));
IkReal x9728=((cj0)*(r02));
IkReal x9729=((IkReal(0.0100000000000000))*(cj5));
IkReal x9730=((IkReal(1.00000000000000))*(py));
IkReal x9731=((r01)*(sj0));
IkReal x9732=((r20)*(sj6));
IkReal x9733=((r11)*(sj0));
IkReal x9734=((IkReal(0.374290000000000))*(cj5));
IkReal x9735=((cj0)*(r12));
IkReal x9736=((sj0)*(x9734));
IkReal x9737=((cj6)*(x9729));
IkReal x9738=((r10)*(sj0)*(sj6));
IkReal x9739=((r00)*(sj0)*(sj6));
IkReal x9740=((cj0)*(cj6)*(x9724));
evalcond[0]=((IkReal(-3.14159265358979))+(IKfmod(((IkReal(3.14159265358979))+(j1)), IkReal(6.28318530717959))));
evalcond[1]=((((sj5)*(x9732)))+(((sj5)*(x9726)))+(((IkReal(-1.00000000000000))*(x9723))));
evalcond[2]=((((x9724)*(x9732)))+(((IkReal(-1.00000000000000))*(x9726)*(x9729)))+(((IkReal(-0.374290000000000))*(x9723)))+(((IkReal(-1.00000000000000))*(r22)*(x9727)))+(pz)+(((IkReal(-1.00000000000000))*(x9729)*(x9732)))+(((x9724)*(x9726))));
evalcond[3]=((IkReal(-0.0690000000000000))+(((cj0)*(r11)*(x9737)))+(((IkReal(-1.00000000000000))*(x9729)*(x9739)))+(((IkReal(-1.00000000000000))*(r02)*(sj0)*(x9727)))+(((x9734)*(x9735)))+(((x9724)*(x9739)))+(((x9727)*(x9735)))+(((IkReal(-1.00000000000000))*(r11)*(x9740)))+(((IkReal(-1.00000000000000))*(r02)*(x9736)))+(((IkReal(-1.00000000000000))*(r10)*(x9724)*(x9725)))+(((r10)*(x9725)*(x9729)))+(((px)*(sj0)))+(((IkReal(-1.00000000000000))*(x9731)*(x9737)))+(((IkReal(-1.00000000000000))*(cj0)*(x9730)))+(((cj6)*(x9724)*(x9731))));
evalcond[4]=((IkReal(0.433420000000000))+(((IkReal(-1.00000000000000))*(cj0)*(px)))+(((x9727)*(x9728)))+(((IkReal(-1.00000000000000))*(x9724)*(x9738)))+(((IkReal(-1.00000000000000))*(cj6)*(x9724)*(x9733)))+(((x9729)*(x9738)))+(((IkReal(-1.00000000000000))*(r01)*(x9740)))+(((r12)*(x9736)))+(((x9728)*(x9734)))+(((r12)*(sj0)*(x9727)))+(((IkReal(-1.00000000000000))*(r00)*(x9724)*(x9725)))+(((cj0)*(r01)*(x9737)))+(((x9733)*(x9737)))+(((IkReal(-1.00000000000000))*(sj0)*(x9730)))+(((r00)*(x9725)*(x9729))));
if( IKabs(evalcond[0]) < 0.0000010000000000  && IKabs(evalcond[1]) < 0.0000010000000000  && IKabs(evalcond[2]) < 0.0000010000000000  && IKabs(evalcond[3]) < 0.0000010000000000  && IKabs(evalcond[4]) < 0.0000010000000000  )
{
{
IkReal j3array[1], cj3array[1], sj3array[1];
bool j3valid[1]={false};
_nj3 = 1;
IkReal x9741=((cj5)*(r02));
IkReal x9742=((cj0)*(sj5));
IkReal x9743=((r10)*(sj6));
IkReal x9744=((IkReal(1.00000000000000))*(cj6));
IkReal x9745=((sj0)*(sj5));
IkReal x9746=((cj5)*(r12));
IkReal x9747=((IkReal(1.00000000000000))*(r00)*(sj6));
if( IKabs(((((IkReal(-1.00000000000000))*(x9745)*(x9747)))+(((IkReal(-1.00000000000000))*(cj0)*(x9746)))+(((cj6)*(r11)*(x9742)))+(((x9742)*(x9743)))+(((IkReal(-1.00000000000000))*(r01)*(x9744)*(x9745)))+(((sj0)*(x9741))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(((((IkReal(-1.00000000000000))*(x9742)*(x9747)))+(((cj0)*(x9741)))+(((sj0)*(x9746)))+(((IkReal(-1.00000000000000))*(r11)*(x9744)*(x9745)))+(((IkReal(-1.00000000000000))*(x9743)*(x9745)))+(((IkReal(-1.00000000000000))*(r01)*(x9742)*(x9744))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(IKsqr(((((IkReal(-1.00000000000000))*(x9745)*(x9747)))+(((IkReal(-1.00000000000000))*(cj0)*(x9746)))+(((cj6)*(r11)*(x9742)))+(((x9742)*(x9743)))+(((IkReal(-1.00000000000000))*(r01)*(x9744)*(x9745)))+(((sj0)*(x9741)))))+IKsqr(((((IkReal(-1.00000000000000))*(x9742)*(x9747)))+(((cj0)*(x9741)))+(((sj0)*(x9746)))+(((IkReal(-1.00000000000000))*(r11)*(x9744)*(x9745)))+(((IkReal(-1.00000000000000))*(x9743)*(x9745)))+(((IkReal(-1.00000000000000))*(r01)*(x9742)*(x9744)))))-1) <= IKFAST_SINCOS_THRESH )
    continue;
j3array[0]=IKatan2(((((IkReal(-1.00000000000000))*(x9745)*(x9747)))+(((IkReal(-1.00000000000000))*(cj0)*(x9746)))+(((cj6)*(r11)*(x9742)))+(((x9742)*(x9743)))+(((IkReal(-1.00000000000000))*(r01)*(x9744)*(x9745)))+(((sj0)*(x9741)))), ((((IkReal(-1.00000000000000))*(x9742)*(x9747)))+(((cj0)*(x9741)))+(((sj0)*(x9746)))+(((IkReal(-1.00000000000000))*(r11)*(x9744)*(x9745)))+(((IkReal(-1.00000000000000))*(x9743)*(x9745)))+(((IkReal(-1.00000000000000))*(r01)*(x9742)*(x9744)))));
sj3array[0]=IKsin(j3array[0]);
cj3array[0]=IKcos(j3array[0]);
if( j3array[0] > IKPI )
{
    j3array[0]-=IK2PI;
}
else if( j3array[0] < -IKPI )
{    j3array[0]+=IK2PI;
}
j3valid[0] = true;
for(int ij3 = 0; ij3 < 1; ++ij3)
{
if( !j3valid[ij3] )
{
    continue;
}
_ij3[0] = ij3; _ij3[1] = -1;
for(int iij3 = ij3+1; iij3 < 1; ++iij3)
{
if( j3valid[iij3] && IKabs(cj3array[ij3]-cj3array[iij3]) < IKFAST_SOLUTION_THRESH && IKabs(sj3array[ij3]-sj3array[iij3]) < IKFAST_SOLUTION_THRESH )
{
    j3valid[iij3]=false; _ij3[1] = iij3; break; 
}
}
j3 = j3array[ij3]; cj3 = cj3array[ij3]; sj3 = sj3array[ij3];
{
IkReal evalcond[2];
IkReal x9748=((cj0)*(cj5));
IkReal x9749=((IkReal(1.00000000000000))*(cj0));
IkReal x9750=((cj6)*(r11));
IkReal x9751=((r10)*(sj6));
IkReal x9752=((cj5)*(sj0));
IkReal x9753=((r00)*(sj5)*(sj6));
IkReal x9754=((cj6)*(r01)*(sj5));
IkReal x9755=((IkReal(1.00000000000000))*(sj0)*(sj5));
evalcond[0]=((((IkReal(-1.00000000000000))*(r02)*(x9752)))+(((sj0)*(x9753)))+(((sj0)*(x9754)))+(((IkReal(-1.00000000000000))*(sj5)*(x9749)*(x9751)))+(((IkReal(-1.00000000000000))*(sj5)*(x9749)*(x9750)))+(IKsin(j3))+(((r12)*(x9748))));
evalcond[1]=((((IkReal(-1.00000000000000))*(x9751)*(x9755)))+(((IkReal(-1.00000000000000))*(x9750)*(x9755)))+(((r12)*(x9752)))+(((IkReal(-1.00000000000000))*(IKcos(j3))))+(((IkReal(-1.00000000000000))*(x9749)*(x9753)))+(((r02)*(x9748)))+(((IkReal(-1.00000000000000))*(x9749)*(x9754))));
if( IKabs(evalcond[0]) > 0.000001  || IKabs(evalcond[1]) > 0.000001  )
{
continue;
}
}

{
IkReal dummyeval[1];
IkReal gconst33;
IkReal x9756=(r21)*(r21);
IkReal x9757=(cj5)*(cj5);
IkReal x9758=(sj6)*(sj6);
IkReal x9759=(cj6)*(cj6);
IkReal x9760=(r20)*(r20);
IkReal x9761=((cj6)*(r21));
IkReal x9762=((IkReal(2.00000000000000))*(r20)*(sj6));
IkReal x9763=((cj5)*(r22)*(sj5));
IkReal x9764=((IkReal(1.00000000000000))*(x9758));
IkReal x9765=((IkReal(1.00000000000000))*(x9759));
gconst33=IKsign(((((IkReal(-2.00000000000000))*(x9761)*(x9763)))+(((IkReal(-1.00000000000000))*(x9757)*(x9760)*(x9764)))+(((IkReal(-1.00000000000000))*((r22)*(r22))*((sj5)*(sj5))))+(((x9761)*(x9762)))+(((IkReal(-1.00000000000000))*(x9760)*(x9765)))+(((IkReal(-1.00000000000000))*(x9756)*(x9757)*(x9765)))+(((IkReal(-1.00000000000000))*(x9757)*(x9761)*(x9762)))+(((IkReal(-1.00000000000000))*(x9756)*(x9764)))+(((IkReal(-1.00000000000000))*(x9762)*(x9763)))));
IkReal x9766=(r21)*(r21);
IkReal x9767=(cj5)*(cj5);
IkReal x9768=(sj6)*(sj6);
IkReal x9769=(cj6)*(cj6);
IkReal x9770=(r20)*(r20);
IkReal x9771=((cj6)*(r21));
IkReal x9772=((IkReal(2.00000000000000))*(r20)*(sj6));
IkReal x9773=((cj5)*(r22)*(sj5));
IkReal x9774=((IkReal(1.00000000000000))*(x9768));
IkReal x9775=((IkReal(1.00000000000000))*(x9769));
dummyeval[0]=((((IkReal(-1.00000000000000))*(x9772)*(x9773)))+(((IkReal(-1.00000000000000))*((r22)*(r22))*((sj5)*(sj5))))+(((IkReal(-1.00000000000000))*(x9766)*(x9767)*(x9775)))+(((IkReal(-1.00000000000000))*(x9770)*(x9775)))+(((IkReal(-1.00000000000000))*(x9766)*(x9774)))+(((IkReal(-1.00000000000000))*(x9767)*(x9770)*(x9774)))+(((IkReal(-2.00000000000000))*(x9771)*(x9773)))+(((IkReal(-1.00000000000000))*(x9767)*(x9771)*(x9772)))+(((x9771)*(x9772))));
if( IKabs(dummyeval[0]) < 0.0000010000000000  )
{
{
IkReal dummyeval[1];
IkReal gconst34;
IkReal x9776=(cj6)*(cj6);
IkReal x9777=(sj6)*(sj6);
IkReal x9778=((IkReal(1.00000000000000))*(r01));
IkReal x9779=((sj0)*(sj5));
IkReal x9780=((cj6)*(r22));
IkReal x9781=((r21)*(sj6));
IkReal x9782=((r00)*(r21));
IkReal x9783=((cj0)*(sj5));
IkReal x9784=((cj6)*(r20));
IkReal x9785=((r22)*(sj6));
IkReal x9786=((cj0)*(cj5));
IkReal x9787=((IkReal(1.00000000000000))*(r10));
IkReal x9788=((cj5)*(sj0));
IkReal x9789=((r20)*(x9777));
IkReal x9790=((x9776)*(x9788));
gconst34=IKsign(((((r00)*(x9779)*(x9780)))+(((r11)*(r20)*(x9776)*(x9786)))+(((r12)*(x9783)*(x9784)))+(((IkReal(-1.00000000000000))*(r21)*(x9777)*(x9786)*(x9787)))+(((IkReal(-1.00000000000000))*(x9780)*(x9783)*(x9787)))+(((IkReal(-1.00000000000000))*(x9778)*(x9788)*(x9789)))+(((r02)*(x9779)*(x9781)))+(((IkReal(-1.00000000000000))*(r20)*(x9778)*(x9790)))+(((r11)*(x9786)*(x9789)))+(((IkReal(-1.00000000000000))*(r12)*(x9781)*(x9783)))+(((IkReal(-1.00000000000000))*(x9778)*(x9779)*(x9785)))+(((x9777)*(x9782)*(x9788)))+(((r11)*(x9783)*(x9785)))+(((IkReal(-1.00000000000000))*(r21)*(x9776)*(x9786)*(x9787)))+(((x9782)*(x9790)))+(((IkReal(-1.00000000000000))*(r02)*(x9779)*(x9784)))));
IkReal x9791=(cj6)*(cj6);
IkReal x9792=(sj6)*(sj6);
IkReal x9793=((IkReal(1.00000000000000))*(r01));
IkReal x9794=((sj0)*(sj5));
IkReal x9795=((cj6)*(r22));
IkReal x9796=((r21)*(sj6));
IkReal x9797=((r00)*(r21));
IkReal x9798=((cj0)*(sj5));
IkReal x9799=((cj6)*(r20));
IkReal x9800=((r22)*(sj6));
IkReal x9801=((cj0)*(cj5));
IkReal x9802=((IkReal(1.00000000000000))*(r10));
IkReal x9803=((cj5)*(sj0));
IkReal x9804=((r20)*(x9792));
IkReal x9805=((x9791)*(x9803));
dummyeval[0]=((((r12)*(x9798)*(x9799)))+(((r00)*(x9794)*(x9795)))+(((r11)*(x9801)*(x9804)))+(((IkReal(-1.00000000000000))*(r21)*(x9791)*(x9801)*(x9802)))+(((IkReal(-1.00000000000000))*(r20)*(x9793)*(x9805)))+(((r11)*(x9798)*(x9800)))+(((IkReal(-1.00000000000000))*(x9793)*(x9794)*(x9800)))+(((x9797)*(x9805)))+(((IkReal(-1.00000000000000))*(r12)*(x9796)*(x9798)))+(((r11)*(r20)*(x9791)*(x9801)))+(((IkReal(-1.00000000000000))*(r21)*(x9792)*(x9801)*(x9802)))+(((IkReal(-1.00000000000000))*(x9795)*(x9798)*(x9802)))+(((x9792)*(x9797)*(x9803)))+(((r02)*(x9794)*(x9796)))+(((IkReal(-1.00000000000000))*(x9793)*(x9803)*(x9804)))+(((IkReal(-1.00000000000000))*(r02)*(x9794)*(x9799))));
if( IKabs(dummyeval[0]) < 0.0000010000000000  )
{
continue;

} else
{
{
IkReal j4array[1], cj4array[1], sj4array[1];
bool j4valid[1]={false};
_nj4 = 1;
IkReal x9806=((sj0)*(sj6));
IkReal x9807=((cj0)*(r10));
IkReal x9808=((IkReal(1.00000000000000))*(cj5));
IkReal x9809=((cj6)*(sj0));
IkReal x9810=((cj0)*(r11));
if( IKabs(((gconst34)*(((((cj6)*(x9807)))+(((IkReal(-1.00000000000000))*(sj6)*(x9810)))+(((IkReal(-1.00000000000000))*(r00)*(x9809)))+(((r01)*(x9806))))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(((gconst34)*(((((IkReal(-1.00000000000000))*(r00)*(x9806)*(x9808)))+(((cj5)*(sj6)*(x9807)))+(((IkReal(-1.00000000000000))*(r01)*(x9808)*(x9809)))+(((cj0)*(r12)*(sj5)))+(((IkReal(-1.00000000000000))*(r02)*(sj0)*(sj5)))+(((cj5)*(cj6)*(x9810))))))) < IKFAST_ATAN2_MAGTHRESH )
    continue;
j4array[0]=IKatan2(((gconst34)*(((((cj6)*(x9807)))+(((IkReal(-1.00000000000000))*(sj6)*(x9810)))+(((IkReal(-1.00000000000000))*(r00)*(x9809)))+(((r01)*(x9806)))))), ((gconst34)*(((((IkReal(-1.00000000000000))*(r00)*(x9806)*(x9808)))+(((cj5)*(sj6)*(x9807)))+(((IkReal(-1.00000000000000))*(r01)*(x9808)*(x9809)))+(((cj0)*(r12)*(sj5)))+(((IkReal(-1.00000000000000))*(r02)*(sj0)*(sj5)))+(((cj5)*(cj6)*(x9810)))))));
sj4array[0]=IKsin(j4array[0]);
cj4array[0]=IKcos(j4array[0]);
if( j4array[0] > IKPI )
{
    j4array[0]-=IK2PI;
}
else if( j4array[0] < -IKPI )
{    j4array[0]+=IK2PI;
}
j4valid[0] = true;
for(int ij4 = 0; ij4 < 1; ++ij4)
{
if( !j4valid[ij4] )
{
    continue;
}
_ij4[0] = ij4; _ij4[1] = -1;
for(int iij4 = ij4+1; iij4 < 1; ++iij4)
{
if( j4valid[iij4] && IKabs(cj4array[ij4]-cj4array[iij4]) < IKFAST_SOLUTION_THRESH && IKabs(sj4array[ij4]-sj4array[iij4]) < IKFAST_SOLUTION_THRESH )
{
    j4valid[iij4]=false; _ij4[1] = iij4; break; 
}
}
j4 = j4array[ij4]; cj4 = cj4array[ij4]; sj4 = sj4array[ij4];
{
IkReal evalcond[6];
IkReal x9811=IKsin(j4);
IkReal x9812=IKcos(j4);
IkReal x9813=((r22)*(sj5));
IkReal x9814=((IkReal(1.00000000000000))*(cj6));
IkReal x9815=((IkReal(1.00000000000000))*(cj0));
IkReal x9816=((cj5)*(r11));
IkReal x9817=((cj5)*(cj6));
IkReal x9818=((r11)*(sj6));
IkReal x9819=((IkReal(1.00000000000000))*(sj6));
IkReal x9820=((cj6)*(r00));
IkReal x9821=((r12)*(sj5));
IkReal x9822=((r02)*(sj5));
IkReal x9823=((cj6)*(r10));
IkReal x9824=((cj5)*(sj6));
IkReal x9825=((cj5)*(r01));
IkReal x9826=((sj0)*(x9811));
IkReal x9827=((r00)*(x9824));
IkReal x9828=((cj0)*(x9811));
IkReal x9829=((sj0)*(x9812));
IkReal x9830=((r20)*(x9812));
IkReal x9831=((cj0)*(x9812));
IkReal x9832=((r21)*(x9811));
IkReal x9833=((r21)*(x9812));
IkReal x9834=((r20)*(x9811));
IkReal x9835=((x9812)*(x9821));
IkReal x9836=((r01)*(sj6)*(x9812));
IkReal x9837=((cj5)*(r10)*(x9819));
evalcond[0]=((IkReal(1.00000000000000))+(((sj6)*(x9833)))+(((x9811)*(x9813)))+(((x9824)*(x9834)))+(((IkReal(-1.00000000000000))*(x9814)*(x9830)))+(((x9817)*(x9832))));
evalcond[1]=((((IkReal(-1.00000000000000))*(x9819)*(x9832)))+(((cj6)*(x9834)))+(((x9817)*(x9833)))+(((x9812)*(x9813)))+(((x9824)*(x9830))));
evalcond[2]=((((IkReal(-1.00000000000000))*(r10)*(x9811)*(x9815)*(x9824)))+(((IkReal(-1.00000000000000))*(r00)*(x9814)*(x9829)))+(((x9826)*(x9827)))+(((IkReal(-1.00000000000000))*(x9814)*(x9816)*(x9828)))+(((r01)*(sj6)*(x9829)))+(((r01)*(x9817)*(x9826)))+(((x9822)*(x9826)))+(((IkReal(-1.00000000000000))*(x9812)*(x9815)*(x9818)))+(((IkReal(-1.00000000000000))*(x9811)*(x9815)*(x9821)))+(((x9823)*(x9831))));
evalcond[3]=((((x9820)*(x9826)))+(((IkReal(-1.00000000000000))*(r01)*(x9819)*(x9826)))+(((r01)*(x9817)*(x9829)))+(((IkReal(-1.00000000000000))*(r10)*(x9812)*(x9815)*(x9824)))+(((x9822)*(x9829)))+(((IkReal(-1.00000000000000))*(x9814)*(x9816)*(x9831)))+(((IkReal(-1.00000000000000))*(r10)*(x9814)*(x9828)))+(((x9827)*(x9829)))+(((IkReal(-1.00000000000000))*(cj3)))+(((x9818)*(x9828)))+(((IkReal(-1.00000000000000))*(x9815)*(x9835))));
evalcond[4]=((((x9820)*(x9831)))+(((IkReal(-1.00000000000000))*(x9814)*(x9816)*(x9826)))+(((IkReal(-1.00000000000000))*(x9811)*(x9815)*(x9822)))+(((IkReal(-1.00000000000000))*(x9818)*(x9829)))+(((IkReal(-1.00000000000000))*(x9821)*(x9826)))+(((x9823)*(x9829)))+(((IkReal(-1.00000000000000))*(x9814)*(x9825)*(x9828)))+(((IkReal(-1.00000000000000))*(x9815)*(x9836)))+(((IkReal(-1.00000000000000))*(x9826)*(x9837)))+(((IkReal(-1.00000000000000))*(x9811)*(x9815)*(x9827))));
evalcond[5]=((((r01)*(sj6)*(x9828)))+(((IkReal(-1.00000000000000))*(r10)*(x9814)*(x9826)))+(((IkReal(-1.00000000000000))*(x9812)*(x9815)*(x9822)))+(((IkReal(-1.00000000000000))*(x9812)*(x9815)*(x9827)))+(((IkReal(-1.00000000000000))*(x9814)*(x9816)*(x9829)))+(((IkReal(-1.00000000000000))*(x9821)*(x9829)))+(((x9818)*(x9826)))+(((IkReal(-1.00000000000000))*(sj3)))+(((IkReal(-1.00000000000000))*(x9829)*(x9837)))+(((IkReal(-1.00000000000000))*(x9814)*(x9825)*(x9831)))+(((IkReal(-1.00000000000000))*(r00)*(x9814)*(x9828))));
if( IKabs(evalcond[0]) > 0.000001  || IKabs(evalcond[1]) > 0.000001  || IKabs(evalcond[2]) > 0.000001  || IKabs(evalcond[3]) > 0.000001  || IKabs(evalcond[4]) > 0.000001  || IKabs(evalcond[5]) > 0.000001  )
{
continue;
}
}

{
std::vector<IkSingleDOFSolutionBase<IkReal> > vinfos(7);
vinfos[0].jointtype = 1;
vinfos[0].foffset = j0;
vinfos[0].indices[0] = _ij0[0];
vinfos[0].indices[1] = _ij0[1];
vinfos[0].maxsolutions = _nj0;
vinfos[1].jointtype = 1;
vinfos[1].foffset = j1;
vinfos[1].indices[0] = _ij1[0];
vinfos[1].indices[1] = _ij1[1];
vinfos[1].maxsolutions = _nj1;
vinfos[2].jointtype = 1;
vinfos[2].foffset = j2;
vinfos[2].indices[0] = _ij2[0];
vinfos[2].indices[1] = _ij2[1];
vinfos[2].maxsolutions = _nj2;
vinfos[3].jointtype = 1;
vinfos[3].foffset = j3;
vinfos[3].indices[0] = _ij3[0];
vinfos[3].indices[1] = _ij3[1];
vinfos[3].maxsolutions = _nj3;
vinfos[4].jointtype = 1;
vinfos[4].foffset = j4;
vinfos[4].indices[0] = _ij4[0];
vinfos[4].indices[1] = _ij4[1];
vinfos[4].maxsolutions = _nj4;
vinfos[5].jointtype = 1;
vinfos[5].foffset = j5;
vinfos[5].indices[0] = _ij5[0];
vinfos[5].indices[1] = _ij5[1];
vinfos[5].maxsolutions = _nj5;
vinfos[6].jointtype = 1;
vinfos[6].foffset = j6;
vinfos[6].indices[0] = _ij6[0];
vinfos[6].indices[1] = _ij6[1];
vinfos[6].maxsolutions = _nj6;
std::vector<int> vfree(0);
solutions.AddSolution(vinfos,vfree);
}
}
}

}

}

} else
{
{
IkReal j4array[1], cj4array[1], sj4array[1];
bool j4valid[1]={false};
_nj4 = 1;
if( IKabs(((gconst33)*(((((cj5)*(r20)*(sj6)))+(((r22)*(sj5)))+(((cj5)*(cj6)*(r21))))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(((gconst33)*(((((r21)*(sj6)))+(((IkReal(-1.00000000000000))*(cj6)*(r20))))))) < IKFAST_ATAN2_MAGTHRESH )
    continue;
j4array[0]=IKatan2(((gconst33)*(((((cj5)*(r20)*(sj6)))+(((r22)*(sj5)))+(((cj5)*(cj6)*(r21)))))), ((gconst33)*(((((r21)*(sj6)))+(((IkReal(-1.00000000000000))*(cj6)*(r20)))))));
sj4array[0]=IKsin(j4array[0]);
cj4array[0]=IKcos(j4array[0]);
if( j4array[0] > IKPI )
{
    j4array[0]-=IK2PI;
}
else if( j4array[0] < -IKPI )
{    j4array[0]+=IK2PI;
}
j4valid[0] = true;
for(int ij4 = 0; ij4 < 1; ++ij4)
{
if( !j4valid[ij4] )
{
    continue;
}
_ij4[0] = ij4; _ij4[1] = -1;
for(int iij4 = ij4+1; iij4 < 1; ++iij4)
{
if( j4valid[iij4] && IKabs(cj4array[ij4]-cj4array[iij4]) < IKFAST_SOLUTION_THRESH && IKabs(sj4array[ij4]-sj4array[iij4]) < IKFAST_SOLUTION_THRESH )
{
    j4valid[iij4]=false; _ij4[1] = iij4; break; 
}
}
j4 = j4array[ij4]; cj4 = cj4array[ij4]; sj4 = sj4array[ij4];
{
IkReal evalcond[6];
IkReal x9838=IKsin(j4);
IkReal x9839=IKcos(j4);
IkReal x9840=((r22)*(sj5));
IkReal x9841=((IkReal(1.00000000000000))*(cj6));
IkReal x9842=((IkReal(1.00000000000000))*(cj0));
IkReal x9843=((cj5)*(r11));
IkReal x9844=((cj5)*(cj6));
IkReal x9845=((r11)*(sj6));
IkReal x9846=((IkReal(1.00000000000000))*(sj6));
IkReal x9847=((cj6)*(r00));
IkReal x9848=((r12)*(sj5));
IkReal x9849=((r02)*(sj5));
IkReal x9850=((cj6)*(r10));
IkReal x9851=((cj5)*(sj6));
IkReal x9852=((cj5)*(r01));
IkReal x9853=((sj0)*(x9838));
IkReal x9854=((r00)*(x9851));
IkReal x9855=((cj0)*(x9838));
IkReal x9856=((sj0)*(x9839));
IkReal x9857=((r20)*(x9839));
IkReal x9858=((cj0)*(x9839));
IkReal x9859=((r21)*(x9838));
IkReal x9860=((r21)*(x9839));
IkReal x9861=((r20)*(x9838));
IkReal x9862=((x9839)*(x9848));
IkReal x9863=((r01)*(sj6)*(x9839));
IkReal x9864=((cj5)*(r10)*(x9846));
evalcond[0]=((IkReal(1.00000000000000))+(((sj6)*(x9860)))+(((x9838)*(x9840)))+(((IkReal(-1.00000000000000))*(x9841)*(x9857)))+(((x9844)*(x9859)))+(((x9851)*(x9861))));
evalcond[1]=((((x9844)*(x9860)))+(((cj6)*(x9861)))+(((x9839)*(x9840)))+(((IkReal(-1.00000000000000))*(x9846)*(x9859)))+(((x9851)*(x9857))));
evalcond[2]=((((x9850)*(x9858)))+(((r01)*(x9844)*(x9853)))+(((r01)*(sj6)*(x9856)))+(((IkReal(-1.00000000000000))*(x9838)*(x9842)*(x9848)))+(((x9849)*(x9853)))+(((IkReal(-1.00000000000000))*(r00)*(x9841)*(x9856)))+(((IkReal(-1.00000000000000))*(r10)*(x9838)*(x9842)*(x9851)))+(((IkReal(-1.00000000000000))*(x9839)*(x9842)*(x9845)))+(((IkReal(-1.00000000000000))*(x9841)*(x9843)*(x9855)))+(((x9853)*(x9854))));
evalcond[3]=((((IkReal(-1.00000000000000))*(x9841)*(x9843)*(x9858)))+(((x9845)*(x9855)))+(((IkReal(-1.00000000000000))*(r01)*(x9846)*(x9853)))+(((IkReal(-1.00000000000000))*(x9842)*(x9862)))+(((x9849)*(x9856)))+(((IkReal(-1.00000000000000))*(r10)*(x9839)*(x9842)*(x9851)))+(((IkReal(-1.00000000000000))*(cj3)))+(((x9847)*(x9853)))+(((r01)*(x9844)*(x9856)))+(((x9854)*(x9856)))+(((IkReal(-1.00000000000000))*(r10)*(x9841)*(x9855))));
evalcond[4]=((((IkReal(-1.00000000000000))*(x9838)*(x9842)*(x9854)))+(((x9850)*(x9856)))+(((IkReal(-1.00000000000000))*(x9841)*(x9852)*(x9855)))+(((IkReal(-1.00000000000000))*(x9845)*(x9856)))+(((IkReal(-1.00000000000000))*(x9842)*(x9863)))+(((IkReal(-1.00000000000000))*(x9848)*(x9853)))+(((x9847)*(x9858)))+(((IkReal(-1.00000000000000))*(x9841)*(x9843)*(x9853)))+(((IkReal(-1.00000000000000))*(x9838)*(x9842)*(x9849)))+(((IkReal(-1.00000000000000))*(x9853)*(x9864))));
evalcond[5]=((((IkReal(-1.00000000000000))*(x9839)*(x9842)*(x9849)))+(((IkReal(-1.00000000000000))*(x9856)*(x9864)))+(((IkReal(-1.00000000000000))*(x9841)*(x9843)*(x9856)))+(((IkReal(-1.00000000000000))*(x9848)*(x9856)))+(((IkReal(-1.00000000000000))*(x9841)*(x9852)*(x9858)))+(((IkReal(-1.00000000000000))*(x9839)*(x9842)*(x9854)))+(((IkReal(-1.00000000000000))*(sj3)))+(((r01)*(sj6)*(x9855)))+(((IkReal(-1.00000000000000))*(r10)*(x9841)*(x9853)))+(((IkReal(-1.00000000000000))*(r00)*(x9841)*(x9855)))+(((x9845)*(x9853))));
if( IKabs(evalcond[0]) > 0.000001  || IKabs(evalcond[1]) > 0.000001  || IKabs(evalcond[2]) > 0.000001  || IKabs(evalcond[3]) > 0.000001  || IKabs(evalcond[4]) > 0.000001  || IKabs(evalcond[5]) > 0.000001  )
{
continue;
}
}

{
std::vector<IkSingleDOFSolutionBase<IkReal> > vinfos(7);
vinfos[0].jointtype = 1;
vinfos[0].foffset = j0;
vinfos[0].indices[0] = _ij0[0];
vinfos[0].indices[1] = _ij0[1];
vinfos[0].maxsolutions = _nj0;
vinfos[1].jointtype = 1;
vinfos[1].foffset = j1;
vinfos[1].indices[0] = _ij1[0];
vinfos[1].indices[1] = _ij1[1];
vinfos[1].maxsolutions = _nj1;
vinfos[2].jointtype = 1;
vinfos[2].foffset = j2;
vinfos[2].indices[0] = _ij2[0];
vinfos[2].indices[1] = _ij2[1];
vinfos[2].maxsolutions = _nj2;
vinfos[3].jointtype = 1;
vinfos[3].foffset = j3;
vinfos[3].indices[0] = _ij3[0];
vinfos[3].indices[1] = _ij3[1];
vinfos[3].maxsolutions = _nj3;
vinfos[4].jointtype = 1;
vinfos[4].foffset = j4;
vinfos[4].indices[0] = _ij4[0];
vinfos[4].indices[1] = _ij4[1];
vinfos[4].maxsolutions = _nj4;
vinfos[5].jointtype = 1;
vinfos[5].foffset = j5;
vinfos[5].indices[0] = _ij5[0];
vinfos[5].indices[1] = _ij5[1];
vinfos[5].maxsolutions = _nj5;
vinfos[6].jointtype = 1;
vinfos[6].foffset = j6;
vinfos[6].indices[0] = _ij6[0];
vinfos[6].indices[1] = _ij6[1];
vinfos[6].maxsolutions = _nj6;
std::vector<int> vfree(0);
solutions.AddSolution(vinfos,vfree);
}
}
}

}

}
}
}

} else
{
IkReal x9865=((cj5)*(r22));
IkReal x9866=((IkReal(0.374290000000000))*(sj5));
IkReal x9867=((cj0)*(sj6));
IkReal x9868=((cj6)*(r21));
IkReal x9869=((IkReal(0.0100000000000000))*(sj5));
IkReal x9870=((cj0)*(r02));
IkReal x9871=((IkReal(0.0100000000000000))*(cj5));
IkReal x9872=((IkReal(1.00000000000000))*(py));
IkReal x9873=((r01)*(sj0));
IkReal x9874=((r20)*(sj6));
IkReal x9875=((r11)*(sj0));
IkReal x9876=((IkReal(0.374290000000000))*(cj5));
IkReal x9877=((cj0)*(r12));
IkReal x9878=((sj0)*(x9876));
IkReal x9879=((cj6)*(x9871));
IkReal x9880=((r10)*(sj0)*(sj6));
IkReal x9881=((r00)*(sj0)*(sj6));
IkReal x9882=((cj0)*(cj6)*(x9866));
evalcond[0]=((IkReal(-3.14159265358979))+(IKfmod(j1, IkReal(6.28318530717959))));
evalcond[1]=((((IkReal(-1.00000000000000))*(x9865)))+(((sj5)*(x9868)))+(((sj5)*(x9874))));
evalcond[2]=((((IkReal(-1.00000000000000))*(x9868)*(x9871)))+(((IkReal(-0.374290000000000))*(x9865)))+(((IkReal(-1.00000000000000))*(r22)*(x9869)))+(((x9866)*(x9868)))+(((x9866)*(x9874)))+(((IkReal(-1.00000000000000))*(x9871)*(x9874)))+(pz));
evalcond[3]=((IkReal(-0.0690000000000000))+(((IkReal(-1.00000000000000))*(x9873)*(x9879)))+(((r10)*(x9867)*(x9871)))+(((cj6)*(x9866)*(x9873)))+(((IkReal(-1.00000000000000))*(x9871)*(x9881)))+(((IkReal(-1.00000000000000))*(r10)*(x9866)*(x9867)))+(((IkReal(-1.00000000000000))*(cj0)*(x9872)))+(((IkReal(-1.00000000000000))*(r02)*(x9878)))+(((x9866)*(x9881)))+(((cj0)*(r11)*(x9879)))+(((x9876)*(x9877)))+(((x9869)*(x9877)))+(((IkReal(-1.00000000000000))*(r11)*(x9882)))+(((px)*(sj0)))+(((IkReal(-1.00000000000000))*(r02)*(sj0)*(x9869))));
evalcond[4]=((IkReal(-0.295420000000000))+(((r00)*(x9867)*(x9871)))+(((x9875)*(x9879)))+(((IkReal(-1.00000000000000))*(cj0)*(px)))+(((x9870)*(x9876)))+(((IkReal(-1.00000000000000))*(r01)*(x9882)))+(((IkReal(-1.00000000000000))*(x9866)*(x9880)))+(((r12)*(sj0)*(x9869)))+(((x9869)*(x9870)))+(((cj0)*(r01)*(x9879)))+(((IkReal(-1.00000000000000))*(sj0)*(x9872)))+(((IkReal(-1.00000000000000))*(r00)*(x9866)*(x9867)))+(((x9871)*(x9880)))+(((r12)*(x9878)))+(((IkReal(-1.00000000000000))*(cj6)*(x9866)*(x9875))));
if( IKabs(evalcond[0]) < 0.0000010000000000  && IKabs(evalcond[1]) < 0.0000010000000000  && IKabs(evalcond[2]) < 0.0000010000000000  && IKabs(evalcond[3]) < 0.0000010000000000  && IKabs(evalcond[4]) < 0.0000010000000000  )
{
{
IkReal j3array[1], cj3array[1], sj3array[1];
bool j3valid[1]={false};
_nj3 = 1;
IkReal x9883=((IkReal(1.00000000000000))*(cj5));
IkReal x9884=((r10)*(sj5)*(sj6));
IkReal x9885=((cj6)*(sj0)*(sj5));
IkReal x9886=((r00)*(sj5)*(sj6));
IkReal x9887=((cj0)*(cj6)*(sj5));
if( IKabs(((((IkReal(-1.00000000000000))*(cj0)*(r12)*(x9883)))+(((cj0)*(x9884)))+(((cj5)*(r02)*(sj0)))+(((IkReal(-1.00000000000000))*(r01)*(x9885)))+(((IkReal(-1.00000000000000))*(sj0)*(x9886)))+(((r11)*(x9887))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(((((r11)*(x9885)))+(((r01)*(x9887)))+(((sj0)*(x9884)))+(((IkReal(-1.00000000000000))*(cj0)*(r02)*(x9883)))+(((cj0)*(x9886)))+(((IkReal(-1.00000000000000))*(r12)*(sj0)*(x9883))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(IKsqr(((((IkReal(-1.00000000000000))*(cj0)*(r12)*(x9883)))+(((cj0)*(x9884)))+(((cj5)*(r02)*(sj0)))+(((IkReal(-1.00000000000000))*(r01)*(x9885)))+(((IkReal(-1.00000000000000))*(sj0)*(x9886)))+(((r11)*(x9887)))))+IKsqr(((((r11)*(x9885)))+(((r01)*(x9887)))+(((sj0)*(x9884)))+(((IkReal(-1.00000000000000))*(cj0)*(r02)*(x9883)))+(((cj0)*(x9886)))+(((IkReal(-1.00000000000000))*(r12)*(sj0)*(x9883)))))-1) <= IKFAST_SINCOS_THRESH )
    continue;
j3array[0]=IKatan2(((((IkReal(-1.00000000000000))*(cj0)*(r12)*(x9883)))+(((cj0)*(x9884)))+(((cj5)*(r02)*(sj0)))+(((IkReal(-1.00000000000000))*(r01)*(x9885)))+(((IkReal(-1.00000000000000))*(sj0)*(x9886)))+(((r11)*(x9887)))), ((((r11)*(x9885)))+(((r01)*(x9887)))+(((sj0)*(x9884)))+(((IkReal(-1.00000000000000))*(cj0)*(r02)*(x9883)))+(((cj0)*(x9886)))+(((IkReal(-1.00000000000000))*(r12)*(sj0)*(x9883)))));
sj3array[0]=IKsin(j3array[0]);
cj3array[0]=IKcos(j3array[0]);
if( j3array[0] > IKPI )
{
    j3array[0]-=IK2PI;
}
else if( j3array[0] < -IKPI )
{    j3array[0]+=IK2PI;
}
j3valid[0] = true;
for(int ij3 = 0; ij3 < 1; ++ij3)
{
if( !j3valid[ij3] )
{
    continue;
}
_ij3[0] = ij3; _ij3[1] = -1;
for(int iij3 = ij3+1; iij3 < 1; ++iij3)
{
if( j3valid[iij3] && IKabs(cj3array[ij3]-cj3array[iij3]) < IKFAST_SOLUTION_THRESH && IKabs(sj3array[ij3]-sj3array[iij3]) < IKFAST_SOLUTION_THRESH )
{
    j3valid[iij3]=false; _ij3[1] = iij3; break; 
}
}
j3 = j3array[ij3]; cj3 = cj3array[ij3]; sj3 = sj3array[ij3];
{
IkReal evalcond[2];
IkReal x9888=((cj0)*(cj5));
IkReal x9889=((IkReal(1.00000000000000))*(cj0));
IkReal x9890=((cj6)*(r11));
IkReal x9891=((r10)*(sj6));
IkReal x9892=((cj5)*(sj0));
IkReal x9893=((r00)*(sj5)*(sj6));
IkReal x9894=((cj6)*(r01)*(sj5));
IkReal x9895=((IkReal(1.00000000000000))*(sj0)*(sj5));
evalcond[0]=((((sj0)*(x9893)))+(((IkReal(-1.00000000000000))*(sj5)*(x9889)*(x9891)))+(((r12)*(x9888)))+(((sj0)*(x9894)))+(((IkReal(-1.00000000000000))*(sj5)*(x9889)*(x9890)))+(IKsin(j3))+(((IkReal(-1.00000000000000))*(r02)*(x9892))));
evalcond[1]=((((IkReal(-1.00000000000000))*(x9890)*(x9895)))+(((IkReal(-1.00000000000000))*(x9891)*(x9895)))+(((IkReal(-1.00000000000000))*(x9889)*(x9893)))+(((r02)*(x9888)))+(((r12)*(x9892)))+(IKcos(j3))+(((IkReal(-1.00000000000000))*(x9889)*(x9894))));
if( IKabs(evalcond[0]) > 0.000001  || IKabs(evalcond[1]) > 0.000001  )
{
continue;
}
}

{
IkReal dummyeval[1];
IkReal gconst37;
IkReal x9896=(cj5)*(cj5);
IkReal x9897=(r20)*(r20);
IkReal x9898=(sj6)*(sj6);
IkReal x9899=(cj6)*(cj6);
IkReal x9900=(r21)*(r21);
IkReal x9901=((cj6)*(r21));
IkReal x9902=((IkReal(2.00000000000000))*(r20)*(sj6));
IkReal x9903=((cj5)*(r22)*(sj5));
gconst37=IKsign(((((x9896)*(x9899)*(x9900)))+(((x9896)*(x9897)*(x9898)))+((((r22)*(r22))*((sj5)*(sj5))))+(((x9902)*(x9903)))+(((x9898)*(x9900)))+(((IkReal(-1.00000000000000))*(x9901)*(x9902)))+(((IkReal(2.00000000000000))*(x9901)*(x9903)))+(((x9897)*(x9899)))+(((x9896)*(x9901)*(x9902)))));
IkReal x9904=(cj5)*(cj5);
IkReal x9905=(r20)*(r20);
IkReal x9906=(sj6)*(sj6);
IkReal x9907=(cj6)*(cj6);
IkReal x9908=(r21)*(r21);
IkReal x9909=((cj6)*(r21));
IkReal x9910=((IkReal(2.00000000000000))*(r20)*(sj6));
IkReal x9911=((cj5)*(r22)*(sj5));
dummyeval[0]=((((x9906)*(x9908)))+(((x9904)*(x9905)*(x9906)))+(((IkReal(-1.00000000000000))*(x9909)*(x9910)))+((((r22)*(r22))*((sj5)*(sj5))))+(((x9910)*(x9911)))+(((IkReal(2.00000000000000))*(x9909)*(x9911)))+(((x9905)*(x9907)))+(((x9904)*(x9907)*(x9908)))+(((x9904)*(x9909)*(x9910))));
if( IKabs(dummyeval[0]) < 0.0000010000000000  )
{
{
IkReal dummyeval[1];
IkReal gconst38;
IkReal x9912=(cj6)*(cj6);
IkReal x9913=(sj6)*(sj6);
IkReal x9914=((IkReal(1.00000000000000))*(r21));
IkReal x9915=((cj6)*(r20));
IkReal x9916=((r22)*(sj5));
IkReal x9917=((r01)*(sj0));
IkReal x9918=((r00)*(sj0));
IkReal x9919=((cj0)*(r10));
IkReal x9920=((r02)*(sj0)*(sj5));
IkReal x9921=((cj5)*(x9912));
IkReal x9922=((cj0)*(r12)*(sj5));
IkReal x9923=((IkReal(1.00000000000000))*(cj0)*(r11));
IkReal x9924=((cj5)*(x9913));
IkReal x9925=((r20)*(x9924));
gconst38=IKsign(((((IkReal(-1.00000000000000))*(x9923)*(x9925)))+(((IkReal(-1.00000000000000))*(x9915)*(x9922)))+(((IkReal(-1.00000000000000))*(sj6)*(x9916)*(x9923)))+(((r21)*(x9919)*(x9921)))+(((cj6)*(x9916)*(x9919)))+(((IkReal(-1.00000000000000))*(x9914)*(x9918)*(x9924)))+(((IkReal(-1.00000000000000))*(r20)*(x9921)*(x9923)))+(((x9915)*(x9920)))+(((IkReal(-1.00000000000000))*(sj6)*(x9914)*(x9920)))+(((r21)*(x9919)*(x9924)))+(((sj6)*(x9916)*(x9917)))+(((r20)*(x9917)*(x9921)))+(((r21)*(sj6)*(x9922)))+(((x9917)*(x9925)))+(((IkReal(-1.00000000000000))*(cj6)*(x9916)*(x9918)))+(((IkReal(-1.00000000000000))*(x9914)*(x9918)*(x9921)))));
IkReal x9926=(cj6)*(cj6);
IkReal x9927=(sj6)*(sj6);
IkReal x9928=((IkReal(1.00000000000000))*(r21));
IkReal x9929=((cj6)*(r20));
IkReal x9930=((r22)*(sj5));
IkReal x9931=((r01)*(sj0));
IkReal x9932=((r00)*(sj0));
IkReal x9933=((cj0)*(r10));
IkReal x9934=((r02)*(sj0)*(sj5));
IkReal x9935=((cj5)*(x9926));
IkReal x9936=((cj0)*(r12)*(sj5));
IkReal x9937=((IkReal(1.00000000000000))*(cj0)*(r11));
IkReal x9938=((cj5)*(x9927));
IkReal x9939=((r20)*(x9938));
dummyeval[0]=((((IkReal(-1.00000000000000))*(x9928)*(x9932)*(x9938)))+(((IkReal(-1.00000000000000))*(r20)*(x9935)*(x9937)))+(((IkReal(-1.00000000000000))*(x9929)*(x9936)))+(((sj6)*(x9930)*(x9931)))+(((x9929)*(x9934)))+(((IkReal(-1.00000000000000))*(cj6)*(x9930)*(x9932)))+(((IkReal(-1.00000000000000))*(x9928)*(x9932)*(x9935)))+(((r20)*(x9931)*(x9935)))+(((IkReal(-1.00000000000000))*(sj6)*(x9928)*(x9934)))+(((r21)*(x9933)*(x9938)))+(((r21)*(sj6)*(x9936)))+(((cj6)*(x9930)*(x9933)))+(((IkReal(-1.00000000000000))*(sj6)*(x9930)*(x9937)))+(((IkReal(-1.00000000000000))*(x9937)*(x9939)))+(((r21)*(x9933)*(x9935)))+(((x9931)*(x9939))));
if( IKabs(dummyeval[0]) < 0.0000010000000000  )
{
continue;

} else
{
{
IkReal j4array[1], cj4array[1], sj4array[1];
bool j4valid[1]={false};
_nj4 = 1;
IkReal x9940=((sj0)*(sj6));
IkReal x9941=((cj0)*(r10));
IkReal x9942=((IkReal(1.00000000000000))*(cj5));
IkReal x9943=((cj6)*(sj0));
IkReal x9944=((cj0)*(r11));
if( IKabs(((gconst38)*(((((IkReal(-1.00000000000000))*(sj6)*(x9944)))+(((IkReal(-1.00000000000000))*(r00)*(x9943)))+(((r01)*(x9940)))+(((cj6)*(x9941))))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(((gconst38)*(((((IkReal(-1.00000000000000))*(r01)*(x9942)*(x9943)))+(((IkReal(-1.00000000000000))*(r00)*(x9940)*(x9942)))+(((cj0)*(r12)*(sj5)))+(((IkReal(-1.00000000000000))*(r02)*(sj0)*(sj5)))+(((cj5)*(sj6)*(x9941)))+(((cj5)*(cj6)*(x9944))))))) < IKFAST_ATAN2_MAGTHRESH )
    continue;
j4array[0]=IKatan2(((gconst38)*(((((IkReal(-1.00000000000000))*(sj6)*(x9944)))+(((IkReal(-1.00000000000000))*(r00)*(x9943)))+(((r01)*(x9940)))+(((cj6)*(x9941)))))), ((gconst38)*(((((IkReal(-1.00000000000000))*(r01)*(x9942)*(x9943)))+(((IkReal(-1.00000000000000))*(r00)*(x9940)*(x9942)))+(((cj0)*(r12)*(sj5)))+(((IkReal(-1.00000000000000))*(r02)*(sj0)*(sj5)))+(((cj5)*(sj6)*(x9941)))+(((cj5)*(cj6)*(x9944)))))));
sj4array[0]=IKsin(j4array[0]);
cj4array[0]=IKcos(j4array[0]);
if( j4array[0] > IKPI )
{
    j4array[0]-=IK2PI;
}
else if( j4array[0] < -IKPI )
{    j4array[0]+=IK2PI;
}
j4valid[0] = true;
for(int ij4 = 0; ij4 < 1; ++ij4)
{
if( !j4valid[ij4] )
{
    continue;
}
_ij4[0] = ij4; _ij4[1] = -1;
for(int iij4 = ij4+1; iij4 < 1; ++iij4)
{
if( j4valid[iij4] && IKabs(cj4array[ij4]-cj4array[iij4]) < IKFAST_SOLUTION_THRESH && IKabs(sj4array[ij4]-sj4array[iij4]) < IKFAST_SOLUTION_THRESH )
{
    j4valid[iij4]=false; _ij4[1] = iij4; break; 
}
}
j4 = j4array[ij4]; cj4 = cj4array[ij4]; sj4 = sj4array[ij4];
{
IkReal evalcond[6];
IkReal x9945=IKsin(j4);
IkReal x9946=IKcos(j4);
IkReal x9947=((r22)*(sj5));
IkReal x9948=((IkReal(1.00000000000000))*(cj6));
IkReal x9949=((IkReal(1.00000000000000))*(cj0));
IkReal x9950=((cj5)*(r11));
IkReal x9951=((cj5)*(cj6));
IkReal x9952=((r11)*(sj6));
IkReal x9953=((IkReal(1.00000000000000))*(sj6));
IkReal x9954=((cj6)*(r00));
IkReal x9955=((r12)*(sj5));
IkReal x9956=((r02)*(sj5));
IkReal x9957=((cj6)*(r10));
IkReal x9958=((cj5)*(sj6));
IkReal x9959=((cj5)*(r01));
IkReal x9960=((sj0)*(x9945));
IkReal x9961=((r00)*(x9958));
IkReal x9962=((cj0)*(x9945));
IkReal x9963=((sj0)*(x9946));
IkReal x9964=((r20)*(x9946));
IkReal x9965=((cj0)*(x9946));
IkReal x9966=((r21)*(x9945));
IkReal x9967=((r21)*(x9946));
IkReal x9968=((r20)*(x9945));
IkReal x9969=((x9946)*(x9955));
IkReal x9970=((r01)*(sj6)*(x9946));
IkReal x9971=((cj5)*(r10)*(x9953));
evalcond[0]=((IkReal(-1.00000000000000))+(((IkReal(-1.00000000000000))*(x9948)*(x9964)))+(((sj6)*(x9967)))+(((x9958)*(x9968)))+(((x9945)*(x9947)))+(((x9951)*(x9966))));
evalcond[1]=((((cj6)*(x9968)))+(((IkReal(-1.00000000000000))*(x9953)*(x9966)))+(((x9958)*(x9964)))+(((x9946)*(x9947)))+(((x9951)*(x9967))));
evalcond[2]=((((x9960)*(x9961)))+(((IkReal(-1.00000000000000))*(x9946)*(x9949)*(x9952)))+(((x9957)*(x9965)))+(((IkReal(-1.00000000000000))*(r00)*(x9948)*(x9963)))+(((IkReal(-1.00000000000000))*(r10)*(x9945)*(x9949)*(x9958)))+(((r01)*(x9951)*(x9960)))+(((IkReal(-1.00000000000000))*(x9945)*(x9949)*(x9955)))+(((r01)*(sj6)*(x9963)))+(((IkReal(-1.00000000000000))*(x9948)*(x9950)*(x9962)))+(((x9956)*(x9960))));
evalcond[3]=((((x9961)*(x9963)))+(((IkReal(-1.00000000000000))*(r10)*(x9946)*(x9949)*(x9958)))+(((IkReal(-1.00000000000000))*(r01)*(x9953)*(x9960)))+(((x9952)*(x9962)))+(((x9956)*(x9963)))+(((IkReal(-1.00000000000000))*(x9948)*(x9950)*(x9965)))+(((IkReal(-1.00000000000000))*(cj3)))+(((IkReal(-1.00000000000000))*(r10)*(x9948)*(x9962)))+(((r01)*(x9951)*(x9963)))+(((x9954)*(x9960)))+(((IkReal(-1.00000000000000))*(x9949)*(x9969))));
evalcond[4]=((((IkReal(-1.00000000000000))*(x9945)*(x9949)*(x9956)))+(((IkReal(-1.00000000000000))*(x9945)*(x9949)*(x9961)))+(((IkReal(-1.00000000000000))*(x9948)*(x9959)*(x9962)))+(((IkReal(-1.00000000000000))*(x9952)*(x9963)))+(((IkReal(-1.00000000000000))*(x9949)*(x9970)))+(((x9957)*(x9963)))+(((x9954)*(x9965)))+(((IkReal(-1.00000000000000))*(x9948)*(x9950)*(x9960)))+(((IkReal(-1.00000000000000))*(x9955)*(x9960)))+(((IkReal(-1.00000000000000))*(x9960)*(x9971))));
evalcond[5]=((((IkReal(-1.00000000000000))*(x9963)*(x9971)))+(((IkReal(-1.00000000000000))*(x9955)*(x9963)))+(((IkReal(-1.00000000000000))*(x9948)*(x9950)*(x9963)))+(sj3)+(((IkReal(-1.00000000000000))*(x9946)*(x9949)*(x9956)))+(((x9952)*(x9960)))+(((IkReal(-1.00000000000000))*(x9948)*(x9959)*(x9965)))+(((r01)*(sj6)*(x9962)))+(((IkReal(-1.00000000000000))*(r00)*(x9948)*(x9962)))+(((IkReal(-1.00000000000000))*(r10)*(x9948)*(x9960)))+(((IkReal(-1.00000000000000))*(x9946)*(x9949)*(x9961))));
if( IKabs(evalcond[0]) > 0.000001  || IKabs(evalcond[1]) > 0.000001  || IKabs(evalcond[2]) > 0.000001  || IKabs(evalcond[3]) > 0.000001  || IKabs(evalcond[4]) > 0.000001  || IKabs(evalcond[5]) > 0.000001  )
{
continue;
}
}

{
std::vector<IkSingleDOFSolutionBase<IkReal> > vinfos(7);
vinfos[0].jointtype = 1;
vinfos[0].foffset = j0;
vinfos[0].indices[0] = _ij0[0];
vinfos[0].indices[1] = _ij0[1];
vinfos[0].maxsolutions = _nj0;
vinfos[1].jointtype = 1;
vinfos[1].foffset = j1;
vinfos[1].indices[0] = _ij1[0];
vinfos[1].indices[1] = _ij1[1];
vinfos[1].maxsolutions = _nj1;
vinfos[2].jointtype = 1;
vinfos[2].foffset = j2;
vinfos[2].indices[0] = _ij2[0];
vinfos[2].indices[1] = _ij2[1];
vinfos[2].maxsolutions = _nj2;
vinfos[3].jointtype = 1;
vinfos[3].foffset = j3;
vinfos[3].indices[0] = _ij3[0];
vinfos[3].indices[1] = _ij3[1];
vinfos[3].maxsolutions = _nj3;
vinfos[4].jointtype = 1;
vinfos[4].foffset = j4;
vinfos[4].indices[0] = _ij4[0];
vinfos[4].indices[1] = _ij4[1];
vinfos[4].maxsolutions = _nj4;
vinfos[5].jointtype = 1;
vinfos[5].foffset = j5;
vinfos[5].indices[0] = _ij5[0];
vinfos[5].indices[1] = _ij5[1];
vinfos[5].maxsolutions = _nj5;
vinfos[6].jointtype = 1;
vinfos[6].foffset = j6;
vinfos[6].indices[0] = _ij6[0];
vinfos[6].indices[1] = _ij6[1];
vinfos[6].maxsolutions = _nj6;
std::vector<int> vfree(0);
solutions.AddSolution(vinfos,vfree);
}
}
}

}

}

} else
{
{
IkReal j4array[1], cj4array[1], sj4array[1];
bool j4valid[1]={false};
_nj4 = 1;
if( IKabs(((gconst37)*(((((cj5)*(r20)*(sj6)))+(((r22)*(sj5)))+(((cj5)*(cj6)*(r21))))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(((gconst37)*(((((r21)*(sj6)))+(((IkReal(-1.00000000000000))*(cj6)*(r20))))))) < IKFAST_ATAN2_MAGTHRESH )
    continue;
j4array[0]=IKatan2(((gconst37)*(((((cj5)*(r20)*(sj6)))+(((r22)*(sj5)))+(((cj5)*(cj6)*(r21)))))), ((gconst37)*(((((r21)*(sj6)))+(((IkReal(-1.00000000000000))*(cj6)*(r20)))))));
sj4array[0]=IKsin(j4array[0]);
cj4array[0]=IKcos(j4array[0]);
if( j4array[0] > IKPI )
{
    j4array[0]-=IK2PI;
}
else if( j4array[0] < -IKPI )
{    j4array[0]+=IK2PI;
}
j4valid[0] = true;
for(int ij4 = 0; ij4 < 1; ++ij4)
{
if( !j4valid[ij4] )
{
    continue;
}
_ij4[0] = ij4; _ij4[1] = -1;
for(int iij4 = ij4+1; iij4 < 1; ++iij4)
{
if( j4valid[iij4] && IKabs(cj4array[ij4]-cj4array[iij4]) < IKFAST_SOLUTION_THRESH && IKabs(sj4array[ij4]-sj4array[iij4]) < IKFAST_SOLUTION_THRESH )
{
    j4valid[iij4]=false; _ij4[1] = iij4; break; 
}
}
j4 = j4array[ij4]; cj4 = cj4array[ij4]; sj4 = sj4array[ij4];
{
IkReal evalcond[6];
IkReal x9972=IKsin(j4);
IkReal x9973=IKcos(j4);
IkReal x9974=((r22)*(sj5));
IkReal x9975=((IkReal(1.00000000000000))*(cj6));
IkReal x9976=((IkReal(1.00000000000000))*(cj0));
IkReal x9977=((cj5)*(r11));
IkReal x9978=((cj5)*(cj6));
IkReal x9979=((r11)*(sj6));
IkReal x9980=((IkReal(1.00000000000000))*(sj6));
IkReal x9981=((cj6)*(r00));
IkReal x9982=((r12)*(sj5));
IkReal x9983=((r02)*(sj5));
IkReal x9984=((cj6)*(r10));
IkReal x9985=((cj5)*(sj6));
IkReal x9986=((cj5)*(r01));
IkReal x9987=((sj0)*(x9972));
IkReal x9988=((r00)*(x9985));
IkReal x9989=((cj0)*(x9972));
IkReal x9990=((sj0)*(x9973));
IkReal x9991=((r20)*(x9973));
IkReal x9992=((cj0)*(x9973));
IkReal x9993=((r21)*(x9972));
IkReal x9994=((r21)*(x9973));
IkReal x9995=((r20)*(x9972));
IkReal x9996=((x9973)*(x9982));
IkReal x9997=((r01)*(sj6)*(x9973));
IkReal x9998=((cj5)*(r10)*(x9980));
evalcond[0]=((IkReal(-1.00000000000000))+(((x9978)*(x9993)))+(((x9972)*(x9974)))+(((x9985)*(x9995)))+(((IkReal(-1.00000000000000))*(x9975)*(x9991)))+(((sj6)*(x9994))));
evalcond[1]=((((x9978)*(x9994)))+(((x9973)*(x9974)))+(((IkReal(-1.00000000000000))*(x9980)*(x9993)))+(((x9985)*(x9991)))+(((cj6)*(x9995))));
evalcond[2]=((((IkReal(-1.00000000000000))*(x9972)*(x9976)*(x9982)))+(((IkReal(-1.00000000000000))*(x9975)*(x9977)*(x9989)))+(((r01)*(x9978)*(x9987)))+(((IkReal(-1.00000000000000))*(r00)*(x9975)*(x9990)))+(((r01)*(sj6)*(x9990)))+(((IkReal(-1.00000000000000))*(r10)*(x9972)*(x9976)*(x9985)))+(((x9987)*(x9988)))+(((IkReal(-1.00000000000000))*(x9973)*(x9976)*(x9979)))+(((x9984)*(x9992)))+(((x9983)*(x9987))));
evalcond[3]=((((IkReal(-1.00000000000000))*(x9976)*(x9996)))+(((x9979)*(x9989)))+(((x9988)*(x9990)))+(((IkReal(-1.00000000000000))*(r10)*(x9973)*(x9976)*(x9985)))+(((IkReal(-1.00000000000000))*(r01)*(x9980)*(x9987)))+(((x9983)*(x9990)))+(((IkReal(-1.00000000000000))*(x9975)*(x9977)*(x9992)))+(((x9981)*(x9987)))+(((IkReal(-1.00000000000000))*(cj3)))+(((r01)*(x9978)*(x9990)))+(((IkReal(-1.00000000000000))*(r10)*(x9975)*(x9989))));
evalcond[4]=((((IkReal(-1.00000000000000))*(x9972)*(x9976)*(x9983)))+(((IkReal(-1.00000000000000))*(x9987)*(x9998)))+(((IkReal(-1.00000000000000))*(x9982)*(x9987)))+(((IkReal(-1.00000000000000))*(x9972)*(x9976)*(x9988)))+(((IkReal(-1.00000000000000))*(x9976)*(x9997)))+(((IkReal(-1.00000000000000))*(x9979)*(x9990)))+(((IkReal(-1.00000000000000))*(x9975)*(x9986)*(x9989)))+(((IkReal(-1.00000000000000))*(x9975)*(x9977)*(x9987)))+(((x9984)*(x9990)))+(((x9981)*(x9992))));
evalcond[5]=((((IkReal(-1.00000000000000))*(x9973)*(x9976)*(x9988)))+(sj3)+(((IkReal(-1.00000000000000))*(x9975)*(x9986)*(x9992)))+(((IkReal(-1.00000000000000))*(x9990)*(x9998)))+(((IkReal(-1.00000000000000))*(r10)*(x9975)*(x9987)))+(((IkReal(-1.00000000000000))*(r00)*(x9975)*(x9989)))+(((x9979)*(x9987)))+(((IkReal(-1.00000000000000))*(x9975)*(x9977)*(x9990)))+(((IkReal(-1.00000000000000))*(x9982)*(x9990)))+(((r01)*(sj6)*(x9989)))+(((IkReal(-1.00000000000000))*(x9973)*(x9976)*(x9983))));
if( IKabs(evalcond[0]) > 0.000001  || IKabs(evalcond[1]) > 0.000001  || IKabs(evalcond[2]) > 0.000001  || IKabs(evalcond[3]) > 0.000001  || IKabs(evalcond[4]) > 0.000001  || IKabs(evalcond[5]) > 0.000001  )
{
continue;
}
}

{
std::vector<IkSingleDOFSolutionBase<IkReal> > vinfos(7);
vinfos[0].jointtype = 1;
vinfos[0].foffset = j0;
vinfos[0].indices[0] = _ij0[0];
vinfos[0].indices[1] = _ij0[1];
vinfos[0].maxsolutions = _nj0;
vinfos[1].jointtype = 1;
vinfos[1].foffset = j1;
vinfos[1].indices[0] = _ij1[0];
vinfos[1].indices[1] = _ij1[1];
vinfos[1].maxsolutions = _nj1;
vinfos[2].jointtype = 1;
vinfos[2].foffset = j2;
vinfos[2].indices[0] = _ij2[0];
vinfos[2].indices[1] = _ij2[1];
vinfos[2].maxsolutions = _nj2;
vinfos[3].jointtype = 1;
vinfos[3].foffset = j3;
vinfos[3].indices[0] = _ij3[0];
vinfos[3].indices[1] = _ij3[1];
vinfos[3].maxsolutions = _nj3;
vinfos[4].jointtype = 1;
vinfos[4].foffset = j4;
vinfos[4].indices[0] = _ij4[0];
vinfos[4].indices[1] = _ij4[1];
vinfos[4].maxsolutions = _nj4;
vinfos[5].jointtype = 1;
vinfos[5].foffset = j5;
vinfos[5].indices[0] = _ij5[0];
vinfos[5].indices[1] = _ij5[1];
vinfos[5].maxsolutions = _nj5;
vinfos[6].jointtype = 1;
vinfos[6].foffset = j6;
vinfos[6].indices[0] = _ij6[0];
vinfos[6].indices[1] = _ij6[1];
vinfos[6].maxsolutions = _nj6;
std::vector<int> vfree(0);
solutions.AddSolution(vinfos,vfree);
}
}
}

}

}
}
}

} else
{
if( 1 )
{
continue;

} else
{
}
}
}
}

} else
{
{
IkReal j3array[1], cj3array[1], sj3array[1];
bool j3valid[1]={false};
_nj3 = 1;
IkReal x9999=((sj5)*(sj6));
IkReal x10000=((IkReal(1.00000000000000))*(sj0));
IkReal x10001=((cj6)*(sj5));
IkReal x10002=((IkReal(1.00000000000000))*(cj5));
if( IKabs(((((IkReal(-1.00000000000000))*(cj0)*(r12)*(x10002)))+(((IkReal(-1.00000000000000))*(r01)*(x10000)*(x10001)))+(((cj0)*(r11)*(x10001)))+(((IkReal(-1.00000000000000))*(r00)*(x10000)*(x9999)))+(((cj5)*(r02)*(sj0)))+(((cj0)*(r10)*(x9999))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(((((IKabs(sj1) != 0)?((IkReal)1/(sj1)):(IkReal)1.0e30))*(((((r20)*(x9999)))+(((IkReal(-1.00000000000000))*(r22)*(x10002)))+(((r21)*(x10001))))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(IKsqr(((((IkReal(-1.00000000000000))*(cj0)*(r12)*(x10002)))+(((IkReal(-1.00000000000000))*(r01)*(x10000)*(x10001)))+(((cj0)*(r11)*(x10001)))+(((IkReal(-1.00000000000000))*(r00)*(x10000)*(x9999)))+(((cj5)*(r02)*(sj0)))+(((cj0)*(r10)*(x9999)))))+IKsqr(((((IKabs(sj1) != 0)?((IkReal)1/(sj1)):(IkReal)1.0e30))*(((((r20)*(x9999)))+(((IkReal(-1.00000000000000))*(r22)*(x10002)))+(((r21)*(x10001)))))))-1) <= IKFAST_SINCOS_THRESH )
    continue;
j3array[0]=IKatan2(((((IkReal(-1.00000000000000))*(cj0)*(r12)*(x10002)))+(((IkReal(-1.00000000000000))*(r01)*(x10000)*(x10001)))+(((cj0)*(r11)*(x10001)))+(((IkReal(-1.00000000000000))*(r00)*(x10000)*(x9999)))+(((cj5)*(r02)*(sj0)))+(((cj0)*(r10)*(x9999)))), ((((IKabs(sj1) != 0)?((IkReal)1/(sj1)):(IkReal)1.0e30))*(((((r20)*(x9999)))+(((IkReal(-1.00000000000000))*(r22)*(x10002)))+(((r21)*(x10001)))))));
sj3array[0]=IKsin(j3array[0]);
cj3array[0]=IKcos(j3array[0]);
if( j3array[0] > IKPI )
{
    j3array[0]-=IK2PI;
}
else if( j3array[0] < -IKPI )
{    j3array[0]+=IK2PI;
}
j3valid[0] = true;
for(int ij3 = 0; ij3 < 1; ++ij3)
{
if( !j3valid[ij3] )
{
    continue;
}
_ij3[0] = ij3; _ij3[1] = -1;
for(int iij3 = ij3+1; iij3 < 1; ++iij3)
{
if( j3valid[iij3] && IKabs(cj3array[ij3]-cj3array[iij3]) < IKFAST_SOLUTION_THRESH && IKabs(sj3array[ij3]-sj3array[iij3]) < IKFAST_SOLUTION_THRESH )
{
    j3valid[iij3]=false; _ij3[1] = iij3; break; 
}
}
j3 = j3array[ij3]; cj3 = cj3array[ij3]; sj3 = sj3array[ij3];
{
IkReal evalcond[3];
IkReal x10003=IKcos(j3);
IkReal x10004=((sj5)*(sj6));
IkReal x10005=((cj0)*(cj5));
IkReal x10006=((IkReal(1.00000000000000))*(cj0));
IkReal x10007=((IkReal(1.00000000000000))*(sj0));
IkReal x10008=((IkReal(1.00000000000000))*(x10003));
IkReal x10009=((cj6)*(r01)*(sj5));
IkReal x10010=((cj6)*(r11)*(sj5));
evalcond[0]=((((cj6)*(r21)*(sj5)))+(((IkReal(-1.00000000000000))*(sj1)*(x10008)))+(((IkReal(-1.00000000000000))*(cj5)*(r22)))+(((r20)*(x10004))));
evalcond[1]=((((IkReal(-1.00000000000000))*(x10006)*(x10010)))+(((sj0)*(x10009)))+(((r12)*(x10005)))+(((IkReal(-1.00000000000000))*(r10)*(x10004)*(x10006)))+(((IkReal(-1.00000000000000))*(cj5)*(r02)*(x10007)))+(IKsin(j3))+(((r00)*(sj0)*(x10004))));
evalcond[2]=((((IkReal(-1.00000000000000))*(x10007)*(x10010)))+(((IkReal(-1.00000000000000))*(r00)*(x10004)*(x10006)))+(((cj5)*(r12)*(sj0)))+(((r02)*(x10005)))+(((IkReal(-1.00000000000000))*(r10)*(x10004)*(x10007)))+(((IkReal(-1.00000000000000))*(cj1)*(x10008)))+(((IkReal(-1.00000000000000))*(x10006)*(x10009))));
if( IKabs(evalcond[0]) > 0.000001  || IKabs(evalcond[1]) > 0.000001  || IKabs(evalcond[2]) > 0.000001  )
{
continue;
}
}

{
IkReal dummyeval[1];
IkReal gconst28;
IkReal x10011=(r21)*(r21);
IkReal x10012=(cj5)*(cj5);
IkReal x10013=(sj6)*(sj6);
IkReal x10014=(cj6)*(cj6);
IkReal x10015=(r20)*(r20);
IkReal x10016=((cj6)*(r21));
IkReal x10017=((IkReal(2.00000000000000))*(r20)*(sj6));
IkReal x10018=((cj5)*(r22)*(sj5));
IkReal x10019=((IkReal(1.00000000000000))*(x10013));
IkReal x10020=((IkReal(1.00000000000000))*(x10014));
gconst28=IKsign(((((IkReal(-1.00000000000000))*(x10011)*(x10012)*(x10020)))+(((IkReal(-1.00000000000000))*(x10012)*(x10016)*(x10017)))+(((IkReal(-2.00000000000000))*(x10016)*(x10018)))+(((IkReal(-1.00000000000000))*((r22)*(r22))*((sj5)*(sj5))))+(((IkReal(-1.00000000000000))*(x10015)*(x10020)))+(((IkReal(-1.00000000000000))*(x10011)*(x10019)))+(((x10016)*(x10017)))+(((IkReal(-1.00000000000000))*(x10012)*(x10015)*(x10019)))+(((IkReal(-1.00000000000000))*(x10017)*(x10018)))));
IkReal x10021=(r21)*(r21);
IkReal x10022=(cj5)*(cj5);
IkReal x10023=(sj6)*(sj6);
IkReal x10024=(cj6)*(cj6);
IkReal x10025=(r20)*(r20);
IkReal x10026=((cj6)*(r21));
IkReal x10027=((IkReal(2.00000000000000))*(r20)*(sj6));
IkReal x10028=((cj5)*(r22)*(sj5));
IkReal x10029=((IkReal(1.00000000000000))*(x10023));
IkReal x10030=((IkReal(1.00000000000000))*(x10024));
dummyeval[0]=((((IkReal(-1.00000000000000))*(x10022)*(x10025)*(x10029)))+(((IkReal(-1.00000000000000))*((r22)*(r22))*((sj5)*(sj5))))+(((IkReal(-1.00000000000000))*(x10021)*(x10022)*(x10030)))+(((IkReal(-1.00000000000000))*(x10025)*(x10030)))+(((IkReal(-1.00000000000000))*(x10022)*(x10026)*(x10027)))+(((IkReal(-2.00000000000000))*(x10026)*(x10028)))+(((x10026)*(x10027)))+(((IkReal(-1.00000000000000))*(x10021)*(x10029)))+(((IkReal(-1.00000000000000))*(x10027)*(x10028))));
if( IKabs(dummyeval[0]) < 0.0000010000000000  )
{
{
IkReal dummyeval[1];
IkReal gconst29;
IkReal x10031=(cj6)*(cj6);
IkReal x10032=(sj6)*(sj6);
IkReal x10033=((IkReal(1.00000000000000))*(r01));
IkReal x10034=((sj0)*(sj5));
IkReal x10035=((cj6)*(r22));
IkReal x10036=((r21)*(sj6));
IkReal x10037=((r00)*(r21));
IkReal x10038=((cj0)*(sj5));
IkReal x10039=((cj6)*(r20));
IkReal x10040=((r22)*(sj6));
IkReal x10041=((cj0)*(cj5));
IkReal x10042=((IkReal(1.00000000000000))*(r10));
IkReal x10043=((cj5)*(sj0));
IkReal x10044=((r20)*(x10032));
IkReal x10045=((x10031)*(x10043));
gconst29=IKsign(((((r11)*(r20)*(x10031)*(x10041)))+(((IkReal(-1.00000000000000))*(r21)*(x10031)*(x10041)*(x10042)))+(((IkReal(-1.00000000000000))*(r20)*(x10033)*(x10045)))+(((r12)*(x10038)*(x10039)))+(((IkReal(-1.00000000000000))*(r12)*(x10036)*(x10038)))+(((IkReal(-1.00000000000000))*(x10033)*(x10034)*(x10040)))+(((IkReal(-1.00000000000000))*(r21)*(x10032)*(x10041)*(x10042)))+(((r02)*(x10034)*(x10036)))+(((IkReal(-1.00000000000000))*(x10033)*(x10043)*(x10044)))+(((r11)*(x10041)*(x10044)))+(((IkReal(-1.00000000000000))*(x10035)*(x10038)*(x10042)))+(((IkReal(-1.00000000000000))*(r02)*(x10034)*(x10039)))+(((x10037)*(x10045)))+(((r00)*(x10034)*(x10035)))+(((x10032)*(x10037)*(x10043)))+(((r11)*(x10038)*(x10040)))));
IkReal x10046=(cj6)*(cj6);
IkReal x10047=(sj6)*(sj6);
IkReal x10048=((IkReal(1.00000000000000))*(r01));
IkReal x10049=((sj0)*(sj5));
IkReal x10050=((cj6)*(r22));
IkReal x10051=((r21)*(sj6));
IkReal x10052=((r00)*(r21));
IkReal x10053=((cj0)*(sj5));
IkReal x10054=((cj6)*(r20));
IkReal x10055=((r22)*(sj6));
IkReal x10056=((cj0)*(cj5));
IkReal x10057=((IkReal(1.00000000000000))*(r10));
IkReal x10058=((cj5)*(sj0));
IkReal x10059=((r20)*(x10047));
IkReal x10060=((x10046)*(x10058));
dummyeval[0]=((((r11)*(x10053)*(x10055)))+(((x10047)*(x10052)*(x10058)))+(((r11)*(r20)*(x10046)*(x10056)))+(((r12)*(x10053)*(x10054)))+(((IkReal(-1.00000000000000))*(r20)*(x10048)*(x10060)))+(((IkReal(-1.00000000000000))*(x10048)*(x10058)*(x10059)))+(((IkReal(-1.00000000000000))*(x10050)*(x10053)*(x10057)))+(((r00)*(x10049)*(x10050)))+(((IkReal(-1.00000000000000))*(x10048)*(x10049)*(x10055)))+(((IkReal(-1.00000000000000))*(r02)*(x10049)*(x10054)))+(((x10052)*(x10060)))+(((IkReal(-1.00000000000000))*(r21)*(x10047)*(x10056)*(x10057)))+(((IkReal(-1.00000000000000))*(r21)*(x10046)*(x10056)*(x10057)))+(((r11)*(x10056)*(x10059)))+(((IkReal(-1.00000000000000))*(r12)*(x10051)*(x10053)))+(((r02)*(x10049)*(x10051))));
if( IKabs(dummyeval[0]) < 0.0000010000000000  )
{
continue;

} else
{
{
IkReal j4array[1], cj4array[1], sj4array[1];
bool j4valid[1]={false};
_nj4 = 1;
IkReal x10061=((cj1)*(cj6));
IkReal x10062=((IkReal(1.00000000000000))*(sj0));
IkReal x10063=((cj0)*(r10));
IkReal x10064=((cj1)*(sj5));
IkReal x10065=((cj1)*(sj6));
IkReal x10066=((cj0)*(r11));
if( IKabs(((gconst29)*(((((IkReal(-1.00000000000000))*(r00)*(x10061)*(x10062)))+(((x10061)*(x10063)))+(((IkReal(-1.00000000000000))*(x10065)*(x10066)))+(((r01)*(sj0)*(x10065))))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(((gconst29)*(((((IkReal(-1.00000000000000))*(cj5)*(r01)*(x10061)*(x10062)))+(((IkReal(-1.00000000000000))*(r02)*(x10062)*(x10064)))+(((IkReal(-1.00000000000000))*(cj5)*(r00)*(x10062)*(x10065)))+(((cj0)*(r12)*(x10064)))+(((cj5)*(x10063)*(x10065)))+(((cj5)*(x10061)*(x10066))))))) < IKFAST_ATAN2_MAGTHRESH )
    continue;
j4array[0]=IKatan2(((gconst29)*(((((IkReal(-1.00000000000000))*(r00)*(x10061)*(x10062)))+(((x10061)*(x10063)))+(((IkReal(-1.00000000000000))*(x10065)*(x10066)))+(((r01)*(sj0)*(x10065)))))), ((gconst29)*(((((IkReal(-1.00000000000000))*(cj5)*(r01)*(x10061)*(x10062)))+(((IkReal(-1.00000000000000))*(r02)*(x10062)*(x10064)))+(((IkReal(-1.00000000000000))*(cj5)*(r00)*(x10062)*(x10065)))+(((cj0)*(r12)*(x10064)))+(((cj5)*(x10063)*(x10065)))+(((cj5)*(x10061)*(x10066)))))));
sj4array[0]=IKsin(j4array[0]);
cj4array[0]=IKcos(j4array[0]);
if( j4array[0] > IKPI )
{
    j4array[0]-=IK2PI;
}
else if( j4array[0] < -IKPI )
{    j4array[0]+=IK2PI;
}
j4valid[0] = true;
for(int ij4 = 0; ij4 < 1; ++ij4)
{
if( !j4valid[ij4] )
{
    continue;
}
_ij4[0] = ij4; _ij4[1] = -1;
for(int iij4 = ij4+1; iij4 < 1; ++iij4)
{
if( j4valid[iij4] && IKabs(cj4array[ij4]-cj4array[iij4]) < IKFAST_SOLUTION_THRESH && IKabs(sj4array[ij4]-sj4array[iij4]) < IKFAST_SOLUTION_THRESH )
{
    j4valid[iij4]=false; _ij4[1] = iij4; break; 
}
}
j4 = j4array[ij4]; cj4 = cj4array[ij4]; sj4 = sj4array[ij4];
{
IkReal evalcond[6];
IkReal x10067=IKsin(j4);
IkReal x10068=IKcos(j4);
IkReal x10069=((r22)*(sj5));
IkReal x10070=((IkReal(1.00000000000000))*(cj6));
IkReal x10071=((IkReal(1.00000000000000))*(cj0));
IkReal x10072=((IkReal(1.00000000000000))*(sj1));
IkReal x10073=((cj5)*(r11));
IkReal x10074=((cj5)*(cj6));
IkReal x10075=((r11)*(sj6));
IkReal x10076=((IkReal(1.00000000000000))*(sj6));
IkReal x10077=((cj6)*(r00));
IkReal x10078=((r12)*(sj5));
IkReal x10079=((r02)*(sj5));
IkReal x10080=((cj6)*(r10));
IkReal x10081=((cj5)*(sj6));
IkReal x10082=((cj5)*(r01));
IkReal x10083=((sj0)*(x10067));
IkReal x10084=((r00)*(x10081));
IkReal x10085=((cj0)*(x10067));
IkReal x10086=((sj0)*(x10068));
IkReal x10087=((r20)*(x10068));
IkReal x10088=((cj0)*(x10068));
IkReal x10089=((r21)*(x10067));
IkReal x10090=((r21)*(x10068));
IkReal x10091=((r20)*(x10067));
IkReal x10092=((x10068)*(x10078));
IkReal x10093=((r01)*(sj6)*(x10068));
IkReal x10094=((cj5)*(r10)*(x10076));
evalcond[0]=((((IkReal(-1.00000000000000))*(x10070)*(x10087)))+(((x10074)*(x10089)))+(cj1)+(((x10081)*(x10091)))+(((sj6)*(x10090)))+(((x10067)*(x10069))));
evalcond[1]=((((IkReal(-1.00000000000000))*(sj3)*(x10072)))+(((x10074)*(x10090)))+(((cj6)*(x10091)))+(((IkReal(-1.00000000000000))*(x10076)*(x10089)))+(((x10081)*(x10087)))+(((x10068)*(x10069))));
evalcond[2]=((((IkReal(-1.00000000000000))*(x10068)*(x10071)*(x10075)))+(((x10080)*(x10088)))+(((r01)*(x10074)*(x10083)))+(((r01)*(sj6)*(x10086)))+(((x10079)*(x10083)))+(((IkReal(-1.00000000000000))*(r00)*(x10070)*(x10086)))+(((IkReal(-1.00000000000000))*(r10)*(x10067)*(x10071)*(x10081)))+(((x10083)*(x10084)))+(((IkReal(-1.00000000000000))*(x10070)*(x10073)*(x10085)))+(((IkReal(-1.00000000000000))*(x10067)*(x10071)*(x10078))));
evalcond[3]=((((IkReal(-1.00000000000000))*(r10)*(x10068)*(x10071)*(x10081)))+(((IkReal(-1.00000000000000))*(r10)*(x10070)*(x10085)))+(((IkReal(-1.00000000000000))*(cj3)))+(((x10084)*(x10086)))+(((IkReal(-1.00000000000000))*(r01)*(x10076)*(x10083)))+(((IkReal(-1.00000000000000))*(x10071)*(x10092)))+(((x10079)*(x10086)))+(((IkReal(-1.00000000000000))*(x10070)*(x10073)*(x10088)))+(((x10075)*(x10085)))+(((x10077)*(x10083)))+(((r01)*(x10074)*(x10086))));
evalcond[4]=((((IkReal(-1.00000000000000))*(x10078)*(x10083)))+(((IkReal(-1.00000000000000))*(x10067)*(x10071)*(x10084)))+(((IkReal(-1.00000000000000))*(x10083)*(x10094)))+(((IkReal(-1.00000000000000))*(x10070)*(x10082)*(x10085)))+(((x10077)*(x10088)))+(((IkReal(-1.00000000000000))*(x10067)*(x10071)*(x10079)))+(((IkReal(-1.00000000000000))*(x10070)*(x10073)*(x10083)))+(((IkReal(-1.00000000000000))*(x10075)*(x10086)))+(((IkReal(-1.00000000000000))*(x10071)*(x10093)))+(((x10080)*(x10086)))+(((IkReal(-1.00000000000000))*(x10072))));
evalcond[5]=((((IkReal(-1.00000000000000))*(x10070)*(x10082)*(x10088)))+(((IkReal(-1.00000000000000))*(x10068)*(x10071)*(x10079)))+(((IkReal(-1.00000000000000))*(x10078)*(x10086)))+(((IkReal(-1.00000000000000))*(x10070)*(x10073)*(x10086)))+(((IkReal(-1.00000000000000))*(r00)*(x10070)*(x10085)))+(((IkReal(-1.00000000000000))*(x10086)*(x10094)))+(((IkReal(-1.00000000000000))*(r10)*(x10070)*(x10083)))+(((IkReal(-1.00000000000000))*(cj1)*(sj3)))+(((r01)*(sj6)*(x10085)))+(((IkReal(-1.00000000000000))*(x10068)*(x10071)*(x10084)))+(((x10075)*(x10083))));
if( IKabs(evalcond[0]) > 0.000001  || IKabs(evalcond[1]) > 0.000001  || IKabs(evalcond[2]) > 0.000001  || IKabs(evalcond[3]) > 0.000001  || IKabs(evalcond[4]) > 0.000001  || IKabs(evalcond[5]) > 0.000001  )
{
continue;
}
}

{
std::vector<IkSingleDOFSolutionBase<IkReal> > vinfos(7);
vinfos[0].jointtype = 1;
vinfos[0].foffset = j0;
vinfos[0].indices[0] = _ij0[0];
vinfos[0].indices[1] = _ij0[1];
vinfos[0].maxsolutions = _nj0;
vinfos[1].jointtype = 1;
vinfos[1].foffset = j1;
vinfos[1].indices[0] = _ij1[0];
vinfos[1].indices[1] = _ij1[1];
vinfos[1].maxsolutions = _nj1;
vinfos[2].jointtype = 1;
vinfos[2].foffset = j2;
vinfos[2].indices[0] = _ij2[0];
vinfos[2].indices[1] = _ij2[1];
vinfos[2].maxsolutions = _nj2;
vinfos[3].jointtype = 1;
vinfos[3].foffset = j3;
vinfos[3].indices[0] = _ij3[0];
vinfos[3].indices[1] = _ij3[1];
vinfos[3].maxsolutions = _nj3;
vinfos[4].jointtype = 1;
vinfos[4].foffset = j4;
vinfos[4].indices[0] = _ij4[0];
vinfos[4].indices[1] = _ij4[1];
vinfos[4].maxsolutions = _nj4;
vinfos[5].jointtype = 1;
vinfos[5].foffset = j5;
vinfos[5].indices[0] = _ij5[0];
vinfos[5].indices[1] = _ij5[1];
vinfos[5].maxsolutions = _nj5;
vinfos[6].jointtype = 1;
vinfos[6].foffset = j6;
vinfos[6].indices[0] = _ij6[0];
vinfos[6].indices[1] = _ij6[1];
vinfos[6].maxsolutions = _nj6;
std::vector<int> vfree(0);
solutions.AddSolution(vinfos,vfree);
}
}
}

}

}

} else
{
{
IkReal j4array[1], cj4array[1], sj4array[1];
bool j4valid[1]={false};
_nj4 = 1;
IkReal x10095=((cj1)*(r20));
IkReal x10096=((cj5)*(sj6));
IkReal x10097=((sj1)*(sj3));
IkReal x10098=((r21)*(sj6));
IkReal x10099=((r22)*(sj5));
IkReal x10100=((IkReal(1.00000000000000))*(cj6));
IkReal x10101=((cj5)*(r21));
if( IKabs(((gconst28)*(((((x10097)*(x10098)))+(((cj1)*(cj6)*(x10101)))+(((x10095)*(x10096)))+(((IkReal(-1.00000000000000))*(r20)*(x10097)*(x10100)))+(((cj1)*(x10099))))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(((gconst28)*(((((cj1)*(x10098)))+(((IkReal(-1.00000000000000))*(r20)*(x10096)*(x10097)))+(((IkReal(-1.00000000000000))*(x10097)*(x10100)*(x10101)))+(((IkReal(-1.00000000000000))*(x10097)*(x10099)))+(((IkReal(-1.00000000000000))*(x10095)*(x10100))))))) < IKFAST_ATAN2_MAGTHRESH )
    continue;
j4array[0]=IKatan2(((gconst28)*(((((x10097)*(x10098)))+(((cj1)*(cj6)*(x10101)))+(((x10095)*(x10096)))+(((IkReal(-1.00000000000000))*(r20)*(x10097)*(x10100)))+(((cj1)*(x10099)))))), ((gconst28)*(((((cj1)*(x10098)))+(((IkReal(-1.00000000000000))*(r20)*(x10096)*(x10097)))+(((IkReal(-1.00000000000000))*(x10097)*(x10100)*(x10101)))+(((IkReal(-1.00000000000000))*(x10097)*(x10099)))+(((IkReal(-1.00000000000000))*(x10095)*(x10100)))))));
sj4array[0]=IKsin(j4array[0]);
cj4array[0]=IKcos(j4array[0]);
if( j4array[0] > IKPI )
{
    j4array[0]-=IK2PI;
}
else if( j4array[0] < -IKPI )
{    j4array[0]+=IK2PI;
}
j4valid[0] = true;
for(int ij4 = 0; ij4 < 1; ++ij4)
{
if( !j4valid[ij4] )
{
    continue;
}
_ij4[0] = ij4; _ij4[1] = -1;
for(int iij4 = ij4+1; iij4 < 1; ++iij4)
{
if( j4valid[iij4] && IKabs(cj4array[ij4]-cj4array[iij4]) < IKFAST_SOLUTION_THRESH && IKabs(sj4array[ij4]-sj4array[iij4]) < IKFAST_SOLUTION_THRESH )
{
    j4valid[iij4]=false; _ij4[1] = iij4; break; 
}
}
j4 = j4array[ij4]; cj4 = cj4array[ij4]; sj4 = sj4array[ij4];
{
IkReal evalcond[6];
IkReal x10102=IKsin(j4);
IkReal x10103=IKcos(j4);
IkReal x10104=((r22)*(sj5));
IkReal x10105=((IkReal(1.00000000000000))*(cj6));
IkReal x10106=((IkReal(1.00000000000000))*(cj0));
IkReal x10107=((IkReal(1.00000000000000))*(sj1));
IkReal x10108=((cj5)*(r11));
IkReal x10109=((cj5)*(cj6));
IkReal x10110=((r11)*(sj6));
IkReal x10111=((IkReal(1.00000000000000))*(sj6));
IkReal x10112=((cj6)*(r00));
IkReal x10113=((r12)*(sj5));
IkReal x10114=((r02)*(sj5));
IkReal x10115=((cj6)*(r10));
IkReal x10116=((cj5)*(sj6));
IkReal x10117=((cj5)*(r01));
IkReal x10118=((sj0)*(x10102));
IkReal x10119=((r00)*(x10116));
IkReal x10120=((cj0)*(x10102));
IkReal x10121=((sj0)*(x10103));
IkReal x10122=((r20)*(x10103));
IkReal x10123=((cj0)*(x10103));
IkReal x10124=((r21)*(x10102));
IkReal x10125=((r21)*(x10103));
IkReal x10126=((r20)*(x10102));
IkReal x10127=((x10103)*(x10113));
IkReal x10128=((r01)*(sj6)*(x10103));
IkReal x10129=((cj5)*(r10)*(x10111));
evalcond[0]=((((x10102)*(x10104)))+(((x10116)*(x10126)))+(((sj6)*(x10125)))+(((x10109)*(x10124)))+(cj1)+(((IkReal(-1.00000000000000))*(x10105)*(x10122))));
evalcond[1]=((((x10116)*(x10122)))+(((IkReal(-1.00000000000000))*(sj3)*(x10107)))+(((x10109)*(x10125)))+(((cj6)*(x10126)))+(((x10103)*(x10104)))+(((IkReal(-1.00000000000000))*(x10111)*(x10124))));
evalcond[2]=((((r01)*(sj6)*(x10121)))+(((x10114)*(x10118)))+(((IkReal(-1.00000000000000))*(x10105)*(x10108)*(x10120)))+(((IkReal(-1.00000000000000))*(x10103)*(x10106)*(x10110)))+(((r01)*(x10109)*(x10118)))+(((x10115)*(x10123)))+(((IkReal(-1.00000000000000))*(r10)*(x10102)*(x10106)*(x10116)))+(((x10118)*(x10119)))+(((IkReal(-1.00000000000000))*(r00)*(x10105)*(x10121)))+(((IkReal(-1.00000000000000))*(x10102)*(x10106)*(x10113))));
evalcond[3]=((((IkReal(-1.00000000000000))*(x10105)*(x10108)*(x10123)))+(((x10110)*(x10120)))+(((IkReal(-1.00000000000000))*(r10)*(x10103)*(x10106)*(x10116)))+(((x10112)*(x10118)))+(((IkReal(-1.00000000000000))*(r01)*(x10111)*(x10118)))+(((IkReal(-1.00000000000000))*(cj3)))+(((x10119)*(x10121)))+(((x10114)*(x10121)))+(((r01)*(x10109)*(x10121)))+(((IkReal(-1.00000000000000))*(x10106)*(x10127)))+(((IkReal(-1.00000000000000))*(r10)*(x10105)*(x10120))));
evalcond[4]=((((x10112)*(x10123)))+(((IkReal(-1.00000000000000))*(x10113)*(x10118)))+(((IkReal(-1.00000000000000))*(x10106)*(x10128)))+(((IkReal(-1.00000000000000))*(x10102)*(x10106)*(x10119)))+(((x10115)*(x10121)))+(((IkReal(-1.00000000000000))*(x10105)*(x10117)*(x10120)))+(((IkReal(-1.00000000000000))*(x10107)))+(((IkReal(-1.00000000000000))*(x10118)*(x10129)))+(((IkReal(-1.00000000000000))*(x10110)*(x10121)))+(((IkReal(-1.00000000000000))*(x10105)*(x10108)*(x10118)))+(((IkReal(-1.00000000000000))*(x10102)*(x10106)*(x10114))));
evalcond[5]=((((IkReal(-1.00000000000000))*(x10103)*(x10106)*(x10119)))+(((IkReal(-1.00000000000000))*(r10)*(x10105)*(x10118)))+(((IkReal(-1.00000000000000))*(x10121)*(x10129)))+(((IkReal(-1.00000000000000))*(r00)*(x10105)*(x10120)))+(((IkReal(-1.00000000000000))*(x10105)*(x10108)*(x10121)))+(((r01)*(sj6)*(x10120)))+(((IkReal(-1.00000000000000))*(cj1)*(sj3)))+(((IkReal(-1.00000000000000))*(x10113)*(x10121)))+(((IkReal(-1.00000000000000))*(x10103)*(x10106)*(x10114)))+(((IkReal(-1.00000000000000))*(x10105)*(x10117)*(x10123)))+(((x10110)*(x10118))));
if( IKabs(evalcond[0]) > 0.000001  || IKabs(evalcond[1]) > 0.000001  || IKabs(evalcond[2]) > 0.000001  || IKabs(evalcond[3]) > 0.000001  || IKabs(evalcond[4]) > 0.000001  || IKabs(evalcond[5]) > 0.000001  )
{
continue;
}
}

{
std::vector<IkSingleDOFSolutionBase<IkReal> > vinfos(7);
vinfos[0].jointtype = 1;
vinfos[0].foffset = j0;
vinfos[0].indices[0] = _ij0[0];
vinfos[0].indices[1] = _ij0[1];
vinfos[0].maxsolutions = _nj0;
vinfos[1].jointtype = 1;
vinfos[1].foffset = j1;
vinfos[1].indices[0] = _ij1[0];
vinfos[1].indices[1] = _ij1[1];
vinfos[1].maxsolutions = _nj1;
vinfos[2].jointtype = 1;
vinfos[2].foffset = j2;
vinfos[2].indices[0] = _ij2[0];
vinfos[2].indices[1] = _ij2[1];
vinfos[2].maxsolutions = _nj2;
vinfos[3].jointtype = 1;
vinfos[3].foffset = j3;
vinfos[3].indices[0] = _ij3[0];
vinfos[3].indices[1] = _ij3[1];
vinfos[3].maxsolutions = _nj3;
vinfos[4].jointtype = 1;
vinfos[4].foffset = j4;
vinfos[4].indices[0] = _ij4[0];
vinfos[4].indices[1] = _ij4[1];
vinfos[4].maxsolutions = _nj4;
vinfos[5].jointtype = 1;
vinfos[5].foffset = j5;
vinfos[5].indices[0] = _ij5[0];
vinfos[5].indices[1] = _ij5[1];
vinfos[5].maxsolutions = _nj5;
vinfos[6].jointtype = 1;
vinfos[6].foffset = j6;
vinfos[6].indices[0] = _ij6[0];
vinfos[6].indices[1] = _ij6[1];
vinfos[6].maxsolutions = _nj6;
std::vector<int> vfree(0);
solutions.AddSolution(vinfos,vfree);
}
}
}

}

}
}
}

}

}

} else
{
{
IkReal j4array[1], cj4array[1], sj4array[1];
bool j4valid[1]={false};
_nj4 = 1;
IkReal x10130=((IkReal(1.00000000000000))*(sj1));
IkReal x10131=((cj0)*(cj1));
IkReal x10132=((cj1)*(sj0));
IkReal x10133=((cj5)*(sj6));
IkReal x10134=((cj5)*(cj6));
IkReal x10135=((sj6)*(x10131));
IkReal x10136=((cj6)*(x10132));
if( IKabs(((gconst27)*(((((cj6)*(r00)*(x10131)))+(((IkReal(-1.00000000000000))*(cj6)*(r20)*(x10130)))+(((IkReal(-1.00000000000000))*(r01)*(x10135)))+(((IkReal(-1.00000000000000))*(r11)*(sj6)*(x10132)))+(((r10)*(x10136)))+(((r21)*(sj1)*(sj6))))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(((gconst27)*(((((IkReal(-1.00000000000000))*(r20)*(x10130)*(x10133)))+(((r10)*(x10132)*(x10133)))+(((r00)*(x10131)*(x10133)))+(((r12)*(sj5)*(x10132)))+(((r02)*(sj5)*(x10131)))+(((r01)*(x10131)*(x10134)))+(((IkReal(-1.00000000000000))*(r21)*(x10130)*(x10134)))+(((IkReal(-1.00000000000000))*(r22)*(sj5)*(x10130)))+(((r11)*(x10132)*(x10134))))))) < IKFAST_ATAN2_MAGTHRESH )
    continue;
j4array[0]=IKatan2(((gconst27)*(((((cj6)*(r00)*(x10131)))+(((IkReal(-1.00000000000000))*(cj6)*(r20)*(x10130)))+(((IkReal(-1.00000000000000))*(r01)*(x10135)))+(((IkReal(-1.00000000000000))*(r11)*(sj6)*(x10132)))+(((r10)*(x10136)))+(((r21)*(sj1)*(sj6)))))), ((gconst27)*(((((IkReal(-1.00000000000000))*(r20)*(x10130)*(x10133)))+(((r10)*(x10132)*(x10133)))+(((r00)*(x10131)*(x10133)))+(((r12)*(sj5)*(x10132)))+(((r02)*(sj5)*(x10131)))+(((r01)*(x10131)*(x10134)))+(((IkReal(-1.00000000000000))*(r21)*(x10130)*(x10134)))+(((IkReal(-1.00000000000000))*(r22)*(sj5)*(x10130)))+(((r11)*(x10132)*(x10134)))))));
sj4array[0]=IKsin(j4array[0]);
cj4array[0]=IKcos(j4array[0]);
if( j4array[0] > IKPI )
{
    j4array[0]-=IK2PI;
}
else if( j4array[0] < -IKPI )
{    j4array[0]+=IK2PI;
}
j4valid[0] = true;
for(int ij4 = 0; ij4 < 1; ++ij4)
{
if( !j4valid[ij4] )
{
    continue;
}
_ij4[0] = ij4; _ij4[1] = -1;
for(int iij4 = ij4+1; iij4 < 1; ++iij4)
{
if( j4valid[iij4] && IKabs(cj4array[ij4]-cj4array[iij4]) < IKFAST_SOLUTION_THRESH && IKabs(sj4array[ij4]-sj4array[iij4]) < IKFAST_SOLUTION_THRESH )
{
    j4valid[iij4]=false; _ij4[1] = iij4; break; 
}
}
j4 = j4array[ij4]; cj4 = cj4array[ij4]; sj4 = sj4array[ij4];
{
IkReal evalcond[3];
IkReal x10137=IKsin(j4);
IkReal x10138=IKcos(j4);
IkReal x10139=((r00)*(sj6));
IkReal x10140=((cj6)*(r01));
IkReal x10141=((IkReal(1.00000000000000))*(cj0));
IkReal x10142=((IkReal(1.00000000000000))*(sj0));
IkReal x10143=((r10)*(sj6));
IkReal x10144=((sj5)*(x10137));
IkReal x10145=((IkReal(1.00000000000000))*(cj6)*(r11));
IkReal x10146=((cj5)*(x10137));
IkReal x10147=((cj6)*(x10138));
IkReal x10148=((sj0)*(x10146));
IkReal x10149=((r01)*(sj6)*(x10138));
IkReal x10150=((r11)*(sj6)*(x10138));
evalcond[0]=((((r21)*(sj6)*(x10138)))+(((cj6)*(r21)*(x10146)))+(cj1)+(((r22)*(x10144)))+(((r20)*(sj6)*(x10146)))+(((IkReal(-1.00000000000000))*(r20)*(x10147))));
evalcond[1]=((((x10139)*(x10148)))+(((IkReal(-1.00000000000000))*(x10141)*(x10150)))+(((cj0)*(r10)*(x10147)))+(((IkReal(-1.00000000000000))*(r00)*(x10142)*(x10147)))+(((IkReal(-1.00000000000000))*(x10141)*(x10143)*(x10146)))+(((r02)*(sj0)*(x10144)))+(((x10140)*(x10148)))+(((IkReal(-1.00000000000000))*(r12)*(x10141)*(x10144)))+(((IkReal(-1.00000000000000))*(cj6)*(r11)*(x10141)*(x10146)))+(((sj0)*(x10149))));
evalcond[2]=((((IkReal(-1.00000000000000))*(r02)*(x10141)*(x10144)))+(((IkReal(-1.00000000000000))*(x10140)*(x10141)*(x10146)))+(((IkReal(-1.00000000000000))*(x10139)*(x10141)*(x10146)))+(((IkReal(-1.00000000000000))*(r12)*(x10142)*(x10144)))+(((IkReal(-1.00000000000000))*(x10141)*(x10149)))+(((cj0)*(r00)*(x10147)))+(((r10)*(sj0)*(x10147)))+(((IkReal(-1.00000000000000))*(x10142)*(x10143)*(x10146)))+(((IkReal(-1.00000000000000))*(sj1)))+(((IkReal(-1.00000000000000))*(cj6)*(r11)*(x10142)*(x10146)))+(((IkReal(-1.00000000000000))*(x10142)*(x10150))));
if( IKabs(evalcond[0]) > 0.000001  || IKabs(evalcond[1]) > 0.000001  || IKabs(evalcond[2]) > 0.000001  )
{
continue;
}
}

{
IkReal dummyeval[1];
IkReal gconst30;
gconst30=IKsign(sj1);
dummyeval[0]=sj1;
if( IKabs(dummyeval[0]) < 0.0000010000000000  )
{
{
IkReal dummyeval[1];
dummyeval[0]=sj1;
if( IKabs(dummyeval[0]) < 0.0000010000000000  )
{
{
IkReal dummyeval[1];
dummyeval[0]=cj1;
if( IKabs(dummyeval[0]) < 0.0000010000000000  )
{
{
IkReal evalcond[9];
IkReal x10151=((IkReal(1.00000000000000))*(cj0));
IkReal x10152=((cj4)*(sj6));
IkReal x10153=((sj0)*(sj6));
IkReal x10154=((cj5)*(sj4));
IkReal x10155=((IkReal(0.374290000000000))*(sj5));
IkReal x10156=((sj4)*(sj5));
IkReal x10157=((cj0)*(cj6));
IkReal x10158=((IkReal(0.0100000000000000))*(cj5));
IkReal x10159=((cj4)*(sj5));
IkReal x10160=((cj5)*(sj0));
IkReal x10161=((IkReal(0.374290000000000))*(r02));
IkReal x10162=((r20)*(sj6));
IkReal x10163=((cj6)*(r21));
IkReal x10164=((IkReal(1.00000000000000))*(sj0));
IkReal x10165=((cj0)*(sj6));
IkReal x10166=((cj4)*(cj6));
IkReal x10167=((IkReal(0.374290000000000))*(r12));
IkReal x10168=((cj0)*(cj5));
IkReal x10169=((cj6)*(sj5));
IkReal x10170=((cj6)*(r01));
IkReal x10171=((r00)*(sj6));
IkReal x10172=((IkReal(0.0100000000000000))*(sj5));
IkReal x10173=((cj6)*(r11));
IkReal x10174=((IkReal(1.00000000000000))*(r10));
IkReal x10175=((r02)*(sj0));
IkReal x10176=((cj6)*(sj4));
IkReal x10177=((r12)*(x10164));
evalcond[0]=((IkReal(-3.14159265358979))+(IKfmod(((IkReal(1.57079632679490))+(j1)), IkReal(6.28318530717959))));
evalcond[1]=((((IkReal(-1.00000000000000))*(r20)*(x10166)))+(((r22)*(x10156)))+(((r21)*(x10152)))+(((x10154)*(x10163)))+(((x10154)*(x10162))));
evalcond[2]=((IkReal(0.364420000000000))+(((x10155)*(x10163)))+(((IkReal(-0.374290000000000))*(cj5)*(r22)))+(((x10155)*(x10162)))+(((IkReal(-1.00000000000000))*(x10158)*(x10162)))+(pz)+(((IkReal(-1.00000000000000))*(r22)*(x10172)))+(((IkReal(-1.00000000000000))*(x10158)*(x10163))));
evalcond[3]=((((IkReal(-1.00000000000000))*(sj5)*(x10153)*(x10174)))+(((IkReal(-1.00000000000000))*(sj5)*(x10151)*(x10171)))+(((IkReal(-1.00000000000000))*(r11)*(x10164)*(x10169)))+(((r02)*(x10168)))+(((IkReal(-1.00000000000000))*(r01)*(x10151)*(x10169)))+(((r12)*(x10160))));
evalcond[4]=((((r00)*(x10153)*(x10154)))+(((IkReal(-1.00000000000000))*(r11)*(x10151)*(x10152)))+(((r01)*(sj0)*(x10152)))+(((IkReal(-1.00000000000000))*(r00)*(x10164)*(x10166)))+(((IkReal(-1.00000000000000))*(r12)*(x10151)*(x10156)))+(((x10156)*(x10175)))+(((cj4)*(r10)*(x10157)))+(((IkReal(-1.00000000000000))*(r10)*(sj6)*(x10151)*(x10154)))+(((sj0)*(x10154)*(x10170)))+(((IkReal(-1.00000000000000))*(x10151)*(x10154)*(x10173))));
evalcond[5]=((IkReal(-1.00000000000000))+(((IkReal(-1.00000000000000))*(x10151)*(x10154)*(x10170)))+(((r10)*(sj0)*(x10166)))+(((IkReal(-1.00000000000000))*(r02)*(x10151)*(x10156)))+(((IkReal(-1.00000000000000))*(r11)*(x10152)*(x10164)))+(((IkReal(-1.00000000000000))*(x10151)*(x10154)*(x10171)))+(((cj4)*(r00)*(x10157)))+(((IkReal(-1.00000000000000))*(r01)*(x10151)*(x10152)))+(((IkReal(-1.00000000000000))*(x10153)*(x10154)*(x10174)))+(((IkReal(-1.00000000000000))*(x10154)*(x10164)*(x10173)))+(((IkReal(-1.00000000000000))*(x10156)*(x10177))));
evalcond[6]=((IkReal(-0.0690000000000000))+(((r10)*(x10158)*(x10165)))+(((IkReal(-1.00000000000000))*(x10160)*(x10161)))+(((cj0)*(r12)*(x10172)))+(((IkReal(-1.00000000000000))*(x10172)*(x10175)))+(((IkReal(-1.00000000000000))*(r10)*(x10155)*(x10165)))+(((r11)*(x10157)*(x10158)))+(((IkReal(-1.00000000000000))*(r00)*(x10153)*(x10158)))+(((IkReal(-1.00000000000000))*(sj0)*(x10158)*(x10170)))+(((IkReal(-1.00000000000000))*(py)*(x10151)))+(((px)*(sj0)))+(((x10167)*(x10168)))+(((r00)*(x10153)*(x10155)))+(((sj0)*(x10155)*(x10170)))+(((IkReal(-1.00000000000000))*(r11)*(x10155)*(x10157))));
evalcond[7]=((((IkReal(-1.00000000000000))*(cj5)*(r01)*(x10151)*(x10166)))+(((IkReal(-1.00000000000000))*(cj5)*(r00)*(x10151)*(x10152)))+(((IkReal(-1.00000000000000))*(r00)*(x10151)*(x10176)))+(((IkReal(-1.00000000000000))*(r11)*(x10160)*(x10166)))+(((r01)*(sj4)*(x10165)))+(((r11)*(sj4)*(x10153)))+(((IkReal(-1.00000000000000))*(x10159)*(x10177)))+(((IkReal(-1.00000000000000))*(r02)*(x10151)*(x10159)))+(((IkReal(-1.00000000000000))*(r10)*(x10164)*(x10176)))+(((IkReal(-1.00000000000000))*(x10152)*(x10160)*(x10174))));
evalcond[8]=((IkReal(0.0690000000000000))+(((r00)*(x10158)*(x10165)))+(((x10160)*(x10167)))+(((cj0)*(r02)*(x10172)))+(((IkReal(-1.00000000000000))*(r01)*(x10155)*(x10157)))+(((IkReal(-1.00000000000000))*(px)*(x10151)))+(((r12)*(sj0)*(x10172)))+(((IkReal(-1.00000000000000))*(py)*(x10164)))+(((IkReal(-1.00000000000000))*(r10)*(x10153)*(x10155)))+(((r10)*(x10153)*(x10158)))+(((r01)*(x10157)*(x10158)))+(((sj0)*(x10158)*(x10173)))+(((IkReal(-1.00000000000000))*(r00)*(x10155)*(x10165)))+(((x10161)*(x10168)))+(((IkReal(-1.00000000000000))*(sj0)*(x10155)*(x10173))));
if( IKabs(evalcond[0]) < 0.0000010000000000  && IKabs(evalcond[1]) < 0.0000010000000000  && IKabs(evalcond[2]) < 0.0000010000000000  && IKabs(evalcond[3]) < 0.0000010000000000  && IKabs(evalcond[4]) < 0.0000010000000000  && IKabs(evalcond[5]) < 0.0000010000000000  && IKabs(evalcond[6]) < 0.0000010000000000  && IKabs(evalcond[7]) < 0.0000010000000000  && IKabs(evalcond[8]) < 0.0000010000000000  )
{
{
IkReal j3array[1], cj3array[1], sj3array[1];
bool j3valid[1]={false};
_nj3 = 1;
IkReal x10178=((r20)*(sj6));
IkReal x10179=((cj4)*(cj5));
IkReal x10180=((cj6)*(r21));
if( IKabs(((((IkReal(-1.00000000000000))*(r21)*(sj4)*(sj6)))+(((x10178)*(x10179)))+(((cj6)*(r20)*(sj4)))+(((cj4)*(r22)*(sj5)))+(((x10179)*(x10180))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(((((sj5)*(x10178)))+(((IkReal(-1.00000000000000))*(cj5)*(r22)))+(((sj5)*(x10180))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(IKsqr(((((IkReal(-1.00000000000000))*(r21)*(sj4)*(sj6)))+(((x10178)*(x10179)))+(((cj6)*(r20)*(sj4)))+(((cj4)*(r22)*(sj5)))+(((x10179)*(x10180)))))+IKsqr(((((sj5)*(x10178)))+(((IkReal(-1.00000000000000))*(cj5)*(r22)))+(((sj5)*(x10180)))))-1) <= IKFAST_SINCOS_THRESH )
    continue;
j3array[0]=IKatan2(((((IkReal(-1.00000000000000))*(r21)*(sj4)*(sj6)))+(((x10178)*(x10179)))+(((cj6)*(r20)*(sj4)))+(((cj4)*(r22)*(sj5)))+(((x10179)*(x10180)))), ((((sj5)*(x10178)))+(((IkReal(-1.00000000000000))*(cj5)*(r22)))+(((sj5)*(x10180)))));
sj3array[0]=IKsin(j3array[0]);
cj3array[0]=IKcos(j3array[0]);
if( j3array[0] > IKPI )
{
    j3array[0]-=IK2PI;
}
else if( j3array[0] < -IKPI )
{    j3array[0]+=IK2PI;
}
j3valid[0] = true;
for(int ij3 = 0; ij3 < 1; ++ij3)
{
if( !j3valid[ij3] )
{
    continue;
}
_ij3[0] = ij3; _ij3[1] = -1;
for(int iij3 = ij3+1; iij3 < 1; ++iij3)
{
if( j3valid[iij3] && IKabs(cj3array[ij3]-cj3array[iij3]) < IKFAST_SOLUTION_THRESH && IKabs(sj3array[ij3]-sj3array[iij3]) < IKFAST_SOLUTION_THRESH )
{
    j3valid[iij3]=false; _ij3[1] = iij3; break; 
}
}
j3 = j3array[ij3]; cj3 = cj3array[ij3]; sj3 = sj3array[ij3];
{
IkReal evalcond[4];
IkReal x10181=IKsin(j3);
IkReal x10182=((sj0)*(sj5));
IkReal x10183=((r00)*(sj6));
IkReal x10184=((cj6)*(r01));
IkReal x10185=((cj5)*(sj0));
IkReal x10186=((cj0)*(cj5));
IkReal x10187=((cj6)*(sj4));
IkReal x10188=((sj4)*(sj6));
IkReal x10189=((cj0)*(r11));
IkReal x10190=((cj4)*(cj6));
IkReal x10191=((cj4)*(sj6));
IkReal x10192=((IkReal(1.00000000000000))*(cj0));
IkReal x10193=((cj4)*(sj5));
IkReal x10194=((sj5)*(sj6));
IkReal x10195=((cj6)*(sj5));
IkReal x10196=((IkReal(1.00000000000000))*(IKcos(j3)));
evalcond[0]=((((r20)*(x10194)))+(((IkReal(-1.00000000000000))*(x10196)))+(((r21)*(x10195)))+(((IkReal(-1.00000000000000))*(cj5)*(r22))));
evalcond[1]=((((IkReal(-1.00000000000000))*(r21)*(x10188)))+(((cj5)*(r20)*(x10191)))+(((cj5)*(r21)*(x10190)))+(((r22)*(x10193)))+(((r20)*(x10187)))+(((IkReal(-1.00000000000000))*(x10181))));
evalcond[2]=((((x10182)*(x10184)))+(((x10182)*(x10183)))+(((IkReal(-1.00000000000000))*(x10189)*(x10195)))+(x10181)+(((IkReal(-1.00000000000000))*(r02)*(x10185)))+(((IkReal(-1.00000000000000))*(r10)*(x10192)*(x10194)))+(((r12)*(x10186))));
evalcond[3]=((((cj4)*(x10183)*(x10185)))+(((cj4)*(x10184)*(x10185)))+(((IkReal(-1.00000000000000))*(x10196)))+(((r00)*(sj0)*(x10187)))+(((IkReal(-1.00000000000000))*(r10)*(x10187)*(x10192)))+(((IkReal(-1.00000000000000))*(r11)*(x10186)*(x10190)))+(((x10188)*(x10189)))+(((cj4)*(r02)*(x10182)))+(((IkReal(-1.00000000000000))*(r12)*(x10192)*(x10193)))+(((IkReal(-1.00000000000000))*(r10)*(x10186)*(x10191)))+(((IkReal(-1.00000000000000))*(r01)*(sj0)*(x10188))));
if( IKabs(evalcond[0]) > 0.000001  || IKabs(evalcond[1]) > 0.000001  || IKabs(evalcond[2]) > 0.000001  || IKabs(evalcond[3]) > 0.000001  )
{
continue;
}
}

{
std::vector<IkSingleDOFSolutionBase<IkReal> > vinfos(7);
vinfos[0].jointtype = 1;
vinfos[0].foffset = j0;
vinfos[0].indices[0] = _ij0[0];
vinfos[0].indices[1] = _ij0[1];
vinfos[0].maxsolutions = _nj0;
vinfos[1].jointtype = 1;
vinfos[1].foffset = j1;
vinfos[1].indices[0] = _ij1[0];
vinfos[1].indices[1] = _ij1[1];
vinfos[1].maxsolutions = _nj1;
vinfos[2].jointtype = 1;
vinfos[2].foffset = j2;
vinfos[2].indices[0] = _ij2[0];
vinfos[2].indices[1] = _ij2[1];
vinfos[2].maxsolutions = _nj2;
vinfos[3].jointtype = 1;
vinfos[3].foffset = j3;
vinfos[3].indices[0] = _ij3[0];
vinfos[3].indices[1] = _ij3[1];
vinfos[3].maxsolutions = _nj3;
vinfos[4].jointtype = 1;
vinfos[4].foffset = j4;
vinfos[4].indices[0] = _ij4[0];
vinfos[4].indices[1] = _ij4[1];
vinfos[4].maxsolutions = _nj4;
vinfos[5].jointtype = 1;
vinfos[5].foffset = j5;
vinfos[5].indices[0] = _ij5[0];
vinfos[5].indices[1] = _ij5[1];
vinfos[5].maxsolutions = _nj5;
vinfos[6].jointtype = 1;
vinfos[6].foffset = j6;
vinfos[6].indices[0] = _ij6[0];
vinfos[6].indices[1] = _ij6[1];
vinfos[6].maxsolutions = _nj6;
std::vector<int> vfree(0);
solutions.AddSolution(vinfos,vfree);
}
}
}

} else
{
IkReal x10197=((IkReal(1.00000000000000))*(cj0));
IkReal x10198=((cj4)*(sj6));
IkReal x10199=((sj0)*(sj6));
IkReal x10200=((cj5)*(sj4));
IkReal x10201=((IkReal(0.374290000000000))*(sj5));
IkReal x10202=((sj4)*(sj5));
IkReal x10203=((cj0)*(cj6));
IkReal x10204=((IkReal(0.0100000000000000))*(cj5));
IkReal x10205=((cj4)*(sj5));
IkReal x10206=((cj5)*(sj0));
IkReal x10207=((IkReal(0.374290000000000))*(r02));
IkReal x10208=((r20)*(sj6));
IkReal x10209=((cj6)*(r21));
IkReal x10210=((IkReal(1.00000000000000))*(sj0));
IkReal x10211=((cj0)*(sj6));
IkReal x10212=((cj4)*(cj6));
IkReal x10213=((IkReal(0.374290000000000))*(r12));
IkReal x10214=((cj0)*(cj5));
IkReal x10215=((cj6)*(sj5));
IkReal x10216=((cj6)*(r01));
IkReal x10217=((r00)*(sj6));
IkReal x10218=((IkReal(0.0100000000000000))*(sj5));
IkReal x10219=((cj6)*(r11));
IkReal x10220=((IkReal(1.00000000000000))*(r10));
IkReal x10221=((r02)*(sj0));
IkReal x10222=((cj6)*(sj4));
IkReal x10223=((r12)*(x10210));
evalcond[0]=((IkReal(-3.14159265358979))+(IKfmod(((IkReal(4.71238898038469))+(j1)), IkReal(6.28318530717959))));
evalcond[1]=((((x10200)*(x10209)))+(((r22)*(x10202)))+(((r21)*(x10198)))+(((IkReal(-1.00000000000000))*(r20)*(x10212)))+(((x10200)*(x10208))));
evalcond[2]=((IkReal(-0.364420000000000))+(((IkReal(-1.00000000000000))*(x10204)*(x10209)))+(((x10201)*(x10209)))+(((IkReal(-0.374290000000000))*(cj5)*(r22)))+(pz)+(((IkReal(-1.00000000000000))*(x10204)*(x10208)))+(((x10201)*(x10208)))+(((IkReal(-1.00000000000000))*(r22)*(x10218))));
evalcond[3]=((((IkReal(-1.00000000000000))*(r11)*(x10210)*(x10215)))+(((r02)*(x10214)))+(((r12)*(x10206)))+(((IkReal(-1.00000000000000))*(r01)*(x10197)*(x10215)))+(((IkReal(-1.00000000000000))*(sj5)*(x10199)*(x10220)))+(((IkReal(-1.00000000000000))*(sj5)*(x10197)*(x10217))));
evalcond[4]=((((IkReal(-1.00000000000000))*(r00)*(x10210)*(x10212)))+(((r00)*(x10199)*(x10200)))+(((sj0)*(x10200)*(x10216)))+(((cj4)*(r10)*(x10203)))+(((x10202)*(x10221)))+(((IkReal(-1.00000000000000))*(r10)*(sj6)*(x10197)*(x10200)))+(((IkReal(-1.00000000000000))*(r12)*(x10197)*(x10202)))+(((IkReal(-1.00000000000000))*(r11)*(x10197)*(x10198)))+(((IkReal(-1.00000000000000))*(x10197)*(x10200)*(x10219)))+(((r01)*(sj0)*(x10198))));
evalcond[5]=((IkReal(1.00000000000000))+(((IkReal(-1.00000000000000))*(x10197)*(x10200)*(x10216)))+(((IkReal(-1.00000000000000))*(x10200)*(x10210)*(x10219)))+(((cj4)*(r00)*(x10203)))+(((IkReal(-1.00000000000000))*(x10202)*(x10223)))+(((IkReal(-1.00000000000000))*(r11)*(x10198)*(x10210)))+(((IkReal(-1.00000000000000))*(r01)*(x10197)*(x10198)))+(((IkReal(-1.00000000000000))*(x10199)*(x10200)*(x10220)))+(((r10)*(sj0)*(x10212)))+(((IkReal(-1.00000000000000))*(x10197)*(x10200)*(x10217)))+(((IkReal(-1.00000000000000))*(r02)*(x10197)*(x10202))));
evalcond[6]=((IkReal(-0.0690000000000000))+(((r11)*(x10203)*(x10204)))+(((r00)*(x10199)*(x10201)))+(((IkReal(-1.00000000000000))*(x10218)*(x10221)))+(((x10213)*(x10214)))+(((IkReal(-1.00000000000000))*(r10)*(x10201)*(x10211)))+(((IkReal(-1.00000000000000))*(r00)*(x10199)*(x10204)))+(((IkReal(-1.00000000000000))*(r11)*(x10201)*(x10203)))+(((cj0)*(r12)*(x10218)))+(((sj0)*(x10201)*(x10216)))+(((px)*(sj0)))+(((IkReal(-1.00000000000000))*(py)*(x10197)))+(((IkReal(-1.00000000000000))*(x10206)*(x10207)))+(((IkReal(-1.00000000000000))*(sj0)*(x10204)*(x10216)))+(((r10)*(x10204)*(x10211))));
evalcond[7]=((((IkReal(-1.00000000000000))*(x10205)*(x10223)))+(((IkReal(-1.00000000000000))*(r10)*(x10210)*(x10222)))+(((IkReal(-1.00000000000000))*(x10198)*(x10206)*(x10220)))+(((IkReal(-1.00000000000000))*(r00)*(x10197)*(x10222)))+(((IkReal(-1.00000000000000))*(cj5)*(r00)*(x10197)*(x10198)))+(((r11)*(sj4)*(x10199)))+(((IkReal(-1.00000000000000))*(r11)*(x10206)*(x10212)))+(((r01)*(sj4)*(x10211)))+(((IkReal(-1.00000000000000))*(cj5)*(r01)*(x10197)*(x10212)))+(((IkReal(-1.00000000000000))*(r02)*(x10197)*(x10205))));
evalcond[8]=((IkReal(0.0690000000000000))+(((IkReal(-1.00000000000000))*(px)*(x10197)))+(((IkReal(-1.00000000000000))*(sj0)*(x10201)*(x10219)))+(((r01)*(x10203)*(x10204)))+(((sj0)*(x10204)*(x10219)))+(((IkReal(-1.00000000000000))*(r01)*(x10201)*(x10203)))+(((r10)*(x10199)*(x10204)))+(((x10206)*(x10213)))+(((x10207)*(x10214)))+(((IkReal(-1.00000000000000))*(r00)*(x10201)*(x10211)))+(((IkReal(-1.00000000000000))*(py)*(x10210)))+(((cj0)*(r02)*(x10218)))+(((IkReal(-1.00000000000000))*(r10)*(x10199)*(x10201)))+(((r12)*(sj0)*(x10218)))+(((r00)*(x10204)*(x10211))));
if( IKabs(evalcond[0]) < 0.0000010000000000  && IKabs(evalcond[1]) < 0.0000010000000000  && IKabs(evalcond[2]) < 0.0000010000000000  && IKabs(evalcond[3]) < 0.0000010000000000  && IKabs(evalcond[4]) < 0.0000010000000000  && IKabs(evalcond[5]) < 0.0000010000000000  && IKabs(evalcond[6]) < 0.0000010000000000  && IKabs(evalcond[7]) < 0.0000010000000000  && IKabs(evalcond[8]) < 0.0000010000000000  )
{
{
IkReal j3array[1], cj3array[1], sj3array[1];
bool j3valid[1]={false};
_nj3 = 1;
IkReal x10224=((IkReal(1.00000000000000))*(sj5));
IkReal x10225=((cj6)*(r21));
IkReal x10226=((r20)*(sj6));
IkReal x10227=((IkReal(1.00000000000000))*(cj4)*(cj5));
if( IKabs(((((IkReal(-1.00000000000000))*(x10225)*(x10227)))+(((r21)*(sj4)*(sj6)))+(((IkReal(-1.00000000000000))*(cj4)*(r22)*(x10224)))+(((IkReal(-1.00000000000000))*(x10226)*(x10227)))+(((IkReal(-1.00000000000000))*(cj6)*(r20)*(sj4))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(((((cj5)*(r22)))+(((IkReal(-1.00000000000000))*(x10224)*(x10226)))+(((IkReal(-1.00000000000000))*(x10224)*(x10225))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(IKsqr(((((IkReal(-1.00000000000000))*(x10225)*(x10227)))+(((r21)*(sj4)*(sj6)))+(((IkReal(-1.00000000000000))*(cj4)*(r22)*(x10224)))+(((IkReal(-1.00000000000000))*(x10226)*(x10227)))+(((IkReal(-1.00000000000000))*(cj6)*(r20)*(sj4)))))+IKsqr(((((cj5)*(r22)))+(((IkReal(-1.00000000000000))*(x10224)*(x10226)))+(((IkReal(-1.00000000000000))*(x10224)*(x10225)))))-1) <= IKFAST_SINCOS_THRESH )
    continue;
j3array[0]=IKatan2(((((IkReal(-1.00000000000000))*(x10225)*(x10227)))+(((r21)*(sj4)*(sj6)))+(((IkReal(-1.00000000000000))*(cj4)*(r22)*(x10224)))+(((IkReal(-1.00000000000000))*(x10226)*(x10227)))+(((IkReal(-1.00000000000000))*(cj6)*(r20)*(sj4)))), ((((cj5)*(r22)))+(((IkReal(-1.00000000000000))*(x10224)*(x10226)))+(((IkReal(-1.00000000000000))*(x10224)*(x10225)))));
sj3array[0]=IKsin(j3array[0]);
cj3array[0]=IKcos(j3array[0]);
if( j3array[0] > IKPI )
{
    j3array[0]-=IK2PI;
}
else if( j3array[0] < -IKPI )
{    j3array[0]+=IK2PI;
}
j3valid[0] = true;
for(int ij3 = 0; ij3 < 1; ++ij3)
{
if( !j3valid[ij3] )
{
    continue;
}
_ij3[0] = ij3; _ij3[1] = -1;
for(int iij3 = ij3+1; iij3 < 1; ++iij3)
{
if( j3valid[iij3] && IKabs(cj3array[ij3]-cj3array[iij3]) < IKFAST_SOLUTION_THRESH && IKabs(sj3array[ij3]-sj3array[iij3]) < IKFAST_SOLUTION_THRESH )
{
    j3valid[iij3]=false; _ij3[1] = iij3; break; 
}
}
j3 = j3array[ij3]; cj3 = cj3array[ij3]; sj3 = sj3array[ij3];
{
IkReal evalcond[4];
IkReal x10228=IKsin(j3);
IkReal x10229=IKcos(j3);
IkReal x10230=((sj0)*(sj5));
IkReal x10231=((r00)*(sj6));
IkReal x10232=((cj6)*(r01));
IkReal x10233=((cj0)*(cj5));
IkReal x10234=((IkReal(1.00000000000000))*(cj5));
IkReal x10235=((cj4)*(cj5));
IkReal x10236=((cj6)*(sj4));
IkReal x10237=((sj4)*(sj6));
IkReal x10238=((cj0)*(r11));
IkReal x10239=((IkReal(1.00000000000000))*(cj4));
IkReal x10240=((cj6)*(r21));
IkReal x10241=((r20)*(sj6));
IkReal x10242=((cj0)*(sj5));
IkReal x10243=((r10)*(sj6));
evalcond[0]=((((sj5)*(x10240)))+(((sj5)*(x10241)))+(((IkReal(-1.00000000000000))*(r22)*(x10234)))+(x10229));
evalcond[1]=((((x10235)*(x10240)))+(x10228)+(((IkReal(-1.00000000000000))*(r21)*(x10237)))+(((cj4)*(r22)*(sj5)))+(((x10235)*(x10241)))+(((r20)*(x10236))));
evalcond[2]=((((IkReal(-1.00000000000000))*(r02)*(sj0)*(x10234)))+(((IkReal(-1.00000000000000))*(cj6)*(sj5)*(x10238)))+(((IkReal(-1.00000000000000))*(x10242)*(x10243)))+(x10228)+(((r12)*(x10233)))+(((x10230)*(x10232)))+(((x10230)*(x10231))));
evalcond[3]=((((IkReal(-1.00000000000000))*(cj6)*(r11)*(x10233)*(x10239)))+(((r00)*(sj0)*(x10236)))+(((IkReal(-1.00000000000000))*(x10229)))+(((x10237)*(x10238)))+(((cj4)*(r02)*(x10230)))+(((IkReal(-1.00000000000000))*(r12)*(x10239)*(x10242)))+(((IkReal(-1.00000000000000))*(r01)*(sj0)*(x10237)))+(((sj0)*(x10232)*(x10235)))+(((sj0)*(x10231)*(x10235)))+(((IkReal(-1.00000000000000))*(cj0)*(r10)*(x10236)))+(((IkReal(-1.00000000000000))*(x10233)*(x10239)*(x10243))));
if( IKabs(evalcond[0]) > 0.000001  || IKabs(evalcond[1]) > 0.000001  || IKabs(evalcond[2]) > 0.000001  || IKabs(evalcond[3]) > 0.000001  )
{
continue;
}
}

{
std::vector<IkSingleDOFSolutionBase<IkReal> > vinfos(7);
vinfos[0].jointtype = 1;
vinfos[0].foffset = j0;
vinfos[0].indices[0] = _ij0[0];
vinfos[0].indices[1] = _ij0[1];
vinfos[0].maxsolutions = _nj0;
vinfos[1].jointtype = 1;
vinfos[1].foffset = j1;
vinfos[1].indices[0] = _ij1[0];
vinfos[1].indices[1] = _ij1[1];
vinfos[1].maxsolutions = _nj1;
vinfos[2].jointtype = 1;
vinfos[2].foffset = j2;
vinfos[2].indices[0] = _ij2[0];
vinfos[2].indices[1] = _ij2[1];
vinfos[2].maxsolutions = _nj2;
vinfos[3].jointtype = 1;
vinfos[3].foffset = j3;
vinfos[3].indices[0] = _ij3[0];
vinfos[3].indices[1] = _ij3[1];
vinfos[3].maxsolutions = _nj3;
vinfos[4].jointtype = 1;
vinfos[4].foffset = j4;
vinfos[4].indices[0] = _ij4[0];
vinfos[4].indices[1] = _ij4[1];
vinfos[4].maxsolutions = _nj4;
vinfos[5].jointtype = 1;
vinfos[5].foffset = j5;
vinfos[5].indices[0] = _ij5[0];
vinfos[5].indices[1] = _ij5[1];
vinfos[5].maxsolutions = _nj5;
vinfos[6].jointtype = 1;
vinfos[6].foffset = j6;
vinfos[6].indices[0] = _ij6[0];
vinfos[6].indices[1] = _ij6[1];
vinfos[6].maxsolutions = _nj6;
std::vector<int> vfree(0);
solutions.AddSolution(vinfos,vfree);
}
}
}

} else
{
IkReal x10244=((IkReal(1.00000000000000))*(cj0));
IkReal x10245=((cj4)*(sj6));
IkReal x10246=((sj0)*(sj4));
IkReal x10247=((cj5)*(sj6));
IkReal x10248=((sj4)*(sj5));
IkReal x10249=((r12)*(sj5));
IkReal x10250=((IkReal(0.374290000000000))*(cj5));
IkReal x10251=((r02)*(sj0));
IkReal x10252=((r20)*(sj4));
IkReal x10253=((IkReal(1.00000000000000))*(sj0));
IkReal x10254=((IkReal(1.00000000000000))*(cj5));
IkReal x10255=((cj0)*(r10));
IkReal x10256=((cj4)*(cj6));
IkReal x10257=((r00)*(sj0));
IkReal x10258=((cj6)*(r21));
IkReal x10259=((IkReal(0.374290000000000))*(sj5));
IkReal x10260=((cj0)*(r00));
IkReal x10261=((IkReal(0.0100000000000000))*(sj5));
IkReal x10262=((cj0)*(r02));
IkReal x10263=((cj5)*(sj4));
IkReal x10264=((cj6)*(r01));
IkReal x10265=((cj6)*(r11));
IkReal x10266=((r01)*(sj0));
IkReal x10267=((r10)*(sj0));
IkReal x10268=((IkReal(0.0100000000000000))*(cj5)*(cj6));
IkReal x10269=((sj6)*(x10259));
IkReal x10270=((cj0)*(cj6)*(x10259));
evalcond[0]=((IkReal(-3.14159265358979))+(IKfmod(((IkReal(3.14159265358979))+(j1)), IkReal(6.28318530717959))));
evalcond[1]=((((IkReal(-1.00000000000000))*(r22)*(x10254)))+(((sj5)*(x10258)))+(((r20)*(sj5)*(sj6))));
evalcond[2]=((IkReal(1.00000000000000))+(((IkReal(-1.00000000000000))*(r20)*(x10256)))+(((x10247)*(x10252)))+(((x10258)*(x10263)))+(((r22)*(x10248)))+(((r21)*(x10245))));
evalcond[3]=((((IkReal(-1.00000000000000))*(r22)*(x10250)))+(((r20)*(x10269)))+(((x10258)*(x10259)))+(((IkReal(-0.0100000000000000))*(r20)*(x10247)))+(pz)+(((IkReal(-0.0100000000000000))*(cj5)*(x10258)))+(((IkReal(-1.00000000000000))*(r22)*(x10261))));
evalcond[4]=((((IkReal(-1.00000000000000))*(r21)*(sj4)*(sj6)))+(((cj4)*(r22)*(sj5)))+(((cj5)*(r20)*(x10245)))+(((cj5)*(r21)*(x10256)))+(((cj6)*(x10252))));
evalcond[5]=((((IkReal(-1.00000000000000))*(x10244)*(x10263)*(x10265)))+(((IkReal(-1.00000000000000))*(r11)*(x10244)*(x10245)))+(((cj5)*(x10246)*(x10264)))+(((r02)*(sj5)*(x10246)))+(((x10245)*(x10266)))+(((IkReal(-1.00000000000000))*(r12)*(x10244)*(x10248)))+(((IkReal(-1.00000000000000))*(r10)*(sj4)*(x10244)*(x10247)))+(((IkReal(-1.00000000000000))*(r00)*(x10253)*(x10256)))+(((r00)*(x10246)*(x10247)))+(((x10255)*(x10256))));
evalcond[6]=((((IkReal(-1.00000000000000))*(x10244)*(x10263)*(x10264)))+(((IkReal(-1.00000000000000))*(r02)*(x10244)*(x10248)))+(((IkReal(-1.00000000000000))*(r10)*(x10246)*(x10247)))+(((IkReal(-1.00000000000000))*(x10246)*(x10249)))+(((IkReal(-1.00000000000000))*(x10246)*(x10254)*(x10265)))+(((IkReal(-1.00000000000000))*(r11)*(x10245)*(x10253)))+(((x10256)*(x10260)))+(((IkReal(-1.00000000000000))*(r00)*(sj4)*(x10244)*(x10247)))+(((IkReal(-1.00000000000000))*(r01)*(x10244)*(x10245)))+(((x10256)*(x10267))));
evalcond[7]=((IkReal(-0.0690000000000000))+(((sj0)*(x10259)*(x10264)))+(((cj0)*(r12)*(x10250)))+(((IkReal(-0.0100000000000000))*(x10247)*(x10257)))+(((IkReal(-1.00000000000000))*(x10251)*(x10261)))+(((IkReal(0.0100000000000000))*(cj0)*(cj5)*(x10265)))+(((IkReal(-0.0100000000000000))*(cj5)*(sj0)*(x10264)))+(((IkReal(0.0100000000000000))*(x10247)*(x10255)))+(((IkReal(-1.00000000000000))*(x10255)*(x10269)))+(((IkReal(-1.00000000000000))*(py)*(x10244)))+(((IkReal(-1.00000000000000))*(cj0)*(x10259)*(x10265)))+(((px)*(sj0)))+(((x10257)*(x10269)))+(((IkReal(-1.00000000000000))*(x10250)*(x10251)))+(((IkReal(0.0100000000000000))*(cj0)*(x10249))));
evalcond[8]=((IkReal(0.433420000000000))+(((r12)*(sj0)*(x10250)))+(((IkReal(0.0100000000000000))*(cj5)*(sj0)*(x10265)))+(((IkReal(-1.00000000000000))*(py)*(x10253)))+(((IkReal(-1.00000000000000))*(cj0)*(x10259)*(x10264)))+(((IkReal(-1.00000000000000))*(px)*(x10244)))+(((IkReal(-1.00000000000000))*(x10260)*(x10269)))+(((IkReal(0.0100000000000000))*(cj0)*(cj5)*(x10264)))+(((x10261)*(x10262)))+(((IkReal(-1.00000000000000))*(sj0)*(x10259)*(x10265)))+(((IkReal(0.0100000000000000))*(sj0)*(x10249)))+(((IkReal(0.0100000000000000))*(x10247)*(x10267)))+(((x10250)*(x10262)))+(((IkReal(-1.00000000000000))*(x10267)*(x10269)))+(((IkReal(0.0100000000000000))*(x10247)*(x10260))));
if( IKabs(evalcond[0]) < 0.0000010000000000  && IKabs(evalcond[1]) < 0.0000010000000000  && IKabs(evalcond[2]) < 0.0000010000000000  && IKabs(evalcond[3]) < 0.0000010000000000  && IKabs(evalcond[4]) < 0.0000010000000000  && IKabs(evalcond[5]) < 0.0000010000000000  && IKabs(evalcond[6]) < 0.0000010000000000  && IKabs(evalcond[7]) < 0.0000010000000000  && IKabs(evalcond[8]) < 0.0000010000000000  )
{
{
IkReal j3array[1], cj3array[1], sj3array[1];
bool j3valid[1]={false};
_nj3 = 1;
IkReal x10271=((cj5)*(r02));
IkReal x10272=((cj0)*(sj5));
IkReal x10273=((r10)*(sj6));
IkReal x10274=((IkReal(1.00000000000000))*(cj6));
IkReal x10275=((sj0)*(sj5));
IkReal x10276=((cj5)*(r12));
IkReal x10277=((IkReal(1.00000000000000))*(r00)*(sj6));
if( IKabs(((((IkReal(-1.00000000000000))*(r01)*(x10274)*(x10275)))+(((cj6)*(r11)*(x10272)))+(((x10272)*(x10273)))+(((IkReal(-1.00000000000000))*(x10275)*(x10277)))+(((IkReal(-1.00000000000000))*(cj0)*(x10276)))+(((sj0)*(x10271))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(((((IkReal(-1.00000000000000))*(x10272)*(x10277)))+(((IkReal(-1.00000000000000))*(r11)*(x10274)*(x10275)))+(((IkReal(-1.00000000000000))*(r01)*(x10272)*(x10274)))+(((IkReal(-1.00000000000000))*(x10273)*(x10275)))+(((cj0)*(x10271)))+(((sj0)*(x10276))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(IKsqr(((((IkReal(-1.00000000000000))*(r01)*(x10274)*(x10275)))+(((cj6)*(r11)*(x10272)))+(((x10272)*(x10273)))+(((IkReal(-1.00000000000000))*(x10275)*(x10277)))+(((IkReal(-1.00000000000000))*(cj0)*(x10276)))+(((sj0)*(x10271)))))+IKsqr(((((IkReal(-1.00000000000000))*(x10272)*(x10277)))+(((IkReal(-1.00000000000000))*(r11)*(x10274)*(x10275)))+(((IkReal(-1.00000000000000))*(r01)*(x10272)*(x10274)))+(((IkReal(-1.00000000000000))*(x10273)*(x10275)))+(((cj0)*(x10271)))+(((sj0)*(x10276)))))-1) <= IKFAST_SINCOS_THRESH )
    continue;
j3array[0]=IKatan2(((((IkReal(-1.00000000000000))*(r01)*(x10274)*(x10275)))+(((cj6)*(r11)*(x10272)))+(((x10272)*(x10273)))+(((IkReal(-1.00000000000000))*(x10275)*(x10277)))+(((IkReal(-1.00000000000000))*(cj0)*(x10276)))+(((sj0)*(x10271)))), ((((IkReal(-1.00000000000000))*(x10272)*(x10277)))+(((IkReal(-1.00000000000000))*(r11)*(x10274)*(x10275)))+(((IkReal(-1.00000000000000))*(r01)*(x10272)*(x10274)))+(((IkReal(-1.00000000000000))*(x10273)*(x10275)))+(((cj0)*(x10271)))+(((sj0)*(x10276)))));
sj3array[0]=IKsin(j3array[0]);
cj3array[0]=IKcos(j3array[0]);
if( j3array[0] > IKPI )
{
    j3array[0]-=IK2PI;
}
else if( j3array[0] < -IKPI )
{    j3array[0]+=IK2PI;
}
j3valid[0] = true;
for(int ij3 = 0; ij3 < 1; ++ij3)
{
if( !j3valid[ij3] )
{
    continue;
}
_ij3[0] = ij3; _ij3[1] = -1;
for(int iij3 = ij3+1; iij3 < 1; ++iij3)
{
if( j3valid[iij3] && IKabs(cj3array[ij3]-cj3array[iij3]) < IKFAST_SOLUTION_THRESH && IKabs(sj3array[ij3]-sj3array[iij3]) < IKFAST_SOLUTION_THRESH )
{
    j3valid[iij3]=false; _ij3[1] = iij3; break; 
}
}
j3 = j3array[ij3]; cj3 = cj3array[ij3]; sj3 = sj3array[ij3];
{
IkReal evalcond[4];
IkReal x10278=IKsin(j3);
IkReal x10279=((sj0)*(sj5));
IkReal x10280=((r00)*(sj6));
IkReal x10281=((IkReal(1.00000000000000))*(cj4));
IkReal x10282=((cj6)*(sj0));
IkReal x10283=((r00)*(sj4));
IkReal x10284=((cj0)*(cj5));
IkReal x10285=((cj6)*(r01));
IkReal x10286=((cj5)*(sj0));
IkReal x10287=((cj0)*(sj5));
IkReal x10288=((cj6)*(r11));
IkReal x10289=((r10)*(sj6));
IkReal x10290=((r10)*(sj4));
IkReal x10291=((IkReal(1.00000000000000))*(IKcos(j3)));
IkReal x10292=((cj0)*(sj4)*(sj6));
IkReal x10293=((sj0)*(sj4)*(sj6));
IkReal x10294=((IkReal(1.00000000000000))*(cj0)*(cj6));
evalcond[0]=((x10278)+(((r12)*(x10284)))+(((x10279)*(x10280)))+(((x10279)*(x10285)))+(((IkReal(-1.00000000000000))*(x10287)*(x10288)))+(((IkReal(-1.00000000000000))*(r02)*(x10286)))+(((IkReal(-1.00000000000000))*(x10287)*(x10289))));
evalcond[1]=((((r12)*(x10286)))+(((IkReal(-1.00000000000000))*(x10279)*(x10289)))+(((r02)*(x10284)))+(((IkReal(-1.00000000000000))*(x10291)))+(((IkReal(-1.00000000000000))*(x10285)*(x10287)))+(((IkReal(-1.00000000000000))*(x10280)*(x10287)))+(((IkReal(-1.00000000000000))*(x10279)*(x10288))));
evalcond[2]=((((cj4)*(r02)*(x10279)))+(((IkReal(-1.00000000000000))*(x10290)*(x10294)))+(((IkReal(-1.00000000000000))*(x10291)))+(((IkReal(-1.00000000000000))*(r12)*(x10281)*(x10287)))+(((IkReal(-1.00000000000000))*(x10281)*(x10284)*(x10288)))+(((IkReal(-1.00000000000000))*(r01)*(x10293)))+(((r11)*(x10292)))+(((cj4)*(cj5)*(r01)*(x10282)))+(((IkReal(-1.00000000000000))*(x10281)*(x10284)*(x10289)))+(((x10282)*(x10283)))+(((cj4)*(x10280)*(x10286))));
evalcond[3]=((((IkReal(-1.00000000000000))*(x10281)*(x10284)*(x10285)))+(((IkReal(-1.00000000000000))*(r12)*(x10279)*(x10281)))+(((IkReal(-1.00000000000000))*(x10281)*(x10286)*(x10289)))+(((r01)*(x10292)))+(((IkReal(-1.00000000000000))*(x10283)*(x10294)))+(((IkReal(-1.00000000000000))*(r02)*(x10281)*(x10287)))+(((IkReal(-1.00000000000000))*(x10282)*(x10290)))+(((IkReal(-1.00000000000000))*(x10280)*(x10281)*(x10284)))+(((IkReal(-1.00000000000000))*(cj5)*(r11)*(x10281)*(x10282)))+(((r11)*(x10293)))+(((IkReal(-1.00000000000000))*(x10278))));
if( IKabs(evalcond[0]) > 0.000001  || IKabs(evalcond[1]) > 0.000001  || IKabs(evalcond[2]) > 0.000001  || IKabs(evalcond[3]) > 0.000001  )
{
continue;
}
}

{
std::vector<IkSingleDOFSolutionBase<IkReal> > vinfos(7);
vinfos[0].jointtype = 1;
vinfos[0].foffset = j0;
vinfos[0].indices[0] = _ij0[0];
vinfos[0].indices[1] = _ij0[1];
vinfos[0].maxsolutions = _nj0;
vinfos[1].jointtype = 1;
vinfos[1].foffset = j1;
vinfos[1].indices[0] = _ij1[0];
vinfos[1].indices[1] = _ij1[1];
vinfos[1].maxsolutions = _nj1;
vinfos[2].jointtype = 1;
vinfos[2].foffset = j2;
vinfos[2].indices[0] = _ij2[0];
vinfos[2].indices[1] = _ij2[1];
vinfos[2].maxsolutions = _nj2;
vinfos[3].jointtype = 1;
vinfos[3].foffset = j3;
vinfos[3].indices[0] = _ij3[0];
vinfos[3].indices[1] = _ij3[1];
vinfos[3].maxsolutions = _nj3;
vinfos[4].jointtype = 1;
vinfos[4].foffset = j4;
vinfos[4].indices[0] = _ij4[0];
vinfos[4].indices[1] = _ij4[1];
vinfos[4].maxsolutions = _nj4;
vinfos[5].jointtype = 1;
vinfos[5].foffset = j5;
vinfos[5].indices[0] = _ij5[0];
vinfos[5].indices[1] = _ij5[1];
vinfos[5].maxsolutions = _nj5;
vinfos[6].jointtype = 1;
vinfos[6].foffset = j6;
vinfos[6].indices[0] = _ij6[0];
vinfos[6].indices[1] = _ij6[1];
vinfos[6].maxsolutions = _nj6;
std::vector<int> vfree(0);
solutions.AddSolution(vinfos,vfree);
}
}
}

} else
{
IkReal x10295=((IkReal(1.00000000000000))*(cj0));
IkReal x10296=((cj4)*(sj6));
IkReal x10297=((sj0)*(sj4));
IkReal x10298=((cj5)*(sj6));
IkReal x10299=((sj4)*(sj5));
IkReal x10300=((r12)*(sj5));
IkReal x10301=((IkReal(0.374290000000000))*(cj5));
IkReal x10302=((r02)*(sj0));
IkReal x10303=((r20)*(sj4));
IkReal x10304=((IkReal(1.00000000000000))*(sj0));
IkReal x10305=((IkReal(1.00000000000000))*(cj5));
IkReal x10306=((cj0)*(r10));
IkReal x10307=((cj4)*(cj6));
IkReal x10308=((r00)*(sj0));
IkReal x10309=((cj6)*(r21));
IkReal x10310=((IkReal(0.374290000000000))*(sj5));
IkReal x10311=((cj0)*(r00));
IkReal x10312=((IkReal(0.0100000000000000))*(sj5));
IkReal x10313=((cj0)*(r02));
IkReal x10314=((cj5)*(sj4));
IkReal x10315=((cj6)*(r01));
IkReal x10316=((cj6)*(r11));
IkReal x10317=((r01)*(sj0));
IkReal x10318=((r10)*(sj0));
IkReal x10319=((IkReal(0.0100000000000000))*(cj5)*(cj6));
IkReal x10320=((sj6)*(x10310));
IkReal x10321=((cj0)*(cj6)*(x10310));
evalcond[0]=((IkReal(-3.14159265358979))+(IKfmod(j1, IkReal(6.28318530717959))));
evalcond[1]=((((IkReal(-1.00000000000000))*(r22)*(x10305)))+(((sj5)*(x10309)))+(((r20)*(sj5)*(sj6))));
evalcond[2]=((IkReal(-1.00000000000000))+(((r21)*(x10296)))+(((x10298)*(x10303)))+(((x10309)*(x10314)))+(((IkReal(-1.00000000000000))*(r20)*(x10307)))+(((r22)*(x10299))));
evalcond[3]=((((IkReal(-1.00000000000000))*(r22)*(x10312)))+(((r20)*(x10320)))+(((IkReal(-0.0100000000000000))*(cj5)*(x10309)))+(((IkReal(-0.0100000000000000))*(r20)*(x10298)))+(((x10309)*(x10310)))+(pz)+(((IkReal(-1.00000000000000))*(r22)*(x10301))));
evalcond[4]=((((IkReal(-1.00000000000000))*(r21)*(sj4)*(sj6)))+(((cj5)*(r21)*(x10307)))+(((cj5)*(r20)*(x10296)))+(((cj4)*(r22)*(sj5)))+(((cj6)*(x10303))));
evalcond[5]=((((IkReal(-1.00000000000000))*(r11)*(x10295)*(x10296)))+(((cj5)*(x10297)*(x10315)))+(((IkReal(-1.00000000000000))*(r10)*(sj4)*(x10295)*(x10298)))+(((x10296)*(x10317)))+(((r02)*(sj5)*(x10297)))+(((IkReal(-1.00000000000000))*(r12)*(x10295)*(x10299)))+(((r00)*(x10297)*(x10298)))+(((x10306)*(x10307)))+(((IkReal(-1.00000000000000))*(r00)*(x10304)*(x10307)))+(((IkReal(-1.00000000000000))*(x10295)*(x10314)*(x10316))));
evalcond[6]=((((IkReal(-1.00000000000000))*(x10297)*(x10305)*(x10316)))+(((IkReal(-1.00000000000000))*(x10295)*(x10314)*(x10315)))+(((IkReal(-1.00000000000000))*(r02)*(x10295)*(x10299)))+(((x10307)*(x10311)))+(((IkReal(-1.00000000000000))*(r11)*(x10296)*(x10304)))+(((IkReal(-1.00000000000000))*(r01)*(x10295)*(x10296)))+(((x10307)*(x10318)))+(((IkReal(-1.00000000000000))*(x10297)*(x10300)))+(((IkReal(-1.00000000000000))*(r00)*(sj4)*(x10295)*(x10298)))+(((IkReal(-1.00000000000000))*(r10)*(x10297)*(x10298))));
evalcond[7]=((IkReal(-0.0690000000000000))+(((IkReal(0.0100000000000000))*(x10298)*(x10306)))+(((IkReal(-1.00000000000000))*(cj0)*(x10310)*(x10316)))+(((IkReal(-1.00000000000000))*(x10306)*(x10320)))+(((cj0)*(r12)*(x10301)))+(((IkReal(-1.00000000000000))*(x10301)*(x10302)))+(((IkReal(-1.00000000000000))*(x10302)*(x10312)))+(((x10308)*(x10320)))+(((IkReal(-0.0100000000000000))*(x10298)*(x10308)))+(((IkReal(-1.00000000000000))*(py)*(x10295)))+(((sj0)*(x10310)*(x10315)))+(((IkReal(-0.0100000000000000))*(cj5)*(sj0)*(x10315)))+(((IkReal(0.0100000000000000))*(cj0)*(x10300)))+(((IkReal(0.0100000000000000))*(cj0)*(cj5)*(x10316)))+(((px)*(sj0))));
evalcond[8]=((IkReal(-0.295420000000000))+(((IkReal(-1.00000000000000))*(px)*(x10295)))+(((IkReal(0.0100000000000000))*(cj0)*(cj5)*(x10315)))+(((IkReal(0.0100000000000000))*(x10298)*(x10311)))+(((IkReal(0.0100000000000000))*(sj0)*(x10300)))+(((IkReal(0.0100000000000000))*(x10298)*(x10318)))+(((IkReal(-1.00000000000000))*(py)*(x10304)))+(((IkReal(-1.00000000000000))*(x10318)*(x10320)))+(((IkReal(0.0100000000000000))*(cj5)*(sj0)*(x10316)))+(((r12)*(sj0)*(x10301)))+(((IkReal(-1.00000000000000))*(x10311)*(x10320)))+(((IkReal(-1.00000000000000))*(cj0)*(x10310)*(x10315)))+(((x10312)*(x10313)))+(((IkReal(-1.00000000000000))*(sj0)*(x10310)*(x10316)))+(((x10301)*(x10313))));
if( IKabs(evalcond[0]) < 0.0000010000000000  && IKabs(evalcond[1]) < 0.0000010000000000  && IKabs(evalcond[2]) < 0.0000010000000000  && IKabs(evalcond[3]) < 0.0000010000000000  && IKabs(evalcond[4]) < 0.0000010000000000  && IKabs(evalcond[5]) < 0.0000010000000000  && IKabs(evalcond[6]) < 0.0000010000000000  && IKabs(evalcond[7]) < 0.0000010000000000  && IKabs(evalcond[8]) < 0.0000010000000000  )
{
{
IkReal j3array[1], cj3array[1], sj3array[1];
bool j3valid[1]={false};
_nj3 = 1;
IkReal x10322=((IkReal(1.00000000000000))*(cj5));
IkReal x10323=((r10)*(sj5)*(sj6));
IkReal x10324=((cj6)*(sj0)*(sj5));
IkReal x10325=((r00)*(sj5)*(sj6));
IkReal x10326=((cj0)*(cj6)*(sj5));
if( IKabs(((((IkReal(-1.00000000000000))*(cj0)*(r12)*(x10322)))+(((r11)*(x10326)))+(((cj0)*(x10323)))+(((IkReal(-1.00000000000000))*(sj0)*(x10325)))+(((cj5)*(r02)*(sj0)))+(((IkReal(-1.00000000000000))*(r01)*(x10324))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(((((sj0)*(x10323)))+(((cj0)*(x10325)))+(((IkReal(-1.00000000000000))*(cj0)*(r02)*(x10322)))+(((r11)*(x10324)))+(((IkReal(-1.00000000000000))*(r12)*(sj0)*(x10322)))+(((r01)*(x10326))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(IKsqr(((((IkReal(-1.00000000000000))*(cj0)*(r12)*(x10322)))+(((r11)*(x10326)))+(((cj0)*(x10323)))+(((IkReal(-1.00000000000000))*(sj0)*(x10325)))+(((cj5)*(r02)*(sj0)))+(((IkReal(-1.00000000000000))*(r01)*(x10324)))))+IKsqr(((((sj0)*(x10323)))+(((cj0)*(x10325)))+(((IkReal(-1.00000000000000))*(cj0)*(r02)*(x10322)))+(((r11)*(x10324)))+(((IkReal(-1.00000000000000))*(r12)*(sj0)*(x10322)))+(((r01)*(x10326)))))-1) <= IKFAST_SINCOS_THRESH )
    continue;
j3array[0]=IKatan2(((((IkReal(-1.00000000000000))*(cj0)*(r12)*(x10322)))+(((r11)*(x10326)))+(((cj0)*(x10323)))+(((IkReal(-1.00000000000000))*(sj0)*(x10325)))+(((cj5)*(r02)*(sj0)))+(((IkReal(-1.00000000000000))*(r01)*(x10324)))), ((((sj0)*(x10323)))+(((cj0)*(x10325)))+(((IkReal(-1.00000000000000))*(cj0)*(r02)*(x10322)))+(((r11)*(x10324)))+(((IkReal(-1.00000000000000))*(r12)*(sj0)*(x10322)))+(((r01)*(x10326)))));
sj3array[0]=IKsin(j3array[0]);
cj3array[0]=IKcos(j3array[0]);
if( j3array[0] > IKPI )
{
    j3array[0]-=IK2PI;
}
else if( j3array[0] < -IKPI )
{    j3array[0]+=IK2PI;
}
j3valid[0] = true;
for(int ij3 = 0; ij3 < 1; ++ij3)
{
if( !j3valid[ij3] )
{
    continue;
}
_ij3[0] = ij3; _ij3[1] = -1;
for(int iij3 = ij3+1; iij3 < 1; ++iij3)
{
if( j3valid[iij3] && IKabs(cj3array[ij3]-cj3array[iij3]) < IKFAST_SOLUTION_THRESH && IKabs(sj3array[ij3]-sj3array[iij3]) < IKFAST_SOLUTION_THRESH )
{
    j3valid[iij3]=false; _ij3[1] = iij3; break; 
}
}
j3 = j3array[ij3]; cj3 = cj3array[ij3]; sj3 = sj3array[ij3];
{
IkReal evalcond[4];
IkReal x10327=IKcos(j3);
IkReal x10328=IKsin(j3);
IkReal x10329=((sj0)*(sj5));
IkReal x10330=((r00)*(sj6));
IkReal x10331=((IkReal(1.00000000000000))*(cj4));
IkReal x10332=((cj6)*(sj0));
IkReal x10333=((r00)*(sj4));
IkReal x10334=((cj0)*(cj5));
IkReal x10335=((cj6)*(r01));
IkReal x10336=((cj5)*(sj0));
IkReal x10337=((cj0)*(sj5));
IkReal x10338=((cj6)*(r11));
IkReal x10339=((r10)*(sj6));
IkReal x10340=((r10)*(sj4));
IkReal x10341=((cj0)*(sj4)*(sj6));
IkReal x10342=((sj0)*(sj4)*(sj6));
IkReal x10343=((IkReal(1.00000000000000))*(cj0)*(cj6));
evalcond[0]=((x10328)+(((x10329)*(x10330)))+(((IkReal(-1.00000000000000))*(r02)*(x10336)))+(((IkReal(-1.00000000000000))*(x10337)*(x10339)))+(((r12)*(x10334)))+(((IkReal(-1.00000000000000))*(x10337)*(x10338)))+(((x10329)*(x10335))));
evalcond[1]=((((r12)*(x10336)))+(x10327)+(((IkReal(-1.00000000000000))*(x10330)*(x10337)))+(((IkReal(-1.00000000000000))*(x10329)*(x10338)))+(((IkReal(-1.00000000000000))*(x10335)*(x10337)))+(((r02)*(x10334)))+(((IkReal(-1.00000000000000))*(x10329)*(x10339))));
evalcond[2]=((((IkReal(-1.00000000000000))*(x10331)*(x10334)*(x10339)))+(((IkReal(-1.00000000000000))*(x10340)*(x10343)))+(((IkReal(-1.00000000000000))*(x10331)*(x10334)*(x10338)))+(((x10332)*(x10333)))+(((IkReal(-1.00000000000000))*(r12)*(x10331)*(x10337)))+(((IkReal(-1.00000000000000))*(r01)*(x10342)))+(((cj4)*(r02)*(x10329)))+(((cj4)*(x10330)*(x10336)))+(((IkReal(-1.00000000000000))*(x10327)))+(((cj4)*(cj5)*(r01)*(x10332)))+(((r11)*(x10341))));
evalcond[3]=((((r11)*(x10342)))+(((IkReal(-1.00000000000000))*(cj5)*(r11)*(x10331)*(x10332)))+(x10328)+(((IkReal(-1.00000000000000))*(x10330)*(x10331)*(x10334)))+(((IkReal(-1.00000000000000))*(r12)*(x10329)*(x10331)))+(((IkReal(-1.00000000000000))*(r02)*(x10331)*(x10337)))+(((r01)*(x10341)))+(((IkReal(-1.00000000000000))*(x10331)*(x10334)*(x10335)))+(((IkReal(-1.00000000000000))*(x10331)*(x10336)*(x10339)))+(((IkReal(-1.00000000000000))*(x10333)*(x10343)))+(((IkReal(-1.00000000000000))*(x10332)*(x10340))));
if( IKabs(evalcond[0]) > 0.000001  || IKabs(evalcond[1]) > 0.000001  || IKabs(evalcond[2]) > 0.000001  || IKabs(evalcond[3]) > 0.000001  )
{
continue;
}
}

{
std::vector<IkSingleDOFSolutionBase<IkReal> > vinfos(7);
vinfos[0].jointtype = 1;
vinfos[0].foffset = j0;
vinfos[0].indices[0] = _ij0[0];
vinfos[0].indices[1] = _ij0[1];
vinfos[0].maxsolutions = _nj0;
vinfos[1].jointtype = 1;
vinfos[1].foffset = j1;
vinfos[1].indices[0] = _ij1[0];
vinfos[1].indices[1] = _ij1[1];
vinfos[1].maxsolutions = _nj1;
vinfos[2].jointtype = 1;
vinfos[2].foffset = j2;
vinfos[2].indices[0] = _ij2[0];
vinfos[2].indices[1] = _ij2[1];
vinfos[2].maxsolutions = _nj2;
vinfos[3].jointtype = 1;
vinfos[3].foffset = j3;
vinfos[3].indices[0] = _ij3[0];
vinfos[3].indices[1] = _ij3[1];
vinfos[3].maxsolutions = _nj3;
vinfos[4].jointtype = 1;
vinfos[4].foffset = j4;
vinfos[4].indices[0] = _ij4[0];
vinfos[4].indices[1] = _ij4[1];
vinfos[4].maxsolutions = _nj4;
vinfos[5].jointtype = 1;
vinfos[5].foffset = j5;
vinfos[5].indices[0] = _ij5[0];
vinfos[5].indices[1] = _ij5[1];
vinfos[5].maxsolutions = _nj5;
vinfos[6].jointtype = 1;
vinfos[6].foffset = j6;
vinfos[6].indices[0] = _ij6[0];
vinfos[6].indices[1] = _ij6[1];
vinfos[6].maxsolutions = _nj6;
std::vector<int> vfree(0);
solutions.AddSolution(vinfos,vfree);
}
}
}

} else
{
if( 1 )
{
continue;

} else
{
}
}
}
}
}
}

} else
{
{
IkReal j3array[1], cj3array[1], sj3array[1];
bool j3valid[1]={false};
_nj3 = 1;
IkReal x10344=((cj5)*(r02));
IkReal x10345=((cj0)*(sj5));
IkReal x10346=((r10)*(sj6));
IkReal x10347=((IkReal(1.00000000000000))*(cj6));
IkReal x10348=((sj0)*(sj5));
IkReal x10349=((cj5)*(r12));
IkReal x10350=((IkReal(1.00000000000000))*(r00)*(sj6));
if( IKabs(((((IkReal(-1.00000000000000))*(cj0)*(x10349)))+(((IkReal(-1.00000000000000))*(x10348)*(x10350)))+(((x10345)*(x10346)))+(((cj6)*(r11)*(x10345)))+(((sj0)*(x10344)))+(((IkReal(-1.00000000000000))*(r01)*(x10347)*(x10348))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(((((IKabs(cj1) != 0)?((IkReal)1/(cj1)):(IkReal)1.0e30))*(((((sj0)*(x10349)))+(((IkReal(-1.00000000000000))*(r11)*(x10347)*(x10348)))+(((cj0)*(x10344)))+(((IkReal(-1.00000000000000))*(x10345)*(x10350)))+(((IkReal(-1.00000000000000))*(r01)*(x10345)*(x10347)))+(((IkReal(-1.00000000000000))*(x10346)*(x10348))))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(IKsqr(((((IkReal(-1.00000000000000))*(cj0)*(x10349)))+(((IkReal(-1.00000000000000))*(x10348)*(x10350)))+(((x10345)*(x10346)))+(((cj6)*(r11)*(x10345)))+(((sj0)*(x10344)))+(((IkReal(-1.00000000000000))*(r01)*(x10347)*(x10348)))))+IKsqr(((((IKabs(cj1) != 0)?((IkReal)1/(cj1)):(IkReal)1.0e30))*(((((sj0)*(x10349)))+(((IkReal(-1.00000000000000))*(r11)*(x10347)*(x10348)))+(((cj0)*(x10344)))+(((IkReal(-1.00000000000000))*(x10345)*(x10350)))+(((IkReal(-1.00000000000000))*(r01)*(x10345)*(x10347)))+(((IkReal(-1.00000000000000))*(x10346)*(x10348)))))))-1) <= IKFAST_SINCOS_THRESH )
    continue;
j3array[0]=IKatan2(((((IkReal(-1.00000000000000))*(cj0)*(x10349)))+(((IkReal(-1.00000000000000))*(x10348)*(x10350)))+(((x10345)*(x10346)))+(((cj6)*(r11)*(x10345)))+(((sj0)*(x10344)))+(((IkReal(-1.00000000000000))*(r01)*(x10347)*(x10348)))), ((((IKabs(cj1) != 0)?((IkReal)1/(cj1)):(IkReal)1.0e30))*(((((sj0)*(x10349)))+(((IkReal(-1.00000000000000))*(r11)*(x10347)*(x10348)))+(((cj0)*(x10344)))+(((IkReal(-1.00000000000000))*(x10345)*(x10350)))+(((IkReal(-1.00000000000000))*(r01)*(x10345)*(x10347)))+(((IkReal(-1.00000000000000))*(x10346)*(x10348)))))));
sj3array[0]=IKsin(j3array[0]);
cj3array[0]=IKcos(j3array[0]);
if( j3array[0] > IKPI )
{
    j3array[0]-=IK2PI;
}
else if( j3array[0] < -IKPI )
{    j3array[0]+=IK2PI;
}
j3valid[0] = true;
for(int ij3 = 0; ij3 < 1; ++ij3)
{
if( !j3valid[ij3] )
{
    continue;
}
_ij3[0] = ij3; _ij3[1] = -1;
for(int iij3 = ij3+1; iij3 < 1; ++iij3)
{
if( j3valid[iij3] && IKabs(cj3array[ij3]-cj3array[iij3]) < IKFAST_SOLUTION_THRESH && IKabs(sj3array[ij3]-sj3array[iij3]) < IKFAST_SOLUTION_THRESH )
{
    j3valid[iij3]=false; _ij3[1] = iij3; break; 
}
}
j3 = j3array[ij3]; cj3 = cj3array[ij3]; sj3 = sj3array[ij3];
{
IkReal evalcond[6];
IkReal x10351=IKsin(j3);
IkReal x10352=IKcos(j3);
IkReal x10353=((sj0)*(sj5));
IkReal x10354=((r00)*(sj6));
IkReal x10355=((IkReal(1.00000000000000))*(cj4));
IkReal x10356=((cj6)*(r01));
IkReal x10357=((cj0)*(cj5));
IkReal x10358=((cj5)*(sj0));
IkReal x10359=((cj6)*(r11));
IkReal x10360=((cj0)*(sj5));
IkReal x10361=((IkReal(1.00000000000000))*(cj1));
IkReal x10362=((cj6)*(sj4));
IkReal x10363=((IkReal(1.00000000000000))*(sj1));
IkReal x10364=((cj4)*(cj5));
IkReal x10365=((cj6)*(r21));
IkReal x10366=((r20)*(sj6));
IkReal x10367=((r10)*(sj6));
IkReal x10368=((IkReal(1.00000000000000))*(cj0));
IkReal x10369=((cj0)*(sj4)*(sj6));
IkReal x10370=((sj0)*(sj4)*(sj6));
evalcond[0]=((((sj5)*(x10365)))+(((IkReal(-1.00000000000000))*(cj5)*(r22)))+(((sj5)*(x10366)))+(((IkReal(-1.00000000000000))*(x10352)*(x10363))));
evalcond[1]=((((IkReal(-1.00000000000000))*(r21)*(sj4)*(sj6)))+(((cj4)*(r22)*(sj5)))+(((IkReal(-1.00000000000000))*(x10351)*(x10363)))+(((x10364)*(x10365)))+(((x10364)*(x10366)))+(((r20)*(x10362))));
evalcond[2]=((((r12)*(x10357)))+(((x10353)*(x10356)))+(((IkReal(-1.00000000000000))*(x10359)*(x10360)))+(x10351)+(((x10353)*(x10354)))+(((IkReal(-1.00000000000000))*(x10360)*(x10367)))+(((IkReal(-1.00000000000000))*(r02)*(x10358))));
evalcond[3]=((((IkReal(-1.00000000000000))*(x10352)*(x10361)))+(((r12)*(x10358)))+(((IkReal(-1.00000000000000))*(x10353)*(x10359)))+(((IkReal(-1.00000000000000))*(x10354)*(x10360)))+(((r02)*(x10357)))+(((IkReal(-1.00000000000000))*(x10353)*(x10367)))+(((IkReal(-1.00000000000000))*(x10356)*(x10360))));
evalcond[4]=((((IkReal(-1.00000000000000))*(x10355)*(x10357)*(x10367)))+(((IkReal(-1.00000000000000))*(x10355)*(x10357)*(x10359)))+(((r11)*(x10369)))+(((cj4)*(r02)*(x10353)))+(((cj4)*(x10354)*(x10358)))+(((cj4)*(x10356)*(x10358)))+(((r00)*(sj0)*(x10362)))+(((IkReal(-1.00000000000000))*(r10)*(x10362)*(x10368)))+(((IkReal(-1.00000000000000))*(r01)*(x10370)))+(((IkReal(-1.00000000000000))*(r12)*(x10355)*(x10360)))+(((IkReal(-1.00000000000000))*(x10352))));
evalcond[5]=((((IkReal(-1.00000000000000))*(x10354)*(x10355)*(x10357)))+(((IkReal(-1.00000000000000))*(r02)*(x10355)*(x10360)))+(((IkReal(-1.00000000000000))*(x10351)*(x10361)))+(((IkReal(-1.00000000000000))*(r12)*(x10353)*(x10355)))+(((IkReal(-1.00000000000000))*(r10)*(sj0)*(x10362)))+(((IkReal(-1.00000000000000))*(x10355)*(x10356)*(x10357)))+(((IkReal(-1.00000000000000))*(x10355)*(x10358)*(x10367)))+(((r01)*(x10369)))+(((IkReal(-1.00000000000000))*(r00)*(x10362)*(x10368)))+(((r11)*(x10370)))+(((IkReal(-1.00000000000000))*(x10355)*(x10358)*(x10359))));
if( IKabs(evalcond[0]) > 0.000001  || IKabs(evalcond[1]) > 0.000001  || IKabs(evalcond[2]) > 0.000001  || IKabs(evalcond[3]) > 0.000001  || IKabs(evalcond[4]) > 0.000001  || IKabs(evalcond[5]) > 0.000001  )
{
continue;
}
}

{
std::vector<IkSingleDOFSolutionBase<IkReal> > vinfos(7);
vinfos[0].jointtype = 1;
vinfos[0].foffset = j0;
vinfos[0].indices[0] = _ij0[0];
vinfos[0].indices[1] = _ij0[1];
vinfos[0].maxsolutions = _nj0;
vinfos[1].jointtype = 1;
vinfos[1].foffset = j1;
vinfos[1].indices[0] = _ij1[0];
vinfos[1].indices[1] = _ij1[1];
vinfos[1].maxsolutions = _nj1;
vinfos[2].jointtype = 1;
vinfos[2].foffset = j2;
vinfos[2].indices[0] = _ij2[0];
vinfos[2].indices[1] = _ij2[1];
vinfos[2].maxsolutions = _nj2;
vinfos[3].jointtype = 1;
vinfos[3].foffset = j3;
vinfos[3].indices[0] = _ij3[0];
vinfos[3].indices[1] = _ij3[1];
vinfos[3].maxsolutions = _nj3;
vinfos[4].jointtype = 1;
vinfos[4].foffset = j4;
vinfos[4].indices[0] = _ij4[0];
vinfos[4].indices[1] = _ij4[1];
vinfos[4].maxsolutions = _nj4;
vinfos[5].jointtype = 1;
vinfos[5].foffset = j5;
vinfos[5].indices[0] = _ij5[0];
vinfos[5].indices[1] = _ij5[1];
vinfos[5].maxsolutions = _nj5;
vinfos[6].jointtype = 1;
vinfos[6].foffset = j6;
vinfos[6].indices[0] = _ij6[0];
vinfos[6].indices[1] = _ij6[1];
vinfos[6].maxsolutions = _nj6;
std::vector<int> vfree(0);
solutions.AddSolution(vinfos,vfree);
}
}
}

}

}

} else
{
{
IkReal j3array[1], cj3array[1], sj3array[1];
bool j3valid[1]={false};
_nj3 = 1;
IkReal x10371=((sj5)*(sj6));
IkReal x10372=((IkReal(1.00000000000000))*(sj0));
IkReal x10373=((cj6)*(sj5));
IkReal x10374=((IkReal(1.00000000000000))*(cj5));
if( IKabs(((((cj0)*(r11)*(x10373)))+(((IkReal(-1.00000000000000))*(r01)*(x10372)*(x10373)))+(((cj0)*(r10)*(x10371)))+(((cj5)*(r02)*(sj0)))+(((IkReal(-1.00000000000000))*(r00)*(x10371)*(x10372)))+(((IkReal(-1.00000000000000))*(cj0)*(r12)*(x10374))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(((((IKabs(sj1) != 0)?((IkReal)1/(sj1)):(IkReal)1.0e30))*(((((IkReal(-1.00000000000000))*(r22)*(x10374)))+(((r20)*(x10371)))+(((r21)*(x10373))))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(IKsqr(((((cj0)*(r11)*(x10373)))+(((IkReal(-1.00000000000000))*(r01)*(x10372)*(x10373)))+(((cj0)*(r10)*(x10371)))+(((cj5)*(r02)*(sj0)))+(((IkReal(-1.00000000000000))*(r00)*(x10371)*(x10372)))+(((IkReal(-1.00000000000000))*(cj0)*(r12)*(x10374)))))+IKsqr(((((IKabs(sj1) != 0)?((IkReal)1/(sj1)):(IkReal)1.0e30))*(((((IkReal(-1.00000000000000))*(r22)*(x10374)))+(((r20)*(x10371)))+(((r21)*(x10373)))))))-1) <= IKFAST_SINCOS_THRESH )
    continue;
j3array[0]=IKatan2(((((cj0)*(r11)*(x10373)))+(((IkReal(-1.00000000000000))*(r01)*(x10372)*(x10373)))+(((cj0)*(r10)*(x10371)))+(((cj5)*(r02)*(sj0)))+(((IkReal(-1.00000000000000))*(r00)*(x10371)*(x10372)))+(((IkReal(-1.00000000000000))*(cj0)*(r12)*(x10374)))), ((((IKabs(sj1) != 0)?((IkReal)1/(sj1)):(IkReal)1.0e30))*(((((IkReal(-1.00000000000000))*(r22)*(x10374)))+(((r20)*(x10371)))+(((r21)*(x10373)))))));
sj3array[0]=IKsin(j3array[0]);
cj3array[0]=IKcos(j3array[0]);
if( j3array[0] > IKPI )
{
    j3array[0]-=IK2PI;
}
else if( j3array[0] < -IKPI )
{    j3array[0]+=IK2PI;
}
j3valid[0] = true;
for(int ij3 = 0; ij3 < 1; ++ij3)
{
if( !j3valid[ij3] )
{
    continue;
}
_ij3[0] = ij3; _ij3[1] = -1;
for(int iij3 = ij3+1; iij3 < 1; ++iij3)
{
if( j3valid[iij3] && IKabs(cj3array[ij3]-cj3array[iij3]) < IKFAST_SOLUTION_THRESH && IKabs(sj3array[ij3]-sj3array[iij3]) < IKFAST_SOLUTION_THRESH )
{
    j3valid[iij3]=false; _ij3[1] = iij3; break; 
}
}
j3 = j3array[ij3]; cj3 = cj3array[ij3]; sj3 = sj3array[ij3];
{
IkReal evalcond[6];
IkReal x10375=IKsin(j3);
IkReal x10376=IKcos(j3);
IkReal x10377=((sj0)*(sj5));
IkReal x10378=((r00)*(sj6));
IkReal x10379=((IkReal(1.00000000000000))*(cj4));
IkReal x10380=((cj6)*(r01));
IkReal x10381=((cj0)*(cj5));
IkReal x10382=((cj5)*(sj0));
IkReal x10383=((cj6)*(r11));
IkReal x10384=((cj0)*(sj5));
IkReal x10385=((IkReal(1.00000000000000))*(cj1));
IkReal x10386=((cj6)*(sj4));
IkReal x10387=((IkReal(1.00000000000000))*(sj1));
IkReal x10388=((cj4)*(cj5));
IkReal x10389=((cj6)*(r21));
IkReal x10390=((r20)*(sj6));
IkReal x10391=((r10)*(sj6));
IkReal x10392=((IkReal(1.00000000000000))*(cj0));
IkReal x10393=((cj0)*(sj4)*(sj6));
IkReal x10394=((sj0)*(sj4)*(sj6));
evalcond[0]=((((sj5)*(x10390)))+(((IkReal(-1.00000000000000))*(x10376)*(x10387)))+(((IkReal(-1.00000000000000))*(cj5)*(r22)))+(((sj5)*(x10389))));
evalcond[1]=((((IkReal(-1.00000000000000))*(r21)*(sj4)*(sj6)))+(((x10388)*(x10390)))+(((r20)*(x10386)))+(((cj4)*(r22)*(sj5)))+(((x10388)*(x10389)))+(((IkReal(-1.00000000000000))*(x10375)*(x10387))));
evalcond[2]=((((x10377)*(x10378)))+(((IkReal(-1.00000000000000))*(x10384)*(x10391)))+(((IkReal(-1.00000000000000))*(x10383)*(x10384)))+(((IkReal(-1.00000000000000))*(r02)*(x10382)))+(x10375)+(((r12)*(x10381)))+(((x10377)*(x10380))));
evalcond[3]=((((IkReal(-1.00000000000000))*(x10377)*(x10391)))+(((IkReal(-1.00000000000000))*(x10378)*(x10384)))+(((IkReal(-1.00000000000000))*(x10376)*(x10385)))+(((IkReal(-1.00000000000000))*(x10377)*(x10383)))+(((r12)*(x10382)))+(((IkReal(-1.00000000000000))*(x10380)*(x10384)))+(((r02)*(x10381))));
evalcond[4]=((((IkReal(-1.00000000000000))*(x10379)*(x10381)*(x10391)))+(((cj4)*(x10380)*(x10382)))+(((r00)*(sj0)*(x10386)))+(((cj4)*(x10378)*(x10382)))+(((cj4)*(r02)*(x10377)))+(((IkReal(-1.00000000000000))*(r12)*(x10379)*(x10384)))+(((IkReal(-1.00000000000000))*(r10)*(x10386)*(x10392)))+(((IkReal(-1.00000000000000))*(x10379)*(x10381)*(x10383)))+(((IkReal(-1.00000000000000))*(r01)*(x10394)))+(((r11)*(x10393)))+(((IkReal(-1.00000000000000))*(x10376))));
evalcond[5]=((((IkReal(-1.00000000000000))*(x10379)*(x10380)*(x10381)))+(((IkReal(-1.00000000000000))*(x10379)*(x10382)*(x10383)))+(((IkReal(-1.00000000000000))*(x10378)*(x10379)*(x10381)))+(((IkReal(-1.00000000000000))*(x10375)*(x10385)))+(((IkReal(-1.00000000000000))*(r12)*(x10377)*(x10379)))+(((r01)*(x10393)))+(((r11)*(x10394)))+(((IkReal(-1.00000000000000))*(r02)*(x10379)*(x10384)))+(((IkReal(-1.00000000000000))*(x10379)*(x10382)*(x10391)))+(((IkReal(-1.00000000000000))*(r00)*(x10386)*(x10392)))+(((IkReal(-1.00000000000000))*(r10)*(sj0)*(x10386))));
if( IKabs(evalcond[0]) > 0.000001  || IKabs(evalcond[1]) > 0.000001  || IKabs(evalcond[2]) > 0.000001  || IKabs(evalcond[3]) > 0.000001  || IKabs(evalcond[4]) > 0.000001  || IKabs(evalcond[5]) > 0.000001  )
{
continue;
}
}

{
std::vector<IkSingleDOFSolutionBase<IkReal> > vinfos(7);
vinfos[0].jointtype = 1;
vinfos[0].foffset = j0;
vinfos[0].indices[0] = _ij0[0];
vinfos[0].indices[1] = _ij0[1];
vinfos[0].maxsolutions = _nj0;
vinfos[1].jointtype = 1;
vinfos[1].foffset = j1;
vinfos[1].indices[0] = _ij1[0];
vinfos[1].indices[1] = _ij1[1];
vinfos[1].maxsolutions = _nj1;
vinfos[2].jointtype = 1;
vinfos[2].foffset = j2;
vinfos[2].indices[0] = _ij2[0];
vinfos[2].indices[1] = _ij2[1];
vinfos[2].maxsolutions = _nj2;
vinfos[3].jointtype = 1;
vinfos[3].foffset = j3;
vinfos[3].indices[0] = _ij3[0];
vinfos[3].indices[1] = _ij3[1];
vinfos[3].maxsolutions = _nj3;
vinfos[4].jointtype = 1;
vinfos[4].foffset = j4;
vinfos[4].indices[0] = _ij4[0];
vinfos[4].indices[1] = _ij4[1];
vinfos[4].maxsolutions = _nj4;
vinfos[5].jointtype = 1;
vinfos[5].foffset = j5;
vinfos[5].indices[0] = _ij5[0];
vinfos[5].indices[1] = _ij5[1];
vinfos[5].maxsolutions = _nj5;
vinfos[6].jointtype = 1;
vinfos[6].foffset = j6;
vinfos[6].indices[0] = _ij6[0];
vinfos[6].indices[1] = _ij6[1];
vinfos[6].maxsolutions = _nj6;
std::vector<int> vfree(0);
solutions.AddSolution(vinfos,vfree);
}
}
}

}

}

} else
{
{
IkReal j3array[1], cj3array[1], sj3array[1];
bool j3valid[1]={false};
_nj3 = 1;
IkReal x10395=((r20)*(sj6));
IkReal x10396=((cj4)*(cj5));
IkReal x10397=((cj6)*(r21));
if( IKabs(((gconst30)*(((((IkReal(-1.00000000000000))*(r21)*(sj4)*(sj6)))+(((cj6)*(r20)*(sj4)))+(((cj4)*(r22)*(sj5)))+(((x10395)*(x10396)))+(((x10396)*(x10397))))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(((gconst30)*(((((sj5)*(x10395)))+(((IkReal(-1.00000000000000))*(cj5)*(r22)))+(((sj5)*(x10397))))))) < IKFAST_ATAN2_MAGTHRESH )
    continue;
j3array[0]=IKatan2(((gconst30)*(((((IkReal(-1.00000000000000))*(r21)*(sj4)*(sj6)))+(((cj6)*(r20)*(sj4)))+(((cj4)*(r22)*(sj5)))+(((x10395)*(x10396)))+(((x10396)*(x10397)))))), ((gconst30)*(((((sj5)*(x10395)))+(((IkReal(-1.00000000000000))*(cj5)*(r22)))+(((sj5)*(x10397)))))));
sj3array[0]=IKsin(j3array[0]);
cj3array[0]=IKcos(j3array[0]);
if( j3array[0] > IKPI )
{
    j3array[0]-=IK2PI;
}
else if( j3array[0] < -IKPI )
{    j3array[0]+=IK2PI;
}
j3valid[0] = true;
for(int ij3 = 0; ij3 < 1; ++ij3)
{
if( !j3valid[ij3] )
{
    continue;
}
_ij3[0] = ij3; _ij3[1] = -1;
for(int iij3 = ij3+1; iij3 < 1; ++iij3)
{
if( j3valid[iij3] && IKabs(cj3array[ij3]-cj3array[iij3]) < IKFAST_SOLUTION_THRESH && IKabs(sj3array[ij3]-sj3array[iij3]) < IKFAST_SOLUTION_THRESH )
{
    j3valid[iij3]=false; _ij3[1] = iij3; break; 
}
}
j3 = j3array[ij3]; cj3 = cj3array[ij3]; sj3 = sj3array[ij3];
{
IkReal evalcond[6];
IkReal x10398=IKsin(j3);
IkReal x10399=IKcos(j3);
IkReal x10400=((sj0)*(sj5));
IkReal x10401=((r00)*(sj6));
IkReal x10402=((IkReal(1.00000000000000))*(cj4));
IkReal x10403=((cj6)*(r01));
IkReal x10404=((cj0)*(cj5));
IkReal x10405=((cj5)*(sj0));
IkReal x10406=((cj6)*(r11));
IkReal x10407=((cj0)*(sj5));
IkReal x10408=((IkReal(1.00000000000000))*(cj1));
IkReal x10409=((cj6)*(sj4));
IkReal x10410=((IkReal(1.00000000000000))*(sj1));
IkReal x10411=((cj4)*(cj5));
IkReal x10412=((cj6)*(r21));
IkReal x10413=((r20)*(sj6));
IkReal x10414=((r10)*(sj6));
IkReal x10415=((IkReal(1.00000000000000))*(cj0));
IkReal x10416=((cj0)*(sj4)*(sj6));
IkReal x10417=((sj0)*(sj4)*(sj6));
evalcond[0]=((((sj5)*(x10412)))+(((sj5)*(x10413)))+(((IkReal(-1.00000000000000))*(cj5)*(r22)))+(((IkReal(-1.00000000000000))*(x10399)*(x10410))));
evalcond[1]=((((IkReal(-1.00000000000000))*(x10398)*(x10410)))+(((IkReal(-1.00000000000000))*(r21)*(sj4)*(sj6)))+(((r20)*(x10409)))+(((x10411)*(x10412)))+(((cj4)*(r22)*(sj5)))+(((x10411)*(x10413))));
evalcond[2]=((((x10400)*(x10403)))+(((IkReal(-1.00000000000000))*(x10407)*(x10414)))+(((r12)*(x10404)))+(((IkReal(-1.00000000000000))*(r02)*(x10405)))+(((x10400)*(x10401)))+(((IkReal(-1.00000000000000))*(x10406)*(x10407)))+(x10398));
evalcond[3]=((((r12)*(x10405)))+(((r02)*(x10404)))+(((IkReal(-1.00000000000000))*(x10400)*(x10406)))+(((IkReal(-1.00000000000000))*(x10403)*(x10407)))+(((IkReal(-1.00000000000000))*(x10399)*(x10408)))+(((IkReal(-1.00000000000000))*(x10401)*(x10407)))+(((IkReal(-1.00000000000000))*(x10400)*(x10414))));
evalcond[4]=((((IkReal(-1.00000000000000))*(r10)*(x10409)*(x10415)))+(((r00)*(sj0)*(x10409)))+(((IkReal(-1.00000000000000))*(x10402)*(x10404)*(x10406)))+(((r11)*(x10416)))+(((IkReal(-1.00000000000000))*(x10399)))+(((cj4)*(x10403)*(x10405)))+(((IkReal(-1.00000000000000))*(r01)*(x10417)))+(((IkReal(-1.00000000000000))*(r12)*(x10402)*(x10407)))+(((cj4)*(x10401)*(x10405)))+(((cj4)*(r02)*(x10400)))+(((IkReal(-1.00000000000000))*(x10402)*(x10404)*(x10414))));
evalcond[5]=((((r11)*(x10417)))+(((IkReal(-1.00000000000000))*(x10401)*(x10402)*(x10404)))+(((IkReal(-1.00000000000000))*(x10402)*(x10405)*(x10414)))+(((IkReal(-1.00000000000000))*(x10402)*(x10405)*(x10406)))+(((IkReal(-1.00000000000000))*(x10402)*(x10403)*(x10404)))+(((r01)*(x10416)))+(((IkReal(-1.00000000000000))*(r10)*(sj0)*(x10409)))+(((IkReal(-1.00000000000000))*(x10398)*(x10408)))+(((IkReal(-1.00000000000000))*(r00)*(x10409)*(x10415)))+(((IkReal(-1.00000000000000))*(r02)*(x10402)*(x10407)))+(((IkReal(-1.00000000000000))*(r12)*(x10400)*(x10402))));
if( IKabs(evalcond[0]) > 0.000001  || IKabs(evalcond[1]) > 0.000001  || IKabs(evalcond[2]) > 0.000001  || IKabs(evalcond[3]) > 0.000001  || IKabs(evalcond[4]) > 0.000001  || IKabs(evalcond[5]) > 0.000001  )
{
continue;
}
}

{
std::vector<IkSingleDOFSolutionBase<IkReal> > vinfos(7);
vinfos[0].jointtype = 1;
vinfos[0].foffset = j0;
vinfos[0].indices[0] = _ij0[0];
vinfos[0].indices[1] = _ij0[1];
vinfos[0].maxsolutions = _nj0;
vinfos[1].jointtype = 1;
vinfos[1].foffset = j1;
vinfos[1].indices[0] = _ij1[0];
vinfos[1].indices[1] = _ij1[1];
vinfos[1].maxsolutions = _nj1;
vinfos[2].jointtype = 1;
vinfos[2].foffset = j2;
vinfos[2].indices[0] = _ij2[0];
vinfos[2].indices[1] = _ij2[1];
vinfos[2].maxsolutions = _nj2;
vinfos[3].jointtype = 1;
vinfos[3].foffset = j3;
vinfos[3].indices[0] = _ij3[0];
vinfos[3].indices[1] = _ij3[1];
vinfos[3].maxsolutions = _nj3;
vinfos[4].jointtype = 1;
vinfos[4].foffset = j4;
vinfos[4].indices[0] = _ij4[0];
vinfos[4].indices[1] = _ij4[1];
vinfos[4].maxsolutions = _nj4;
vinfos[5].jointtype = 1;
vinfos[5].foffset = j5;
vinfos[5].indices[0] = _ij5[0];
vinfos[5].indices[1] = _ij5[1];
vinfos[5].maxsolutions = _nj5;
vinfos[6].jointtype = 1;
vinfos[6].foffset = j6;
vinfos[6].indices[0] = _ij6[0];
vinfos[6].indices[1] = _ij6[1];
vinfos[6].maxsolutions = _nj6;
std::vector<int> vfree(0);
solutions.AddSolution(vinfos,vfree);
}
}
}

}

}
}
}

}

}

} else
{
{
IkReal j4array[1], cj4array[1], sj4array[1];
bool j4valid[1]={false};
_nj4 = 1;
IkReal x10418=((cj1)*(sj6));
IkReal x10419=((r01)*(sj0));
IkReal x10420=((cj0)*(r11));
IkReal x10421=((cj1)*(cj6));
IkReal x10422=((cj0)*(r10));
IkReal x10423=((IkReal(1.00000000000000))*(sj0));
IkReal x10424=((cj1)*(sj5));
if( IKabs(((gconst26)*(((((IkReal(-1.00000000000000))*(r00)*(x10421)*(x10423)))+(((IkReal(-1.00000000000000))*(x10418)*(x10420)))+(((x10421)*(x10422)))+(((x10418)*(x10419))))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(((gconst26)*(((((IkReal(-1.00000000000000))*(cj5)*(x10419)*(x10421)))+(((IkReal(-1.00000000000000))*(cj5)*(r00)*(x10418)*(x10423)))+(((IkReal(-1.00000000000000))*(r02)*(x10423)*(x10424)))+(((cj5)*(x10418)*(x10422)))+(((cj5)*(x10420)*(x10421)))+(((cj0)*(r12)*(x10424))))))) < IKFAST_ATAN2_MAGTHRESH )
    continue;
j4array[0]=IKatan2(((gconst26)*(((((IkReal(-1.00000000000000))*(r00)*(x10421)*(x10423)))+(((IkReal(-1.00000000000000))*(x10418)*(x10420)))+(((x10421)*(x10422)))+(((x10418)*(x10419)))))), ((gconst26)*(((((IkReal(-1.00000000000000))*(cj5)*(x10419)*(x10421)))+(((IkReal(-1.00000000000000))*(cj5)*(r00)*(x10418)*(x10423)))+(((IkReal(-1.00000000000000))*(r02)*(x10423)*(x10424)))+(((cj5)*(x10418)*(x10422)))+(((cj5)*(x10420)*(x10421)))+(((cj0)*(r12)*(x10424)))))));
sj4array[0]=IKsin(j4array[0]);
cj4array[0]=IKcos(j4array[0]);
if( j4array[0] > IKPI )
{
    j4array[0]-=IK2PI;
}
else if( j4array[0] < -IKPI )
{    j4array[0]+=IK2PI;
}
j4valid[0] = true;
for(int ij4 = 0; ij4 < 1; ++ij4)
{
if( !j4valid[ij4] )
{
    continue;
}
_ij4[0] = ij4; _ij4[1] = -1;
for(int iij4 = ij4+1; iij4 < 1; ++iij4)
{
if( j4valid[iij4] && IKabs(cj4array[ij4]-cj4array[iij4]) < IKFAST_SOLUTION_THRESH && IKabs(sj4array[ij4]-sj4array[iij4]) < IKFAST_SOLUTION_THRESH )
{
    j4valid[iij4]=false; _ij4[1] = iij4; break; 
}
}
j4 = j4array[ij4]; cj4 = cj4array[ij4]; sj4 = sj4array[ij4];
{
IkReal evalcond[3];
IkReal x10425=IKsin(j4);
IkReal x10426=IKcos(j4);
IkReal x10427=((r00)*(sj6));
IkReal x10428=((cj6)*(r01));
IkReal x10429=((IkReal(1.00000000000000))*(cj0));
IkReal x10430=((IkReal(1.00000000000000))*(sj0));
IkReal x10431=((r10)*(sj6));
IkReal x10432=((sj5)*(x10425));
IkReal x10433=((IkReal(1.00000000000000))*(cj6)*(r11));
IkReal x10434=((cj5)*(x10425));
IkReal x10435=((cj6)*(x10426));
IkReal x10436=((sj0)*(x10434));
IkReal x10437=((r01)*(sj6)*(x10426));
IkReal x10438=((r11)*(sj6)*(x10426));
evalcond[0]=((((r22)*(x10432)))+(((r20)*(sj6)*(x10434)))+(((cj6)*(r21)*(x10434)))+(cj1)+(((IkReal(-1.00000000000000))*(r20)*(x10435)))+(((r21)*(sj6)*(x10426))));
evalcond[1]=((((IkReal(-1.00000000000000))*(r12)*(x10429)*(x10432)))+(((sj0)*(x10437)))+(((IkReal(-1.00000000000000))*(x10429)*(x10431)*(x10434)))+(((cj0)*(r10)*(x10435)))+(((r02)*(sj0)*(x10432)))+(((IkReal(-1.00000000000000))*(r00)*(x10430)*(x10435)))+(((x10427)*(x10436)))+(((IkReal(-1.00000000000000))*(cj6)*(r11)*(x10429)*(x10434)))+(((x10428)*(x10436)))+(((IkReal(-1.00000000000000))*(x10429)*(x10438))));
evalcond[2]=((((IkReal(-1.00000000000000))*(cj6)*(r11)*(x10430)*(x10434)))+(((IkReal(-1.00000000000000))*(x10430)*(x10438)))+(((IkReal(-1.00000000000000))*(x10429)*(x10437)))+(((IkReal(-1.00000000000000))*(sj1)))+(((r10)*(sj0)*(x10435)))+(((IkReal(-1.00000000000000))*(r12)*(x10430)*(x10432)))+(((cj0)*(r00)*(x10435)))+(((IkReal(-1.00000000000000))*(x10428)*(x10429)*(x10434)))+(((IkReal(-1.00000000000000))*(r02)*(x10429)*(x10432)))+(((IkReal(-1.00000000000000))*(x10427)*(x10429)*(x10434)))+(((IkReal(-1.00000000000000))*(x10430)*(x10431)*(x10434))));
if( IKabs(evalcond[0]) > 0.000001  || IKabs(evalcond[1]) > 0.000001  || IKabs(evalcond[2]) > 0.000001  )
{
continue;
}
}

{
IkReal dummyeval[1];
IkReal gconst30;
gconst30=IKsign(sj1);
dummyeval[0]=sj1;
if( IKabs(dummyeval[0]) < 0.0000010000000000  )
{
{
IkReal dummyeval[1];
dummyeval[0]=sj1;
if( IKabs(dummyeval[0]) < 0.0000010000000000  )
{
{
IkReal dummyeval[1];
dummyeval[0]=cj1;
if( IKabs(dummyeval[0]) < 0.0000010000000000  )
{
{
IkReal evalcond[9];
IkReal x10439=((IkReal(1.00000000000000))*(cj0));
IkReal x10440=((cj4)*(sj6));
IkReal x10441=((sj0)*(sj6));
IkReal x10442=((cj5)*(sj4));
IkReal x10443=((IkReal(0.374290000000000))*(sj5));
IkReal x10444=((sj4)*(sj5));
IkReal x10445=((cj0)*(cj6));
IkReal x10446=((IkReal(0.0100000000000000))*(cj5));
IkReal x10447=((cj4)*(sj5));
IkReal x10448=((cj5)*(sj0));
IkReal x10449=((IkReal(0.374290000000000))*(r02));
IkReal x10450=((r20)*(sj6));
IkReal x10451=((cj6)*(r21));
IkReal x10452=((IkReal(1.00000000000000))*(sj0));
IkReal x10453=((cj0)*(sj6));
IkReal x10454=((cj4)*(cj6));
IkReal x10455=((IkReal(0.374290000000000))*(r12));
IkReal x10456=((cj0)*(cj5));
IkReal x10457=((cj6)*(sj5));
IkReal x10458=((cj6)*(r01));
IkReal x10459=((r00)*(sj6));
IkReal x10460=((IkReal(0.0100000000000000))*(sj5));
IkReal x10461=((cj6)*(r11));
IkReal x10462=((IkReal(1.00000000000000))*(r10));
IkReal x10463=((r02)*(sj0));
IkReal x10464=((cj6)*(sj4));
IkReal x10465=((r12)*(x10452));
evalcond[0]=((IkReal(-3.14159265358979))+(IKfmod(((IkReal(1.57079632679490))+(j1)), IkReal(6.28318530717959))));
evalcond[1]=((((IkReal(-1.00000000000000))*(r20)*(x10454)))+(((r22)*(x10444)))+(((x10442)*(x10451)))+(((x10442)*(x10450)))+(((r21)*(x10440))));
evalcond[2]=((IkReal(0.364420000000000))+(((IkReal(-1.00000000000000))*(x10446)*(x10451)))+(((IkReal(-0.374290000000000))*(cj5)*(r22)))+(((IkReal(-1.00000000000000))*(r22)*(x10460)))+(((x10443)*(x10450)))+(pz)+(((IkReal(-1.00000000000000))*(x10446)*(x10450)))+(((x10443)*(x10451))));
evalcond[3]=((((IkReal(-1.00000000000000))*(sj5)*(x10441)*(x10462)))+(((IkReal(-1.00000000000000))*(sj5)*(x10439)*(x10459)))+(((IkReal(-1.00000000000000))*(r01)*(x10439)*(x10457)))+(((r12)*(x10448)))+(((IkReal(-1.00000000000000))*(r11)*(x10452)*(x10457)))+(((r02)*(x10456))));
evalcond[4]=((((cj4)*(r10)*(x10445)))+(((IkReal(-1.00000000000000))*(r00)*(x10452)*(x10454)))+(((x10444)*(x10463)))+(((r01)*(sj0)*(x10440)))+(((IkReal(-1.00000000000000))*(r10)*(sj6)*(x10439)*(x10442)))+(((sj0)*(x10442)*(x10458)))+(((IkReal(-1.00000000000000))*(r12)*(x10439)*(x10444)))+(((r00)*(x10441)*(x10442)))+(((IkReal(-1.00000000000000))*(x10439)*(x10442)*(x10461)))+(((IkReal(-1.00000000000000))*(r11)*(x10439)*(x10440))));
evalcond[5]=((IkReal(-1.00000000000000))+(((IkReal(-1.00000000000000))*(x10444)*(x10465)))+(((r10)*(sj0)*(x10454)))+(((IkReal(-1.00000000000000))*(x10439)*(x10442)*(x10458)))+(((IkReal(-1.00000000000000))*(r01)*(x10439)*(x10440)))+(((cj4)*(r00)*(x10445)))+(((IkReal(-1.00000000000000))*(x10442)*(x10452)*(x10461)))+(((IkReal(-1.00000000000000))*(r11)*(x10440)*(x10452)))+(((IkReal(-1.00000000000000))*(x10439)*(x10442)*(x10459)))+(((IkReal(-1.00000000000000))*(x10441)*(x10442)*(x10462)))+(((IkReal(-1.00000000000000))*(r02)*(x10439)*(x10444))));
evalcond[6]=((IkReal(-0.0690000000000000))+(((IkReal(-1.00000000000000))*(r00)*(x10441)*(x10446)))+(((r10)*(x10446)*(x10453)))+(((IkReal(-1.00000000000000))*(r11)*(x10443)*(x10445)))+(((IkReal(-1.00000000000000))*(sj0)*(x10446)*(x10458)))+(((IkReal(-1.00000000000000))*(x10460)*(x10463)))+(((cj0)*(r12)*(x10460)))+(((sj0)*(x10443)*(x10458)))+(((IkReal(-1.00000000000000))*(py)*(x10439)))+(((r11)*(x10445)*(x10446)))+(((px)*(sj0)))+(((x10455)*(x10456)))+(((IkReal(-1.00000000000000))*(x10448)*(x10449)))+(((IkReal(-1.00000000000000))*(r10)*(x10443)*(x10453)))+(((r00)*(x10441)*(x10443))));
evalcond[7]=((((IkReal(-1.00000000000000))*(r02)*(x10439)*(x10447)))+(((IkReal(-1.00000000000000))*(r10)*(x10452)*(x10464)))+(((IkReal(-1.00000000000000))*(cj5)*(r01)*(x10439)*(x10454)))+(((IkReal(-1.00000000000000))*(r11)*(x10448)*(x10454)))+(((r01)*(sj4)*(x10453)))+(((IkReal(-1.00000000000000))*(r00)*(x10439)*(x10464)))+(((IkReal(-1.00000000000000))*(x10447)*(x10465)))+(((IkReal(-1.00000000000000))*(x10440)*(x10448)*(x10462)))+(((IkReal(-1.00000000000000))*(cj5)*(r00)*(x10439)*(x10440)))+(((r11)*(sj4)*(x10441))));
evalcond[8]=((IkReal(0.0690000000000000))+(((IkReal(-1.00000000000000))*(px)*(x10439)))+(((IkReal(-1.00000000000000))*(py)*(x10452)))+(((r01)*(x10445)*(x10446)))+(((IkReal(-1.00000000000000))*(r00)*(x10443)*(x10453)))+(((sj0)*(x10446)*(x10461)))+(((IkReal(-1.00000000000000))*(r01)*(x10443)*(x10445)))+(((x10449)*(x10456)))+(((r00)*(x10446)*(x10453)))+(((cj0)*(r02)*(x10460)))+(((IkReal(-1.00000000000000))*(sj0)*(x10443)*(x10461)))+(((x10448)*(x10455)))+(((r12)*(sj0)*(x10460)))+(((r10)*(x10441)*(x10446)))+(((IkReal(-1.00000000000000))*(r10)*(x10441)*(x10443))));
if( IKabs(evalcond[0]) < 0.0000010000000000  && IKabs(evalcond[1]) < 0.0000010000000000  && IKabs(evalcond[2]) < 0.0000010000000000  && IKabs(evalcond[3]) < 0.0000010000000000  && IKabs(evalcond[4]) < 0.0000010000000000  && IKabs(evalcond[5]) < 0.0000010000000000  && IKabs(evalcond[6]) < 0.0000010000000000  && IKabs(evalcond[7]) < 0.0000010000000000  && IKabs(evalcond[8]) < 0.0000010000000000  )
{
{
IkReal j3array[1], cj3array[1], sj3array[1];
bool j3valid[1]={false};
_nj3 = 1;
IkReal x10466=((r20)*(sj6));
IkReal x10467=((cj4)*(cj5));
IkReal x10468=((cj6)*(r21));
if( IKabs(((((IkReal(-1.00000000000000))*(r21)*(sj4)*(sj6)))+(((x10467)*(x10468)))+(((cj6)*(r20)*(sj4)))+(((cj4)*(r22)*(sj5)))+(((x10466)*(x10467))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(((((sj5)*(x10466)))+(((IkReal(-1.00000000000000))*(cj5)*(r22)))+(((sj5)*(x10468))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(IKsqr(((((IkReal(-1.00000000000000))*(r21)*(sj4)*(sj6)))+(((x10467)*(x10468)))+(((cj6)*(r20)*(sj4)))+(((cj4)*(r22)*(sj5)))+(((x10466)*(x10467)))))+IKsqr(((((sj5)*(x10466)))+(((IkReal(-1.00000000000000))*(cj5)*(r22)))+(((sj5)*(x10468)))))-1) <= IKFAST_SINCOS_THRESH )
    continue;
j3array[0]=IKatan2(((((IkReal(-1.00000000000000))*(r21)*(sj4)*(sj6)))+(((x10467)*(x10468)))+(((cj6)*(r20)*(sj4)))+(((cj4)*(r22)*(sj5)))+(((x10466)*(x10467)))), ((((sj5)*(x10466)))+(((IkReal(-1.00000000000000))*(cj5)*(r22)))+(((sj5)*(x10468)))));
sj3array[0]=IKsin(j3array[0]);
cj3array[0]=IKcos(j3array[0]);
if( j3array[0] > IKPI )
{
    j3array[0]-=IK2PI;
}
else if( j3array[0] < -IKPI )
{    j3array[0]+=IK2PI;
}
j3valid[0] = true;
for(int ij3 = 0; ij3 < 1; ++ij3)
{
if( !j3valid[ij3] )
{
    continue;
}
_ij3[0] = ij3; _ij3[1] = -1;
for(int iij3 = ij3+1; iij3 < 1; ++iij3)
{
if( j3valid[iij3] && IKabs(cj3array[ij3]-cj3array[iij3]) < IKFAST_SOLUTION_THRESH && IKabs(sj3array[ij3]-sj3array[iij3]) < IKFAST_SOLUTION_THRESH )
{
    j3valid[iij3]=false; _ij3[1] = iij3; break; 
}
}
j3 = j3array[ij3]; cj3 = cj3array[ij3]; sj3 = sj3array[ij3];
{
IkReal evalcond[4];
IkReal x10469=IKsin(j3);
IkReal x10470=((sj0)*(sj5));
IkReal x10471=((r00)*(sj6));
IkReal x10472=((cj6)*(r01));
IkReal x10473=((cj5)*(sj0));
IkReal x10474=((cj0)*(cj5));
IkReal x10475=((cj6)*(sj4));
IkReal x10476=((sj4)*(sj6));
IkReal x10477=((cj0)*(r11));
IkReal x10478=((cj4)*(cj6));
IkReal x10479=((cj4)*(sj6));
IkReal x10480=((IkReal(1.00000000000000))*(cj0));
IkReal x10481=((cj4)*(sj5));
IkReal x10482=((sj5)*(sj6));
IkReal x10483=((cj6)*(sj5));
IkReal x10484=((IkReal(1.00000000000000))*(IKcos(j3)));
evalcond[0]=((((r21)*(x10483)))+(((r20)*(x10482)))+(((IkReal(-1.00000000000000))*(cj5)*(r22)))+(((IkReal(-1.00000000000000))*(x10484))));
evalcond[1]=((((cj5)*(r20)*(x10479)))+(((IkReal(-1.00000000000000))*(x10469)))+(((IkReal(-1.00000000000000))*(r21)*(x10476)))+(((r22)*(x10481)))+(((cj5)*(r21)*(x10478)))+(((r20)*(x10475))));
evalcond[2]=((((IkReal(-1.00000000000000))*(r02)*(x10473)))+(((IkReal(-1.00000000000000))*(r10)*(x10480)*(x10482)))+(((r12)*(x10474)))+(((IkReal(-1.00000000000000))*(x10477)*(x10483)))+(((x10470)*(x10471)))+(((x10470)*(x10472)))+(x10469));
evalcond[3]=((((r00)*(sj0)*(x10475)))+(((IkReal(-1.00000000000000))*(r12)*(x10480)*(x10481)))+(((cj4)*(x10471)*(x10473)))+(((IkReal(-1.00000000000000))*(r01)*(sj0)*(x10476)))+(((IkReal(-1.00000000000000))*(r10)*(x10474)*(x10479)))+(((cj4)*(r02)*(x10470)))+(((x10476)*(x10477)))+(((cj4)*(x10472)*(x10473)))+(((IkReal(-1.00000000000000))*(r10)*(x10475)*(x10480)))+(((IkReal(-1.00000000000000))*(x10484)))+(((IkReal(-1.00000000000000))*(r11)*(x10474)*(x10478))));
if( IKabs(evalcond[0]) > 0.000001  || IKabs(evalcond[1]) > 0.000001  || IKabs(evalcond[2]) > 0.000001  || IKabs(evalcond[3]) > 0.000001  )
{
continue;
}
}

{
std::vector<IkSingleDOFSolutionBase<IkReal> > vinfos(7);
vinfos[0].jointtype = 1;
vinfos[0].foffset = j0;
vinfos[0].indices[0] = _ij0[0];
vinfos[0].indices[1] = _ij0[1];
vinfos[0].maxsolutions = _nj0;
vinfos[1].jointtype = 1;
vinfos[1].foffset = j1;
vinfos[1].indices[0] = _ij1[0];
vinfos[1].indices[1] = _ij1[1];
vinfos[1].maxsolutions = _nj1;
vinfos[2].jointtype = 1;
vinfos[2].foffset = j2;
vinfos[2].indices[0] = _ij2[0];
vinfos[2].indices[1] = _ij2[1];
vinfos[2].maxsolutions = _nj2;
vinfos[3].jointtype = 1;
vinfos[3].foffset = j3;
vinfos[3].indices[0] = _ij3[0];
vinfos[3].indices[1] = _ij3[1];
vinfos[3].maxsolutions = _nj3;
vinfos[4].jointtype = 1;
vinfos[4].foffset = j4;
vinfos[4].indices[0] = _ij4[0];
vinfos[4].indices[1] = _ij4[1];
vinfos[4].maxsolutions = _nj4;
vinfos[5].jointtype = 1;
vinfos[5].foffset = j5;
vinfos[5].indices[0] = _ij5[0];
vinfos[5].indices[1] = _ij5[1];
vinfos[5].maxsolutions = _nj5;
vinfos[6].jointtype = 1;
vinfos[6].foffset = j6;
vinfos[6].indices[0] = _ij6[0];
vinfos[6].indices[1] = _ij6[1];
vinfos[6].maxsolutions = _nj6;
std::vector<int> vfree(0);
solutions.AddSolution(vinfos,vfree);
}
}
}

} else
{
IkReal x10485=((IkReal(1.00000000000000))*(cj0));
IkReal x10486=((cj4)*(sj6));
IkReal x10487=((sj0)*(sj6));
IkReal x10488=((cj5)*(sj4));
IkReal x10489=((IkReal(0.374290000000000))*(sj5));
IkReal x10490=((sj4)*(sj5));
IkReal x10491=((cj0)*(cj6));
IkReal x10492=((IkReal(0.0100000000000000))*(cj5));
IkReal x10493=((cj4)*(sj5));
IkReal x10494=((cj5)*(sj0));
IkReal x10495=((IkReal(0.374290000000000))*(r02));
IkReal x10496=((r20)*(sj6));
IkReal x10497=((cj6)*(r21));
IkReal x10498=((IkReal(1.00000000000000))*(sj0));
IkReal x10499=((cj0)*(sj6));
IkReal x10500=((cj4)*(cj6));
IkReal x10501=((IkReal(0.374290000000000))*(r12));
IkReal x10502=((cj0)*(cj5));
IkReal x10503=((cj6)*(sj5));
IkReal x10504=((cj6)*(r01));
IkReal x10505=((r00)*(sj6));
IkReal x10506=((IkReal(0.0100000000000000))*(sj5));
IkReal x10507=((cj6)*(r11));
IkReal x10508=((IkReal(1.00000000000000))*(r10));
IkReal x10509=((r02)*(sj0));
IkReal x10510=((cj6)*(sj4));
IkReal x10511=((r12)*(x10498));
evalcond[0]=((IkReal(-3.14159265358979))+(IKfmod(((IkReal(4.71238898038469))+(j1)), IkReal(6.28318530717959))));
evalcond[1]=((((x10488)*(x10497)))+(((x10488)*(x10496)))+(((IkReal(-1.00000000000000))*(r20)*(x10500)))+(((r22)*(x10490)))+(((r21)*(x10486))));
evalcond[2]=((IkReal(-0.364420000000000))+(((IkReal(-0.374290000000000))*(cj5)*(r22)))+(pz)+(((x10489)*(x10497)))+(((IkReal(-1.00000000000000))*(x10492)*(x10496)))+(((IkReal(-1.00000000000000))*(x10492)*(x10497)))+(((x10489)*(x10496)))+(((IkReal(-1.00000000000000))*(r22)*(x10506))));
evalcond[3]=((((IkReal(-1.00000000000000))*(sj5)*(x10485)*(x10505)))+(((r02)*(x10502)))+(((IkReal(-1.00000000000000))*(sj5)*(x10487)*(x10508)))+(((r12)*(x10494)))+(((IkReal(-1.00000000000000))*(r11)*(x10498)*(x10503)))+(((IkReal(-1.00000000000000))*(r01)*(x10485)*(x10503))));
evalcond[4]=((((IkReal(-1.00000000000000))*(r12)*(x10485)*(x10490)))+(((IkReal(-1.00000000000000))*(r00)*(x10498)*(x10500)))+(((r01)*(sj0)*(x10486)))+(((IkReal(-1.00000000000000))*(r11)*(x10485)*(x10486)))+(((x10490)*(x10509)))+(((r00)*(x10487)*(x10488)))+(((cj4)*(r10)*(x10491)))+(((sj0)*(x10488)*(x10504)))+(((IkReal(-1.00000000000000))*(r10)*(sj6)*(x10485)*(x10488)))+(((IkReal(-1.00000000000000))*(x10485)*(x10488)*(x10507))));
evalcond[5]=((IkReal(1.00000000000000))+(((IkReal(-1.00000000000000))*(r11)*(x10486)*(x10498)))+(((IkReal(-1.00000000000000))*(x10485)*(x10488)*(x10504)))+(((IkReal(-1.00000000000000))*(x10485)*(x10488)*(x10505)))+(((IkReal(-1.00000000000000))*(x10490)*(x10511)))+(((IkReal(-1.00000000000000))*(x10488)*(x10498)*(x10507)))+(((IkReal(-1.00000000000000))*(r01)*(x10485)*(x10486)))+(((IkReal(-1.00000000000000))*(r02)*(x10485)*(x10490)))+(((cj4)*(r00)*(x10491)))+(((IkReal(-1.00000000000000))*(x10487)*(x10488)*(x10508)))+(((r10)*(sj0)*(x10500))));
evalcond[6]=((IkReal(-0.0690000000000000))+(((r00)*(x10487)*(x10489)))+(((IkReal(-1.00000000000000))*(sj0)*(x10492)*(x10504)))+(((IkReal(-1.00000000000000))*(r00)*(x10487)*(x10492)))+(((r10)*(x10492)*(x10499)))+(((IkReal(-1.00000000000000))*(r10)*(x10489)*(x10499)))+(((IkReal(-1.00000000000000))*(x10494)*(x10495)))+(((IkReal(-1.00000000000000))*(py)*(x10485)))+(((r11)*(x10491)*(x10492)))+(((px)*(sj0)))+(((IkReal(-1.00000000000000))*(x10506)*(x10509)))+(((IkReal(-1.00000000000000))*(r11)*(x10489)*(x10491)))+(((x10501)*(x10502)))+(((cj0)*(r12)*(x10506)))+(((sj0)*(x10489)*(x10504))));
evalcond[7]=((((IkReal(-1.00000000000000))*(x10493)*(x10511)))+(((r11)*(sj4)*(x10487)))+(((IkReal(-1.00000000000000))*(r00)*(x10485)*(x10510)))+(((IkReal(-1.00000000000000))*(r10)*(x10498)*(x10510)))+(((IkReal(-1.00000000000000))*(cj5)*(r00)*(x10485)*(x10486)))+(((IkReal(-1.00000000000000))*(r11)*(x10494)*(x10500)))+(((IkReal(-1.00000000000000))*(r02)*(x10485)*(x10493)))+(((IkReal(-1.00000000000000))*(cj5)*(r01)*(x10485)*(x10500)))+(((IkReal(-1.00000000000000))*(x10486)*(x10494)*(x10508)))+(((r01)*(sj4)*(x10499))));
evalcond[8]=((IkReal(0.0690000000000000))+(((IkReal(-1.00000000000000))*(r10)*(x10487)*(x10489)))+(((r10)*(x10487)*(x10492)))+(((IkReal(-1.00000000000000))*(sj0)*(x10489)*(x10507)))+(((IkReal(-1.00000000000000))*(r01)*(x10489)*(x10491)))+(((sj0)*(x10492)*(x10507)))+(((x10494)*(x10501)))+(((IkReal(-1.00000000000000))*(py)*(x10498)))+(((r12)*(sj0)*(x10506)))+(((IkReal(-1.00000000000000))*(r00)*(x10489)*(x10499)))+(((IkReal(-1.00000000000000))*(px)*(x10485)))+(((r01)*(x10491)*(x10492)))+(((cj0)*(r02)*(x10506)))+(((r00)*(x10492)*(x10499)))+(((x10495)*(x10502))));
if( IKabs(evalcond[0]) < 0.0000010000000000  && IKabs(evalcond[1]) < 0.0000010000000000  && IKabs(evalcond[2]) < 0.0000010000000000  && IKabs(evalcond[3]) < 0.0000010000000000  && IKabs(evalcond[4]) < 0.0000010000000000  && IKabs(evalcond[5]) < 0.0000010000000000  && IKabs(evalcond[6]) < 0.0000010000000000  && IKabs(evalcond[7]) < 0.0000010000000000  && IKabs(evalcond[8]) < 0.0000010000000000  )
{
{
IkReal j3array[1], cj3array[1], sj3array[1];
bool j3valid[1]={false};
_nj3 = 1;
IkReal x10512=((IkReal(1.00000000000000))*(sj5));
IkReal x10513=((cj6)*(r21));
IkReal x10514=((r20)*(sj6));
IkReal x10515=((IkReal(1.00000000000000))*(cj4)*(cj5));
if( IKabs(((((IkReal(-1.00000000000000))*(cj4)*(r22)*(x10512)))+(((IkReal(-1.00000000000000))*(x10514)*(x10515)))+(((r21)*(sj4)*(sj6)))+(((IkReal(-1.00000000000000))*(x10513)*(x10515)))+(((IkReal(-1.00000000000000))*(cj6)*(r20)*(sj4))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(((((IkReal(-1.00000000000000))*(x10512)*(x10513)))+(((IkReal(-1.00000000000000))*(x10512)*(x10514)))+(((cj5)*(r22))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(IKsqr(((((IkReal(-1.00000000000000))*(cj4)*(r22)*(x10512)))+(((IkReal(-1.00000000000000))*(x10514)*(x10515)))+(((r21)*(sj4)*(sj6)))+(((IkReal(-1.00000000000000))*(x10513)*(x10515)))+(((IkReal(-1.00000000000000))*(cj6)*(r20)*(sj4)))))+IKsqr(((((IkReal(-1.00000000000000))*(x10512)*(x10513)))+(((IkReal(-1.00000000000000))*(x10512)*(x10514)))+(((cj5)*(r22)))))-1) <= IKFAST_SINCOS_THRESH )
    continue;
j3array[0]=IKatan2(((((IkReal(-1.00000000000000))*(cj4)*(r22)*(x10512)))+(((IkReal(-1.00000000000000))*(x10514)*(x10515)))+(((r21)*(sj4)*(sj6)))+(((IkReal(-1.00000000000000))*(x10513)*(x10515)))+(((IkReal(-1.00000000000000))*(cj6)*(r20)*(sj4)))), ((((IkReal(-1.00000000000000))*(x10512)*(x10513)))+(((IkReal(-1.00000000000000))*(x10512)*(x10514)))+(((cj5)*(r22)))));
sj3array[0]=IKsin(j3array[0]);
cj3array[0]=IKcos(j3array[0]);
if( j3array[0] > IKPI )
{
    j3array[0]-=IK2PI;
}
else if( j3array[0] < -IKPI )
{    j3array[0]+=IK2PI;
}
j3valid[0] = true;
for(int ij3 = 0; ij3 < 1; ++ij3)
{
if( !j3valid[ij3] )
{
    continue;
}
_ij3[0] = ij3; _ij3[1] = -1;
for(int iij3 = ij3+1; iij3 < 1; ++iij3)
{
if( j3valid[iij3] && IKabs(cj3array[ij3]-cj3array[iij3]) < IKFAST_SOLUTION_THRESH && IKabs(sj3array[ij3]-sj3array[iij3]) < IKFAST_SOLUTION_THRESH )
{
    j3valid[iij3]=false; _ij3[1] = iij3; break; 
}
}
j3 = j3array[ij3]; cj3 = cj3array[ij3]; sj3 = sj3array[ij3];
{
IkReal evalcond[4];
IkReal x10516=IKsin(j3);
IkReal x10517=IKcos(j3);
IkReal x10518=((sj0)*(sj5));
IkReal x10519=((r00)*(sj6));
IkReal x10520=((cj6)*(r01));
IkReal x10521=((cj0)*(cj5));
IkReal x10522=((IkReal(1.00000000000000))*(cj5));
IkReal x10523=((cj4)*(cj5));
IkReal x10524=((cj6)*(sj4));
IkReal x10525=((sj4)*(sj6));
IkReal x10526=((cj0)*(r11));
IkReal x10527=((IkReal(1.00000000000000))*(cj4));
IkReal x10528=((cj6)*(r21));
IkReal x10529=((r20)*(sj6));
IkReal x10530=((cj0)*(sj5));
IkReal x10531=((r10)*(sj6));
evalcond[0]=((((sj5)*(x10528)))+(x10517)+(((sj5)*(x10529)))+(((IkReal(-1.00000000000000))*(r22)*(x10522))));
evalcond[1]=((((r20)*(x10524)))+(((cj4)*(r22)*(sj5)))+(((IkReal(-1.00000000000000))*(r21)*(x10525)))+(x10516)+(((x10523)*(x10529)))+(((x10523)*(x10528))));
evalcond[2]=((((IkReal(-1.00000000000000))*(cj6)*(sj5)*(x10526)))+(((r12)*(x10521)))+(((x10518)*(x10519)))+(((IkReal(-1.00000000000000))*(x10530)*(x10531)))+(x10516)+(((x10518)*(x10520)))+(((IkReal(-1.00000000000000))*(r02)*(sj0)*(x10522))));
evalcond[3]=((((IkReal(-1.00000000000000))*(cj0)*(r10)*(x10524)))+(((IkReal(-1.00000000000000))*(cj6)*(r11)*(x10521)*(x10527)))+(((cj4)*(r02)*(x10518)))+(((IkReal(-1.00000000000000))*(r12)*(x10527)*(x10530)))+(((x10525)*(x10526)))+(((sj0)*(x10519)*(x10523)))+(((IkReal(-1.00000000000000))*(r01)*(sj0)*(x10525)))+(((IkReal(-1.00000000000000))*(x10517)))+(((IkReal(-1.00000000000000))*(x10521)*(x10527)*(x10531)))+(((sj0)*(x10520)*(x10523)))+(((r00)*(sj0)*(x10524))));
if( IKabs(evalcond[0]) > 0.000001  || IKabs(evalcond[1]) > 0.000001  || IKabs(evalcond[2]) > 0.000001  || IKabs(evalcond[3]) > 0.000001  )
{
continue;
}
}

{
std::vector<IkSingleDOFSolutionBase<IkReal> > vinfos(7);
vinfos[0].jointtype = 1;
vinfos[0].foffset = j0;
vinfos[0].indices[0] = _ij0[0];
vinfos[0].indices[1] = _ij0[1];
vinfos[0].maxsolutions = _nj0;
vinfos[1].jointtype = 1;
vinfos[1].foffset = j1;
vinfos[1].indices[0] = _ij1[0];
vinfos[1].indices[1] = _ij1[1];
vinfos[1].maxsolutions = _nj1;
vinfos[2].jointtype = 1;
vinfos[2].foffset = j2;
vinfos[2].indices[0] = _ij2[0];
vinfos[2].indices[1] = _ij2[1];
vinfos[2].maxsolutions = _nj2;
vinfos[3].jointtype = 1;
vinfos[3].foffset = j3;
vinfos[3].indices[0] = _ij3[0];
vinfos[3].indices[1] = _ij3[1];
vinfos[3].maxsolutions = _nj3;
vinfos[4].jointtype = 1;
vinfos[4].foffset = j4;
vinfos[4].indices[0] = _ij4[0];
vinfos[4].indices[1] = _ij4[1];
vinfos[4].maxsolutions = _nj4;
vinfos[5].jointtype = 1;
vinfos[5].foffset = j5;
vinfos[5].indices[0] = _ij5[0];
vinfos[5].indices[1] = _ij5[1];
vinfos[5].maxsolutions = _nj5;
vinfos[6].jointtype = 1;
vinfos[6].foffset = j6;
vinfos[6].indices[0] = _ij6[0];
vinfos[6].indices[1] = _ij6[1];
vinfos[6].maxsolutions = _nj6;
std::vector<int> vfree(0);
solutions.AddSolution(vinfos,vfree);
}
}
}

} else
{
IkReal x10532=((IkReal(1.00000000000000))*(cj0));
IkReal x10533=((cj4)*(sj6));
IkReal x10534=((sj0)*(sj4));
IkReal x10535=((cj5)*(sj6));
IkReal x10536=((sj4)*(sj5));
IkReal x10537=((r12)*(sj5));
IkReal x10538=((IkReal(0.374290000000000))*(cj5));
IkReal x10539=((r02)*(sj0));
IkReal x10540=((r20)*(sj4));
IkReal x10541=((IkReal(1.00000000000000))*(sj0));
IkReal x10542=((IkReal(1.00000000000000))*(cj5));
IkReal x10543=((cj0)*(r10));
IkReal x10544=((cj4)*(cj6));
IkReal x10545=((r00)*(sj0));
IkReal x10546=((cj6)*(r21));
IkReal x10547=((IkReal(0.374290000000000))*(sj5));
IkReal x10548=((cj0)*(r00));
IkReal x10549=((IkReal(0.0100000000000000))*(sj5));
IkReal x10550=((cj0)*(r02));
IkReal x10551=((cj5)*(sj4));
IkReal x10552=((cj6)*(r01));
IkReal x10553=((cj6)*(r11));
IkReal x10554=((r01)*(sj0));
IkReal x10555=((r10)*(sj0));
IkReal x10556=((IkReal(0.0100000000000000))*(cj5)*(cj6));
IkReal x10557=((sj6)*(x10547));
IkReal x10558=((cj0)*(cj6)*(x10547));
evalcond[0]=((IkReal(-3.14159265358979))+(IKfmod(((IkReal(3.14159265358979))+(j1)), IkReal(6.28318530717959))));
evalcond[1]=((((sj5)*(x10546)))+(((IkReal(-1.00000000000000))*(r22)*(x10542)))+(((r20)*(sj5)*(sj6))));
evalcond[2]=((IkReal(1.00000000000000))+(((r21)*(x10533)))+(((IkReal(-1.00000000000000))*(r20)*(x10544)))+(((x10535)*(x10540)))+(((x10546)*(x10551)))+(((r22)*(x10536))));
evalcond[3]=((((IkReal(-1.00000000000000))*(r22)*(x10538)))+(((x10546)*(x10547)))+(((IkReal(-0.0100000000000000))*(cj5)*(x10546)))+(((r20)*(x10557)))+(pz)+(((IkReal(-1.00000000000000))*(r22)*(x10549)))+(((IkReal(-0.0100000000000000))*(r20)*(x10535))));
evalcond[4]=((((IkReal(-1.00000000000000))*(r21)*(sj4)*(sj6)))+(((cj4)*(r22)*(sj5)))+(((cj5)*(r20)*(x10533)))+(((cj6)*(x10540)))+(((cj5)*(r21)*(x10544))));
evalcond[5]=((((r02)*(sj5)*(x10534)))+(((cj5)*(x10534)*(x10552)))+(((x10543)*(x10544)))+(((x10533)*(x10554)))+(((IkReal(-1.00000000000000))*(x10532)*(x10551)*(x10553)))+(((IkReal(-1.00000000000000))*(r10)*(sj4)*(x10532)*(x10535)))+(((IkReal(-1.00000000000000))*(r11)*(x10532)*(x10533)))+(((r00)*(x10534)*(x10535)))+(((IkReal(-1.00000000000000))*(r12)*(x10532)*(x10536)))+(((IkReal(-1.00000000000000))*(r00)*(x10541)*(x10544))));
evalcond[6]=((((IkReal(-1.00000000000000))*(r02)*(x10532)*(x10536)))+(((IkReal(-1.00000000000000))*(r10)*(x10534)*(x10535)))+(((IkReal(-1.00000000000000))*(r00)*(sj4)*(x10532)*(x10535)))+(((IkReal(-1.00000000000000))*(x10532)*(x10551)*(x10552)))+(((IkReal(-1.00000000000000))*(r11)*(x10533)*(x10541)))+(((IkReal(-1.00000000000000))*(x10534)*(x10537)))+(((IkReal(-1.00000000000000))*(r01)*(x10532)*(x10533)))+(((x10544)*(x10555)))+(((x10544)*(x10548)))+(((IkReal(-1.00000000000000))*(x10534)*(x10542)*(x10553))));
evalcond[7]=((IkReal(-0.0690000000000000))+(((IkReal(0.0100000000000000))*(cj0)*(cj5)*(x10553)))+(((IkReal(-0.0100000000000000))*(cj5)*(sj0)*(x10552)))+(((IkReal(-1.00000000000000))*(x10543)*(x10557)))+(((IkReal(0.0100000000000000))*(x10535)*(x10543)))+(((IkReal(-1.00000000000000))*(py)*(x10532)))+(((IkReal(-0.0100000000000000))*(x10535)*(x10545)))+(((IkReal(-1.00000000000000))*(cj0)*(x10547)*(x10553)))+(((cj0)*(r12)*(x10538)))+(((x10545)*(x10557)))+(((IkReal(-1.00000000000000))*(x10538)*(x10539)))+(((IkReal(0.0100000000000000))*(cj0)*(x10537)))+(((sj0)*(x10547)*(x10552)))+(((px)*(sj0)))+(((IkReal(-1.00000000000000))*(x10539)*(x10549))));
evalcond[8]=((IkReal(0.433420000000000))+(((IkReal(-1.00000000000000))*(x10548)*(x10557)))+(((IkReal(-1.00000000000000))*(px)*(x10532)))+(((IkReal(0.0100000000000000))*(sj0)*(x10537)))+(((IkReal(0.0100000000000000))*(cj0)*(cj5)*(x10552)))+(((IkReal(-1.00000000000000))*(py)*(x10541)))+(((r12)*(sj0)*(x10538)))+(((IkReal(0.0100000000000000))*(x10535)*(x10548)))+(((IkReal(-1.00000000000000))*(x10555)*(x10557)))+(((IkReal(0.0100000000000000))*(x10535)*(x10555)))+(((x10549)*(x10550)))+(((x10538)*(x10550)))+(((IkReal(-1.00000000000000))*(sj0)*(x10547)*(x10553)))+(((IkReal(0.0100000000000000))*(cj5)*(sj0)*(x10553)))+(((IkReal(-1.00000000000000))*(cj0)*(x10547)*(x10552))));
if( IKabs(evalcond[0]) < 0.0000010000000000  && IKabs(evalcond[1]) < 0.0000010000000000  && IKabs(evalcond[2]) < 0.0000010000000000  && IKabs(evalcond[3]) < 0.0000010000000000  && IKabs(evalcond[4]) < 0.0000010000000000  && IKabs(evalcond[5]) < 0.0000010000000000  && IKabs(evalcond[6]) < 0.0000010000000000  && IKabs(evalcond[7]) < 0.0000010000000000  && IKabs(evalcond[8]) < 0.0000010000000000  )
{
{
IkReal j3array[1], cj3array[1], sj3array[1];
bool j3valid[1]={false};
_nj3 = 1;
IkReal x10559=((cj5)*(r02));
IkReal x10560=((cj0)*(sj5));
IkReal x10561=((r10)*(sj6));
IkReal x10562=((IkReal(1.00000000000000))*(cj6));
IkReal x10563=((sj0)*(sj5));
IkReal x10564=((cj5)*(r12));
IkReal x10565=((IkReal(1.00000000000000))*(r00)*(sj6));
if( IKabs(((((x10560)*(x10561)))+(((IkReal(-1.00000000000000))*(r01)*(x10562)*(x10563)))+(((IkReal(-1.00000000000000))*(cj0)*(x10564)))+(((IkReal(-1.00000000000000))*(x10563)*(x10565)))+(((cj6)*(r11)*(x10560)))+(((sj0)*(x10559))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(((((IkReal(-1.00000000000000))*(x10561)*(x10563)))+(((cj0)*(x10559)))+(((IkReal(-1.00000000000000))*(r01)*(x10560)*(x10562)))+(((sj0)*(x10564)))+(((IkReal(-1.00000000000000))*(x10560)*(x10565)))+(((IkReal(-1.00000000000000))*(r11)*(x10562)*(x10563))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(IKsqr(((((x10560)*(x10561)))+(((IkReal(-1.00000000000000))*(r01)*(x10562)*(x10563)))+(((IkReal(-1.00000000000000))*(cj0)*(x10564)))+(((IkReal(-1.00000000000000))*(x10563)*(x10565)))+(((cj6)*(r11)*(x10560)))+(((sj0)*(x10559)))))+IKsqr(((((IkReal(-1.00000000000000))*(x10561)*(x10563)))+(((cj0)*(x10559)))+(((IkReal(-1.00000000000000))*(r01)*(x10560)*(x10562)))+(((sj0)*(x10564)))+(((IkReal(-1.00000000000000))*(x10560)*(x10565)))+(((IkReal(-1.00000000000000))*(r11)*(x10562)*(x10563)))))-1) <= IKFAST_SINCOS_THRESH )
    continue;
j3array[0]=IKatan2(((((x10560)*(x10561)))+(((IkReal(-1.00000000000000))*(r01)*(x10562)*(x10563)))+(((IkReal(-1.00000000000000))*(cj0)*(x10564)))+(((IkReal(-1.00000000000000))*(x10563)*(x10565)))+(((cj6)*(r11)*(x10560)))+(((sj0)*(x10559)))), ((((IkReal(-1.00000000000000))*(x10561)*(x10563)))+(((cj0)*(x10559)))+(((IkReal(-1.00000000000000))*(r01)*(x10560)*(x10562)))+(((sj0)*(x10564)))+(((IkReal(-1.00000000000000))*(x10560)*(x10565)))+(((IkReal(-1.00000000000000))*(r11)*(x10562)*(x10563)))));
sj3array[0]=IKsin(j3array[0]);
cj3array[0]=IKcos(j3array[0]);
if( j3array[0] > IKPI )
{
    j3array[0]-=IK2PI;
}
else if( j3array[0] < -IKPI )
{    j3array[0]+=IK2PI;
}
j3valid[0] = true;
for(int ij3 = 0; ij3 < 1; ++ij3)
{
if( !j3valid[ij3] )
{
    continue;
}
_ij3[0] = ij3; _ij3[1] = -1;
for(int iij3 = ij3+1; iij3 < 1; ++iij3)
{
if( j3valid[iij3] && IKabs(cj3array[ij3]-cj3array[iij3]) < IKFAST_SOLUTION_THRESH && IKabs(sj3array[ij3]-sj3array[iij3]) < IKFAST_SOLUTION_THRESH )
{
    j3valid[iij3]=false; _ij3[1] = iij3; break; 
}
}
j3 = j3array[ij3]; cj3 = cj3array[ij3]; sj3 = sj3array[ij3];
{
IkReal evalcond[4];
IkReal x10566=IKsin(j3);
IkReal x10567=((sj0)*(sj5));
IkReal x10568=((r00)*(sj6));
IkReal x10569=((IkReal(1.00000000000000))*(cj4));
IkReal x10570=((cj6)*(sj0));
IkReal x10571=((r00)*(sj4));
IkReal x10572=((cj0)*(cj5));
IkReal x10573=((cj6)*(r01));
IkReal x10574=((cj5)*(sj0));
IkReal x10575=((cj0)*(sj5));
IkReal x10576=((cj6)*(r11));
IkReal x10577=((r10)*(sj6));
IkReal x10578=((r10)*(sj4));
IkReal x10579=((IkReal(1.00000000000000))*(IKcos(j3)));
IkReal x10580=((cj0)*(sj4)*(sj6));
IkReal x10581=((sj0)*(sj4)*(sj6));
IkReal x10582=((IkReal(1.00000000000000))*(cj0)*(cj6));
evalcond[0]=((((IkReal(-1.00000000000000))*(r02)*(x10574)))+(((r12)*(x10572)))+(((x10567)*(x10573)))+(x10566)+(((x10567)*(x10568)))+(((IkReal(-1.00000000000000))*(x10575)*(x10576)))+(((IkReal(-1.00000000000000))*(x10575)*(x10577))));
evalcond[1]=((((r12)*(x10574)))+(((IkReal(-1.00000000000000))*(x10568)*(x10575)))+(((IkReal(-1.00000000000000))*(x10567)*(x10576)))+(((IkReal(-1.00000000000000))*(x10579)))+(((IkReal(-1.00000000000000))*(x10573)*(x10575)))+(((IkReal(-1.00000000000000))*(x10567)*(x10577)))+(((r02)*(x10572))));
evalcond[2]=((((x10570)*(x10571)))+(((IkReal(-1.00000000000000))*(x10578)*(x10582)))+(((IkReal(-1.00000000000000))*(x10579)))+(((IkReal(-1.00000000000000))*(r12)*(x10569)*(x10575)))+(((IkReal(-1.00000000000000))*(x10569)*(x10572)*(x10576)))+(((cj4)*(cj5)*(r01)*(x10570)))+(((IkReal(-1.00000000000000))*(r01)*(x10581)))+(((r11)*(x10580)))+(((IkReal(-1.00000000000000))*(x10569)*(x10572)*(x10577)))+(((cj4)*(x10568)*(x10574)))+(((cj4)*(r02)*(x10567))));
evalcond[3]=((((r01)*(x10580)))+(((IkReal(-1.00000000000000))*(r12)*(x10567)*(x10569)))+(((IkReal(-1.00000000000000))*(x10569)*(x10572)*(x10573)))+(((IkReal(-1.00000000000000))*(x10569)*(x10574)*(x10577)))+(((IkReal(-1.00000000000000))*(x10566)))+(((IkReal(-1.00000000000000))*(x10568)*(x10569)*(x10572)))+(((r11)*(x10581)))+(((IkReal(-1.00000000000000))*(r02)*(x10569)*(x10575)))+(((IkReal(-1.00000000000000))*(x10570)*(x10578)))+(((IkReal(-1.00000000000000))*(x10571)*(x10582)))+(((IkReal(-1.00000000000000))*(cj5)*(r11)*(x10569)*(x10570))));
if( IKabs(evalcond[0]) > 0.000001  || IKabs(evalcond[1]) > 0.000001  || IKabs(evalcond[2]) > 0.000001  || IKabs(evalcond[3]) > 0.000001  )
{
continue;
}
}

{
std::vector<IkSingleDOFSolutionBase<IkReal> > vinfos(7);
vinfos[0].jointtype = 1;
vinfos[0].foffset = j0;
vinfos[0].indices[0] = _ij0[0];
vinfos[0].indices[1] = _ij0[1];
vinfos[0].maxsolutions = _nj0;
vinfos[1].jointtype = 1;
vinfos[1].foffset = j1;
vinfos[1].indices[0] = _ij1[0];
vinfos[1].indices[1] = _ij1[1];
vinfos[1].maxsolutions = _nj1;
vinfos[2].jointtype = 1;
vinfos[2].foffset = j2;
vinfos[2].indices[0] = _ij2[0];
vinfos[2].indices[1] = _ij2[1];
vinfos[2].maxsolutions = _nj2;
vinfos[3].jointtype = 1;
vinfos[3].foffset = j3;
vinfos[3].indices[0] = _ij3[0];
vinfos[3].indices[1] = _ij3[1];
vinfos[3].maxsolutions = _nj3;
vinfos[4].jointtype = 1;
vinfos[4].foffset = j4;
vinfos[4].indices[0] = _ij4[0];
vinfos[4].indices[1] = _ij4[1];
vinfos[4].maxsolutions = _nj4;
vinfos[5].jointtype = 1;
vinfos[5].foffset = j5;
vinfos[5].indices[0] = _ij5[0];
vinfos[5].indices[1] = _ij5[1];
vinfos[5].maxsolutions = _nj5;
vinfos[6].jointtype = 1;
vinfos[6].foffset = j6;
vinfos[6].indices[0] = _ij6[0];
vinfos[6].indices[1] = _ij6[1];
vinfos[6].maxsolutions = _nj6;
std::vector<int> vfree(0);
solutions.AddSolution(vinfos,vfree);
}
}
}

} else
{
IkReal x10583=((IkReal(1.00000000000000))*(cj0));
IkReal x10584=((cj4)*(sj6));
IkReal x10585=((sj0)*(sj4));
IkReal x10586=((cj5)*(sj6));
IkReal x10587=((sj4)*(sj5));
IkReal x10588=((r12)*(sj5));
IkReal x10589=((IkReal(0.374290000000000))*(cj5));
IkReal x10590=((r02)*(sj0));
IkReal x10591=((r20)*(sj4));
IkReal x10592=((IkReal(1.00000000000000))*(sj0));
IkReal x10593=((IkReal(1.00000000000000))*(cj5));
IkReal x10594=((cj0)*(r10));
IkReal x10595=((cj4)*(cj6));
IkReal x10596=((r00)*(sj0));
IkReal x10597=((cj6)*(r21));
IkReal x10598=((IkReal(0.374290000000000))*(sj5));
IkReal x10599=((cj0)*(r00));
IkReal x10600=((IkReal(0.0100000000000000))*(sj5));
IkReal x10601=((cj0)*(r02));
IkReal x10602=((cj5)*(sj4));
IkReal x10603=((cj6)*(r01));
IkReal x10604=((cj6)*(r11));
IkReal x10605=((r01)*(sj0));
IkReal x10606=((r10)*(sj0));
IkReal x10607=((IkReal(0.0100000000000000))*(cj5)*(cj6));
IkReal x10608=((sj6)*(x10598));
IkReal x10609=((cj0)*(cj6)*(x10598));
evalcond[0]=((IkReal(-3.14159265358979))+(IKfmod(j1, IkReal(6.28318530717959))));
evalcond[1]=((((IkReal(-1.00000000000000))*(r22)*(x10593)))+(((sj5)*(x10597)))+(((r20)*(sj5)*(sj6))));
evalcond[2]=((IkReal(-1.00000000000000))+(((x10586)*(x10591)))+(((r21)*(x10584)))+(((r22)*(x10587)))+(((IkReal(-1.00000000000000))*(r20)*(x10595)))+(((x10597)*(x10602))));
evalcond[3]=((((IkReal(-0.0100000000000000))*(cj5)*(x10597)))+(((r20)*(x10608)))+(((IkReal(-1.00000000000000))*(r22)*(x10589)))+(((IkReal(-1.00000000000000))*(r22)*(x10600)))+(((IkReal(-0.0100000000000000))*(r20)*(x10586)))+(pz)+(((x10597)*(x10598))));
evalcond[4]=((((IkReal(-1.00000000000000))*(r21)*(sj4)*(sj6)))+(((cj5)*(r21)*(x10595)))+(((cj4)*(r22)*(sj5)))+(((cj5)*(r20)*(x10584)))+(((cj6)*(x10591))));
evalcond[5]=((((x10584)*(x10605)))+(((IkReal(-1.00000000000000))*(r00)*(x10592)*(x10595)))+(((IkReal(-1.00000000000000))*(r10)*(sj4)*(x10583)*(x10586)))+(((x10594)*(x10595)))+(((r00)*(x10585)*(x10586)))+(((IkReal(-1.00000000000000))*(r11)*(x10583)*(x10584)))+(((r02)*(sj5)*(x10585)))+(((IkReal(-1.00000000000000))*(r12)*(x10583)*(x10587)))+(((cj5)*(x10585)*(x10603)))+(((IkReal(-1.00000000000000))*(x10583)*(x10602)*(x10604))));
evalcond[6]=((((IkReal(-1.00000000000000))*(r11)*(x10584)*(x10592)))+(((IkReal(-1.00000000000000))*(x10583)*(x10602)*(x10603)))+(((IkReal(-1.00000000000000))*(x10585)*(x10588)))+(((IkReal(-1.00000000000000))*(r02)*(x10583)*(x10587)))+(((x10595)*(x10606)))+(((IkReal(-1.00000000000000))*(x10585)*(x10593)*(x10604)))+(((IkReal(-1.00000000000000))*(r01)*(x10583)*(x10584)))+(((IkReal(-1.00000000000000))*(r00)*(sj4)*(x10583)*(x10586)))+(((x10595)*(x10599)))+(((IkReal(-1.00000000000000))*(r10)*(x10585)*(x10586))));
evalcond[7]=((IkReal(-0.0690000000000000))+(((x10596)*(x10608)))+(((sj0)*(x10598)*(x10603)))+(((IkReal(0.0100000000000000))*(x10586)*(x10594)))+(((IkReal(-1.00000000000000))*(x10590)*(x10600)))+(((IkReal(0.0100000000000000))*(cj0)*(cj5)*(x10604)))+(((IkReal(0.0100000000000000))*(cj0)*(x10588)))+(((IkReal(-0.0100000000000000))*(x10586)*(x10596)))+(((IkReal(-1.00000000000000))*(py)*(x10583)))+(((IkReal(-1.00000000000000))*(x10594)*(x10608)))+(((IkReal(-1.00000000000000))*(cj0)*(x10598)*(x10604)))+(((cj0)*(r12)*(x10589)))+(((px)*(sj0)))+(((IkReal(-1.00000000000000))*(x10589)*(x10590)))+(((IkReal(-0.0100000000000000))*(cj5)*(sj0)*(x10603))));
evalcond[8]=((IkReal(-0.295420000000000))+(((IkReal(0.0100000000000000))*(x10586)*(x10606)))+(((IkReal(-1.00000000000000))*(x10606)*(x10608)))+(((IkReal(-1.00000000000000))*(cj0)*(x10598)*(x10603)))+(((IkReal(0.0100000000000000))*(cj0)*(cj5)*(x10603)))+(((IkReal(-1.00000000000000))*(x10599)*(x10608)))+(((x10589)*(x10601)))+(((IkReal(0.0100000000000000))*(sj0)*(x10588)))+(((IkReal(-1.00000000000000))*(px)*(x10583)))+(((IkReal(0.0100000000000000))*(cj5)*(sj0)*(x10604)))+(((r12)*(sj0)*(x10589)))+(((IkReal(-1.00000000000000))*(py)*(x10592)))+(((IkReal(-1.00000000000000))*(sj0)*(x10598)*(x10604)))+(((x10600)*(x10601)))+(((IkReal(0.0100000000000000))*(x10586)*(x10599))));
if( IKabs(evalcond[0]) < 0.0000010000000000  && IKabs(evalcond[1]) < 0.0000010000000000  && IKabs(evalcond[2]) < 0.0000010000000000  && IKabs(evalcond[3]) < 0.0000010000000000  && IKabs(evalcond[4]) < 0.0000010000000000  && IKabs(evalcond[5]) < 0.0000010000000000  && IKabs(evalcond[6]) < 0.0000010000000000  && IKabs(evalcond[7]) < 0.0000010000000000  && IKabs(evalcond[8]) < 0.0000010000000000  )
{
{
IkReal j3array[1], cj3array[1], sj3array[1];
bool j3valid[1]={false};
_nj3 = 1;
IkReal x10610=((IkReal(1.00000000000000))*(cj5));
IkReal x10611=((r10)*(sj5)*(sj6));
IkReal x10612=((cj6)*(sj0)*(sj5));
IkReal x10613=((r00)*(sj5)*(sj6));
IkReal x10614=((cj0)*(cj6)*(sj5));
if( IKabs(((((IkReal(-1.00000000000000))*(cj0)*(r12)*(x10610)))+(((cj0)*(x10611)))+(((IkReal(-1.00000000000000))*(r01)*(x10612)))+(((cj5)*(r02)*(sj0)))+(((r11)*(x10614)))+(((IkReal(-1.00000000000000))*(sj0)*(x10613))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(((((IkReal(-1.00000000000000))*(r12)*(sj0)*(x10610)))+(((cj0)*(x10613)))+(((sj0)*(x10611)))+(((r11)*(x10612)))+(((IkReal(-1.00000000000000))*(cj0)*(r02)*(x10610)))+(((r01)*(x10614))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(IKsqr(((((IkReal(-1.00000000000000))*(cj0)*(r12)*(x10610)))+(((cj0)*(x10611)))+(((IkReal(-1.00000000000000))*(r01)*(x10612)))+(((cj5)*(r02)*(sj0)))+(((r11)*(x10614)))+(((IkReal(-1.00000000000000))*(sj0)*(x10613)))))+IKsqr(((((IkReal(-1.00000000000000))*(r12)*(sj0)*(x10610)))+(((cj0)*(x10613)))+(((sj0)*(x10611)))+(((r11)*(x10612)))+(((IkReal(-1.00000000000000))*(cj0)*(r02)*(x10610)))+(((r01)*(x10614)))))-1) <= IKFAST_SINCOS_THRESH )
    continue;
j3array[0]=IKatan2(((((IkReal(-1.00000000000000))*(cj0)*(r12)*(x10610)))+(((cj0)*(x10611)))+(((IkReal(-1.00000000000000))*(r01)*(x10612)))+(((cj5)*(r02)*(sj0)))+(((r11)*(x10614)))+(((IkReal(-1.00000000000000))*(sj0)*(x10613)))), ((((IkReal(-1.00000000000000))*(r12)*(sj0)*(x10610)))+(((cj0)*(x10613)))+(((sj0)*(x10611)))+(((r11)*(x10612)))+(((IkReal(-1.00000000000000))*(cj0)*(r02)*(x10610)))+(((r01)*(x10614)))));
sj3array[0]=IKsin(j3array[0]);
cj3array[0]=IKcos(j3array[0]);
if( j3array[0] > IKPI )
{
    j3array[0]-=IK2PI;
}
else if( j3array[0] < -IKPI )
{    j3array[0]+=IK2PI;
}
j3valid[0] = true;
for(int ij3 = 0; ij3 < 1; ++ij3)
{
if( !j3valid[ij3] )
{
    continue;
}
_ij3[0] = ij3; _ij3[1] = -1;
for(int iij3 = ij3+1; iij3 < 1; ++iij3)
{
if( j3valid[iij3] && IKabs(cj3array[ij3]-cj3array[iij3]) < IKFAST_SOLUTION_THRESH && IKabs(sj3array[ij3]-sj3array[iij3]) < IKFAST_SOLUTION_THRESH )
{
    j3valid[iij3]=false; _ij3[1] = iij3; break; 
}
}
j3 = j3array[ij3]; cj3 = cj3array[ij3]; sj3 = sj3array[ij3];
{
IkReal evalcond[4];
IkReal x10615=IKcos(j3);
IkReal x10616=IKsin(j3);
IkReal x10617=((sj0)*(sj5));
IkReal x10618=((r00)*(sj6));
IkReal x10619=((IkReal(1.00000000000000))*(cj4));
IkReal x10620=((cj6)*(sj0));
IkReal x10621=((r00)*(sj4));
IkReal x10622=((cj0)*(cj5));
IkReal x10623=((cj6)*(r01));
IkReal x10624=((cj5)*(sj0));
IkReal x10625=((cj0)*(sj5));
IkReal x10626=((cj6)*(r11));
IkReal x10627=((r10)*(sj6));
IkReal x10628=((r10)*(sj4));
IkReal x10629=((cj0)*(sj4)*(sj6));
IkReal x10630=((sj0)*(sj4)*(sj6));
IkReal x10631=((IkReal(1.00000000000000))*(cj0)*(cj6));
evalcond[0]=((((IkReal(-1.00000000000000))*(x10625)*(x10627)))+(((x10617)*(x10618)))+(((IkReal(-1.00000000000000))*(r02)*(x10624)))+(((IkReal(-1.00000000000000))*(x10625)*(x10626)))+(x10616)+(((x10617)*(x10623)))+(((r12)*(x10622))));
evalcond[1]=((((IkReal(-1.00000000000000))*(x10618)*(x10625)))+(((IkReal(-1.00000000000000))*(x10623)*(x10625)))+(((r02)*(x10622)))+(((IkReal(-1.00000000000000))*(x10617)*(x10627)))+(((r12)*(x10624)))+(x10615)+(((IkReal(-1.00000000000000))*(x10617)*(x10626))));
evalcond[2]=((((IkReal(-1.00000000000000))*(x10628)*(x10631)))+(((IkReal(-1.00000000000000))*(r12)*(x10619)*(x10625)))+(((r11)*(x10629)))+(((cj4)*(cj5)*(r01)*(x10620)))+(((cj4)*(x10618)*(x10624)))+(((IkReal(-1.00000000000000))*(x10615)))+(((IkReal(-1.00000000000000))*(x10619)*(x10622)*(x10626)))+(((cj4)*(r02)*(x10617)))+(((IkReal(-1.00000000000000))*(x10619)*(x10622)*(x10627)))+(((IkReal(-1.00000000000000))*(r01)*(x10630)))+(((x10620)*(x10621))));
evalcond[3]=((((IkReal(-1.00000000000000))*(cj5)*(r11)*(x10619)*(x10620)))+(((IkReal(-1.00000000000000))*(x10620)*(x10628)))+(((r11)*(x10630)))+(((IkReal(-1.00000000000000))*(x10619)*(x10624)*(x10627)))+(x10616)+(((r01)*(x10629)))+(((IkReal(-1.00000000000000))*(x10621)*(x10631)))+(((IkReal(-1.00000000000000))*(x10619)*(x10622)*(x10623)))+(((IkReal(-1.00000000000000))*(r02)*(x10619)*(x10625)))+(((IkReal(-1.00000000000000))*(x10618)*(x10619)*(x10622)))+(((IkReal(-1.00000000000000))*(r12)*(x10617)*(x10619))));
if( IKabs(evalcond[0]) > 0.000001  || IKabs(evalcond[1]) > 0.000001  || IKabs(evalcond[2]) > 0.000001  || IKabs(evalcond[3]) > 0.000001  )
{
continue;
}
}

{
std::vector<IkSingleDOFSolutionBase<IkReal> > vinfos(7);
vinfos[0].jointtype = 1;
vinfos[0].foffset = j0;
vinfos[0].indices[0] = _ij0[0];
vinfos[0].indices[1] = _ij0[1];
vinfos[0].maxsolutions = _nj0;
vinfos[1].jointtype = 1;
vinfos[1].foffset = j1;
vinfos[1].indices[0] = _ij1[0];
vinfos[1].indices[1] = _ij1[1];
vinfos[1].maxsolutions = _nj1;
vinfos[2].jointtype = 1;
vinfos[2].foffset = j2;
vinfos[2].indices[0] = _ij2[0];
vinfos[2].indices[1] = _ij2[1];
vinfos[2].maxsolutions = _nj2;
vinfos[3].jointtype = 1;
vinfos[3].foffset = j3;
vinfos[3].indices[0] = _ij3[0];
vinfos[3].indices[1] = _ij3[1];
vinfos[3].maxsolutions = _nj3;
vinfos[4].jointtype = 1;
vinfos[4].foffset = j4;
vinfos[4].indices[0] = _ij4[0];
vinfos[4].indices[1] = _ij4[1];
vinfos[4].maxsolutions = _nj4;
vinfos[5].jointtype = 1;
vinfos[5].foffset = j5;
vinfos[5].indices[0] = _ij5[0];
vinfos[5].indices[1] = _ij5[1];
vinfos[5].maxsolutions = _nj5;
vinfos[6].jointtype = 1;
vinfos[6].foffset = j6;
vinfos[6].indices[0] = _ij6[0];
vinfos[6].indices[1] = _ij6[1];
vinfos[6].maxsolutions = _nj6;
std::vector<int> vfree(0);
solutions.AddSolution(vinfos,vfree);
}
}
}

} else
{
if( 1 )
{
continue;

} else
{
}
}
}
}
}
}

} else
{
{
IkReal j3array[1], cj3array[1], sj3array[1];
bool j3valid[1]={false};
_nj3 = 1;
IkReal x10632=((cj5)*(r02));
IkReal x10633=((cj0)*(sj5));
IkReal x10634=((r10)*(sj6));
IkReal x10635=((IkReal(1.00000000000000))*(cj6));
IkReal x10636=((sj0)*(sj5));
IkReal x10637=((cj5)*(r12));
IkReal x10638=((IkReal(1.00000000000000))*(r00)*(sj6));
if( IKabs(((((IkReal(-1.00000000000000))*(cj0)*(x10637)))+(((IkReal(-1.00000000000000))*(x10636)*(x10638)))+(((IkReal(-1.00000000000000))*(r01)*(x10635)*(x10636)))+(((sj0)*(x10632)))+(((x10633)*(x10634)))+(((cj6)*(r11)*(x10633))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(((((IKabs(cj1) != 0)?((IkReal)1/(cj1)):(IkReal)1.0e30))*(((((IkReal(-1.00000000000000))*(r01)*(x10633)*(x10635)))+(((sj0)*(x10637)))+(((IkReal(-1.00000000000000))*(r11)*(x10635)*(x10636)))+(((IkReal(-1.00000000000000))*(x10633)*(x10638)))+(((IkReal(-1.00000000000000))*(x10634)*(x10636)))+(((cj0)*(x10632))))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(IKsqr(((((IkReal(-1.00000000000000))*(cj0)*(x10637)))+(((IkReal(-1.00000000000000))*(x10636)*(x10638)))+(((IkReal(-1.00000000000000))*(r01)*(x10635)*(x10636)))+(((sj0)*(x10632)))+(((x10633)*(x10634)))+(((cj6)*(r11)*(x10633)))))+IKsqr(((((IKabs(cj1) != 0)?((IkReal)1/(cj1)):(IkReal)1.0e30))*(((((IkReal(-1.00000000000000))*(r01)*(x10633)*(x10635)))+(((sj0)*(x10637)))+(((IkReal(-1.00000000000000))*(r11)*(x10635)*(x10636)))+(((IkReal(-1.00000000000000))*(x10633)*(x10638)))+(((IkReal(-1.00000000000000))*(x10634)*(x10636)))+(((cj0)*(x10632)))))))-1) <= IKFAST_SINCOS_THRESH )
    continue;
j3array[0]=IKatan2(((((IkReal(-1.00000000000000))*(cj0)*(x10637)))+(((IkReal(-1.00000000000000))*(x10636)*(x10638)))+(((IkReal(-1.00000000000000))*(r01)*(x10635)*(x10636)))+(((sj0)*(x10632)))+(((x10633)*(x10634)))+(((cj6)*(r11)*(x10633)))), ((((IKabs(cj1) != 0)?((IkReal)1/(cj1)):(IkReal)1.0e30))*(((((IkReal(-1.00000000000000))*(r01)*(x10633)*(x10635)))+(((sj0)*(x10637)))+(((IkReal(-1.00000000000000))*(r11)*(x10635)*(x10636)))+(((IkReal(-1.00000000000000))*(x10633)*(x10638)))+(((IkReal(-1.00000000000000))*(x10634)*(x10636)))+(((cj0)*(x10632)))))));
sj3array[0]=IKsin(j3array[0]);
cj3array[0]=IKcos(j3array[0]);
if( j3array[0] > IKPI )
{
    j3array[0]-=IK2PI;
}
else if( j3array[0] < -IKPI )
{    j3array[0]+=IK2PI;
}
j3valid[0] = true;
for(int ij3 = 0; ij3 < 1; ++ij3)
{
if( !j3valid[ij3] )
{
    continue;
}
_ij3[0] = ij3; _ij3[1] = -1;
for(int iij3 = ij3+1; iij3 < 1; ++iij3)
{
if( j3valid[iij3] && IKabs(cj3array[ij3]-cj3array[iij3]) < IKFAST_SOLUTION_THRESH && IKabs(sj3array[ij3]-sj3array[iij3]) < IKFAST_SOLUTION_THRESH )
{
    j3valid[iij3]=false; _ij3[1] = iij3; break; 
}
}
j3 = j3array[ij3]; cj3 = cj3array[ij3]; sj3 = sj3array[ij3];
{
IkReal evalcond[6];
IkReal x10639=IKsin(j3);
IkReal x10640=IKcos(j3);
IkReal x10641=((sj0)*(sj5));
IkReal x10642=((r00)*(sj6));
IkReal x10643=((IkReal(1.00000000000000))*(cj4));
IkReal x10644=((cj6)*(r01));
IkReal x10645=((cj0)*(cj5));
IkReal x10646=((cj5)*(sj0));
IkReal x10647=((cj6)*(r11));
IkReal x10648=((cj0)*(sj5));
IkReal x10649=((IkReal(1.00000000000000))*(cj1));
IkReal x10650=((cj6)*(sj4));
IkReal x10651=((IkReal(1.00000000000000))*(sj1));
IkReal x10652=((cj4)*(cj5));
IkReal x10653=((cj6)*(r21));
IkReal x10654=((r20)*(sj6));
IkReal x10655=((r10)*(sj6));
IkReal x10656=((IkReal(1.00000000000000))*(cj0));
IkReal x10657=((cj0)*(sj4)*(sj6));
IkReal x10658=((sj0)*(sj4)*(sj6));
evalcond[0]=((((sj5)*(x10654)))+(((IkReal(-1.00000000000000))*(cj5)*(r22)))+(((sj5)*(x10653)))+(((IkReal(-1.00000000000000))*(x10640)*(x10651))));
evalcond[1]=((((IkReal(-1.00000000000000))*(x10639)*(x10651)))+(((IkReal(-1.00000000000000))*(r21)*(sj4)*(sj6)))+(((cj4)*(r22)*(sj5)))+(((x10652)*(x10654)))+(((r20)*(x10650)))+(((x10652)*(x10653))));
evalcond[2]=((((IkReal(-1.00000000000000))*(x10648)*(x10655)))+(((IkReal(-1.00000000000000))*(x10647)*(x10648)))+(x10639)+(((x10641)*(x10644)))+(((x10641)*(x10642)))+(((r12)*(x10645)))+(((IkReal(-1.00000000000000))*(r02)*(x10646))));
evalcond[3]=((((IkReal(-1.00000000000000))*(x10641)*(x10655)))+(((IkReal(-1.00000000000000))*(x10641)*(x10647)))+(((r12)*(x10646)))+(((IkReal(-1.00000000000000))*(x10642)*(x10648)))+(((IkReal(-1.00000000000000))*(x10640)*(x10649)))+(((r02)*(x10645)))+(((IkReal(-1.00000000000000))*(x10644)*(x10648))));
evalcond[4]=((((cj4)*(x10644)*(x10646)))+(((r11)*(x10657)))+(((IkReal(-1.00000000000000))*(r10)*(x10650)*(x10656)))+(((IkReal(-1.00000000000000))*(r01)*(x10658)))+(((IkReal(-1.00000000000000))*(x10640)))+(((IkReal(-1.00000000000000))*(x10643)*(x10645)*(x10647)))+(((cj4)*(x10642)*(x10646)))+(((cj4)*(r02)*(x10641)))+(((IkReal(-1.00000000000000))*(x10643)*(x10645)*(x10655)))+(((r00)*(sj0)*(x10650)))+(((IkReal(-1.00000000000000))*(r12)*(x10643)*(x10648))));
evalcond[5]=((((IkReal(-1.00000000000000))*(x10639)*(x10649)))+(((IkReal(-1.00000000000000))*(x10643)*(x10646)*(x10655)))+(((IkReal(-1.00000000000000))*(x10643)*(x10646)*(x10647)))+(((IkReal(-1.00000000000000))*(r02)*(x10643)*(x10648)))+(((IkReal(-1.00000000000000))*(r10)*(sj0)*(x10650)))+(((IkReal(-1.00000000000000))*(r12)*(x10641)*(x10643)))+(((r11)*(x10658)))+(((IkReal(-1.00000000000000))*(r00)*(x10650)*(x10656)))+(((r01)*(x10657)))+(((IkReal(-1.00000000000000))*(x10643)*(x10644)*(x10645)))+(((IkReal(-1.00000000000000))*(x10642)*(x10643)*(x10645))));
if( IKabs(evalcond[0]) > 0.000001  || IKabs(evalcond[1]) > 0.000001  || IKabs(evalcond[2]) > 0.000001  || IKabs(evalcond[3]) > 0.000001  || IKabs(evalcond[4]) > 0.000001  || IKabs(evalcond[5]) > 0.000001  )
{
continue;
}
}

{
std::vector<IkSingleDOFSolutionBase<IkReal> > vinfos(7);
vinfos[0].jointtype = 1;
vinfos[0].foffset = j0;
vinfos[0].indices[0] = _ij0[0];
vinfos[0].indices[1] = _ij0[1];
vinfos[0].maxsolutions = _nj0;
vinfos[1].jointtype = 1;
vinfos[1].foffset = j1;
vinfos[1].indices[0] = _ij1[0];
vinfos[1].indices[1] = _ij1[1];
vinfos[1].maxsolutions = _nj1;
vinfos[2].jointtype = 1;
vinfos[2].foffset = j2;
vinfos[2].indices[0] = _ij2[0];
vinfos[2].indices[1] = _ij2[1];
vinfos[2].maxsolutions = _nj2;
vinfos[3].jointtype = 1;
vinfos[3].foffset = j3;
vinfos[3].indices[0] = _ij3[0];
vinfos[3].indices[1] = _ij3[1];
vinfos[3].maxsolutions = _nj3;
vinfos[4].jointtype = 1;
vinfos[4].foffset = j4;
vinfos[4].indices[0] = _ij4[0];
vinfos[4].indices[1] = _ij4[1];
vinfos[4].maxsolutions = _nj4;
vinfos[5].jointtype = 1;
vinfos[5].foffset = j5;
vinfos[5].indices[0] = _ij5[0];
vinfos[5].indices[1] = _ij5[1];
vinfos[5].maxsolutions = _nj5;
vinfos[6].jointtype = 1;
vinfos[6].foffset = j6;
vinfos[6].indices[0] = _ij6[0];
vinfos[6].indices[1] = _ij6[1];
vinfos[6].maxsolutions = _nj6;
std::vector<int> vfree(0);
solutions.AddSolution(vinfos,vfree);
}
}
}

}

}

} else
{
{
IkReal j3array[1], cj3array[1], sj3array[1];
bool j3valid[1]={false};
_nj3 = 1;
IkReal x10659=((sj5)*(sj6));
IkReal x10660=((IkReal(1.00000000000000))*(sj0));
IkReal x10661=((cj6)*(sj5));
IkReal x10662=((IkReal(1.00000000000000))*(cj5));
if( IKabs(((((cj0)*(r10)*(x10659)))+(((IkReal(-1.00000000000000))*(r01)*(x10660)*(x10661)))+(((cj0)*(r11)*(x10661)))+(((IkReal(-1.00000000000000))*(r00)*(x10659)*(x10660)))+(((cj5)*(r02)*(sj0)))+(((IkReal(-1.00000000000000))*(cj0)*(r12)*(x10662))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(((((IKabs(sj1) != 0)?((IkReal)1/(sj1)):(IkReal)1.0e30))*(((((IkReal(-1.00000000000000))*(r22)*(x10662)))+(((r20)*(x10659)))+(((r21)*(x10661))))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(IKsqr(((((cj0)*(r10)*(x10659)))+(((IkReal(-1.00000000000000))*(r01)*(x10660)*(x10661)))+(((cj0)*(r11)*(x10661)))+(((IkReal(-1.00000000000000))*(r00)*(x10659)*(x10660)))+(((cj5)*(r02)*(sj0)))+(((IkReal(-1.00000000000000))*(cj0)*(r12)*(x10662)))))+IKsqr(((((IKabs(sj1) != 0)?((IkReal)1/(sj1)):(IkReal)1.0e30))*(((((IkReal(-1.00000000000000))*(r22)*(x10662)))+(((r20)*(x10659)))+(((r21)*(x10661)))))))-1) <= IKFAST_SINCOS_THRESH )
    continue;
j3array[0]=IKatan2(((((cj0)*(r10)*(x10659)))+(((IkReal(-1.00000000000000))*(r01)*(x10660)*(x10661)))+(((cj0)*(r11)*(x10661)))+(((IkReal(-1.00000000000000))*(r00)*(x10659)*(x10660)))+(((cj5)*(r02)*(sj0)))+(((IkReal(-1.00000000000000))*(cj0)*(r12)*(x10662)))), ((((IKabs(sj1) != 0)?((IkReal)1/(sj1)):(IkReal)1.0e30))*(((((IkReal(-1.00000000000000))*(r22)*(x10662)))+(((r20)*(x10659)))+(((r21)*(x10661)))))));
sj3array[0]=IKsin(j3array[0]);
cj3array[0]=IKcos(j3array[0]);
if( j3array[0] > IKPI )
{
    j3array[0]-=IK2PI;
}
else if( j3array[0] < -IKPI )
{    j3array[0]+=IK2PI;
}
j3valid[0] = true;
for(int ij3 = 0; ij3 < 1; ++ij3)
{
if( !j3valid[ij3] )
{
    continue;
}
_ij3[0] = ij3; _ij3[1] = -1;
for(int iij3 = ij3+1; iij3 < 1; ++iij3)
{
if( j3valid[iij3] && IKabs(cj3array[ij3]-cj3array[iij3]) < IKFAST_SOLUTION_THRESH && IKabs(sj3array[ij3]-sj3array[iij3]) < IKFAST_SOLUTION_THRESH )
{
    j3valid[iij3]=false; _ij3[1] = iij3; break; 
}
}
j3 = j3array[ij3]; cj3 = cj3array[ij3]; sj3 = sj3array[ij3];
{
IkReal evalcond[6];
IkReal x10663=IKsin(j3);
IkReal x10664=IKcos(j3);
IkReal x10665=((sj0)*(sj5));
IkReal x10666=((r00)*(sj6));
IkReal x10667=((IkReal(1.00000000000000))*(cj4));
IkReal x10668=((cj6)*(r01));
IkReal x10669=((cj0)*(cj5));
IkReal x10670=((cj5)*(sj0));
IkReal x10671=((cj6)*(r11));
IkReal x10672=((cj0)*(sj5));
IkReal x10673=((IkReal(1.00000000000000))*(cj1));
IkReal x10674=((cj6)*(sj4));
IkReal x10675=((IkReal(1.00000000000000))*(sj1));
IkReal x10676=((cj4)*(cj5));
IkReal x10677=((cj6)*(r21));
IkReal x10678=((r20)*(sj6));
IkReal x10679=((r10)*(sj6));
IkReal x10680=((IkReal(1.00000000000000))*(cj0));
IkReal x10681=((cj0)*(sj4)*(sj6));
IkReal x10682=((sj0)*(sj4)*(sj6));
evalcond[0]=((((sj5)*(x10678)))+(((IkReal(-1.00000000000000))*(x10664)*(x10675)))+(((IkReal(-1.00000000000000))*(cj5)*(r22)))+(((sj5)*(x10677))));
evalcond[1]=((((IkReal(-1.00000000000000))*(x10663)*(x10675)))+(((IkReal(-1.00000000000000))*(r21)*(sj4)*(sj6)))+(((cj4)*(r22)*(sj5)))+(((x10676)*(x10677)))+(((r20)*(x10674)))+(((x10676)*(x10678))));
evalcond[2]=((((IkReal(-1.00000000000000))*(x10671)*(x10672)))+(((x10665)*(x10668)))+(((r12)*(x10669)))+(((IkReal(-1.00000000000000))*(x10672)*(x10679)))+(((IkReal(-1.00000000000000))*(r02)*(x10670)))+(x10663)+(((x10665)*(x10666))));
evalcond[3]=((((IkReal(-1.00000000000000))*(x10664)*(x10673)))+(((IkReal(-1.00000000000000))*(x10666)*(x10672)))+(((r12)*(x10670)))+(((IkReal(-1.00000000000000))*(x10668)*(x10672)))+(((IkReal(-1.00000000000000))*(x10665)*(x10679)))+(((r02)*(x10669)))+(((IkReal(-1.00000000000000))*(x10665)*(x10671))));
evalcond[4]=((((cj4)*(x10666)*(x10670)))+(((IkReal(-1.00000000000000))*(x10667)*(x10669)*(x10671)))+(((IkReal(-1.00000000000000))*(r12)*(x10667)*(x10672)))+(((IkReal(-1.00000000000000))*(r10)*(x10674)*(x10680)))+(((cj4)*(r02)*(x10665)))+(((r11)*(x10681)))+(((IkReal(-1.00000000000000))*(x10664)))+(((IkReal(-1.00000000000000))*(r01)*(x10682)))+(((IkReal(-1.00000000000000))*(x10667)*(x10669)*(x10679)))+(((cj4)*(x10668)*(x10670)))+(((r00)*(sj0)*(x10674))));
evalcond[5]=((((IkReal(-1.00000000000000))*(r00)*(x10674)*(x10680)))+(((IkReal(-1.00000000000000))*(r10)*(sj0)*(x10674)))+(((r01)*(x10681)))+(((IkReal(-1.00000000000000))*(x10667)*(x10670)*(x10671)))+(((IkReal(-1.00000000000000))*(r02)*(x10667)*(x10672)))+(((IkReal(-1.00000000000000))*(r12)*(x10665)*(x10667)))+(((IkReal(-1.00000000000000))*(x10666)*(x10667)*(x10669)))+(((IkReal(-1.00000000000000))*(x10667)*(x10670)*(x10679)))+(((IkReal(-1.00000000000000))*(x10667)*(x10668)*(x10669)))+(((IkReal(-1.00000000000000))*(x10663)*(x10673)))+(((r11)*(x10682))));
if( IKabs(evalcond[0]) > 0.000001  || IKabs(evalcond[1]) > 0.000001  || IKabs(evalcond[2]) > 0.000001  || IKabs(evalcond[3]) > 0.000001  || IKabs(evalcond[4]) > 0.000001  || IKabs(evalcond[5]) > 0.000001  )
{
continue;
}
}

{
std::vector<IkSingleDOFSolutionBase<IkReal> > vinfos(7);
vinfos[0].jointtype = 1;
vinfos[0].foffset = j0;
vinfos[0].indices[0] = _ij0[0];
vinfos[0].indices[1] = _ij0[1];
vinfos[0].maxsolutions = _nj0;
vinfos[1].jointtype = 1;
vinfos[1].foffset = j1;
vinfos[1].indices[0] = _ij1[0];
vinfos[1].indices[1] = _ij1[1];
vinfos[1].maxsolutions = _nj1;
vinfos[2].jointtype = 1;
vinfos[2].foffset = j2;
vinfos[2].indices[0] = _ij2[0];
vinfos[2].indices[1] = _ij2[1];
vinfos[2].maxsolutions = _nj2;
vinfos[3].jointtype = 1;
vinfos[3].foffset = j3;
vinfos[3].indices[0] = _ij3[0];
vinfos[3].indices[1] = _ij3[1];
vinfos[3].maxsolutions = _nj3;
vinfos[4].jointtype = 1;
vinfos[4].foffset = j4;
vinfos[4].indices[0] = _ij4[0];
vinfos[4].indices[1] = _ij4[1];
vinfos[4].maxsolutions = _nj4;
vinfos[5].jointtype = 1;
vinfos[5].foffset = j5;
vinfos[5].indices[0] = _ij5[0];
vinfos[5].indices[1] = _ij5[1];
vinfos[5].maxsolutions = _nj5;
vinfos[6].jointtype = 1;
vinfos[6].foffset = j6;
vinfos[6].indices[0] = _ij6[0];
vinfos[6].indices[1] = _ij6[1];
vinfos[6].maxsolutions = _nj6;
std::vector<int> vfree(0);
solutions.AddSolution(vinfos,vfree);
}
}
}

}

}

} else
{
{
IkReal j3array[1], cj3array[1], sj3array[1];
bool j3valid[1]={false};
_nj3 = 1;
IkReal x10683=((r20)*(sj6));
IkReal x10684=((cj4)*(cj5));
IkReal x10685=((cj6)*(r21));
if( IKabs(((gconst30)*(((((IkReal(-1.00000000000000))*(r21)*(sj4)*(sj6)))+(((x10683)*(x10684)))+(((cj6)*(r20)*(sj4)))+(((cj4)*(r22)*(sj5)))+(((x10684)*(x10685))))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(((gconst30)*(((((sj5)*(x10685)))+(((IkReal(-1.00000000000000))*(cj5)*(r22)))+(((sj5)*(x10683))))))) < IKFAST_ATAN2_MAGTHRESH )
    continue;
j3array[0]=IKatan2(((gconst30)*(((((IkReal(-1.00000000000000))*(r21)*(sj4)*(sj6)))+(((x10683)*(x10684)))+(((cj6)*(r20)*(sj4)))+(((cj4)*(r22)*(sj5)))+(((x10684)*(x10685)))))), ((gconst30)*(((((sj5)*(x10685)))+(((IkReal(-1.00000000000000))*(cj5)*(r22)))+(((sj5)*(x10683)))))));
sj3array[0]=IKsin(j3array[0]);
cj3array[0]=IKcos(j3array[0]);
if( j3array[0] > IKPI )
{
    j3array[0]-=IK2PI;
}
else if( j3array[0] < -IKPI )
{    j3array[0]+=IK2PI;
}
j3valid[0] = true;
for(int ij3 = 0; ij3 < 1; ++ij3)
{
if( !j3valid[ij3] )
{
    continue;
}
_ij3[0] = ij3; _ij3[1] = -1;
for(int iij3 = ij3+1; iij3 < 1; ++iij3)
{
if( j3valid[iij3] && IKabs(cj3array[ij3]-cj3array[iij3]) < IKFAST_SOLUTION_THRESH && IKabs(sj3array[ij3]-sj3array[iij3]) < IKFAST_SOLUTION_THRESH )
{
    j3valid[iij3]=false; _ij3[1] = iij3; break; 
}
}
j3 = j3array[ij3]; cj3 = cj3array[ij3]; sj3 = sj3array[ij3];
{
IkReal evalcond[6];
IkReal x10686=IKsin(j3);
IkReal x10687=IKcos(j3);
IkReal x10688=((sj0)*(sj5));
IkReal x10689=((r00)*(sj6));
IkReal x10690=((IkReal(1.00000000000000))*(cj4));
IkReal x10691=((cj6)*(r01));
IkReal x10692=((cj0)*(cj5));
IkReal x10693=((cj5)*(sj0));
IkReal x10694=((cj6)*(r11));
IkReal x10695=((cj0)*(sj5));
IkReal x10696=((IkReal(1.00000000000000))*(cj1));
IkReal x10697=((cj6)*(sj4));
IkReal x10698=((IkReal(1.00000000000000))*(sj1));
IkReal x10699=((cj4)*(cj5));
IkReal x10700=((cj6)*(r21));
IkReal x10701=((r20)*(sj6));
IkReal x10702=((r10)*(sj6));
IkReal x10703=((IkReal(1.00000000000000))*(cj0));
IkReal x10704=((cj0)*(sj4)*(sj6));
IkReal x10705=((sj0)*(sj4)*(sj6));
evalcond[0]=((((IkReal(-1.00000000000000))*(x10687)*(x10698)))+(((sj5)*(x10700)))+(((IkReal(-1.00000000000000))*(cj5)*(r22)))+(((sj5)*(x10701))));
evalcond[1]=((((x10699)*(x10700)))+(((r20)*(x10697)))+(((x10699)*(x10701)))+(((IkReal(-1.00000000000000))*(r21)*(sj4)*(sj6)))+(((IkReal(-1.00000000000000))*(x10686)*(x10698)))+(((cj4)*(r22)*(sj5))));
evalcond[2]=((((IkReal(-1.00000000000000))*(x10695)*(x10702)))+(((IkReal(-1.00000000000000))*(x10694)*(x10695)))+(((IkReal(-1.00000000000000))*(r02)*(x10693)))+(x10686)+(((x10688)*(x10691)))+(((x10688)*(x10689)))+(((r12)*(x10692))));
evalcond[3]=((((r12)*(x10693)))+(((IkReal(-1.00000000000000))*(x10689)*(x10695)))+(((IkReal(-1.00000000000000))*(x10687)*(x10696)))+(((IkReal(-1.00000000000000))*(x10688)*(x10694)))+(((IkReal(-1.00000000000000))*(x10691)*(x10695)))+(((IkReal(-1.00000000000000))*(x10688)*(x10702)))+(((r02)*(x10692))));
evalcond[4]=((((IkReal(-1.00000000000000))*(r01)*(x10705)))+(((r00)*(sj0)*(x10697)))+(((r11)*(x10704)))+(((cj4)*(x10691)*(x10693)))+(((IkReal(-1.00000000000000))*(x10690)*(x10692)*(x10702)))+(((cj4)*(x10689)*(x10693)))+(((cj4)*(r02)*(x10688)))+(((IkReal(-1.00000000000000))*(x10687)))+(((IkReal(-1.00000000000000))*(r10)*(x10697)*(x10703)))+(((IkReal(-1.00000000000000))*(r12)*(x10690)*(x10695)))+(((IkReal(-1.00000000000000))*(x10690)*(x10692)*(x10694))));
evalcond[5]=((((IkReal(-1.00000000000000))*(x10690)*(x10691)*(x10692)))+(((IkReal(-1.00000000000000))*(r10)*(sj0)*(x10697)))+(((r01)*(x10704)))+(((IkReal(-1.00000000000000))*(x10689)*(x10690)*(x10692)))+(((IkReal(-1.00000000000000))*(r02)*(x10690)*(x10695)))+(((IkReal(-1.00000000000000))*(x10690)*(x10693)*(x10694)))+(((r11)*(x10705)))+(((IkReal(-1.00000000000000))*(x10686)*(x10696)))+(((IkReal(-1.00000000000000))*(r12)*(x10688)*(x10690)))+(((IkReal(-1.00000000000000))*(x10690)*(x10693)*(x10702)))+(((IkReal(-1.00000000000000))*(r00)*(x10697)*(x10703))));
if( IKabs(evalcond[0]) > 0.000001  || IKabs(evalcond[1]) > 0.000001  || IKabs(evalcond[2]) > 0.000001  || IKabs(evalcond[3]) > 0.000001  || IKabs(evalcond[4]) > 0.000001  || IKabs(evalcond[5]) > 0.000001  )
{
continue;
}
}

{
std::vector<IkSingleDOFSolutionBase<IkReal> > vinfos(7);
vinfos[0].jointtype = 1;
vinfos[0].foffset = j0;
vinfos[0].indices[0] = _ij0[0];
vinfos[0].indices[1] = _ij0[1];
vinfos[0].maxsolutions = _nj0;
vinfos[1].jointtype = 1;
vinfos[1].foffset = j1;
vinfos[1].indices[0] = _ij1[0];
vinfos[1].indices[1] = _ij1[1];
vinfos[1].maxsolutions = _nj1;
vinfos[2].jointtype = 1;
vinfos[2].foffset = j2;
vinfos[2].indices[0] = _ij2[0];
vinfos[2].indices[1] = _ij2[1];
vinfos[2].maxsolutions = _nj2;
vinfos[3].jointtype = 1;
vinfos[3].foffset = j3;
vinfos[3].indices[0] = _ij3[0];
vinfos[3].indices[1] = _ij3[1];
vinfos[3].maxsolutions = _nj3;
vinfos[4].jointtype = 1;
vinfos[4].foffset = j4;
vinfos[4].indices[0] = _ij4[0];
vinfos[4].indices[1] = _ij4[1];
vinfos[4].maxsolutions = _nj4;
vinfos[5].jointtype = 1;
vinfos[5].foffset = j5;
vinfos[5].indices[0] = _ij5[0];
vinfos[5].indices[1] = _ij5[1];
vinfos[5].maxsolutions = _nj5;
vinfos[6].jointtype = 1;
vinfos[6].foffset = j6;
vinfos[6].indices[0] = _ij6[0];
vinfos[6].indices[1] = _ij6[1];
vinfos[6].maxsolutions = _nj6;
std::vector<int> vfree(0);
solutions.AddSolution(vinfos,vfree);
}
}
}

}

}
}
}

}

}

} else
{
if( 1 )
{
continue;

} else
{
}
}
}
}

} else
{
{
IkReal j3array[1], cj3array[1], sj3array[1];
bool j3valid[1]={false};
_nj3 = 1;
IkReal x10706=(cj1)*(cj1);
IkReal x10707=(sj1)*(sj1);
IkReal x10708=((r00)*(sj6));
IkReal x10709=((cj6)*(r01));
IkReal x10710=((IkReal(1.00000000000000))*(cj1));
IkReal x10711=((cj5)*(r22));
IkReal x10712=((sj5)*(sj6));
IkReal x10713=((r10)*(sj0));
IkReal x10714=((cj1)*(cj5));
IkReal x10715=((cj0)*(r02));
IkReal x10716=((r12)*(sj0));
IkReal x10717=((IkReal(1.00000000000000))*(sj1));
IkReal x10718=((cj6)*(sj5));
IkReal x10719=((cj0)*(sj5));
IkReal x10720=((r11)*(sj0));
IkReal x10721=((sj1)*(x10719));
if( IKabs(((((IKabs(((((cj2)*(x10706)))+(((cj2)*(x10707))))) != 0)?((IkReal)1/(((((cj2)*(x10706)))+(((cj2)*(x10707)))))):(IkReal)1.0e30))*(((((IkReal(-1.00000000000000))*(x10710)*(x10711)))+(((cj1)*(r20)*(x10712)))+(((sj1)*(x10712)*(x10713)))+(((IkReal(-1.00000000000000))*(cj5)*(x10716)*(x10717)))+(((cj1)*(r21)*(x10718)))+(((sj1)*(x10718)*(x10720)))+(((x10709)*(x10721)))+(((IkReal(-1.00000000000000))*(cj5)*(x10715)*(x10717)))+(((x10708)*(x10721))))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(((((IKabs(((x10707)+(x10706))) != 0)?((IkReal)1/(((x10707)+(x10706)))):(IkReal)1.0e30))*(((((IkReal(-1.00000000000000))*(x10709)*(x10710)*(x10719)))+(((IkReal(-1.00000000000000))*(x10708)*(x10710)*(x10719)))+(((IkReal(-1.00000000000000))*(x10710)*(x10712)*(x10713)))+(((IkReal(-1.00000000000000))*(x10710)*(x10718)*(x10720)))+(((IkReal(-1.00000000000000))*(x10711)*(x10717)))+(((r21)*(sj1)*(x10718)))+(((x10714)*(x10716)))+(((x10714)*(x10715)))+(((r20)*(sj1)*(x10712))))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(IKsqr(((((IKabs(((((cj2)*(x10706)))+(((cj2)*(x10707))))) != 0)?((IkReal)1/(((((cj2)*(x10706)))+(((cj2)*(x10707)))))):(IkReal)1.0e30))*(((((IkReal(-1.00000000000000))*(x10710)*(x10711)))+(((cj1)*(r20)*(x10712)))+(((sj1)*(x10712)*(x10713)))+(((IkReal(-1.00000000000000))*(cj5)*(x10716)*(x10717)))+(((cj1)*(r21)*(x10718)))+(((sj1)*(x10718)*(x10720)))+(((x10709)*(x10721)))+(((IkReal(-1.00000000000000))*(cj5)*(x10715)*(x10717)))+(((x10708)*(x10721)))))))+IKsqr(((((IKabs(((x10707)+(x10706))) != 0)?((IkReal)1/(((x10707)+(x10706)))):(IkReal)1.0e30))*(((((IkReal(-1.00000000000000))*(x10709)*(x10710)*(x10719)))+(((IkReal(-1.00000000000000))*(x10708)*(x10710)*(x10719)))+(((IkReal(-1.00000000000000))*(x10710)*(x10712)*(x10713)))+(((IkReal(-1.00000000000000))*(x10710)*(x10718)*(x10720)))+(((IkReal(-1.00000000000000))*(x10711)*(x10717)))+(((r21)*(sj1)*(x10718)))+(((x10714)*(x10716)))+(((x10714)*(x10715)))+(((r20)*(sj1)*(x10712)))))))-1) <= IKFAST_SINCOS_THRESH )
    continue;
j3array[0]=IKatan2(((((IKabs(((((cj2)*(x10706)))+(((cj2)*(x10707))))) != 0)?((IkReal)1/(((((cj2)*(x10706)))+(((cj2)*(x10707)))))):(IkReal)1.0e30))*(((((IkReal(-1.00000000000000))*(x10710)*(x10711)))+(((cj1)*(r20)*(x10712)))+(((sj1)*(x10712)*(x10713)))+(((IkReal(-1.00000000000000))*(cj5)*(x10716)*(x10717)))+(((cj1)*(r21)*(x10718)))+(((sj1)*(x10718)*(x10720)))+(((x10709)*(x10721)))+(((IkReal(-1.00000000000000))*(cj5)*(x10715)*(x10717)))+(((x10708)*(x10721)))))), ((((IKabs(((x10707)+(x10706))) != 0)?((IkReal)1/(((x10707)+(x10706)))):(IkReal)1.0e30))*(((((IkReal(-1.00000000000000))*(x10709)*(x10710)*(x10719)))+(((IkReal(-1.00000000000000))*(x10708)*(x10710)*(x10719)))+(((IkReal(-1.00000000000000))*(x10710)*(x10712)*(x10713)))+(((IkReal(-1.00000000000000))*(x10710)*(x10718)*(x10720)))+(((IkReal(-1.00000000000000))*(x10711)*(x10717)))+(((r21)*(sj1)*(x10718)))+(((x10714)*(x10716)))+(((x10714)*(x10715)))+(((r20)*(sj1)*(x10712)))))));
sj3array[0]=IKsin(j3array[0]);
cj3array[0]=IKcos(j3array[0]);
if( j3array[0] > IKPI )
{
    j3array[0]-=IK2PI;
}
else if( j3array[0] < -IKPI )
{    j3array[0]+=IK2PI;
}
j3valid[0] = true;
for(int ij3 = 0; ij3 < 1; ++ij3)
{
if( !j3valid[ij3] )
{
    continue;
}
_ij3[0] = ij3; _ij3[1] = -1;
for(int iij3 = ij3+1; iij3 < 1; ++iij3)
{
if( j3valid[iij3] && IKabs(cj3array[ij3]-cj3array[iij3]) < IKFAST_SOLUTION_THRESH && IKabs(sj3array[ij3]-sj3array[iij3]) < IKFAST_SOLUTION_THRESH )
{
    j3valid[iij3]=false; _ij3[1] = iij3; break; 
}
}
j3 = j3array[ij3]; cj3 = cj3array[ij3]; sj3 = sj3array[ij3];
{
IkReal evalcond[3];
IkReal x10722=IKsin(j3);
IkReal x10723=IKcos(j3);
IkReal x10724=((sj5)*(sj6));
IkReal x10725=((cj0)*(cj5));
IkReal x10726=((IkReal(1.00000000000000))*(cj0));
IkReal x10727=((IkReal(1.00000000000000))*(sj0));
IkReal x10728=((IkReal(1.00000000000000))*(x10723));
IkReal x10729=((IkReal(1.00000000000000))*(x10722));
IkReal x10730=((cj6)*(r01)*(sj5));
IkReal x10731=((cj6)*(r11)*(sj5));
evalcond[0]=((((IkReal(-1.00000000000000))*(sj1)*(x10728)))+(((cj6)*(r21)*(sj5)))+(((IkReal(-1.00000000000000))*(cj1)*(cj2)*(x10729)))+(((IkReal(-1.00000000000000))*(cj5)*(r22)))+(((r20)*(x10724))));
evalcond[1]=((((IkReal(-1.00000000000000))*(sj2)*(x10729)))+(((sj0)*(x10730)))+(((IkReal(-1.00000000000000))*(x10726)*(x10731)))+(((r00)*(sj0)*(x10724)))+(((IkReal(-1.00000000000000))*(cj5)*(r02)*(x10727)))+(((r12)*(x10725)))+(((IkReal(-1.00000000000000))*(r10)*(x10724)*(x10726))));
evalcond[2]=((((IkReal(-1.00000000000000))*(x10727)*(x10731)))+(((IkReal(-1.00000000000000))*(x10726)*(x10730)))+(((cj5)*(r12)*(sj0)))+(((IkReal(-1.00000000000000))*(r00)*(x10724)*(x10726)))+(((IkReal(-1.00000000000000))*(r10)*(x10724)*(x10727)))+(((cj2)*(sj1)*(x10722)))+(((r02)*(x10725)))+(((IkReal(-1.00000000000000))*(cj1)*(x10728))));
if( IKabs(evalcond[0]) > 0.000001  || IKabs(evalcond[1]) > 0.000001  || IKabs(evalcond[2]) > 0.000001  )
{
continue;
}
}

{
IkReal dummyeval[1];
IkReal gconst2;
IkReal x10732=(r21)*(r21);
IkReal x10733=(cj5)*(cj5);
IkReal x10734=(sj6)*(sj6);
IkReal x10735=(cj6)*(cj6);
IkReal x10736=(r20)*(r20);
IkReal x10737=((cj6)*(r21));
IkReal x10738=((IkReal(2.00000000000000))*(r20)*(sj6));
IkReal x10739=((cj5)*(r22)*(sj5));
IkReal x10740=((IkReal(1.00000000000000))*(x10734));
IkReal x10741=((IkReal(1.00000000000000))*(x10735));
gconst2=IKsign(((((IkReal(-1.00000000000000))*(x10736)*(x10741)))+(((IkReal(-1.00000000000000))*(x10733)*(x10736)*(x10740)))+(((IkReal(-1.00000000000000))*((r22)*(r22))*((sj5)*(sj5))))+(((IkReal(-1.00000000000000))*(x10733)*(x10737)*(x10738)))+(((x10737)*(x10738)))+(((IkReal(-2.00000000000000))*(x10737)*(x10739)))+(((IkReal(-1.00000000000000))*(x10732)*(x10740)))+(((IkReal(-1.00000000000000))*(x10732)*(x10733)*(x10741)))+(((IkReal(-1.00000000000000))*(x10738)*(x10739)))));
IkReal x10742=(r21)*(r21);
IkReal x10743=(cj5)*(cj5);
IkReal x10744=(sj6)*(sj6);
IkReal x10745=(cj6)*(cj6);
IkReal x10746=(r20)*(r20);
IkReal x10747=((cj6)*(r21));
IkReal x10748=((IkReal(2.00000000000000))*(r20)*(sj6));
IkReal x10749=((cj5)*(r22)*(sj5));
IkReal x10750=((IkReal(1.00000000000000))*(x10744));
IkReal x10751=((IkReal(1.00000000000000))*(x10745));
dummyeval[0]=((((IkReal(-1.00000000000000))*(x10742)*(x10743)*(x10751)))+(((IkReal(-1.00000000000000))*(x10743)*(x10746)*(x10750)))+(((IkReal(-1.00000000000000))*((r22)*(r22))*((sj5)*(sj5))))+(((IkReal(-1.00000000000000))*(x10743)*(x10747)*(x10748)))+(((IkReal(-1.00000000000000))*(x10746)*(x10751)))+(((IkReal(-1.00000000000000))*(x10748)*(x10749)))+(((x10747)*(x10748)))+(((IkReal(-1.00000000000000))*(x10742)*(x10750)))+(((IkReal(-2.00000000000000))*(x10747)*(x10749))));
if( IKabs(dummyeval[0]) < 0.0000010000000000  )
{
{
IkReal dummyeval[1];
IkReal gconst3;
IkReal x10752=(cj6)*(cj6);
IkReal x10753=(sj6)*(sj6);
IkReal x10754=((IkReal(1.00000000000000))*(r21));
IkReal x10755=((cj6)*(r20));
IkReal x10756=((r22)*(sj5));
IkReal x10757=((r01)*(sj0));
IkReal x10758=((r00)*(sj0));
IkReal x10759=((cj0)*(r10));
IkReal x10760=((r02)*(sj0)*(sj5));
IkReal x10761=((cj5)*(x10752));
IkReal x10762=((cj0)*(r12)*(sj5));
IkReal x10763=((IkReal(1.00000000000000))*(cj0)*(r11));
IkReal x10764=((cj5)*(x10753));
IkReal x10765=((r20)*(x10764));
gconst3=IKsign(((((x10757)*(x10765)))+(((IkReal(-1.00000000000000))*(x10754)*(x10758)*(x10764)))+(((IkReal(-1.00000000000000))*(x10763)*(x10765)))+(((IkReal(-1.00000000000000))*(sj6)*(x10756)*(x10763)))+(((IkReal(-1.00000000000000))*(r20)*(x10761)*(x10763)))+(((sj6)*(x10756)*(x10757)))+(((IkReal(-1.00000000000000))*(x10755)*(x10762)))+(((r20)*(x10757)*(x10761)))+(((r21)*(sj6)*(x10762)))+(((IkReal(-1.00000000000000))*(x10754)*(x10758)*(x10761)))+(((IkReal(-1.00000000000000))*(cj6)*(x10756)*(x10758)))+(((cj6)*(x10756)*(x10759)))+(((x10755)*(x10760)))+(((IkReal(-1.00000000000000))*(sj6)*(x10754)*(x10760)))+(((r21)*(x10759)*(x10761)))+(((r21)*(x10759)*(x10764)))));
IkReal x10766=(cj6)*(cj6);
IkReal x10767=(sj6)*(sj6);
IkReal x10768=((IkReal(1.00000000000000))*(r21));
IkReal x10769=((cj6)*(r20));
IkReal x10770=((r22)*(sj5));
IkReal x10771=((r01)*(sj0));
IkReal x10772=((r00)*(sj0));
IkReal x10773=((cj0)*(r10));
IkReal x10774=((r02)*(sj0)*(sj5));
IkReal x10775=((cj5)*(x10766));
IkReal x10776=((cj0)*(r12)*(sj5));
IkReal x10777=((IkReal(1.00000000000000))*(cj0)*(r11));
IkReal x10778=((cj5)*(x10767));
IkReal x10779=((r20)*(x10778));
dummyeval[0]=((((IkReal(-1.00000000000000))*(sj6)*(x10770)*(x10777)))+(((IkReal(-1.00000000000000))*(x10777)*(x10779)))+(((r21)*(sj6)*(x10776)))+(((r21)*(x10773)*(x10778)))+(((IkReal(-1.00000000000000))*(cj6)*(x10770)*(x10772)))+(((r20)*(x10771)*(x10775)))+(((IkReal(-1.00000000000000))*(x10768)*(x10772)*(x10778)))+(((cj6)*(x10770)*(x10773)))+(((sj6)*(x10770)*(x10771)))+(((IkReal(-1.00000000000000))*(sj6)*(x10768)*(x10774)))+(((IkReal(-1.00000000000000))*(x10769)*(x10776)))+(((r21)*(x10773)*(x10775)))+(((IkReal(-1.00000000000000))*(x10768)*(x10772)*(x10775)))+(((x10771)*(x10779)))+(((x10769)*(x10774)))+(((IkReal(-1.00000000000000))*(r20)*(x10775)*(x10777))));
if( IKabs(dummyeval[0]) < 0.0000010000000000  )
{
continue;

} else
{
{
IkReal j4array[1], cj4array[1], sj4array[1];
bool j4valid[1]={false};
_nj4 = 1;
IkReal x10780=((cj5)*(sj6));
IkReal x10781=((cj2)*(r21));
IkReal x10782=((cj5)*(cj6));
IkReal x10783=((IkReal(1.00000000000000))*(cj2)*(r20));
IkReal x10784=((cj0)*(cj1)*(sj2));
IkReal x10785=((IkReal(1.00000000000000))*(cj1)*(sj0)*(sj2));
IkReal x10786=((r10)*(x10784));
if( IKabs(((gconst3)*(((((IkReal(-1.00000000000000))*(cj6)*(r00)*(x10785)))+(((cj6)*(x10786)))+(((cj1)*(r01)*(sj0)*(sj2)*(sj6)))+(((sj6)*(x10781)))+(((IkReal(-1.00000000000000))*(cj6)*(x10783)))+(((IkReal(-1.00000000000000))*(r11)*(sj6)*(x10784))))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(((gconst3)*(((((r11)*(x10782)*(x10784)))+(((r12)*(sj5)*(x10784)))+(((IkReal(-1.00000000000000))*(r02)*(sj5)*(x10785)))+(((x10780)*(x10786)))+(((IkReal(-1.00000000000000))*(cj2)*(r22)*(sj5)))+(((IkReal(-1.00000000000000))*(x10781)*(x10782)))+(((IkReal(-1.00000000000000))*(r00)*(x10780)*(x10785)))+(((IkReal(-1.00000000000000))*(r01)*(x10782)*(x10785)))+(((IkReal(-1.00000000000000))*(x10780)*(x10783))))))) < IKFAST_ATAN2_MAGTHRESH )
    continue;
j4array[0]=IKatan2(((gconst3)*(((((IkReal(-1.00000000000000))*(cj6)*(r00)*(x10785)))+(((cj6)*(x10786)))+(((cj1)*(r01)*(sj0)*(sj2)*(sj6)))+(((sj6)*(x10781)))+(((IkReal(-1.00000000000000))*(cj6)*(x10783)))+(((IkReal(-1.00000000000000))*(r11)*(sj6)*(x10784)))))), ((gconst3)*(((((r11)*(x10782)*(x10784)))+(((r12)*(sj5)*(x10784)))+(((IkReal(-1.00000000000000))*(r02)*(sj5)*(x10785)))+(((x10780)*(x10786)))+(((IkReal(-1.00000000000000))*(cj2)*(r22)*(sj5)))+(((IkReal(-1.00000000000000))*(x10781)*(x10782)))+(((IkReal(-1.00000000000000))*(r00)*(x10780)*(x10785)))+(((IkReal(-1.00000000000000))*(r01)*(x10782)*(x10785)))+(((IkReal(-1.00000000000000))*(x10780)*(x10783)))))));
sj4array[0]=IKsin(j4array[0]);
cj4array[0]=IKcos(j4array[0]);
if( j4array[0] > IKPI )
{
    j4array[0]-=IK2PI;
}
else if( j4array[0] < -IKPI )
{    j4array[0]+=IK2PI;
}
j4valid[0] = true;
for(int ij4 = 0; ij4 < 1; ++ij4)
{
if( !j4valid[ij4] )
{
    continue;
}
_ij4[0] = ij4; _ij4[1] = -1;
for(int iij4 = ij4+1; iij4 < 1; ++iij4)
{
if( j4valid[iij4] && IKabs(cj4array[ij4]-cj4array[iij4]) < IKFAST_SOLUTION_THRESH && IKabs(sj4array[ij4]-sj4array[iij4]) < IKFAST_SOLUTION_THRESH )
{
    j4valid[iij4]=false; _ij4[1] = iij4; break; 
}
}
j4 = j4array[ij4]; cj4 = cj4array[ij4]; sj4 = sj4array[ij4];
{
IkReal evalcond[6];
IkReal x10787=IKsin(j4);
IkReal x10788=IKcos(j4);
IkReal x10789=((r00)*(sj6));
IkReal x10790=((IkReal(1.00000000000000))*(r12));
IkReal x10791=((IkReal(1.00000000000000))*(cj6));
IkReal x10792=((cj6)*(r01));
IkReal x10793=((IkReal(1.00000000000000))*(cj1));
IkReal x10794=((cj2)*(cj3));
IkReal x10795=((IkReal(1.00000000000000))*(sj1));
IkReal x10796=((r11)*(sj6));
IkReal x10797=((r01)*(sj6));
IkReal x10798=((IkReal(1.00000000000000))*(cj5));
IkReal x10799=((r10)*(sj6));
IkReal x10800=((cj5)*(r11));
IkReal x10801=((cj6)*(r00));
IkReal x10802=((r21)*(sj6));
IkReal x10803=((r02)*(sj5));
IkReal x10804=((cj6)*(r10));
IkReal x10805=((cj5)*(sj6));
IkReal x10806=((cj5)*(r01));
IkReal x10807=((sj5)*(x10787));
IkReal x10808=((cj0)*(x10788));
IkReal x10809=((cj0)*(x10787));
IkReal x10810=((sj0)*(x10788));
IkReal x10811=((sj0)*(x10787));
IkReal x10812=((r20)*(x10788));
IkReal x10813=((cj5)*(cj6)*(r21));
IkReal x10814=((r20)*(x10787));
IkReal x10815=((cj5)*(x10811));
evalcond[0]=((((x10787)*(x10813)))+(((x10788)*(x10802)))+(((IkReal(-1.00000000000000))*(sj2)*(x10793)))+(((r22)*(x10807)))+(((x10805)*(x10814)))+(((IkReal(-1.00000000000000))*(x10791)*(x10812))));
evalcond[1]=((((x10788)*(x10813)))+(((cj1)*(x10794)))+(((r22)*(sj5)*(x10788)))+(((x10805)*(x10812)))+(((IkReal(-1.00000000000000))*(sj3)*(x10795)))+(((cj6)*(x10814)))+(((IkReal(-1.00000000000000))*(x10787)*(x10802))));
evalcond[2]=((((IkReal(-1.00000000000000))*(x10791)*(x10800)*(x10809)))+(((IkReal(-1.00000000000000))*(x10798)*(x10799)*(x10809)))+(((x10803)*(x10811)))+(((IkReal(-1.00000000000000))*(x10796)*(x10808)))+(((x10804)*(x10808)))+(((IkReal(-1.00000000000000))*(cj0)*(x10790)*(x10807)))+(((x10797)*(x10810)))+(cj2)+(((IkReal(-1.00000000000000))*(r00)*(x10791)*(x10810)))+(((x10792)*(x10815)))+(((x10789)*(x10815))));
evalcond[3]=((((cj5)*(x10789)*(x10810)))+(((IkReal(-1.00000000000000))*(sj5)*(x10790)*(x10808)))+(((x10801)*(x10811)))+(((IkReal(-1.00000000000000))*(x10797)*(x10811)))+(((cj5)*(x10792)*(x10810)))+(((x10796)*(x10809)))+(((cj3)*(sj2)))+(((IkReal(-1.00000000000000))*(r10)*(x10791)*(x10809)))+(((IkReal(-1.00000000000000))*(x10798)*(x10799)*(x10808)))+(((x10803)*(x10810)))+(((IkReal(-1.00000000000000))*(x10791)*(x10800)*(x10808))));
evalcond[4]=((((IkReal(-1.00000000000000))*(sj0)*(x10790)*(x10807)))+(((IkReal(-1.00000000000000))*(x10797)*(x10808)))+(((IkReal(-1.00000000000000))*(x10791)*(x10800)*(x10811)))+(((IkReal(-1.00000000000000))*(x10798)*(x10799)*(x10811)))+(((IkReal(-1.00000000000000))*(x10796)*(x10810)))+(((sj1)*(sj2)))+(((x10801)*(x10808)))+(((IkReal(-1.00000000000000))*(x10803)*(x10809)))+(((IkReal(-1.00000000000000))*(x10789)*(x10798)*(x10809)))+(((IkReal(-1.00000000000000))*(x10791)*(x10806)*(x10809)))+(((x10804)*(x10810))));
evalcond[5]=((((IkReal(-1.00000000000000))*(x10791)*(x10800)*(x10810)))+(((IkReal(-1.00000000000000))*(x10789)*(x10798)*(x10808)))+(((x10797)*(x10809)))+(((IkReal(-1.00000000000000))*(sj3)*(x10793)))+(((x10796)*(x10811)))+(((IkReal(-1.00000000000000))*(x10803)*(x10808)))+(((IkReal(-1.00000000000000))*(r00)*(x10791)*(x10809)))+(((IkReal(-1.00000000000000))*(x10791)*(x10806)*(x10808)))+(((IkReal(-1.00000000000000))*(sj5)*(x10790)*(x10810)))+(((IkReal(-1.00000000000000))*(r10)*(x10791)*(x10811)))+(((IkReal(-1.00000000000000))*(x10794)*(x10795)))+(((IkReal(-1.00000000000000))*(x10798)*(x10799)*(x10810))));
if( IKabs(evalcond[0]) > 0.000001  || IKabs(evalcond[1]) > 0.000001  || IKabs(evalcond[2]) > 0.000001  || IKabs(evalcond[3]) > 0.000001  || IKabs(evalcond[4]) > 0.000001  || IKabs(evalcond[5]) > 0.000001  )
{
continue;
}
}

{
std::vector<IkSingleDOFSolutionBase<IkReal> > vinfos(7);
vinfos[0].jointtype = 1;
vinfos[0].foffset = j0;
vinfos[0].indices[0] = _ij0[0];
vinfos[0].indices[1] = _ij0[1];
vinfos[0].maxsolutions = _nj0;
vinfos[1].jointtype = 1;
vinfos[1].foffset = j1;
vinfos[1].indices[0] = _ij1[0];
vinfos[1].indices[1] = _ij1[1];
vinfos[1].maxsolutions = _nj1;
vinfos[2].jointtype = 1;
vinfos[2].foffset = j2;
vinfos[2].indices[0] = _ij2[0];
vinfos[2].indices[1] = _ij2[1];
vinfos[2].maxsolutions = _nj2;
vinfos[3].jointtype = 1;
vinfos[3].foffset = j3;
vinfos[3].indices[0] = _ij3[0];
vinfos[3].indices[1] = _ij3[1];
vinfos[3].maxsolutions = _nj3;
vinfos[4].jointtype = 1;
vinfos[4].foffset = j4;
vinfos[4].indices[0] = _ij4[0];
vinfos[4].indices[1] = _ij4[1];
vinfos[4].maxsolutions = _nj4;
vinfos[5].jointtype = 1;
vinfos[5].foffset = j5;
vinfos[5].indices[0] = _ij5[0];
vinfos[5].indices[1] = _ij5[1];
vinfos[5].maxsolutions = _nj5;
vinfos[6].jointtype = 1;
vinfos[6].foffset = j6;
vinfos[6].indices[0] = _ij6[0];
vinfos[6].indices[1] = _ij6[1];
vinfos[6].maxsolutions = _nj6;
std::vector<int> vfree(0);
solutions.AddSolution(vinfos,vfree);
}
}
}

}

}

} else
{
{
IkReal j4array[1], cj4array[1], sj4array[1];
bool j4valid[1]={false};
_nj4 = 1;
IkReal x10816=((cj1)*(sj2));
IkReal x10817=((cj6)*(r20));
IkReal x10818=((sj1)*(sj3));
IkReal x10819=((r21)*(sj6));
IkReal x10820=((IkReal(1.00000000000000))*(cj5));
IkReal x10821=((cj6)*(r21));
IkReal x10822=((r20)*(sj6));
IkReal x10823=((IkReal(1.00000000000000))*(r22)*(sj5));
IkReal x10824=((cj1)*(cj2)*(cj3));
if( IKabs(((gconst2)*(((((x10818)*(x10819)))+(((IkReal(-1.00000000000000))*(x10816)*(x10820)*(x10822)))+(((IkReal(-1.00000000000000))*(x10816)*(x10820)*(x10821)))+(((IkReal(-1.00000000000000))*(x10819)*(x10824)))+(((x10817)*(x10824)))+(((IkReal(-1.00000000000000))*(x10816)*(x10823)))+(((IkReal(-1.00000000000000))*(x10817)*(x10818))))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(((gconst2)*(((((IkReal(-1.00000000000000))*(x10818)*(x10820)*(x10822)))+(((cj5)*(x10821)*(x10824)))+(((IkReal(-1.00000000000000))*(x10816)*(x10819)))+(((r22)*(sj5)*(x10824)))+(((IkReal(-1.00000000000000))*(x10818)*(x10823)))+(((cj5)*(x10822)*(x10824)))+(((IkReal(-1.00000000000000))*(x10818)*(x10820)*(x10821)))+(((x10816)*(x10817))))))) < IKFAST_ATAN2_MAGTHRESH )
    continue;
j4array[0]=IKatan2(((gconst2)*(((((x10818)*(x10819)))+(((IkReal(-1.00000000000000))*(x10816)*(x10820)*(x10822)))+(((IkReal(-1.00000000000000))*(x10816)*(x10820)*(x10821)))+(((IkReal(-1.00000000000000))*(x10819)*(x10824)))+(((x10817)*(x10824)))+(((IkReal(-1.00000000000000))*(x10816)*(x10823)))+(((IkReal(-1.00000000000000))*(x10817)*(x10818)))))), ((gconst2)*(((((IkReal(-1.00000000000000))*(x10818)*(x10820)*(x10822)))+(((cj5)*(x10821)*(x10824)))+(((IkReal(-1.00000000000000))*(x10816)*(x10819)))+(((r22)*(sj5)*(x10824)))+(((IkReal(-1.00000000000000))*(x10818)*(x10823)))+(((cj5)*(x10822)*(x10824)))+(((IkReal(-1.00000000000000))*(x10818)*(x10820)*(x10821)))+(((x10816)*(x10817)))))));
sj4array[0]=IKsin(j4array[0]);
cj4array[0]=IKcos(j4array[0]);
if( j4array[0] > IKPI )
{
    j4array[0]-=IK2PI;
}
else if( j4array[0] < -IKPI )
{    j4array[0]+=IK2PI;
}
j4valid[0] = true;
for(int ij4 = 0; ij4 < 1; ++ij4)
{
if( !j4valid[ij4] )
{
    continue;
}
_ij4[0] = ij4; _ij4[1] = -1;
for(int iij4 = ij4+1; iij4 < 1; ++iij4)
{
if( j4valid[iij4] && IKabs(cj4array[ij4]-cj4array[iij4]) < IKFAST_SOLUTION_THRESH && IKabs(sj4array[ij4]-sj4array[iij4]) < IKFAST_SOLUTION_THRESH )
{
    j4valid[iij4]=false; _ij4[1] = iij4; break; 
}
}
j4 = j4array[ij4]; cj4 = cj4array[ij4]; sj4 = sj4array[ij4];
{
IkReal evalcond[6];
IkReal x10825=IKsin(j4);
IkReal x10826=IKcos(j4);
IkReal x10827=((r00)*(sj6));
IkReal x10828=((IkReal(1.00000000000000))*(r12));
IkReal x10829=((IkReal(1.00000000000000))*(cj6));
IkReal x10830=((cj6)*(r01));
IkReal x10831=((IkReal(1.00000000000000))*(cj1));
IkReal x10832=((cj2)*(cj3));
IkReal x10833=((IkReal(1.00000000000000))*(sj1));
IkReal x10834=((r11)*(sj6));
IkReal x10835=((r01)*(sj6));
IkReal x10836=((IkReal(1.00000000000000))*(cj5));
IkReal x10837=((r10)*(sj6));
IkReal x10838=((cj5)*(r11));
IkReal x10839=((cj6)*(r00));
IkReal x10840=((r21)*(sj6));
IkReal x10841=((r02)*(sj5));
IkReal x10842=((cj6)*(r10));
IkReal x10843=((cj5)*(sj6));
IkReal x10844=((cj5)*(r01));
IkReal x10845=((sj5)*(x10825));
IkReal x10846=((cj0)*(x10826));
IkReal x10847=((cj0)*(x10825));
IkReal x10848=((sj0)*(x10826));
IkReal x10849=((sj0)*(x10825));
IkReal x10850=((r20)*(x10826));
IkReal x10851=((cj5)*(cj6)*(r21));
IkReal x10852=((r20)*(x10825));
IkReal x10853=((cj5)*(x10849));
evalcond[0]=((((x10825)*(x10851)))+(((x10843)*(x10852)))+(((IkReal(-1.00000000000000))*(x10829)*(x10850)))+(((r22)*(x10845)))+(((x10826)*(x10840)))+(((IkReal(-1.00000000000000))*(sj2)*(x10831))));
evalcond[1]=((((x10843)*(x10850)))+(((cj6)*(x10852)))+(((x10826)*(x10851)))+(((IkReal(-1.00000000000000))*(x10825)*(x10840)))+(((r22)*(sj5)*(x10826)))+(((cj1)*(x10832)))+(((IkReal(-1.00000000000000))*(sj3)*(x10833))));
evalcond[2]=((((IkReal(-1.00000000000000))*(x10834)*(x10846)))+(((x10842)*(x10846)))+(((x10835)*(x10848)))+(((x10841)*(x10849)))+(((IkReal(-1.00000000000000))*(x10829)*(x10838)*(x10847)))+(((x10830)*(x10853)))+(cj2)+(((IkReal(-1.00000000000000))*(r00)*(x10829)*(x10848)))+(((IkReal(-1.00000000000000))*(x10836)*(x10837)*(x10847)))+(((x10827)*(x10853)))+(((IkReal(-1.00000000000000))*(cj0)*(x10828)*(x10845))));
evalcond[3]=((((IkReal(-1.00000000000000))*(r10)*(x10829)*(x10847)))+(((IkReal(-1.00000000000000))*(x10829)*(x10838)*(x10846)))+(((x10839)*(x10849)))+(((cj5)*(x10830)*(x10848)))+(((IkReal(-1.00000000000000))*(x10836)*(x10837)*(x10846)))+(((x10834)*(x10847)))+(((cj3)*(sj2)))+(((IkReal(-1.00000000000000))*(x10835)*(x10849)))+(((x10841)*(x10848)))+(((cj5)*(x10827)*(x10848)))+(((IkReal(-1.00000000000000))*(sj5)*(x10828)*(x10846))));
evalcond[4]=((((IkReal(-1.00000000000000))*(x10836)*(x10837)*(x10849)))+(((IkReal(-1.00000000000000))*(x10834)*(x10848)))+(((IkReal(-1.00000000000000))*(x10835)*(x10846)))+(((IkReal(-1.00000000000000))*(x10841)*(x10847)))+(((IkReal(-1.00000000000000))*(sj0)*(x10828)*(x10845)))+(((IkReal(-1.00000000000000))*(x10829)*(x10844)*(x10847)))+(((x10842)*(x10848)))+(((IkReal(-1.00000000000000))*(x10827)*(x10836)*(x10847)))+(((IkReal(-1.00000000000000))*(x10829)*(x10838)*(x10849)))+(((sj1)*(sj2)))+(((x10839)*(x10846))));
evalcond[5]=((((x10834)*(x10849)))+(((IkReal(-1.00000000000000))*(x10829)*(x10838)*(x10848)))+(((IkReal(-1.00000000000000))*(x10836)*(x10837)*(x10848)))+(((IkReal(-1.00000000000000))*(r00)*(x10829)*(x10847)))+(((IkReal(-1.00000000000000))*(x10829)*(x10844)*(x10846)))+(((IkReal(-1.00000000000000))*(sj3)*(x10831)))+(((IkReal(-1.00000000000000))*(r10)*(x10829)*(x10849)))+(((IkReal(-1.00000000000000))*(x10832)*(x10833)))+(((IkReal(-1.00000000000000))*(x10827)*(x10836)*(x10846)))+(((IkReal(-1.00000000000000))*(sj5)*(x10828)*(x10848)))+(((IkReal(-1.00000000000000))*(x10841)*(x10846)))+(((x10835)*(x10847))));
if( IKabs(evalcond[0]) > 0.000001  || IKabs(evalcond[1]) > 0.000001  || IKabs(evalcond[2]) > 0.000001  || IKabs(evalcond[3]) > 0.000001  || IKabs(evalcond[4]) > 0.000001  || IKabs(evalcond[5]) > 0.000001  )
{
continue;
}
}

{
std::vector<IkSingleDOFSolutionBase<IkReal> > vinfos(7);
vinfos[0].jointtype = 1;
vinfos[0].foffset = j0;
vinfos[0].indices[0] = _ij0[0];
vinfos[0].indices[1] = _ij0[1];
vinfos[0].maxsolutions = _nj0;
vinfos[1].jointtype = 1;
vinfos[1].foffset = j1;
vinfos[1].indices[0] = _ij1[0];
vinfos[1].indices[1] = _ij1[1];
vinfos[1].maxsolutions = _nj1;
vinfos[2].jointtype = 1;
vinfos[2].foffset = j2;
vinfos[2].indices[0] = _ij2[0];
vinfos[2].indices[1] = _ij2[1];
vinfos[2].maxsolutions = _nj2;
vinfos[3].jointtype = 1;
vinfos[3].foffset = j3;
vinfos[3].indices[0] = _ij3[0];
vinfos[3].indices[1] = _ij3[1];
vinfos[3].maxsolutions = _nj3;
vinfos[4].jointtype = 1;
vinfos[4].foffset = j4;
vinfos[4].indices[0] = _ij4[0];
vinfos[4].indices[1] = _ij4[1];
vinfos[4].maxsolutions = _nj4;
vinfos[5].jointtype = 1;
vinfos[5].foffset = j5;
vinfos[5].indices[0] = _ij5[0];
vinfos[5].indices[1] = _ij5[1];
vinfos[5].maxsolutions = _nj5;
vinfos[6].jointtype = 1;
vinfos[6].foffset = j6;
vinfos[6].indices[0] = _ij6[0];
vinfos[6].indices[1] = _ij6[1];
vinfos[6].maxsolutions = _nj6;
std::vector<int> vfree(0);
solutions.AddSolution(vinfos,vfree);
}
}
}

}

}
}
}

}

}

} else
{
{
IkReal j4array[1], cj4array[1], sj4array[1];
bool j4valid[1]={false};
_nj4 = 1;
IkReal x10854=((cj0)*(r00));
IkReal x10855=((r10)*(sj0));
IkReal x10856=((cj0)*(r01));
IkReal x10857=((IkReal(1.00000000000000))*(cj5));
IkReal x10858=((r11)*(sj0));
IkReal x10859=((sj2)*(sj5));
IkReal x10860=((IkReal(1.00000000000000))*(cj1));
IkReal x10861=((r20)*(sj1)*(sj2));
IkReal x10862=((cj1)*(sj2)*(sj6));
IkReal x10863=((r21)*(sj1)*(sj2));
IkReal x10864=((cj6)*(sj2)*(x10860));
if( IKabs(((gconst1)*(((((IkReal(-1.00000000000000))*(sj6)*(x10863)))+(((x10858)*(x10862)))+(((IkReal(-1.00000000000000))*(x10854)*(x10864)))+(((x10856)*(x10862)))+(((cj6)*(x10861)))+(((IkReal(-1.00000000000000))*(x10855)*(x10864))))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(((gconst1)*(((((IkReal(-1.00000000000000))*(cj0)*(r02)*(x10859)*(x10860)))+(((IkReal(-1.00000000000000))*(x10854)*(x10857)*(x10862)))+(((IkReal(-1.00000000000000))*(cj1)*(cj6)*(sj2)*(x10857)*(x10858)))+(((IkReal(-1.00000000000000))*(cj1)*(cj6)*(sj2)*(x10856)*(x10857)))+(((cj5)*(sj6)*(x10861)))+(((r22)*(sj1)*(x10859)))+(((IkReal(-1.00000000000000))*(r12)*(sj0)*(x10859)*(x10860)))+(((IkReal(-1.00000000000000))*(x10855)*(x10857)*(x10862)))+(((cj5)*(cj6)*(x10863))))))) < IKFAST_ATAN2_MAGTHRESH )
    continue;
j4array[0]=IKatan2(((gconst1)*(((((IkReal(-1.00000000000000))*(sj6)*(x10863)))+(((x10858)*(x10862)))+(((IkReal(-1.00000000000000))*(x10854)*(x10864)))+(((x10856)*(x10862)))+(((cj6)*(x10861)))+(((IkReal(-1.00000000000000))*(x10855)*(x10864)))))), ((gconst1)*(((((IkReal(-1.00000000000000))*(cj0)*(r02)*(x10859)*(x10860)))+(((IkReal(-1.00000000000000))*(x10854)*(x10857)*(x10862)))+(((IkReal(-1.00000000000000))*(cj1)*(cj6)*(sj2)*(x10857)*(x10858)))+(((IkReal(-1.00000000000000))*(cj1)*(cj6)*(sj2)*(x10856)*(x10857)))+(((cj5)*(sj6)*(x10861)))+(((r22)*(sj1)*(x10859)))+(((IkReal(-1.00000000000000))*(r12)*(sj0)*(x10859)*(x10860)))+(((IkReal(-1.00000000000000))*(x10855)*(x10857)*(x10862)))+(((cj5)*(cj6)*(x10863)))))));
sj4array[0]=IKsin(j4array[0]);
cj4array[0]=IKcos(j4array[0]);
if( j4array[0] > IKPI )
{
    j4array[0]-=IK2PI;
}
else if( j4array[0] < -IKPI )
{    j4array[0]+=IK2PI;
}
j4valid[0] = true;
for(int ij4 = 0; ij4 < 1; ++ij4)
{
if( !j4valid[ij4] )
{
    continue;
}
_ij4[0] = ij4; _ij4[1] = -1;
for(int iij4 = ij4+1; iij4 < 1; ++iij4)
{
if( j4valid[iij4] && IKabs(cj4array[ij4]-cj4array[iij4]) < IKFAST_SOLUTION_THRESH && IKabs(sj4array[ij4]-sj4array[iij4]) < IKFAST_SOLUTION_THRESH )
{
    j4valid[iij4]=false; _ij4[1] = iij4; break; 
}
}
j4 = j4array[ij4]; cj4 = cj4array[ij4]; sj4 = sj4array[ij4];
{
IkReal evalcond[3];
IkReal x10865=IKsin(j4);
IkReal x10866=IKcos(j4);
IkReal x10867=((r00)*(sj6));
IkReal x10868=((cj6)*(r01));
IkReal x10869=((IkReal(1.00000000000000))*(cj0));
IkReal x10870=((IkReal(1.00000000000000))*(sj0));
IkReal x10871=((r10)*(sj6));
IkReal x10872=((sj5)*(x10865));
IkReal x10873=((IkReal(1.00000000000000))*(cj6)*(r11));
IkReal x10874=((cj5)*(x10865));
IkReal x10875=((cj6)*(x10866));
IkReal x10876=((sj0)*(x10874));
IkReal x10877=((r01)*(sj6)*(x10866));
IkReal x10878=((r11)*(sj6)*(x10866));
evalcond[0]=((((IkReal(-1.00000000000000))*(r20)*(x10875)))+(((cj6)*(r21)*(x10874)))+(((IkReal(-1.00000000000000))*(cj1)*(sj2)))+(((r21)*(sj6)*(x10866)))+(((r20)*(sj6)*(x10874)))+(((r22)*(x10872))));
evalcond[1]=((((IkReal(-1.00000000000000))*(x10869)*(x10878)))+(((cj0)*(r10)*(x10875)))+(((IkReal(-1.00000000000000))*(cj6)*(r11)*(x10869)*(x10874)))+(((sj0)*(x10877)))+(((IkReal(-1.00000000000000))*(r12)*(x10869)*(x10872)))+(((x10868)*(x10876)))+(((IkReal(-1.00000000000000))*(x10869)*(x10871)*(x10874)))+(cj2)+(((r02)*(sj0)*(x10872)))+(((x10867)*(x10876)))+(((IkReal(-1.00000000000000))*(r00)*(x10870)*(x10875))));
evalcond[2]=((((IkReal(-1.00000000000000))*(x10869)*(x10877)))+(((cj0)*(r00)*(x10875)))+(((IkReal(-1.00000000000000))*(r02)*(x10869)*(x10872)))+(((IkReal(-1.00000000000000))*(cj6)*(r11)*(x10870)*(x10874)))+(((IkReal(-1.00000000000000))*(x10870)*(x10878)))+(((sj1)*(sj2)))+(((IkReal(-1.00000000000000))*(x10867)*(x10869)*(x10874)))+(((IkReal(-1.00000000000000))*(x10868)*(x10869)*(x10874)))+(((IkReal(-1.00000000000000))*(r12)*(x10870)*(x10872)))+(((IkReal(-1.00000000000000))*(x10870)*(x10871)*(x10874)))+(((r10)*(sj0)*(x10875))));
if( IKabs(evalcond[0]) > 0.000001  || IKabs(evalcond[1]) > 0.000001  || IKabs(evalcond[2]) > 0.000001  )
{
continue;
}
}

{
IkReal dummyeval[1];
IkReal gconst4;
gconst4=IKsign((((sj1)*(sj1))+((((cj1)*(cj1))*((cj2)*(cj2))))));
dummyeval[0]=(((sj1)*(sj1))+((((cj1)*(cj1))*((cj2)*(cj2)))));
if( IKabs(dummyeval[0]) < 0.0000010000000000  )
{
{
IkReal dummyeval[2];
IkReal x10879=(cj1)*(cj1);
IkReal x10880=(sj1)*(sj1);
dummyeval[0]=((((cj2)*(x10880)))+(((cj2)*(x10879))));
dummyeval[1]=((x10879)+(x10880));
if( IKabs(dummyeval[0]) < 0.0000010000000000  || IKabs(dummyeval[1]) < 0.0000010000000000  )
{
{
IkReal dummyeval[2];
dummyeval[0]=sj2;
dummyeval[1]=sj1;
if( IKabs(dummyeval[0]) < 0.0000010000000000  || IKabs(dummyeval[1]) < 0.0000010000000000  )
{
{
IkReal evalcond[9];
IkReal x10881=((cj5)*(sj4));
IkReal x10882=((IkReal(1.00000000000000))*(sj6));
IkReal x10883=((r10)*(sj0));
IkReal x10884=((sj4)*(sj5));
IkReal x10885=((cj4)*(cj5));
IkReal x10886=((IkReal(1.00000000000000))*(r02));
IkReal x10887=((IkReal(0.374290000000000))*(cj0));
IkReal x10888=((cj5)*(r12));
IkReal x10889=((cj6)*(sj5));
IkReal x10890=((cj0)*(r11));
IkReal x10891=((cj5)*(sj0));
IkReal x10892=((r20)*(sj6));
IkReal x10893=((IkReal(1.00000000000000))*(sj0));
IkReal x10894=((IkReal(1.00000000000000))*(cj6));
IkReal x10895=((IkReal(0.0100000000000000))*(cj5));
IkReal x10896=((IkReal(0.0100000000000000))*(sj5));
IkReal x10897=((sj5)*(sj6));
IkReal x10898=((cj0)*(r10));
IkReal x10899=((cj4)*(cj6));
IkReal x10900=((cj0)*(r01));
IkReal x10901=((cj0)*(r00));
IkReal x10902=((cj6)*(r21));
IkReal x10903=((IkReal(0.374290000000000))*(sj0));
IkReal x10904=((IkReal(0.374290000000000))*(sj5));
IkReal x10905=((cj6)*(r11));
IkReal x10906=((sj0)*(sj4));
IkReal x10907=((cj4)*(sj5));
IkReal x10908=((cj4)*(sj6));
IkReal x10909=((IkReal(1.00000000000000))*(cj0));
IkReal x10910=((r02)*(sj0));
IkReal x10911=((r00)*(sj0)*(sj6));
IkReal x10912=((cj6)*(r01)*(sj0));
IkReal x10913=((r00)*(x10899));
IkReal x10914=((r12)*(x10909));
evalcond[0]=((IkReal(-3.14159265358979))+(IKfmod(((IkReal(3.14159265358979))+(j2)), IkReal(6.28318530717959))));
evalcond[1]=((((r21)*(x10908)))+(((x10881)*(x10902)))+(((r22)*(x10884)))+(((x10881)*(x10892)))+(((IkReal(-1.00000000000000))*(cj4)*(r20)*(x10894))));
evalcond[2]=((((IkReal(0.364420000000000))*(sj1)))+(((IkReal(0.374290000000000))*(r21)*(x10889)))+(((IkReal(-1.00000000000000))*(r22)*(x10896)))+(((IkReal(-0.374290000000000))*(cj5)*(r22)))+(((x10892)*(x10904)))+(((IkReal(-1.00000000000000))*(x10892)*(x10895)))+(pz)+(((IkReal(-1.00000000000000))*(x10895)*(x10902)))+(((IkReal(0.0690000000000000))*(cj1))));
evalcond[3]=((((IkReal(-1.00000000000000))*(x10886)*(x10891)))+(((r00)*(sj0)*(x10897)))+(((r01)*(sj0)*(x10889)))+(((IkReal(-1.00000000000000))*(x10889)*(x10890)))+(((IkReal(-1.00000000000000))*(sj5)*(x10882)*(x10898)))+(((cj0)*(x10888))));
evalcond[4]=((IkReal(1.00000000000000))+(((IkReal(-1.00000000000000))*(x10881)*(x10890)*(x10894)))+(((x10898)*(x10899)))+(((IkReal(-1.00000000000000))*(x10884)*(x10914)))+(((x10881)*(x10911)))+(((r01)*(sj0)*(x10908)))+(((IkReal(-1.00000000000000))*(x10893)*(x10913)))+(((IkReal(-1.00000000000000))*(x10881)*(x10882)*(x10898)))+(((IkReal(-1.00000000000000))*(cj4)*(x10882)*(x10890)))+(((x10884)*(x10910)))+(((x10881)*(x10912))));
evalcond[5]=((((IkReal(-1.00000000000000))*(x10882)*(x10885)*(x10898)))+(((IkReal(-1.00000000000000))*(x10885)*(x10890)*(x10894)))+(((sj4)*(sj6)*(x10890)))+(((IkReal(-1.00000000000000))*(sj4)*(x10894)*(x10898)))+(((IkReal(-1.00000000000000))*(r01)*(x10882)*(x10906)))+(((x10907)*(x10910)))+(((x10885)*(x10912)))+(((x10885)*(x10911)))+(((cj6)*(r00)*(x10906)))+(((IkReal(-1.00000000000000))*(x10907)*(x10914))));
evalcond[6]=((((IkReal(-1.00000000000000))*(r12)*(x10884)*(x10893)))+(((IkReal(-1.00000000000000))*(x10881)*(x10893)*(x10905)))+(((IkReal(-1.00000000000000))*(cj4)*(r11)*(sj0)*(x10882)))+(((IkReal(-1.00000000000000))*(x10881)*(x10882)*(x10883)))+(((IkReal(-1.00000000000000))*(cj0)*(x10884)*(x10886)))+(((IkReal(-1.00000000000000))*(x10881)*(x10894)*(x10900)))+(((IkReal(-1.00000000000000))*(x10881)*(x10882)*(x10901)))+(((x10899)*(x10901)))+(((x10883)*(x10899)))+(((IkReal(-1.00000000000000))*(cj4)*(x10882)*(x10900))));
evalcond[7]=((((IkReal(-0.374290000000000))*(r02)*(x10891)))+(((IkReal(-0.0100000000000000))*(r00)*(sj6)*(x10891)))+(((IkReal(-1.00000000000000))*(x10896)*(x10910)))+(((IkReal(-1.00000000000000))*(r11)*(x10887)*(x10889)))+(((sj6)*(x10895)*(x10898)))+(((IkReal(-0.0100000000000000))*(cj6)*(r01)*(x10891)))+(((IkReal(-1.00000000000000))*(py)*(x10909)))+(((r00)*(x10897)*(x10903)))+(((cj6)*(x10890)*(x10895)))+(((IkReal(-1.00000000000000))*(r10)*(x10887)*(x10897)))+(((x10887)*(x10888)))+(((r01)*(x10889)*(x10903)))+(((px)*(sj0)))+(((cj0)*(r12)*(x10896))));
evalcond[8]=((IkReal(0.0690000000000000))+(((cj0)*(r02)*(x10896)))+(((IkReal(-0.0690000000000000))*(sj1)))+(((x10888)*(x10903)))+(((r12)*(sj0)*(x10896)))+(((IkReal(-1.00000000000000))*(py)*(x10893)))+(((IkReal(-0.374290000000000))*(x10883)*(x10897)))+(((IkReal(-1.00000000000000))*(r01)*(x10887)*(x10889)))+(((sj6)*(x10883)*(x10895)))+(((cj6)*(x10895)*(x10900)))+(((cj5)*(r02)*(x10887)))+(((IkReal(-1.00000000000000))*(px)*(x10909)))+(((IkReal(-1.00000000000000))*(r11)*(x10889)*(x10903)))+(((IkReal(0.0100000000000000))*(x10891)*(x10905)))+(((IkReal(-1.00000000000000))*(r00)*(x10887)*(x10897)))+(((sj6)*(x10895)*(x10901)))+(((IkReal(0.364420000000000))*(cj1))));
if( IKabs(evalcond[0]) < 0.0000010000000000  && IKabs(evalcond[1]) < 0.0000010000000000  && IKabs(evalcond[2]) < 0.0000010000000000  && IKabs(evalcond[3]) < 0.0000010000000000  && IKabs(evalcond[4]) < 0.0000010000000000  && IKabs(evalcond[5]) < 0.0000010000000000  && IKabs(evalcond[6]) < 0.0000010000000000  && IKabs(evalcond[7]) < 0.0000010000000000  && IKabs(evalcond[8]) < 0.0000010000000000  )
{
{
IkReal dummyeval[1];
IkReal gconst5;
gconst5=IKsign((((cj1)*(cj1))+((sj1)*(sj1))));
dummyeval[0]=(((cj1)*(cj1))+((sj1)*(sj1)));
if( IKabs(dummyeval[0]) < 0.0000010000000000  )
{
{
IkReal dummyeval[1];
IkReal gconst6;
gconst6=IKsign((((cj1)*(cj1))+((sj1)*(sj1))));
dummyeval[0]=(((cj1)*(cj1))+((sj1)*(sj1)));
if( IKabs(dummyeval[0]) < 0.0000010000000000  )
{
continue;

} else
{
{
IkReal j3array[1], cj3array[1], sj3array[1];
bool j3valid[1]={false};
_nj3 = 1;
IkReal x10915=((sj5)*(sj6));
IkReal x10916=((IkReal(1.00000000000000))*(sj0));
IkReal x10917=((cj5)*(r12));
IkReal x10918=((cj0)*(r00));
IkReal x10919=((cj0)*(cj1));
IkReal x10920=((cj6)*(sj5));
IkReal x10921=((cj5)*(r02));
IkReal x10922=((IkReal(1.00000000000000))*(cj1));
IkReal x10923=((sj0)*(sj1));
IkReal x10924=((cj0)*(sj1));
IkReal x10925=((cj5)*(r22));
if( IKabs(((gconst6)*(((((r10)*(x10915)*(x10923)))+(((IkReal(-1.00000000000000))*(sj1)*(x10916)*(x10917)))+(((sj1)*(x10915)*(x10918)))+(((cj1)*(r21)*(x10920)))+(((r11)*(x10920)*(x10923)))+(((cj1)*(r20)*(x10915)))+(((IkReal(-1.00000000000000))*(x10921)*(x10924)))+(((IkReal(-1.00000000000000))*(x10922)*(x10925)))+(((r01)*(x10920)*(x10924))))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(((gconst6)*(((((r21)*(sj1)*(x10920)))+(((x10919)*(x10921)))+(((IkReal(-1.00000000000000))*(cj1)*(r11)*(x10916)*(x10920)))+(((r20)*(sj1)*(x10915)))+(((IkReal(-1.00000000000000))*(cj1)*(r10)*(x10915)*(x10916)))+(((cj1)*(sj0)*(x10917)))+(((IkReal(-1.00000000000000))*(r01)*(x10919)*(x10920)))+(((IkReal(-1.00000000000000))*(sj1)*(x10925)))+(((IkReal(-1.00000000000000))*(x10915)*(x10918)*(x10922))))))) < IKFAST_ATAN2_MAGTHRESH )
    continue;
j3array[0]=IKatan2(((gconst6)*(((((r10)*(x10915)*(x10923)))+(((IkReal(-1.00000000000000))*(sj1)*(x10916)*(x10917)))+(((sj1)*(x10915)*(x10918)))+(((cj1)*(r21)*(x10920)))+(((r11)*(x10920)*(x10923)))+(((cj1)*(r20)*(x10915)))+(((IkReal(-1.00000000000000))*(x10921)*(x10924)))+(((IkReal(-1.00000000000000))*(x10922)*(x10925)))+(((r01)*(x10920)*(x10924)))))), ((gconst6)*(((((r21)*(sj1)*(x10920)))+(((x10919)*(x10921)))+(((IkReal(-1.00000000000000))*(cj1)*(r11)*(x10916)*(x10920)))+(((r20)*(sj1)*(x10915)))+(((IkReal(-1.00000000000000))*(cj1)*(r10)*(x10915)*(x10916)))+(((cj1)*(sj0)*(x10917)))+(((IkReal(-1.00000000000000))*(r01)*(x10919)*(x10920)))+(((IkReal(-1.00000000000000))*(sj1)*(x10925)))+(((IkReal(-1.00000000000000))*(x10915)*(x10918)*(x10922)))))));
sj3array[0]=IKsin(j3array[0]);
cj3array[0]=IKcos(j3array[0]);
if( j3array[0] > IKPI )
{
    j3array[0]-=IK2PI;
}
else if( j3array[0] < -IKPI )
{    j3array[0]+=IK2PI;
}
j3valid[0] = true;
for(int ij3 = 0; ij3 < 1; ++ij3)
{
if( !j3valid[ij3] )
{
    continue;
}
_ij3[0] = ij3; _ij3[1] = -1;
for(int iij3 = ij3+1; iij3 < 1; ++iij3)
{
if( j3valid[iij3] && IKabs(cj3array[ij3]-cj3array[iij3]) < IKFAST_SOLUTION_THRESH && IKabs(sj3array[ij3]-sj3array[iij3]) < IKFAST_SOLUTION_THRESH )
{
    j3valid[iij3]=false; _ij3[1] = iij3; break; 
}
}
j3 = j3array[ij3]; cj3 = cj3array[ij3]; sj3 = sj3array[ij3];
{
IkReal evalcond[4];
IkReal x10926=IKcos(j3);
IkReal x10927=IKsin(j3);
IkReal x10928=((IkReal(1.00000000000000))*(cj4));
IkReal x10929=((sj0)*(sj5));
IkReal x10930=((cj0)*(cj5));
IkReal x10931=((cj6)*(r01));
IkReal x10932=((r00)*(sj6));
IkReal x10933=((cj6)*(r11));
IkReal x10934=((cj5)*(sj0));
IkReal x10935=((cj6)*(sj4));
IkReal x10936=((sj4)*(sj6));
IkReal x10937=((cj4)*(cj5));
IkReal x10938=((cj6)*(r21));
IkReal x10939=((r20)*(sj6));
IkReal x10940=((r10)*(sj6));
IkReal x10941=((cj1)*(x10926));
IkReal x10942=((IkReal(1.00000000000000))*(cj0)*(sj5));
IkReal x10943=((IkReal(1.00000000000000))*(x10927));
IkReal x10944=((IkReal(1.00000000000000))*(sj1)*(x10926));
IkReal x10945=((cj1)*(x10943));
IkReal x10946=((x10945)+(x10944));
evalcond[0]=((((sj5)*(x10939)))+(((IkReal(-1.00000000000000))*(cj5)*(r22)))+(((IkReal(-1.00000000000000))*(x10946)))+(((sj5)*(x10938))));
evalcond[1]=((x10941)+(((x10937)*(x10939)))+(((r20)*(x10935)))+(((IkReal(-1.00000000000000))*(sj1)*(x10943)))+(((cj4)*(r22)*(sj5)))+(((IkReal(-1.00000000000000))*(r21)*(x10936)))+(((x10937)*(x10938))));
evalcond[2]=((((r02)*(x10930)))+(((IkReal(-1.00000000000000))*(x10929)*(x10933)))+(((sj1)*(x10927)))+(((IkReal(-1.00000000000000))*(x10931)*(x10942)))+(((IkReal(-1.00000000000000))*(x10932)*(x10942)))+(((IkReal(-1.00000000000000))*(x10929)*(x10940)))+(((IkReal(-1.00000000000000))*(x10941)))+(((r12)*(x10934))));
evalcond[3]=((((IkReal(-1.00000000000000))*(x10928)*(x10930)*(x10931)))+(((IkReal(-1.00000000000000))*(x10928)*(x10934)*(x10940)))+(((IkReal(-1.00000000000000))*(cj0)*(r02)*(sj5)*(x10928)))+(((IkReal(-1.00000000000000))*(r10)*(sj0)*(x10935)))+(((cj0)*(r01)*(x10936)))+(((IkReal(-1.00000000000000))*(cj0)*(r00)*(x10935)))+(((IkReal(-1.00000000000000))*(x10946)))+(((IkReal(-1.00000000000000))*(x10928)*(x10930)*(x10932)))+(((IkReal(-1.00000000000000))*(x10928)*(x10933)*(x10934)))+(((r11)*(sj0)*(x10936)))+(((IkReal(-1.00000000000000))*(r12)*(x10928)*(x10929))));
if( IKabs(evalcond[0]) > 0.000001  || IKabs(evalcond[1]) > 0.000001  || IKabs(evalcond[2]) > 0.000001  || IKabs(evalcond[3]) > 0.000001  )
{
continue;
}
}

{
std::vector<IkSingleDOFSolutionBase<IkReal> > vinfos(7);
vinfos[0].jointtype = 1;
vinfos[0].foffset = j0;
vinfos[0].indices[0] = _ij0[0];
vinfos[0].indices[1] = _ij0[1];
vinfos[0].maxsolutions = _nj0;
vinfos[1].jointtype = 1;
vinfos[1].foffset = j1;
vinfos[1].indices[0] = _ij1[0];
vinfos[1].indices[1] = _ij1[1];
vinfos[1].maxsolutions = _nj1;
vinfos[2].jointtype = 1;
vinfos[2].foffset = j2;
vinfos[2].indices[0] = _ij2[0];
vinfos[2].indices[1] = _ij2[1];
vinfos[2].maxsolutions = _nj2;
vinfos[3].jointtype = 1;
vinfos[3].foffset = j3;
vinfos[3].indices[0] = _ij3[0];
vinfos[3].indices[1] = _ij3[1];
vinfos[3].maxsolutions = _nj3;
vinfos[4].jointtype = 1;
vinfos[4].foffset = j4;
vinfos[4].indices[0] = _ij4[0];
vinfos[4].indices[1] = _ij4[1];
vinfos[4].maxsolutions = _nj4;
vinfos[5].jointtype = 1;
vinfos[5].foffset = j5;
vinfos[5].indices[0] = _ij5[0];
vinfos[5].indices[1] = _ij5[1];
vinfos[5].maxsolutions = _nj5;
vinfos[6].jointtype = 1;
vinfos[6].foffset = j6;
vinfos[6].indices[0] = _ij6[0];
vinfos[6].indices[1] = _ij6[1];
vinfos[6].maxsolutions = _nj6;
std::vector<int> vfree(0);
solutions.AddSolution(vinfos,vfree);
}
}
}

}

}

} else
{
{
IkReal j3array[1], cj3array[1], sj3array[1];
bool j3valid[1]={false};
_nj3 = 1;
IkReal x10947=((sj1)*(sj5));
IkReal x10948=((r20)*(sj6));
IkReal x10949=((cj4)*(r22));
IkReal x10950=((IkReal(1.00000000000000))*(cj1));
IkReal x10951=((cj5)*(sj1));
IkReal x10952=((cj6)*(r21));
IkReal x10953=((cj1)*(sj5));
IkReal x10954=((cj4)*(cj5));
IkReal x10955=((cj6)*(r20)*(sj4));
IkReal x10956=((r21)*(sj4)*(sj6));
if( IKabs(((gconst5)*(((((x10952)*(x10953)))+(((IkReal(-1.00000000000000))*(cj5)*(r22)*(x10950)))+(((cj4)*(x10951)*(x10952)))+(((x10948)*(x10953)))+(((x10947)*(x10949)))+(((sj1)*(x10955)))+(((cj4)*(x10948)*(x10951)))+(((IkReal(-1.00000000000000))*(sj1)*(x10956))))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(((gconst5)*(((((IkReal(-1.00000000000000))*(x10950)*(x10952)*(x10954)))+(((x10947)*(x10948)))+(((x10947)*(x10952)))+(((IkReal(-1.00000000000000))*(x10950)*(x10955)))+(((IkReal(-1.00000000000000))*(x10948)*(x10950)*(x10954)))+(((IkReal(-1.00000000000000))*(sj5)*(x10949)*(x10950)))+(((cj1)*(x10956)))+(((IkReal(-1.00000000000000))*(r22)*(x10951))))))) < IKFAST_ATAN2_MAGTHRESH )
    continue;
j3array[0]=IKatan2(((gconst5)*(((((x10952)*(x10953)))+(((IkReal(-1.00000000000000))*(cj5)*(r22)*(x10950)))+(((cj4)*(x10951)*(x10952)))+(((x10948)*(x10953)))+(((x10947)*(x10949)))+(((sj1)*(x10955)))+(((cj4)*(x10948)*(x10951)))+(((IkReal(-1.00000000000000))*(sj1)*(x10956)))))), ((gconst5)*(((((IkReal(-1.00000000000000))*(x10950)*(x10952)*(x10954)))+(((x10947)*(x10948)))+(((x10947)*(x10952)))+(((IkReal(-1.00000000000000))*(x10950)*(x10955)))+(((IkReal(-1.00000000000000))*(x10948)*(x10950)*(x10954)))+(((IkReal(-1.00000000000000))*(sj5)*(x10949)*(x10950)))+(((cj1)*(x10956)))+(((IkReal(-1.00000000000000))*(r22)*(x10951)))))));
sj3array[0]=IKsin(j3array[0]);
cj3array[0]=IKcos(j3array[0]);
if( j3array[0] > IKPI )
{
    j3array[0]-=IK2PI;
}
else if( j3array[0] < -IKPI )
{    j3array[0]+=IK2PI;
}
j3valid[0] = true;
for(int ij3 = 0; ij3 < 1; ++ij3)
{
if( !j3valid[ij3] )
{
    continue;
}
_ij3[0] = ij3; _ij3[1] = -1;
for(int iij3 = ij3+1; iij3 < 1; ++iij3)
{
if( j3valid[iij3] && IKabs(cj3array[ij3]-cj3array[iij3]) < IKFAST_SOLUTION_THRESH && IKabs(sj3array[ij3]-sj3array[iij3]) < IKFAST_SOLUTION_THRESH )
{
    j3valid[iij3]=false; _ij3[1] = iij3; break; 
}
}
j3 = j3array[ij3]; cj3 = cj3array[ij3]; sj3 = sj3array[ij3];
{
IkReal evalcond[4];
IkReal x10957=IKcos(j3);
IkReal x10958=IKsin(j3);
IkReal x10959=((IkReal(1.00000000000000))*(cj4));
IkReal x10960=((sj0)*(sj5));
IkReal x10961=((cj0)*(cj5));
IkReal x10962=((cj6)*(r01));
IkReal x10963=((r00)*(sj6));
IkReal x10964=((cj6)*(r11));
IkReal x10965=((cj5)*(sj0));
IkReal x10966=((cj6)*(sj4));
IkReal x10967=((sj4)*(sj6));
IkReal x10968=((cj4)*(cj5));
IkReal x10969=((cj6)*(r21));
IkReal x10970=((r20)*(sj6));
IkReal x10971=((r10)*(sj6));
IkReal x10972=((cj1)*(x10957));
IkReal x10973=((IkReal(1.00000000000000))*(cj0)*(sj5));
IkReal x10974=((IkReal(1.00000000000000))*(x10958));
IkReal x10975=((IkReal(1.00000000000000))*(sj1)*(x10957));
IkReal x10976=((cj1)*(x10974));
IkReal x10977=((x10976)+(x10975));
evalcond[0]=((((IkReal(-1.00000000000000))*(x10977)))+(((sj5)*(x10969)))+(((IkReal(-1.00000000000000))*(cj5)*(r22)))+(((sj5)*(x10970))));
evalcond[1]=((((r20)*(x10966)))+(((x10968)*(x10969)))+(((IkReal(-1.00000000000000))*(sj1)*(x10974)))+(((x10968)*(x10970)))+(((cj4)*(r22)*(sj5)))+(((IkReal(-1.00000000000000))*(r21)*(x10967)))+(x10972));
evalcond[2]=((((IkReal(-1.00000000000000))*(x10972)))+(((r12)*(x10965)))+(((IkReal(-1.00000000000000))*(x10963)*(x10973)))+(((IkReal(-1.00000000000000))*(x10962)*(x10973)))+(((r02)*(x10961)))+(((IkReal(-1.00000000000000))*(x10960)*(x10964)))+(((sj1)*(x10958)))+(((IkReal(-1.00000000000000))*(x10960)*(x10971))));
evalcond[3]=((((IkReal(-1.00000000000000))*(x10977)))+(((IkReal(-1.00000000000000))*(x10959)*(x10961)*(x10963)))+(((IkReal(-1.00000000000000))*(x10959)*(x10964)*(x10965)))+(((IkReal(-1.00000000000000))*(x10959)*(x10961)*(x10962)))+(((IkReal(-1.00000000000000))*(cj0)*(r00)*(x10966)))+(((r11)*(sj0)*(x10967)))+(((IkReal(-1.00000000000000))*(r10)*(sj0)*(x10966)))+(((IkReal(-1.00000000000000))*(r12)*(x10959)*(x10960)))+(((IkReal(-1.00000000000000))*(x10959)*(x10965)*(x10971)))+(((cj0)*(r01)*(x10967)))+(((IkReal(-1.00000000000000))*(cj0)*(r02)*(sj5)*(x10959))));
if( IKabs(evalcond[0]) > 0.000001  || IKabs(evalcond[1]) > 0.000001  || IKabs(evalcond[2]) > 0.000001  || IKabs(evalcond[3]) > 0.000001  )
{
continue;
}
}

{
std::vector<IkSingleDOFSolutionBase<IkReal> > vinfos(7);
vinfos[0].jointtype = 1;
vinfos[0].foffset = j0;
vinfos[0].indices[0] = _ij0[0];
vinfos[0].indices[1] = _ij0[1];
vinfos[0].maxsolutions = _nj0;
vinfos[1].jointtype = 1;
vinfos[1].foffset = j1;
vinfos[1].indices[0] = _ij1[0];
vinfos[1].indices[1] = _ij1[1];
vinfos[1].maxsolutions = _nj1;
vinfos[2].jointtype = 1;
vinfos[2].foffset = j2;
vinfos[2].indices[0] = _ij2[0];
vinfos[2].indices[1] = _ij2[1];
vinfos[2].maxsolutions = _nj2;
vinfos[3].jointtype = 1;
vinfos[3].foffset = j3;
vinfos[3].indices[0] = _ij3[0];
vinfos[3].indices[1] = _ij3[1];
vinfos[3].maxsolutions = _nj3;
vinfos[4].jointtype = 1;
vinfos[4].foffset = j4;
vinfos[4].indices[0] = _ij4[0];
vinfos[4].indices[1] = _ij4[1];
vinfos[4].maxsolutions = _nj4;
vinfos[5].jointtype = 1;
vinfos[5].foffset = j5;
vinfos[5].indices[0] = _ij5[0];
vinfos[5].indices[1] = _ij5[1];
vinfos[5].maxsolutions = _nj5;
vinfos[6].jointtype = 1;
vinfos[6].foffset = j6;
vinfos[6].indices[0] = _ij6[0];
vinfos[6].indices[1] = _ij6[1];
vinfos[6].maxsolutions = _nj6;
std::vector<int> vfree(0);
solutions.AddSolution(vinfos,vfree);
}
}
}

}

}

} else
{
IkReal x10978=((cj5)*(sj4));
IkReal x10979=((IkReal(1.00000000000000))*(sj6));
IkReal x10980=((r10)*(sj0));
IkReal x10981=((sj4)*(sj5));
IkReal x10982=((cj4)*(cj5));
IkReal x10983=((IkReal(1.00000000000000))*(r02));
IkReal x10984=((IkReal(0.374290000000000))*(cj0));
IkReal x10985=((cj5)*(r12));
IkReal x10986=((cj6)*(sj5));
IkReal x10987=((cj0)*(r11));
IkReal x10988=((cj5)*(sj0));
IkReal x10989=((r20)*(sj6));
IkReal x10990=((IkReal(1.00000000000000))*(sj0));
IkReal x10991=((IkReal(1.00000000000000))*(cj6));
IkReal x10992=((IkReal(0.0100000000000000))*(cj5));
IkReal x10993=((IkReal(0.0100000000000000))*(sj5));
IkReal x10994=((sj5)*(sj6));
IkReal x10995=((cj0)*(r10));
IkReal x10996=((cj4)*(cj6));
IkReal x10997=((cj0)*(r01));
IkReal x10998=((cj0)*(r00));
IkReal x10999=((cj6)*(r21));
IkReal x11000=((IkReal(0.374290000000000))*(sj0));
IkReal x11001=((IkReal(0.374290000000000))*(sj5));
IkReal x11002=((cj6)*(r11));
IkReal x11003=((sj0)*(sj4));
IkReal x11004=((cj4)*(sj5));
IkReal x11005=((cj4)*(sj6));
IkReal x11006=((IkReal(1.00000000000000))*(cj0));
IkReal x11007=((r02)*(sj0));
IkReal x11008=((r00)*(sj0)*(sj6));
IkReal x11009=((cj6)*(r01)*(sj0));
IkReal x11010=((r00)*(x10996));
IkReal x11011=((r12)*(x11006));
evalcond[0]=((IkReal(-3.14159265358979))+(IKfmod(j2, IkReal(6.28318530717959))));
evalcond[1]=((((IkReal(-1.00000000000000))*(cj4)*(r20)*(x10991)))+(((x10978)*(x10989)))+(((r21)*(x11005)))+(((r22)*(x10981)))+(((x10978)*(x10999))));
evalcond[2]=((((IkReal(0.364420000000000))*(sj1)))+(((IkReal(-0.0690000000000000))*(cj1)))+(((IkReal(-1.00000000000000))*(r22)*(x10993)))+(((IkReal(-0.374290000000000))*(cj5)*(r22)))+(pz)+(((IkReal(0.374290000000000))*(r21)*(x10986)))+(((IkReal(-1.00000000000000))*(x10992)*(x10999)))+(((x10989)*(x11001)))+(((IkReal(-1.00000000000000))*(x10989)*(x10992))));
evalcond[3]=((((cj0)*(x10985)))+(((r01)*(sj0)*(x10986)))+(((r00)*(sj0)*(x10994)))+(((IkReal(-1.00000000000000))*(sj5)*(x10979)*(x10995)))+(((IkReal(-1.00000000000000))*(x10986)*(x10987)))+(((IkReal(-1.00000000000000))*(x10983)*(x10988))));
evalcond[4]=((IkReal(-1.00000000000000))+(((IkReal(-1.00000000000000))*(cj4)*(x10979)*(x10987)))+(((x10981)*(x11007)))+(((IkReal(-1.00000000000000))*(x10981)*(x11011)))+(((x10995)*(x10996)))+(((IkReal(-1.00000000000000))*(x10990)*(x11010)))+(((x10978)*(x11008)))+(((r01)*(sj0)*(x11005)))+(((x10978)*(x11009)))+(((IkReal(-1.00000000000000))*(x10978)*(x10987)*(x10991)))+(((IkReal(-1.00000000000000))*(x10978)*(x10979)*(x10995))));
evalcond[5]=((((IkReal(-1.00000000000000))*(x11004)*(x11011)))+(((x10982)*(x11008)))+(((IkReal(-1.00000000000000))*(r01)*(x10979)*(x11003)))+(((IkReal(-1.00000000000000))*(x10982)*(x10987)*(x10991)))+(((IkReal(-1.00000000000000))*(sj4)*(x10991)*(x10995)))+(((sj4)*(sj6)*(x10987)))+(((x10982)*(x11009)))+(((x11004)*(x11007)))+(((cj6)*(r00)*(x11003)))+(((IkReal(-1.00000000000000))*(x10979)*(x10982)*(x10995))));
evalcond[6]=((((x10996)*(x10998)))+(((IkReal(-1.00000000000000))*(x10978)*(x10991)*(x10997)))+(((IkReal(-1.00000000000000))*(x10978)*(x10979)*(x10980)))+(((IkReal(-1.00000000000000))*(cj0)*(x10981)*(x10983)))+(((IkReal(-1.00000000000000))*(x10978)*(x10990)*(x11002)))+(((IkReal(-1.00000000000000))*(cj4)*(x10979)*(x10997)))+(((x10980)*(x10996)))+(((IkReal(-1.00000000000000))*(cj4)*(r11)*(sj0)*(x10979)))+(((IkReal(-1.00000000000000))*(r12)*(x10981)*(x10990)))+(((IkReal(-1.00000000000000))*(x10978)*(x10979)*(x10998))));
evalcond[7]=((((IkReal(-0.374290000000000))*(r02)*(x10988)))+(((r00)*(x10994)*(x11000)))+(((IkReal(-1.00000000000000))*(x10993)*(x11007)))+(((cj6)*(x10987)*(x10992)))+(((IkReal(-0.0100000000000000))*(r00)*(sj6)*(x10988)))+(((r01)*(x10986)*(x11000)))+(((IkReal(-1.00000000000000))*(r11)*(x10984)*(x10986)))+(((x10984)*(x10985)))+(((sj6)*(x10992)*(x10995)))+(((px)*(sj0)))+(((IkReal(-0.0100000000000000))*(cj6)*(r01)*(x10988)))+(((cj0)*(r12)*(x10993)))+(((IkReal(-1.00000000000000))*(r10)*(x10984)*(x10994)))+(((IkReal(-1.00000000000000))*(py)*(x11006))));
evalcond[8]=((IkReal(0.0690000000000000))+(((IkReal(-1.00000000000000))*(r01)*(x10984)*(x10986)))+(((IkReal(-1.00000000000000))*(px)*(x11006)))+(((IkReal(0.0100000000000000))*(x10988)*(x11002)))+(((IkReal(-1.00000000000000))*(r00)*(x10984)*(x10994)))+(((IkReal(0.0690000000000000))*(sj1)))+(((cj0)*(r02)*(x10993)))+(((cj6)*(x10992)*(x10997)))+(((IkReal(-1.00000000000000))*(py)*(x10990)))+(((sj6)*(x10980)*(x10992)))+(((r12)*(sj0)*(x10993)))+(((cj5)*(r02)*(x10984)))+(((IkReal(-0.374290000000000))*(x10980)*(x10994)))+(((x10985)*(x11000)))+(((sj6)*(x10992)*(x10998)))+(((IkReal(-1.00000000000000))*(r11)*(x10986)*(x11000)))+(((IkReal(0.364420000000000))*(cj1))));
if( IKabs(evalcond[0]) < 0.0000010000000000  && IKabs(evalcond[1]) < 0.0000010000000000  && IKabs(evalcond[2]) < 0.0000010000000000  && IKabs(evalcond[3]) < 0.0000010000000000  && IKabs(evalcond[4]) < 0.0000010000000000  && IKabs(evalcond[5]) < 0.0000010000000000  && IKabs(evalcond[6]) < 0.0000010000000000  && IKabs(evalcond[7]) < 0.0000010000000000  && IKabs(evalcond[8]) < 0.0000010000000000  )
{
{
IkReal dummyeval[1];
IkReal gconst7;
gconst7=IKsign((((cj1)*(cj1))+((sj1)*(sj1))));
dummyeval[0]=(((cj1)*(cj1))+((sj1)*(sj1)));
if( IKabs(dummyeval[0]) < 0.0000010000000000  )
{
{
IkReal dummyeval[1];
IkReal gconst8;
gconst8=IKsign((((cj1)*(cj1))+((sj1)*(sj1))));
dummyeval[0]=(((cj1)*(cj1))+((sj1)*(sj1)));
if( IKabs(dummyeval[0]) < 0.0000010000000000  )
{
continue;

} else
{
{
IkReal j3array[1], cj3array[1], sj3array[1];
bool j3valid[1]={false};
_nj3 = 1;
IkReal x11012=((IkReal(1.00000000000000))*(sj0));
IkReal x11013=((cj6)*(r21));
IkReal x11014=((cj0)*(r00));
IkReal x11015=((cj5)*(sj1));
IkReal x11016=((r12)*(sj0));
IkReal x11017=((cj1)*(cj5));
IkReal x11018=((cj0)*(r02));
IkReal x11019=((sj1)*(sj5));
IkReal x11020=((cj6)*(r11));
IkReal x11021=((cj1)*(sj5));
IkReal x11022=((sj6)*(x11019));
IkReal x11023=((IkReal(1.00000000000000))*(x11021));
IkReal x11024=((cj0)*(cj6)*(r01));
if( IKabs(((gconst8)*(((((IkReal(-1.00000000000000))*(r20)*(sj6)*(x11023)))+(((IkReal(-1.00000000000000))*(x11019)*(x11024)))+(((x11015)*(x11018)))+(((IkReal(-1.00000000000000))*(x11014)*(x11022)))+(((IkReal(-1.00000000000000))*(x11013)*(x11023)))+(((IkReal(-1.00000000000000))*(r10)*(x11012)*(x11022)))+(((IkReal(-1.00000000000000))*(x11012)*(x11019)*(x11020)))+(((r22)*(x11017)))+(((x11015)*(x11016))))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(((gconst8)*(((((IkReal(-1.00000000000000))*(x11012)*(x11020)*(x11021)))+(((x11016)*(x11017)))+(((r20)*(x11022)))+(((IkReal(-1.00000000000000))*(sj6)*(x11014)*(x11023)))+(((x11013)*(x11019)))+(((x11017)*(x11018)))+(((IkReal(-1.00000000000000))*(r10)*(sj6)*(x11012)*(x11021)))+(((IkReal(-1.00000000000000))*(r22)*(x11015)))+(((IkReal(-1.00000000000000))*(x11023)*(x11024))))))) < IKFAST_ATAN2_MAGTHRESH )
    continue;
j3array[0]=IKatan2(((gconst8)*(((((IkReal(-1.00000000000000))*(r20)*(sj6)*(x11023)))+(((IkReal(-1.00000000000000))*(x11019)*(x11024)))+(((x11015)*(x11018)))+(((IkReal(-1.00000000000000))*(x11014)*(x11022)))+(((IkReal(-1.00000000000000))*(x11013)*(x11023)))+(((IkReal(-1.00000000000000))*(r10)*(x11012)*(x11022)))+(((IkReal(-1.00000000000000))*(x11012)*(x11019)*(x11020)))+(((r22)*(x11017)))+(((x11015)*(x11016)))))), ((gconst8)*(((((IkReal(-1.00000000000000))*(x11012)*(x11020)*(x11021)))+(((x11016)*(x11017)))+(((r20)*(x11022)))+(((IkReal(-1.00000000000000))*(sj6)*(x11014)*(x11023)))+(((x11013)*(x11019)))+(((x11017)*(x11018)))+(((IkReal(-1.00000000000000))*(r10)*(sj6)*(x11012)*(x11021)))+(((IkReal(-1.00000000000000))*(r22)*(x11015)))+(((IkReal(-1.00000000000000))*(x11023)*(x11024)))))));
sj3array[0]=IKsin(j3array[0]);
cj3array[0]=IKcos(j3array[0]);
if( j3array[0] > IKPI )
{
    j3array[0]-=IK2PI;
}
else if( j3array[0] < -IKPI )
{    j3array[0]+=IK2PI;
}
j3valid[0] = true;
for(int ij3 = 0; ij3 < 1; ++ij3)
{
if( !j3valid[ij3] )
{
    continue;
}
_ij3[0] = ij3; _ij3[1] = -1;
for(int iij3 = ij3+1; iij3 < 1; ++iij3)
{
if( j3valid[iij3] && IKabs(cj3array[ij3]-cj3array[iij3]) < IKFAST_SOLUTION_THRESH && IKabs(sj3array[ij3]-sj3array[iij3]) < IKFAST_SOLUTION_THRESH )
{
    j3valid[iij3]=false; _ij3[1] = iij3; break; 
}
}
j3 = j3array[ij3]; cj3 = cj3array[ij3]; sj3 = sj3array[ij3];
{
IkReal evalcond[4];
IkReal x11025=IKsin(j3);
IkReal x11026=IKcos(j3);
IkReal x11027=((IkReal(1.00000000000000))*(cj4));
IkReal x11028=((sj0)*(sj5));
IkReal x11029=((cj0)*(cj5));
IkReal x11030=((cj6)*(r01));
IkReal x11031=((r00)*(sj6));
IkReal x11032=((cj6)*(r11));
IkReal x11033=((cj5)*(sj0));
IkReal x11034=((cj6)*(sj4));
IkReal x11035=((sj4)*(sj6));
IkReal x11036=((cj4)*(cj5));
IkReal x11037=((cj6)*(r21));
IkReal x11038=((r20)*(sj6));
IkReal x11039=((r10)*(sj6));
IkReal x11040=((cj1)*(x11025));
IkReal x11041=((IkReal(1.00000000000000))*(cj0)*(sj5));
IkReal x11042=((IkReal(1.00000000000000))*(x11026));
IkReal x11043=((IkReal(1.00000000000000))*(sj1)*(x11025));
IkReal x11044=((cj1)*(x11042));
IkReal x11045=((x11044)+(x11043));
evalcond[0]=((((IkReal(-1.00000000000000))*(sj1)*(x11042)))+(((sj5)*(x11037)))+(((sj5)*(x11038)))+(((IkReal(-1.00000000000000))*(cj5)*(r22)))+(x11040));
evalcond[1]=((((IkReal(-1.00000000000000))*(r21)*(x11035)))+(((r20)*(x11034)))+(((cj4)*(r22)*(sj5)))+(((IkReal(-1.00000000000000))*(x11045)))+(((x11036)*(x11037)))+(((x11036)*(x11038))));
evalcond[2]=((((IkReal(-1.00000000000000))*(x11028)*(x11039)))+(((r02)*(x11029)))+(((IkReal(-1.00000000000000))*(x11028)*(x11032)))+(((r12)*(x11033)))+(((IkReal(-1.00000000000000))*(x11045)))+(((IkReal(-1.00000000000000))*(x11031)*(x11041)))+(((IkReal(-1.00000000000000))*(x11030)*(x11041))));
evalcond[3]=((((IkReal(-1.00000000000000))*(r12)*(x11027)*(x11028)))+(((sj1)*(x11026)))+(((IkReal(-1.00000000000000))*(cj0)*(r00)*(x11034)))+(((IkReal(-1.00000000000000))*(x11027)*(x11029)*(x11030)))+(((IkReal(-1.00000000000000))*(r10)*(sj0)*(x11034)))+(((IkReal(-1.00000000000000))*(cj0)*(r02)*(sj5)*(x11027)))+(((IkReal(-1.00000000000000))*(x11027)*(x11032)*(x11033)))+(((IkReal(-1.00000000000000))*(x11040)))+(((IkReal(-1.00000000000000))*(x11027)*(x11033)*(x11039)))+(((IkReal(-1.00000000000000))*(x11027)*(x11029)*(x11031)))+(((r11)*(sj0)*(x11035)))+(((cj0)*(r01)*(x11035))));
if( IKabs(evalcond[0]) > 0.000001  || IKabs(evalcond[1]) > 0.000001  || IKabs(evalcond[2]) > 0.000001  || IKabs(evalcond[3]) > 0.000001  )
{
continue;
}
}

{
std::vector<IkSingleDOFSolutionBase<IkReal> > vinfos(7);
vinfos[0].jointtype = 1;
vinfos[0].foffset = j0;
vinfos[0].indices[0] = _ij0[0];
vinfos[0].indices[1] = _ij0[1];
vinfos[0].maxsolutions = _nj0;
vinfos[1].jointtype = 1;
vinfos[1].foffset = j1;
vinfos[1].indices[0] = _ij1[0];
vinfos[1].indices[1] = _ij1[1];
vinfos[1].maxsolutions = _nj1;
vinfos[2].jointtype = 1;
vinfos[2].foffset = j2;
vinfos[2].indices[0] = _ij2[0];
vinfos[2].indices[1] = _ij2[1];
vinfos[2].maxsolutions = _nj2;
vinfos[3].jointtype = 1;
vinfos[3].foffset = j3;
vinfos[3].indices[0] = _ij3[0];
vinfos[3].indices[1] = _ij3[1];
vinfos[3].maxsolutions = _nj3;
vinfos[4].jointtype = 1;
vinfos[4].foffset = j4;
vinfos[4].indices[0] = _ij4[0];
vinfos[4].indices[1] = _ij4[1];
vinfos[4].maxsolutions = _nj4;
vinfos[5].jointtype = 1;
vinfos[5].foffset = j5;
vinfos[5].indices[0] = _ij5[0];
vinfos[5].indices[1] = _ij5[1];
vinfos[5].maxsolutions = _nj5;
vinfos[6].jointtype = 1;
vinfos[6].foffset = j6;
vinfos[6].indices[0] = _ij6[0];
vinfos[6].indices[1] = _ij6[1];
vinfos[6].maxsolutions = _nj6;
std::vector<int> vfree(0);
solutions.AddSolution(vinfos,vfree);
}
}
}

}

}

} else
{
{
IkReal j3array[1], cj3array[1], sj3array[1];
bool j3valid[1]={false};
_nj3 = 1;
IkReal x11046=((sj1)*(sj6));
IkReal x11047=((r20)*(sj5));
IkReal x11048=((IkReal(1.00000000000000))*(r21));
IkReal x11049=((cj1)*(cj6));
IkReal x11050=((r20)*(sj4));
IkReal x11051=((cj6)*(sj1));
IkReal x11052=((cj4)*(cj5));
IkReal x11053=((cj1)*(sj6));
IkReal x11054=((cj5)*(r22));
IkReal x11055=((cj4)*(r22)*(sj5));
if( IKabs(((gconst7)*(((((r20)*(x11046)*(x11052)))+(((sj1)*(x11055)))+(((r21)*(x11051)*(x11052)))+(((IkReal(-1.00000000000000))*(sj4)*(x11046)*(x11048)))+(((IkReal(-1.00000000000000))*(sj5)*(x11048)*(x11049)))+(((cj1)*(x11054)))+(((x11050)*(x11051)))+(((IkReal(-1.00000000000000))*(x11047)*(x11053))))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(((gconst7)*(((((r21)*(x11049)*(x11052)))+(((x11049)*(x11050)))+(((x11046)*(x11047)))+(((cj1)*(x11055)))+(((r21)*(sj5)*(x11051)))+(((IkReal(-1.00000000000000))*(sj1)*(x11054)))+(((IkReal(-1.00000000000000))*(sj4)*(x11048)*(x11053)))+(((r20)*(x11052)*(x11053))))))) < IKFAST_ATAN2_MAGTHRESH )
    continue;
j3array[0]=IKatan2(((gconst7)*(((((r20)*(x11046)*(x11052)))+(((sj1)*(x11055)))+(((r21)*(x11051)*(x11052)))+(((IkReal(-1.00000000000000))*(sj4)*(x11046)*(x11048)))+(((IkReal(-1.00000000000000))*(sj5)*(x11048)*(x11049)))+(((cj1)*(x11054)))+(((x11050)*(x11051)))+(((IkReal(-1.00000000000000))*(x11047)*(x11053)))))), ((gconst7)*(((((r21)*(x11049)*(x11052)))+(((x11049)*(x11050)))+(((x11046)*(x11047)))+(((cj1)*(x11055)))+(((r21)*(sj5)*(x11051)))+(((IkReal(-1.00000000000000))*(sj1)*(x11054)))+(((IkReal(-1.00000000000000))*(sj4)*(x11048)*(x11053)))+(((r20)*(x11052)*(x11053)))))));
sj3array[0]=IKsin(j3array[0]);
cj3array[0]=IKcos(j3array[0]);
if( j3array[0] > IKPI )
{
    j3array[0]-=IK2PI;
}
else if( j3array[0] < -IKPI )
{    j3array[0]+=IK2PI;
}
j3valid[0] = true;
for(int ij3 = 0; ij3 < 1; ++ij3)
{
if( !j3valid[ij3] )
{
    continue;
}
_ij3[0] = ij3; _ij3[1] = -1;
for(int iij3 = ij3+1; iij3 < 1; ++iij3)
{
if( j3valid[iij3] && IKabs(cj3array[ij3]-cj3array[iij3]) < IKFAST_SOLUTION_THRESH && IKabs(sj3array[ij3]-sj3array[iij3]) < IKFAST_SOLUTION_THRESH )
{
    j3valid[iij3]=false; _ij3[1] = iij3; break; 
}
}
j3 = j3array[ij3]; cj3 = cj3array[ij3]; sj3 = sj3array[ij3];
{
IkReal evalcond[4];
IkReal x11056=IKsin(j3);
IkReal x11057=IKcos(j3);
IkReal x11058=((IkReal(1.00000000000000))*(cj4));
IkReal x11059=((sj0)*(sj5));
IkReal x11060=((cj0)*(cj5));
IkReal x11061=((cj6)*(r01));
IkReal x11062=((r00)*(sj6));
IkReal x11063=((cj6)*(r11));
IkReal x11064=((cj5)*(sj0));
IkReal x11065=((cj6)*(sj4));
IkReal x11066=((sj4)*(sj6));
IkReal x11067=((cj4)*(cj5));
IkReal x11068=((cj6)*(r21));
IkReal x11069=((r20)*(sj6));
IkReal x11070=((r10)*(sj6));
IkReal x11071=((cj1)*(x11056));
IkReal x11072=((IkReal(1.00000000000000))*(cj0)*(sj5));
IkReal x11073=((IkReal(1.00000000000000))*(x11057));
IkReal x11074=((IkReal(1.00000000000000))*(sj1)*(x11056));
IkReal x11075=((cj1)*(x11073));
IkReal x11076=((x11074)+(x11075));
evalcond[0]=((x11071)+(((sj5)*(x11068)))+(((IkReal(-1.00000000000000))*(cj5)*(r22)))+(((sj5)*(x11069)))+(((IkReal(-1.00000000000000))*(sj1)*(x11073))));
evalcond[1]=((((x11067)*(x11069)))+(((IkReal(-1.00000000000000))*(x11076)))+(((cj4)*(r22)*(sj5)))+(((r20)*(x11065)))+(((x11067)*(x11068)))+(((IkReal(-1.00000000000000))*(r21)*(x11066))));
evalcond[2]=((((IkReal(-1.00000000000000))*(x11061)*(x11072)))+(((IkReal(-1.00000000000000))*(x11062)*(x11072)))+(((IkReal(-1.00000000000000))*(x11059)*(x11063)))+(((IkReal(-1.00000000000000))*(x11076)))+(((r02)*(x11060)))+(((IkReal(-1.00000000000000))*(x11059)*(x11070)))+(((r12)*(x11064))));
evalcond[3]=((((IkReal(-1.00000000000000))*(x11058)*(x11063)*(x11064)))+(((IkReal(-1.00000000000000))*(x11058)*(x11064)*(x11070)))+(((cj0)*(r01)*(x11066)))+(((IkReal(-1.00000000000000))*(cj0)*(r00)*(x11065)))+(((r11)*(sj0)*(x11066)))+(((IkReal(-1.00000000000000))*(cj0)*(r02)*(sj5)*(x11058)))+(((IkReal(-1.00000000000000))*(x11058)*(x11060)*(x11062)))+(((IkReal(-1.00000000000000))*(x11058)*(x11060)*(x11061)))+(((IkReal(-1.00000000000000))*(r12)*(x11058)*(x11059)))+(((IkReal(-1.00000000000000))*(r10)*(sj0)*(x11065)))+(((sj1)*(x11057)))+(((IkReal(-1.00000000000000))*(x11071))));
if( IKabs(evalcond[0]) > 0.000001  || IKabs(evalcond[1]) > 0.000001  || IKabs(evalcond[2]) > 0.000001  || IKabs(evalcond[3]) > 0.000001  )
{
continue;
}
}

{
std::vector<IkSingleDOFSolutionBase<IkReal> > vinfos(7);
vinfos[0].jointtype = 1;
vinfos[0].foffset = j0;
vinfos[0].indices[0] = _ij0[0];
vinfos[0].indices[1] = _ij0[1];
vinfos[0].maxsolutions = _nj0;
vinfos[1].jointtype = 1;
vinfos[1].foffset = j1;
vinfos[1].indices[0] = _ij1[0];
vinfos[1].indices[1] = _ij1[1];
vinfos[1].maxsolutions = _nj1;
vinfos[2].jointtype = 1;
vinfos[2].foffset = j2;
vinfos[2].indices[0] = _ij2[0];
vinfos[2].indices[1] = _ij2[1];
vinfos[2].maxsolutions = _nj2;
vinfos[3].jointtype = 1;
vinfos[3].foffset = j3;
vinfos[3].indices[0] = _ij3[0];
vinfos[3].indices[1] = _ij3[1];
vinfos[3].maxsolutions = _nj3;
vinfos[4].jointtype = 1;
vinfos[4].foffset = j4;
vinfos[4].indices[0] = _ij4[0];
vinfos[4].indices[1] = _ij4[1];
vinfos[4].maxsolutions = _nj4;
vinfos[5].jointtype = 1;
vinfos[5].foffset = j5;
vinfos[5].indices[0] = _ij5[0];
vinfos[5].indices[1] = _ij5[1];
vinfos[5].maxsolutions = _nj5;
vinfos[6].jointtype = 1;
vinfos[6].foffset = j6;
vinfos[6].indices[0] = _ij6[0];
vinfos[6].indices[1] = _ij6[1];
vinfos[6].maxsolutions = _nj6;
std::vector<int> vfree(0);
solutions.AddSolution(vinfos,vfree);
}
}
}

}

}

} else
{
IkReal x11077=((IkReal(1.00000000000000))*(cj0));
IkReal x11078=((cj4)*(sj6));
IkReal x11079=((sj0)*(sj4));
IkReal x11080=((cj5)*(sj6));
IkReal x11081=((sj4)*(sj5));
IkReal x11082=((r12)*(sj5));
IkReal x11083=((IkReal(0.374290000000000))*(cj5));
IkReal x11084=((r02)*(sj0));
IkReal x11085=((cj6)*(r21));
IkReal x11086=((IkReal(0.0100000000000000))*(cj5));
IkReal x11087=((IkReal(1.00000000000000))*(sj0));
IkReal x11088=((cj0)*(r10));
IkReal x11089=((cj4)*(cj6));
IkReal x11090=((r00)*(sj0));
IkReal x11091=((IkReal(0.374290000000000))*(sj5));
IkReal x11092=((cj0)*(r00));
IkReal x11093=((IkReal(0.0100000000000000))*(sj5));
IkReal x11094=((cj0)*(r02));
IkReal x11095=((cj5)*(sj4));
IkReal x11096=((cj6)*(r01));
IkReal x11097=((cj6)*(r11));
IkReal x11098=((r10)*(sj0));
IkReal x11099=((sj6)*(x11091));
IkReal x11100=((cj0)*(cj6)*(x11091));
evalcond[0]=((IkReal(-3.14159265358979))+(IKfmod(((IkReal(3.14159265358979))+(j1)), IkReal(6.28318530717959))));
evalcond[1]=((((IkReal(-1.00000000000000))*(sj2)))+(((r21)*(x11078)))+(((r22)*(x11081)))+(((r20)*(sj4)*(x11080)))+(((x11085)*(x11095)))+(((IkReal(-1.00000000000000))*(r20)*(x11089))));
evalcond[2]=((((r20)*(x11099)))+(((IkReal(-1.00000000000000))*(r22)*(x11083)))+(((IkReal(-0.0100000000000000))*(r20)*(x11080)))+(pz)+(((IkReal(0.0690000000000000))*(cj2)))+(((x11085)*(x11091)))+(((IkReal(-1.00000000000000))*(r22)*(x11093)))+(((IkReal(-1.00000000000000))*(x11085)*(x11086))));
evalcond[3]=((((cj5)*(x11079)*(x11096)))+(((IkReal(-1.00000000000000))*(r12)*(x11077)*(x11081)))+(((IkReal(-1.00000000000000))*(r10)*(sj4)*(x11077)*(x11080)))+(((r02)*(sj5)*(x11079)))+(((IkReal(-1.00000000000000))*(r11)*(x11077)*(x11078)))+(cj2)+(((IkReal(-1.00000000000000))*(r00)*(x11087)*(x11089)))+(((r01)*(sj0)*(x11078)))+(((r00)*(x11079)*(x11080)))+(((IkReal(-1.00000000000000))*(x11077)*(x11095)*(x11097)))+(((x11088)*(x11089))));
evalcond[4]=((((IkReal(-1.00000000000000))*(x11077)*(x11095)*(x11096)))+(((IkReal(-1.00000000000000))*(r11)*(x11078)*(x11087)))+(((IkReal(-1.00000000000000))*(r10)*(x11079)*(x11080)))+(((IkReal(-1.00000000000000))*(r02)*(x11077)*(x11081)))+(((x11089)*(x11098)))+(((x11089)*(x11092)))+(((IkReal(-1.00000000000000))*(x11079)*(x11082)))+(((IkReal(-1.00000000000000))*(r00)*(sj4)*(x11077)*(x11080)))+(((IkReal(-1.00000000000000))*(r01)*(x11077)*(x11078)))+(((IkReal(-1.00000000000000))*(cj5)*(x11079)*(x11097))));
evalcond[5]=((((cj0)*(x11086)*(x11097)))+(((IkReal(-1.00000000000000))*(x11083)*(x11084)))+(((IkReal(0.0690000000000000))*(sj2)))+(((IkReal(0.0100000000000000))*(cj0)*(x11082)))+(((IkReal(-1.00000000000000))*(sj0)*(x11086)*(x11096)))+(((cj0)*(r12)*(x11083)))+(((IkReal(-1.00000000000000))*(x11084)*(x11093)))+(((IkReal(-1.00000000000000))*(x11088)*(x11099)))+(((IkReal(-1.00000000000000))*(cj0)*(x11091)*(x11097)))+(((IkReal(0.0100000000000000))*(x11080)*(x11088)))+(((x11090)*(x11099)))+(((IkReal(-0.0100000000000000))*(x11080)*(x11090)))+(((px)*(sj0)))+(((sj0)*(x11091)*(x11096)))+(((IkReal(-1.00000000000000))*(py)*(x11077))));
evalcond[6]=((IkReal(0.433420000000000))+(((IkReal(-1.00000000000000))*(py)*(x11087)))+(((IkReal(-1.00000000000000))*(x11092)*(x11099)))+(((sj0)*(x11086)*(x11097)))+(((r12)*(sj0)*(x11083)))+(((x11083)*(x11094)))+(((x11093)*(x11094)))+(((IkReal(-1.00000000000000))*(px)*(x11077)))+(((IkReal(-1.00000000000000))*(sj0)*(x11091)*(x11097)))+(((IkReal(0.0100000000000000))*(x11080)*(x11098)))+(((IkReal(0.0100000000000000))*(sj0)*(x11082)))+(((cj0)*(x11086)*(x11096)))+(((IkReal(-1.00000000000000))*(cj0)*(x11091)*(x11096)))+(((IkReal(-1.00000000000000))*(x11098)*(x11099)))+(((IkReal(0.0100000000000000))*(x11080)*(x11092))));
if( IKabs(evalcond[0]) < 0.0000010000000000  && IKabs(evalcond[1]) < 0.0000010000000000  && IKabs(evalcond[2]) < 0.0000010000000000  && IKabs(evalcond[3]) < 0.0000010000000000  && IKabs(evalcond[4]) < 0.0000010000000000  && IKabs(evalcond[5]) < 0.0000010000000000  && IKabs(evalcond[6]) < 0.0000010000000000  )
{
{
IkReal dummyeval[1];
IkReal gconst9;
gconst9=IKsign(cj2);
dummyeval[0]=cj2;
if( IKabs(dummyeval[0]) < 0.0000010000000000  )
{
{
IkReal dummyeval[1];
dummyeval[0]=cj2;
if( IKabs(dummyeval[0]) < 0.0000010000000000  )
{
{
IkReal dummyeval[1];
dummyeval[0]=sj2;
if( IKabs(dummyeval[0]) < 0.0000010000000000  )
{
{
IkReal evalcond[9];
IkReal x11101=((cj5)*(sj4));
IkReal x11102=((IkReal(1.00000000000000))*(sj6));
IkReal x11103=((r10)*(sj0));
IkReal x11104=((sj4)*(sj5));
IkReal x11105=((cj5)*(cj6));
IkReal x11106=((r01)*(sj0));
IkReal x11107=((IkReal(1.00000000000000))*(r02));
IkReal x11108=((IkReal(0.374290000000000))*(cj0));
IkReal x11109=((cj5)*(r12));
IkReal x11110=((cj6)*(sj5));
IkReal x11111=((cj0)*(r11));
IkReal x11112=((cj5)*(sj0));
IkReal x11113=((r20)*(sj6));
IkReal x11114=((IkReal(1.00000000000000))*(sj0));
IkReal x11115=((cj4)*(cj5));
IkReal x11116=((IkReal(1.00000000000000))*(cj6));
IkReal x11117=((IkReal(0.0100000000000000))*(sj5));
IkReal x11118=((sj5)*(sj6));
IkReal x11119=((cj0)*(r10));
IkReal x11120=((cj4)*(cj6));
IkReal x11121=((cj0)*(r01));
IkReal x11122=((IkReal(1.00000000000000))*(cj4));
IkReal x11123=((cj0)*(r00));
IkReal x11124=((IkReal(0.374290000000000))*(sj0));
IkReal x11125=((cj0)*(r12));
IkReal x11126=((IkReal(0.374290000000000))*(sj5));
IkReal x11127=((cj4)*(sj6));
IkReal x11128=((IkReal(1.00000000000000))*(cj0));
IkReal x11129=((r02)*(sj0));
IkReal x11130=((IkReal(0.0100000000000000))*(cj5));
IkReal x11131=((r11)*(sj0));
IkReal x11132=((r00)*(sj0)*(sj6));
IkReal x11133=((r00)*(x11120));
IkReal x11134=((sj6)*(x11130));
evalcond[0]=((IkReal(-3.14159265358979))+(IKfmod(((IkReal(3.14159265358979))+(j2)), IkReal(6.28318530717959))));
evalcond[1]=((((r21)*(x11127)))+(((r22)*(x11104)))+(((x11101)*(x11113)))+(((IkReal(-1.00000000000000))*(cj4)*(r20)*(x11116)))+(((cj6)*(r21)*(x11101))));
evalcond[2]=((IkReal(0.0690000000000000))+(((IkReal(-1.00000000000000))*(x11113)*(x11130)))+(((x11113)*(x11126)))+(((IkReal(-0.374290000000000))*(cj5)*(r22)))+(((IkReal(0.374290000000000))*(r21)*(x11110)))+(pz)+(((IkReal(-0.0100000000000000))*(r21)*(x11105)))+(((IkReal(-1.00000000000000))*(r22)*(x11117))));
evalcond[3]=((((x11106)*(x11110)))+(((IkReal(-1.00000000000000))*(sj5)*(x11102)*(x11119)))+(((cj0)*(x11109)))+(((r00)*(sj0)*(x11118)))+(((IkReal(-1.00000000000000))*(x11107)*(x11112)))+(((IkReal(-1.00000000000000))*(x11110)*(x11111))));
evalcond[4]=((IkReal(1.00000000000000))+(((IkReal(-1.00000000000000))*(x11101)*(x11111)*(x11116)))+(((IkReal(-1.00000000000000))*(x11101)*(x11102)*(x11119)))+(((x11119)*(x11120)))+(((IkReal(-1.00000000000000))*(cj4)*(x11102)*(x11111)))+(((IkReal(-1.00000000000000))*(x11114)*(x11133)))+(((x11101)*(x11132)))+(((x11104)*(x11129)))+(((cj6)*(x11101)*(x11106)))+(((x11106)*(x11127)))+(((IkReal(-1.00000000000000))*(x11104)*(x11125))));
evalcond[5]=((((cj4)*(x11105)*(x11106)))+(((cj4)*(sj5)*(x11129)))+(((cj6)*(r00)*(sj0)*(sj4)))+(((IkReal(-1.00000000000000))*(sj4)*(x11116)*(x11119)))+(((IkReal(-1.00000000000000))*(sj5)*(x11122)*(x11125)))+(((IkReal(-1.00000000000000))*(x11105)*(x11111)*(x11122)))+(((sj4)*(sj6)*(x11111)))+(((r00)*(x11112)*(x11127)))+(((IkReal(-1.00000000000000))*(sj4)*(x11102)*(x11106)))+(((IkReal(-1.00000000000000))*(x11102)*(x11115)*(x11119))));
evalcond[6]=((((IkReal(-1.00000000000000))*(cj4)*(x11102)*(x11121)))+(((IkReal(-1.00000000000000))*(x11101)*(x11116)*(x11121)))+(((IkReal(-1.00000000000000))*(cj0)*(x11104)*(x11107)))+(((IkReal(-1.00000000000000))*(x11101)*(x11102)*(x11103)))+(((IkReal(-1.00000000000000))*(cj6)*(r11)*(x11101)*(x11114)))+(((IkReal(-1.00000000000000))*(r12)*(x11104)*(x11114)))+(((IkReal(-1.00000000000000))*(cj4)*(x11102)*(x11131)))+(((x11103)*(x11120)))+(((x11120)*(x11123)))+(((IkReal(-1.00000000000000))*(x11101)*(x11102)*(x11123))));
evalcond[7]=((((x11117)*(x11125)))+(((IkReal(-1.00000000000000))*(x11117)*(x11129)))+(((IkReal(0.0100000000000000))*(x11105)*(x11111)))+(((x11119)*(x11134)))+(((IkReal(-1.00000000000000))*(r10)*(x11108)*(x11118)))+(((x11108)*(x11109)))+(((IkReal(-1.00000000000000))*(r11)*(x11108)*(x11110)))+(((IkReal(-0.0100000000000000))*(x11105)*(x11106)))+(((r00)*(x11118)*(x11124)))+(((IkReal(0.374290000000000))*(x11106)*(x11110)))+(((px)*(sj0)))+(((IkReal(-0.0100000000000000))*(r00)*(sj6)*(x11112)))+(((IkReal(-1.00000000000000))*(py)*(x11128)))+(((IkReal(-0.374290000000000))*(r02)*(x11112))));
evalcond[8]=((IkReal(0.433420000000000))+(((IkReal(0.0100000000000000))*(x11105)*(x11121)))+(((r12)*(sj0)*(x11117)))+(((IkReal(-1.00000000000000))*(r00)*(x11108)*(x11118)))+(((IkReal(-1.00000000000000))*(r11)*(x11110)*(x11124)))+(((IkReal(-1.00000000000000))*(px)*(x11128)))+(((x11123)*(x11134)))+(((x11103)*(x11134)))+(((IkReal(-1.00000000000000))*(r01)*(x11108)*(x11110)))+(((cj5)*(r02)*(x11108)))+(((IkReal(0.0100000000000000))*(x11105)*(x11131)))+(((x11109)*(x11124)))+(((cj0)*(r02)*(x11117)))+(((IkReal(-0.374290000000000))*(x11103)*(x11118)))+(((IkReal(-1.00000000000000))*(py)*(x11114))));
if( IKabs(evalcond[0]) < 0.0000010000000000  && IKabs(evalcond[1]) < 0.0000010000000000  && IKabs(evalcond[2]) < 0.0000010000000000  && IKabs(evalcond[3]) < 0.0000010000000000  && IKabs(evalcond[4]) < 0.0000010000000000  && IKabs(evalcond[5]) < 0.0000010000000000  && IKabs(evalcond[6]) < 0.0000010000000000  && IKabs(evalcond[7]) < 0.0000010000000000  && IKabs(evalcond[8]) < 0.0000010000000000  )
{
{
IkReal j3array[1], cj3array[1], sj3array[1];
bool j3valid[1]={false};
_nj3 = 1;
IkReal x11135=((IkReal(1.00000000000000))*(cj4));
IkReal x11136=((cj6)*(r21));
IkReal x11137=((r20)*(sj6));
if( IKabs(((((IkReal(-1.00000000000000))*(cj5)*(r22)))+(((sj5)*(x11136)))+(((sj5)*(x11137))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(((((IkReal(-1.00000000000000))*(r22)*(sj5)*(x11135)))+(((IkReal(-1.00000000000000))*(cj5)*(x11135)*(x11136)))+(((r21)*(sj4)*(sj6)))+(((IkReal(-1.00000000000000))*(cj5)*(x11135)*(x11137)))+(((IkReal(-1.00000000000000))*(cj6)*(r20)*(sj4))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(IKsqr(((((IkReal(-1.00000000000000))*(cj5)*(r22)))+(((sj5)*(x11136)))+(((sj5)*(x11137)))))+IKsqr(((((IkReal(-1.00000000000000))*(r22)*(sj5)*(x11135)))+(((IkReal(-1.00000000000000))*(cj5)*(x11135)*(x11136)))+(((r21)*(sj4)*(sj6)))+(((IkReal(-1.00000000000000))*(cj5)*(x11135)*(x11137)))+(((IkReal(-1.00000000000000))*(cj6)*(r20)*(sj4)))))-1) <= IKFAST_SINCOS_THRESH )
    continue;
j3array[0]=IKatan2(((((IkReal(-1.00000000000000))*(cj5)*(r22)))+(((sj5)*(x11136)))+(((sj5)*(x11137)))), ((((IkReal(-1.00000000000000))*(r22)*(sj5)*(x11135)))+(((IkReal(-1.00000000000000))*(cj5)*(x11135)*(x11136)))+(((r21)*(sj4)*(sj6)))+(((IkReal(-1.00000000000000))*(cj5)*(x11135)*(x11137)))+(((IkReal(-1.00000000000000))*(cj6)*(r20)*(sj4)))));
sj3array[0]=IKsin(j3array[0]);
cj3array[0]=IKcos(j3array[0]);
if( j3array[0] > IKPI )
{
    j3array[0]-=IK2PI;
}
else if( j3array[0] < -IKPI )
{    j3array[0]+=IK2PI;
}
j3valid[0] = true;
for(int ij3 = 0; ij3 < 1; ++ij3)
{
if( !j3valid[ij3] )
{
    continue;
}
_ij3[0] = ij3; _ij3[1] = -1;
for(int iij3 = ij3+1; iij3 < 1; ++iij3)
{
if( j3valid[iij3] && IKabs(cj3array[ij3]-cj3array[iij3]) < IKFAST_SOLUTION_THRESH && IKabs(sj3array[ij3]-sj3array[iij3]) < IKFAST_SOLUTION_THRESH )
{
    j3valid[iij3]=false; _ij3[1] = iij3; break; 
}
}
j3 = j3array[ij3]; cj3 = cj3array[ij3]; sj3 = sj3array[ij3];
{
IkReal evalcond[4];
IkReal x11138=IKcos(j3);
IkReal x11139=((IkReal(1.00000000000000))*(cj4));
IkReal x11140=((sj0)*(sj5));
IkReal x11141=((cj0)*(cj5));
IkReal x11142=((cj6)*(r01));
IkReal x11143=((r00)*(sj6));
IkReal x11144=((cj6)*(r11));
IkReal x11145=((cj5)*(sj0));
IkReal x11146=((cj6)*(sj4));
IkReal x11147=((sj4)*(sj6));
IkReal x11148=((cj4)*(cj5));
IkReal x11149=((cj6)*(r21));
IkReal x11150=((r20)*(sj6));
IkReal x11151=((r10)*(sj6));
IkReal x11152=((IkReal(1.00000000000000))*(IKsin(j3)));
IkReal x11153=((IkReal(1.00000000000000))*(cj0)*(sj5));
evalcond[0]=((((IkReal(-1.00000000000000))*(x11152)))+(((IkReal(-1.00000000000000))*(cj5)*(r22)))+(((sj5)*(x11149)))+(((sj5)*(x11150))));
evalcond[1]=((((x11148)*(x11149)))+(((x11148)*(x11150)))+(((cj4)*(r22)*(sj5)))+(((r20)*(x11146)))+(((IkReal(-1.00000000000000))*(r21)*(x11147)))+(x11138));
evalcond[2]=((((IkReal(-1.00000000000000))*(x11138)))+(((r02)*(x11141)))+(((IkReal(-1.00000000000000))*(x11140)*(x11144)))+(((IkReal(-1.00000000000000))*(x11142)*(x11153)))+(((r12)*(x11145)))+(((IkReal(-1.00000000000000))*(x11143)*(x11153)))+(((IkReal(-1.00000000000000))*(x11140)*(x11151))));
evalcond[3]=((((IkReal(-1.00000000000000))*(x11139)*(x11141)*(x11142)))+(((IkReal(-1.00000000000000))*(x11139)*(x11141)*(x11143)))+(((IkReal(-1.00000000000000))*(cj0)*(r00)*(x11146)))+(((IkReal(-1.00000000000000))*(x11152)))+(((r11)*(sj0)*(x11147)))+(((cj0)*(r01)*(x11147)))+(((IkReal(-1.00000000000000))*(cj0)*(r02)*(sj5)*(x11139)))+(((IkReal(-1.00000000000000))*(x11139)*(x11145)*(x11151)))+(((IkReal(-1.00000000000000))*(r12)*(x11139)*(x11140)))+(((IkReal(-1.00000000000000))*(x11139)*(x11144)*(x11145)))+(((IkReal(-1.00000000000000))*(r10)*(sj0)*(x11146))));
if( IKabs(evalcond[0]) > 0.000001  || IKabs(evalcond[1]) > 0.000001  || IKabs(evalcond[2]) > 0.000001  || IKabs(evalcond[3]) > 0.000001  )
{
continue;
}
}

{
std::vector<IkSingleDOFSolutionBase<IkReal> > vinfos(7);
vinfos[0].jointtype = 1;
vinfos[0].foffset = j0;
vinfos[0].indices[0] = _ij0[0];
vinfos[0].indices[1] = _ij0[1];
vinfos[0].maxsolutions = _nj0;
vinfos[1].jointtype = 1;
vinfos[1].foffset = j1;
vinfos[1].indices[0] = _ij1[0];
vinfos[1].indices[1] = _ij1[1];
vinfos[1].maxsolutions = _nj1;
vinfos[2].jointtype = 1;
vinfos[2].foffset = j2;
vinfos[2].indices[0] = _ij2[0];
vinfos[2].indices[1] = _ij2[1];
vinfos[2].maxsolutions = _nj2;
vinfos[3].jointtype = 1;
vinfos[3].foffset = j3;
vinfos[3].indices[0] = _ij3[0];
vinfos[3].indices[1] = _ij3[1];
vinfos[3].maxsolutions = _nj3;
vinfos[4].jointtype = 1;
vinfos[4].foffset = j4;
vinfos[4].indices[0] = _ij4[0];
vinfos[4].indices[1] = _ij4[1];
vinfos[4].maxsolutions = _nj4;
vinfos[5].jointtype = 1;
vinfos[5].foffset = j5;
vinfos[5].indices[0] = _ij5[0];
vinfos[5].indices[1] = _ij5[1];
vinfos[5].maxsolutions = _nj5;
vinfos[6].jointtype = 1;
vinfos[6].foffset = j6;
vinfos[6].indices[0] = _ij6[0];
vinfos[6].indices[1] = _ij6[1];
vinfos[6].maxsolutions = _nj6;
std::vector<int> vfree(0);
solutions.AddSolution(vinfos,vfree);
}
}
}

} else
{
IkReal x11154=((cj5)*(sj4));
IkReal x11155=((IkReal(1.00000000000000))*(sj6));
IkReal x11156=((r10)*(sj0));
IkReal x11157=((sj4)*(sj5));
IkReal x11158=((cj5)*(cj6));
IkReal x11159=((r01)*(sj0));
IkReal x11160=((IkReal(1.00000000000000))*(r02));
IkReal x11161=((IkReal(0.374290000000000))*(cj0));
IkReal x11162=((cj5)*(r12));
IkReal x11163=((cj6)*(sj5));
IkReal x11164=((cj0)*(r11));
IkReal x11165=((cj5)*(sj0));
IkReal x11166=((r20)*(sj6));
IkReal x11167=((IkReal(1.00000000000000))*(sj0));
IkReal x11168=((cj4)*(cj5));
IkReal x11169=((IkReal(1.00000000000000))*(cj6));
IkReal x11170=((IkReal(0.0100000000000000))*(sj5));
IkReal x11171=((sj5)*(sj6));
IkReal x11172=((cj0)*(r10));
IkReal x11173=((cj4)*(cj6));
IkReal x11174=((cj0)*(r01));
IkReal x11175=((IkReal(1.00000000000000))*(cj4));
IkReal x11176=((cj0)*(r00));
IkReal x11177=((IkReal(0.374290000000000))*(sj0));
IkReal x11178=((cj0)*(r12));
IkReal x11179=((IkReal(0.374290000000000))*(sj5));
IkReal x11180=((cj4)*(sj6));
IkReal x11181=((IkReal(1.00000000000000))*(cj0));
IkReal x11182=((r02)*(sj0));
IkReal x11183=((IkReal(0.0100000000000000))*(cj5));
IkReal x11184=((r11)*(sj0));
IkReal x11185=((r00)*(sj0)*(sj6));
IkReal x11186=((r00)*(x11173));
IkReal x11187=((sj6)*(x11183));
evalcond[0]=((IkReal(-3.14159265358979))+(IKfmod(j2, IkReal(6.28318530717959))));
evalcond[1]=((((x11154)*(x11166)))+(((r22)*(x11157)))+(((cj6)*(r21)*(x11154)))+(((IkReal(-1.00000000000000))*(cj4)*(r20)*(x11169)))+(((r21)*(x11180))));
evalcond[2]=((IkReal(-0.0690000000000000))+(((x11166)*(x11179)))+(((IkReal(-0.0100000000000000))*(r21)*(x11158)))+(((IkReal(-0.374290000000000))*(cj5)*(r22)))+(((IkReal(0.374290000000000))*(r21)*(x11163)))+(pz)+(((IkReal(-1.00000000000000))*(r22)*(x11170)))+(((IkReal(-1.00000000000000))*(x11166)*(x11183))));
evalcond[3]=((((cj0)*(x11162)))+(((IkReal(-1.00000000000000))*(sj5)*(x11155)*(x11172)))+(((r00)*(sj0)*(x11171)))+(((IkReal(-1.00000000000000))*(x11163)*(x11164)))+(((IkReal(-1.00000000000000))*(x11160)*(x11165)))+(((x11159)*(x11163))));
evalcond[4]=((IkReal(-1.00000000000000))+(((cj6)*(x11154)*(x11159)))+(((IkReal(-1.00000000000000))*(x11154)*(x11155)*(x11172)))+(((IkReal(-1.00000000000000))*(cj4)*(x11155)*(x11164)))+(((x11172)*(x11173)))+(((x11159)*(x11180)))+(((x11154)*(x11185)))+(((x11157)*(x11182)))+(((IkReal(-1.00000000000000))*(x11167)*(x11186)))+(((IkReal(-1.00000000000000))*(x11157)*(x11178)))+(((IkReal(-1.00000000000000))*(x11154)*(x11164)*(x11169))));
evalcond[5]=((((IkReal(-1.00000000000000))*(x11158)*(x11164)*(x11175)))+(((cj4)*(sj5)*(x11182)))+(((IkReal(-1.00000000000000))*(sj5)*(x11175)*(x11178)))+(((sj4)*(sj6)*(x11164)))+(((cj4)*(x11158)*(x11159)))+(((cj6)*(r00)*(sj0)*(sj4)))+(((IkReal(-1.00000000000000))*(x11155)*(x11168)*(x11172)))+(((r00)*(x11165)*(x11180)))+(((IkReal(-1.00000000000000))*(sj4)*(x11155)*(x11159)))+(((IkReal(-1.00000000000000))*(sj4)*(x11169)*(x11172))));
evalcond[6]=((((x11173)*(x11176)))+(((IkReal(-1.00000000000000))*(x11154)*(x11155)*(x11156)))+(((IkReal(-1.00000000000000))*(cj4)*(x11155)*(x11174)))+(((IkReal(-1.00000000000000))*(cj4)*(x11155)*(x11184)))+(((x11156)*(x11173)))+(((IkReal(-1.00000000000000))*(cj6)*(r11)*(x11154)*(x11167)))+(((IkReal(-1.00000000000000))*(cj0)*(x11157)*(x11160)))+(((IkReal(-1.00000000000000))*(x11154)*(x11155)*(x11176)))+(((IkReal(-1.00000000000000))*(r12)*(x11157)*(x11167)))+(((IkReal(-1.00000000000000))*(x11154)*(x11169)*(x11174))));
evalcond[7]=((((IkReal(-1.00000000000000))*(x11170)*(x11182)))+(((x11172)*(x11187)))+(((x11161)*(x11162)))+(((x11170)*(x11178)))+(((IkReal(-0.0100000000000000))*(x11158)*(x11159)))+(((IkReal(-0.374290000000000))*(r02)*(x11165)))+(((IkReal(0.0100000000000000))*(x11158)*(x11164)))+(((IkReal(-1.00000000000000))*(r11)*(x11161)*(x11163)))+(((IkReal(-0.0100000000000000))*(r00)*(sj6)*(x11165)))+(((IkReal(0.374290000000000))*(x11159)*(x11163)))+(((px)*(sj0)))+(((IkReal(-1.00000000000000))*(py)*(x11181)))+(((r00)*(x11171)*(x11177)))+(((IkReal(-1.00000000000000))*(r10)*(x11161)*(x11171))));
evalcond[8]=((IkReal(0.433420000000000))+(((IkReal(-1.00000000000000))*(r00)*(x11161)*(x11171)))+(((cj0)*(r02)*(x11170)))+(((IkReal(0.0100000000000000))*(x11158)*(x11174)))+(((IkReal(-1.00000000000000))*(px)*(x11181)))+(((cj5)*(r02)*(x11161)))+(((IkReal(-1.00000000000000))*(r01)*(x11161)*(x11163)))+(((IkReal(-1.00000000000000))*(py)*(x11167)))+(((r12)*(sj0)*(x11170)))+(((x11176)*(x11187)))+(((x11162)*(x11177)))+(((x11156)*(x11187)))+(((IkReal(-1.00000000000000))*(r11)*(x11163)*(x11177)))+(((IkReal(-0.374290000000000))*(x11156)*(x11171)))+(((IkReal(0.0100000000000000))*(x11158)*(x11184))));
if( IKabs(evalcond[0]) < 0.0000010000000000  && IKabs(evalcond[1]) < 0.0000010000000000  && IKabs(evalcond[2]) < 0.0000010000000000  && IKabs(evalcond[3]) < 0.0000010000000000  && IKabs(evalcond[4]) < 0.0000010000000000  && IKabs(evalcond[5]) < 0.0000010000000000  && IKabs(evalcond[6]) < 0.0000010000000000  && IKabs(evalcond[7]) < 0.0000010000000000  && IKabs(evalcond[8]) < 0.0000010000000000  )
{
{
IkReal j3array[1], cj3array[1], sj3array[1];
bool j3valid[1]={false};
_nj3 = 1;
IkReal x11188=((IkReal(1.00000000000000))*(r21));
IkReal x11189=((cj4)*(cj5));
IkReal x11190=((r20)*(sj6));
if( IKabs(((((IkReal(-1.00000000000000))*(cj6)*(sj5)*(x11188)))+(((IkReal(-1.00000000000000))*(sj5)*(x11190)))+(((cj5)*(r22))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(((((cj6)*(r21)*(x11189)))+(((IkReal(-1.00000000000000))*(sj4)*(sj6)*(x11188)))+(((cj6)*(r20)*(sj4)))+(((cj4)*(r22)*(sj5)))+(((x11189)*(x11190))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(IKsqr(((((IkReal(-1.00000000000000))*(cj6)*(sj5)*(x11188)))+(((IkReal(-1.00000000000000))*(sj5)*(x11190)))+(((cj5)*(r22)))))+IKsqr(((((cj6)*(r21)*(x11189)))+(((IkReal(-1.00000000000000))*(sj4)*(sj6)*(x11188)))+(((cj6)*(r20)*(sj4)))+(((cj4)*(r22)*(sj5)))+(((x11189)*(x11190)))))-1) <= IKFAST_SINCOS_THRESH )
    continue;
j3array[0]=IKatan2(((((IkReal(-1.00000000000000))*(cj6)*(sj5)*(x11188)))+(((IkReal(-1.00000000000000))*(sj5)*(x11190)))+(((cj5)*(r22)))), ((((cj6)*(r21)*(x11189)))+(((IkReal(-1.00000000000000))*(sj4)*(sj6)*(x11188)))+(((cj6)*(r20)*(sj4)))+(((cj4)*(r22)*(sj5)))+(((x11189)*(x11190)))));
sj3array[0]=IKsin(j3array[0]);
cj3array[0]=IKcos(j3array[0]);
if( j3array[0] > IKPI )
{
    j3array[0]-=IK2PI;
}
else if( j3array[0] < -IKPI )
{    j3array[0]+=IK2PI;
}
j3valid[0] = true;
for(int ij3 = 0; ij3 < 1; ++ij3)
{
if( !j3valid[ij3] )
{
    continue;
}
_ij3[0] = ij3; _ij3[1] = -1;
for(int iij3 = ij3+1; iij3 < 1; ++iij3)
{
if( j3valid[iij3] && IKabs(cj3array[ij3]-cj3array[iij3]) < IKFAST_SOLUTION_THRESH && IKabs(sj3array[ij3]-sj3array[iij3]) < IKFAST_SOLUTION_THRESH )
{
    j3valid[iij3]=false; _ij3[1] = iij3; break; 
}
}
j3 = j3array[ij3]; cj3 = cj3array[ij3]; sj3 = sj3array[ij3];
{
IkReal evalcond[4];
IkReal x11191=IKsin(j3);
IkReal x11192=((IkReal(1.00000000000000))*(cj4));
IkReal x11193=((sj0)*(sj5));
IkReal x11194=((cj0)*(cj5));
IkReal x11195=((cj6)*(r01));
IkReal x11196=((r00)*(sj6));
IkReal x11197=((cj6)*(r11));
IkReal x11198=((cj5)*(sj0));
IkReal x11199=((cj6)*(sj4));
IkReal x11200=((sj4)*(sj6));
IkReal x11201=((cj4)*(cj5));
IkReal x11202=((cj6)*(r21));
IkReal x11203=((r20)*(sj6));
IkReal x11204=((r10)*(sj6));
IkReal x11205=((IkReal(1.00000000000000))*(IKcos(j3)));
IkReal x11206=((IkReal(1.00000000000000))*(cj0)*(sj5));
evalcond[0]=((x11191)+(((IkReal(-1.00000000000000))*(cj5)*(r22)))+(((sj5)*(x11202)))+(((sj5)*(x11203))));
evalcond[1]=((((r20)*(x11199)))+(((x11201)*(x11202)))+(((IkReal(-1.00000000000000))*(x11205)))+(((cj4)*(r22)*(sj5)))+(((x11201)*(x11203)))+(((IkReal(-1.00000000000000))*(r21)*(x11200))));
evalcond[2]=((((IkReal(-1.00000000000000))*(x11196)*(x11206)))+(((IkReal(-1.00000000000000))*(x11205)))+(((IkReal(-1.00000000000000))*(x11195)*(x11206)))+(((IkReal(-1.00000000000000))*(x11193)*(x11204)))+(((IkReal(-1.00000000000000))*(x11193)*(x11197)))+(((r02)*(x11194)))+(((r12)*(x11198))));
evalcond[3]=((((IkReal(-1.00000000000000))*(r10)*(sj0)*(x11199)))+(((cj0)*(r01)*(x11200)))+(((IkReal(-1.00000000000000))*(x11192)*(x11197)*(x11198)))+(((IkReal(-1.00000000000000))*(x11192)*(x11194)*(x11196)))+(((r11)*(sj0)*(x11200)))+(((IkReal(-1.00000000000000))*(x11191)))+(((IkReal(-1.00000000000000))*(r12)*(x11192)*(x11193)))+(((IkReal(-1.00000000000000))*(cj0)*(r00)*(x11199)))+(((IkReal(-1.00000000000000))*(x11192)*(x11194)*(x11195)))+(((IkReal(-1.00000000000000))*(x11192)*(x11198)*(x11204)))+(((IkReal(-1.00000000000000))*(cj0)*(r02)*(sj5)*(x11192))));
if( IKabs(evalcond[0]) > 0.000001  || IKabs(evalcond[1]) > 0.000001  || IKabs(evalcond[2]) > 0.000001  || IKabs(evalcond[3]) > 0.000001  )
{
continue;
}
}

{
std::vector<IkSingleDOFSolutionBase<IkReal> > vinfos(7);
vinfos[0].jointtype = 1;
vinfos[0].foffset = j0;
vinfos[0].indices[0] = _ij0[0];
vinfos[0].indices[1] = _ij0[1];
vinfos[0].maxsolutions = _nj0;
vinfos[1].jointtype = 1;
vinfos[1].foffset = j1;
vinfos[1].indices[0] = _ij1[0];
vinfos[1].indices[1] = _ij1[1];
vinfos[1].maxsolutions = _nj1;
vinfos[2].jointtype = 1;
vinfos[2].foffset = j2;
vinfos[2].indices[0] = _ij2[0];
vinfos[2].indices[1] = _ij2[1];
vinfos[2].maxsolutions = _nj2;
vinfos[3].jointtype = 1;
vinfos[3].foffset = j3;
vinfos[3].indices[0] = _ij3[0];
vinfos[3].indices[1] = _ij3[1];
vinfos[3].maxsolutions = _nj3;
vinfos[4].jointtype = 1;
vinfos[4].foffset = j4;
vinfos[4].indices[0] = _ij4[0];
vinfos[4].indices[1] = _ij4[1];
vinfos[4].maxsolutions = _nj4;
vinfos[5].jointtype = 1;
vinfos[5].foffset = j5;
vinfos[5].indices[0] = _ij5[0];
vinfos[5].indices[1] = _ij5[1];
vinfos[5].maxsolutions = _nj5;
vinfos[6].jointtype = 1;
vinfos[6].foffset = j6;
vinfos[6].indices[0] = _ij6[0];
vinfos[6].indices[1] = _ij6[1];
vinfos[6].maxsolutions = _nj6;
std::vector<int> vfree(0);
solutions.AddSolution(vinfos,vfree);
}
}
}

} else
{
IkReal x11207=((IkReal(1.00000000000000))*(cj0));
IkReal x11208=((cj4)*(sj6));
IkReal x11209=((sj0)*(sj4));
IkReal x11210=((cj5)*(sj6));
IkReal x11211=((sj4)*(sj5));
IkReal x11212=((r12)*(sj5));
IkReal x11213=((IkReal(0.374290000000000))*(cj5));
IkReal x11214=((r02)*(sj0));
IkReal x11215=((r20)*(sj4));
IkReal x11216=((IkReal(1.00000000000000))*(sj0));
IkReal x11217=((IkReal(1.00000000000000))*(cj5));
IkReal x11218=((cj0)*(r10));
IkReal x11219=((cj4)*(cj6));
IkReal x11220=((r00)*(sj0));
IkReal x11221=((cj6)*(r21));
IkReal x11222=((IkReal(0.374290000000000))*(sj5));
IkReal x11223=((cj0)*(r00));
IkReal x11224=((IkReal(0.0100000000000000))*(sj5));
IkReal x11225=((cj0)*(r02));
IkReal x11226=((cj5)*(sj4));
IkReal x11227=((cj6)*(r01));
IkReal x11228=((cj6)*(r11));
IkReal x11229=((r01)*(sj0));
IkReal x11230=((r10)*(sj0));
IkReal x11231=((IkReal(0.0100000000000000))*(cj5)*(cj6));
IkReal x11232=((sj6)*(x11222));
IkReal x11233=((cj0)*(cj6)*(x11222));
evalcond[0]=((IkReal(-3.14159265358979))+(IKfmod(((IkReal(1.57079632679490))+(j2)), IkReal(6.28318530717959))));
evalcond[1]=((((sj5)*(x11221)))+(((IkReal(-1.00000000000000))*(r22)*(x11217)))+(((r20)*(sj5)*(sj6))));
evalcond[2]=((IkReal(-1.00000000000000))+(((r22)*(x11211)))+(((x11221)*(x11226)))+(((x11210)*(x11215)))+(((IkReal(-1.00000000000000))*(r20)*(x11219)))+(((r21)*(x11208))));
evalcond[3]=((((IkReal(-0.0100000000000000))*(r20)*(x11210)))+(((IkReal(-1.00000000000000))*(r22)*(x11213)))+(((x11221)*(x11222)))+(((r20)*(x11232)))+(((IkReal(-1.00000000000000))*(r22)*(x11224)))+(pz)+(((IkReal(-0.0100000000000000))*(cj5)*(x11221))));
evalcond[4]=((((IkReal(-1.00000000000000))*(r21)*(sj4)*(sj6)))+(((cj5)*(r20)*(x11208)))+(((cj5)*(r21)*(x11219)))+(((cj4)*(r22)*(sj5)))+(((cj6)*(x11215))));
evalcond[5]=((((IkReal(-1.00000000000000))*(r12)*(x11207)*(x11211)))+(((IkReal(-1.00000000000000))*(x11207)*(x11226)*(x11228)))+(((r00)*(x11209)*(x11210)))+(((cj5)*(x11209)*(x11227)))+(((IkReal(-1.00000000000000))*(r11)*(x11207)*(x11208)))+(((IkReal(-1.00000000000000))*(r10)*(sj4)*(x11207)*(x11210)))+(((x11218)*(x11219)))+(((IkReal(-1.00000000000000))*(r00)*(x11216)*(x11219)))+(((x11208)*(x11229)))+(((r02)*(sj5)*(x11209))));
evalcond[6]=((((IkReal(-1.00000000000000))*(r00)*(sj4)*(x11207)*(x11210)))+(((IkReal(-1.00000000000000))*(r02)*(x11207)*(x11211)))+(((x11219)*(x11223)))+(((IkReal(-1.00000000000000))*(x11209)*(x11212)))+(((IkReal(-1.00000000000000))*(r10)*(x11209)*(x11210)))+(((IkReal(-1.00000000000000))*(x11207)*(x11226)*(x11227)))+(((x11219)*(x11230)))+(((IkReal(-1.00000000000000))*(x11209)*(x11217)*(x11228)))+(((IkReal(-1.00000000000000))*(r01)*(x11207)*(x11208)))+(((IkReal(-1.00000000000000))*(r11)*(x11208)*(x11216))));
evalcond[7]=((IkReal(0.0690000000000000))+(((cj0)*(r12)*(x11213)))+(((IkReal(-1.00000000000000))*(py)*(x11207)))+(((IkReal(0.0100000000000000))*(x11210)*(x11218)))+(((IkReal(-1.00000000000000))*(x11214)*(x11224)))+(((x11220)*(x11232)))+(((IkReal(-1.00000000000000))*(cj0)*(x11222)*(x11228)))+(((IkReal(0.0100000000000000))*(cj0)*(cj5)*(x11228)))+(((IkReal(0.0100000000000000))*(cj0)*(x11212)))+(((IkReal(-1.00000000000000))*(x11218)*(x11232)))+(((sj0)*(x11222)*(x11227)))+(((IkReal(-1.00000000000000))*(x11213)*(x11214)))+(((px)*(sj0)))+(((IkReal(-0.0100000000000000))*(cj5)*(sj0)*(x11227)))+(((IkReal(-0.0100000000000000))*(x11210)*(x11220))));
evalcond[8]=((IkReal(0.433420000000000))+(((IkReal(0.0100000000000000))*(cj5)*(sj0)*(x11228)))+(((IkReal(-1.00000000000000))*(x11223)*(x11232)))+(((IkReal(0.0100000000000000))*(cj0)*(cj5)*(x11227)))+(((IkReal(0.0100000000000000))*(x11210)*(x11223)))+(((IkReal(-1.00000000000000))*(cj0)*(x11222)*(x11227)))+(((x11213)*(x11225)))+(((IkReal(0.0100000000000000))*(x11210)*(x11230)))+(((IkReal(0.0100000000000000))*(sj0)*(x11212)))+(((IkReal(-1.00000000000000))*(py)*(x11216)))+(((IkReal(-1.00000000000000))*(sj0)*(x11222)*(x11228)))+(((x11224)*(x11225)))+(((r12)*(sj0)*(x11213)))+(((IkReal(-1.00000000000000))*(x11230)*(x11232)))+(((IkReal(-1.00000000000000))*(px)*(x11207))));
if( IKabs(evalcond[0]) < 0.0000010000000000  && IKabs(evalcond[1]) < 0.0000010000000000  && IKabs(evalcond[2]) < 0.0000010000000000  && IKabs(evalcond[3]) < 0.0000010000000000  && IKabs(evalcond[4]) < 0.0000010000000000  && IKabs(evalcond[5]) < 0.0000010000000000  && IKabs(evalcond[6]) < 0.0000010000000000  && IKabs(evalcond[7]) < 0.0000010000000000  && IKabs(evalcond[8]) < 0.0000010000000000  )
{
{
IkReal j3array[1], cj3array[1], sj3array[1];
bool j3valid[1]={false};
_nj3 = 1;
IkReal x11234=((cj0)*(cj5));
IkReal x11235=((IkReal(1.00000000000000))*(cj0));
IkReal x11236=((cj6)*(r11));
IkReal x11237=((r10)*(sj6));
IkReal x11238=((cj5)*(sj0));
IkReal x11239=((r00)*(sj5)*(sj6));
IkReal x11240=((cj6)*(r01)*(sj5));
IkReal x11241=((IkReal(1.00000000000000))*(sj0)*(sj5));
if( IKabs(((((sj0)*(x11240)))+(((IkReal(-1.00000000000000))*(r02)*(x11238)))+(((sj0)*(x11239)))+(((IkReal(-1.00000000000000))*(sj5)*(x11235)*(x11237)))+(((IkReal(-1.00000000000000))*(sj5)*(x11235)*(x11236)))+(((r12)*(x11234))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(((((IkReal(-1.00000000000000))*(x11237)*(x11241)))+(((IkReal(-1.00000000000000))*(x11236)*(x11241)))+(((r02)*(x11234)))+(((IkReal(-1.00000000000000))*(x11235)*(x11240)))+(((r12)*(x11238)))+(((IkReal(-1.00000000000000))*(x11235)*(x11239))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(IKsqr(((((sj0)*(x11240)))+(((IkReal(-1.00000000000000))*(r02)*(x11238)))+(((sj0)*(x11239)))+(((IkReal(-1.00000000000000))*(sj5)*(x11235)*(x11237)))+(((IkReal(-1.00000000000000))*(sj5)*(x11235)*(x11236)))+(((r12)*(x11234)))))+IKsqr(((((IkReal(-1.00000000000000))*(x11237)*(x11241)))+(((IkReal(-1.00000000000000))*(x11236)*(x11241)))+(((r02)*(x11234)))+(((IkReal(-1.00000000000000))*(x11235)*(x11240)))+(((r12)*(x11238)))+(((IkReal(-1.00000000000000))*(x11235)*(x11239)))))-1) <= IKFAST_SINCOS_THRESH )
    continue;
j3array[0]=IKatan2(((((sj0)*(x11240)))+(((IkReal(-1.00000000000000))*(r02)*(x11238)))+(((sj0)*(x11239)))+(((IkReal(-1.00000000000000))*(sj5)*(x11235)*(x11237)))+(((IkReal(-1.00000000000000))*(sj5)*(x11235)*(x11236)))+(((r12)*(x11234)))), ((((IkReal(-1.00000000000000))*(x11237)*(x11241)))+(((IkReal(-1.00000000000000))*(x11236)*(x11241)))+(((r02)*(x11234)))+(((IkReal(-1.00000000000000))*(x11235)*(x11240)))+(((r12)*(x11238)))+(((IkReal(-1.00000000000000))*(x11235)*(x11239)))));
sj3array[0]=IKsin(j3array[0]);
cj3array[0]=IKcos(j3array[0]);
if( j3array[0] > IKPI )
{
    j3array[0]-=IK2PI;
}
else if( j3array[0] < -IKPI )
{    j3array[0]+=IK2PI;
}
j3valid[0] = true;
for(int ij3 = 0; ij3 < 1; ++ij3)
{
if( !j3valid[ij3] )
{
    continue;
}
_ij3[0] = ij3; _ij3[1] = -1;
for(int iij3 = ij3+1; iij3 < 1; ++iij3)
{
if( j3valid[iij3] && IKabs(cj3array[ij3]-cj3array[iij3]) < IKFAST_SOLUTION_THRESH && IKabs(sj3array[ij3]-sj3array[iij3]) < IKFAST_SOLUTION_THRESH )
{
    j3valid[iij3]=false; _ij3[1] = iij3; break; 
}
}
j3 = j3array[ij3]; cj3 = cj3array[ij3]; sj3 = sj3array[ij3];
{
IkReal evalcond[4];
IkReal x11242=IKcos(j3);
IkReal x11243=((sj0)*(sj5));
IkReal x11244=((r00)*(sj6));
IkReal x11245=((cj6)*(sj0));
IkReal x11246=((IkReal(1.00000000000000))*(cj4));
IkReal x11247=((r00)*(sj4));
IkReal x11248=((cj0)*(cj5));
IkReal x11249=((cj5)*(sj0));
IkReal x11250=((cj6)*(r11));
IkReal x11251=((r10)*(sj6));
IkReal x11252=((cj0)*(sj5));
IkReal x11253=((r10)*(sj4));
IkReal x11254=((IkReal(1.00000000000000))*(IKsin(j3)));
IkReal x11255=((cj4)*(cj5)*(r01));
IkReal x11256=((IkReal(1.00000000000000))*(cj0)*(cj6));
IkReal x11257=((cj0)*(sj4)*(sj6));
IkReal x11258=((sj0)*(sj4)*(sj6));
evalcond[0]=((((cj6)*(r01)*(x11243)))+(((x11243)*(x11244)))+(((IkReal(-1.00000000000000))*(r02)*(x11249)))+(((IkReal(-1.00000000000000))*(x11254)))+(((IkReal(-1.00000000000000))*(x11250)*(x11252)))+(((IkReal(-1.00000000000000))*(x11251)*(x11252)))+(((r12)*(x11248))));
evalcond[1]=((((r12)*(x11249)))+(((r02)*(x11248)))+(((IkReal(-1.00000000000000))*(cj6)*(r01)*(x11252)))+(((IkReal(-1.00000000000000))*(x11242)))+(((IkReal(-1.00000000000000))*(x11243)*(x11250)))+(((IkReal(-1.00000000000000))*(x11243)*(x11251)))+(((IkReal(-1.00000000000000))*(x11244)*(x11252))));
evalcond[2]=((((IkReal(-1.00000000000000))*(r01)*(x11258)))+(((r11)*(x11257)))+(((cj4)*(r02)*(x11243)))+(((IkReal(-1.00000000000000))*(x11246)*(x11248)*(x11251)))+(((IkReal(-1.00000000000000))*(r12)*(x11246)*(x11252)))+(((IkReal(-1.00000000000000))*(x11253)*(x11256)))+(x11242)+(((IkReal(-1.00000000000000))*(x11246)*(x11248)*(x11250)))+(((cj4)*(x11244)*(x11249)))+(((x11245)*(x11255)))+(((x11245)*(x11247))));
evalcond[3]=((((IkReal(-1.00000000000000))*(x11245)*(x11253)))+(((IkReal(-1.00000000000000))*(cj5)*(r11)*(x11245)*(x11246)))+(((IkReal(-1.00000000000000))*(x11244)*(x11246)*(x11248)))+(((r01)*(x11257)))+(((IkReal(-1.00000000000000))*(x11254)))+(((IkReal(-1.00000000000000))*(x11246)*(x11249)*(x11251)))+(((r11)*(x11258)))+(((IkReal(-1.00000000000000))*(x11247)*(x11256)))+(((IkReal(-1.00000000000000))*(r12)*(x11243)*(x11246)))+(((IkReal(-1.00000000000000))*(r02)*(x11246)*(x11252)))+(((IkReal(-1.00000000000000))*(cj6)*(r01)*(x11246)*(x11248))));
if( IKabs(evalcond[0]) > 0.000001  || IKabs(evalcond[1]) > 0.000001  || IKabs(evalcond[2]) > 0.000001  || IKabs(evalcond[3]) > 0.000001  )
{
continue;
}
}

{
std::vector<IkSingleDOFSolutionBase<IkReal> > vinfos(7);
vinfos[0].jointtype = 1;
vinfos[0].foffset = j0;
vinfos[0].indices[0] = _ij0[0];
vinfos[0].indices[1] = _ij0[1];
vinfos[0].maxsolutions = _nj0;
vinfos[1].jointtype = 1;
vinfos[1].foffset = j1;
vinfos[1].indices[0] = _ij1[0];
vinfos[1].indices[1] = _ij1[1];
vinfos[1].maxsolutions = _nj1;
vinfos[2].jointtype = 1;
vinfos[2].foffset = j2;
vinfos[2].indices[0] = _ij2[0];
vinfos[2].indices[1] = _ij2[1];
vinfos[2].maxsolutions = _nj2;
vinfos[3].jointtype = 1;
vinfos[3].foffset = j3;
vinfos[3].indices[0] = _ij3[0];
vinfos[3].indices[1] = _ij3[1];
vinfos[3].maxsolutions = _nj3;
vinfos[4].jointtype = 1;
vinfos[4].foffset = j4;
vinfos[4].indices[0] = _ij4[0];
vinfos[4].indices[1] = _ij4[1];
vinfos[4].maxsolutions = _nj4;
vinfos[5].jointtype = 1;
vinfos[5].foffset = j5;
vinfos[5].indices[0] = _ij5[0];
vinfos[5].indices[1] = _ij5[1];
vinfos[5].maxsolutions = _nj5;
vinfos[6].jointtype = 1;
vinfos[6].foffset = j6;
vinfos[6].indices[0] = _ij6[0];
vinfos[6].indices[1] = _ij6[1];
vinfos[6].maxsolutions = _nj6;
std::vector<int> vfree(0);
solutions.AddSolution(vinfos,vfree);
}
}
}

} else
{
IkReal x11259=((IkReal(1.00000000000000))*(cj0));
IkReal x11260=((cj4)*(sj6));
IkReal x11261=((sj0)*(sj4));
IkReal x11262=((cj5)*(sj6));
IkReal x11263=((sj4)*(sj5));
IkReal x11264=((r12)*(sj5));
IkReal x11265=((IkReal(0.374290000000000))*(cj5));
IkReal x11266=((r02)*(sj0));
IkReal x11267=((r20)*(sj4));
IkReal x11268=((IkReal(1.00000000000000))*(sj0));
IkReal x11269=((IkReal(1.00000000000000))*(cj5));
IkReal x11270=((cj0)*(r10));
IkReal x11271=((cj4)*(cj6));
IkReal x11272=((r00)*(sj0));
IkReal x11273=((cj6)*(r21));
IkReal x11274=((IkReal(0.374290000000000))*(sj5));
IkReal x11275=((cj0)*(r00));
IkReal x11276=((IkReal(0.0100000000000000))*(sj5));
IkReal x11277=((cj0)*(r02));
IkReal x11278=((cj5)*(sj4));
IkReal x11279=((cj6)*(r01));
IkReal x11280=((cj6)*(r11));
IkReal x11281=((r01)*(sj0));
IkReal x11282=((r10)*(sj0));
IkReal x11283=((IkReal(0.0100000000000000))*(cj5)*(cj6));
IkReal x11284=((sj6)*(x11274));
IkReal x11285=((cj0)*(cj6)*(x11274));
evalcond[0]=((IkReal(-3.14159265358979))+(IKfmod(((IkReal(4.71238898038469))+(j2)), IkReal(6.28318530717959))));
evalcond[1]=((((r20)*(sj5)*(sj6)))+(((IkReal(-1.00000000000000))*(r22)*(x11269)))+(((sj5)*(x11273))));
evalcond[2]=((IkReal(1.00000000000000))+(((x11273)*(x11278)))+(((r21)*(x11260)))+(((IkReal(-1.00000000000000))*(r20)*(x11271)))+(((r22)*(x11263)))+(((x11262)*(x11267))));
evalcond[3]=((((IkReal(-0.0100000000000000))*(r20)*(x11262)))+(((x11273)*(x11274)))+(((IkReal(-0.0100000000000000))*(cj5)*(x11273)))+(((IkReal(-1.00000000000000))*(r22)*(x11265)))+(((IkReal(-1.00000000000000))*(r22)*(x11276)))+(pz)+(((r20)*(x11284))));
evalcond[4]=((((cj6)*(x11267)))+(((IkReal(-1.00000000000000))*(r21)*(sj4)*(sj6)))+(((cj5)*(r21)*(x11271)))+(((cj4)*(r22)*(sj5)))+(((cj5)*(r20)*(x11260))));
evalcond[5]=((((IkReal(-1.00000000000000))*(r12)*(x11259)*(x11263)))+(((cj5)*(x11261)*(x11279)))+(((x11270)*(x11271)))+(((IkReal(-1.00000000000000))*(r11)*(x11259)*(x11260)))+(((r02)*(sj5)*(x11261)))+(((r00)*(x11261)*(x11262)))+(((IkReal(-1.00000000000000))*(r00)*(x11268)*(x11271)))+(((IkReal(-1.00000000000000))*(r10)*(sj4)*(x11259)*(x11262)))+(((IkReal(-1.00000000000000))*(x11259)*(x11278)*(x11280)))+(((x11260)*(x11281))));
evalcond[6]=((((x11271)*(x11275)))+(((IkReal(-1.00000000000000))*(r02)*(x11259)*(x11263)))+(((IkReal(-1.00000000000000))*(x11261)*(x11269)*(x11280)))+(((IkReal(-1.00000000000000))*(x11261)*(x11264)))+(((IkReal(-1.00000000000000))*(r11)*(x11260)*(x11268)))+(((IkReal(-1.00000000000000))*(r01)*(x11259)*(x11260)))+(((IkReal(-1.00000000000000))*(r00)*(sj4)*(x11259)*(x11262)))+(((IkReal(-1.00000000000000))*(r10)*(x11261)*(x11262)))+(((x11271)*(x11282)))+(((IkReal(-1.00000000000000))*(x11259)*(x11278)*(x11279))));
evalcond[7]=((IkReal(-0.0690000000000000))+(((IkReal(0.0100000000000000))*(x11262)*(x11270)))+(((IkReal(-0.0100000000000000))*(cj5)*(sj0)*(x11279)))+(((IkReal(-1.00000000000000))*(x11265)*(x11266)))+(((IkReal(-0.0100000000000000))*(x11262)*(x11272)))+(((cj0)*(r12)*(x11265)))+(((IkReal(-1.00000000000000))*(cj0)*(x11274)*(x11280)))+(((IkReal(0.0100000000000000))*(cj0)*(x11264)))+(((IkReal(-1.00000000000000))*(x11270)*(x11284)))+(((IkReal(-1.00000000000000))*(x11266)*(x11276)))+(((sj0)*(x11274)*(x11279)))+(((IkReal(0.0100000000000000))*(cj0)*(cj5)*(x11280)))+(((px)*(sj0)))+(((x11272)*(x11284)))+(((IkReal(-1.00000000000000))*(py)*(x11259))));
evalcond[8]=((IkReal(0.433420000000000))+(((x11276)*(x11277)))+(((IkReal(-1.00000000000000))*(cj0)*(x11274)*(x11279)))+(((IkReal(-1.00000000000000))*(py)*(x11268)))+(((IkReal(-1.00000000000000))*(sj0)*(x11274)*(x11280)))+(((IkReal(-1.00000000000000))*(x11275)*(x11284)))+(((IkReal(0.0100000000000000))*(x11262)*(x11282)))+(((IkReal(0.0100000000000000))*(cj5)*(sj0)*(x11280)))+(((IkReal(-1.00000000000000))*(px)*(x11259)))+(((IkReal(0.0100000000000000))*(sj0)*(x11264)))+(((IkReal(0.0100000000000000))*(x11262)*(x11275)))+(((IkReal(-1.00000000000000))*(x11282)*(x11284)))+(((IkReal(0.0100000000000000))*(cj0)*(cj5)*(x11279)))+(((x11265)*(x11277)))+(((r12)*(sj0)*(x11265))));
if( IKabs(evalcond[0]) < 0.0000010000000000  && IKabs(evalcond[1]) < 0.0000010000000000  && IKabs(evalcond[2]) < 0.0000010000000000  && IKabs(evalcond[3]) < 0.0000010000000000  && IKabs(evalcond[4]) < 0.0000010000000000  && IKabs(evalcond[5]) < 0.0000010000000000  && IKabs(evalcond[6]) < 0.0000010000000000  && IKabs(evalcond[7]) < 0.0000010000000000  && IKabs(evalcond[8]) < 0.0000010000000000  )
{
{
IkReal j3array[1], cj3array[1], sj3array[1];
bool j3valid[1]={false};
_nj3 = 1;
IkReal x11286=((cj5)*(r02));
IkReal x11287=((cj0)*(sj5));
IkReal x11288=((r10)*(sj6));
IkReal x11289=((IkReal(1.00000000000000))*(cj6));
IkReal x11290=((sj0)*(sj5));
IkReal x11291=((cj5)*(r12));
IkReal x11292=((IkReal(1.00000000000000))*(r00)*(sj6));
if( IKabs(((((x11287)*(x11288)))+(((IkReal(-1.00000000000000))*(r01)*(x11289)*(x11290)))+(((IkReal(-1.00000000000000))*(cj0)*(x11291)))+(((cj6)*(r11)*(x11287)))+(((sj0)*(x11286)))+(((IkReal(-1.00000000000000))*(x11290)*(x11292))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(((((sj0)*(x11291)))+(((IkReal(-1.00000000000000))*(r11)*(x11289)*(x11290)))+(((IkReal(-1.00000000000000))*(x11287)*(x11292)))+(((IkReal(-1.00000000000000))*(r01)*(x11287)*(x11289)))+(((IkReal(-1.00000000000000))*(x11288)*(x11290)))+(((cj0)*(x11286))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(IKsqr(((((x11287)*(x11288)))+(((IkReal(-1.00000000000000))*(r01)*(x11289)*(x11290)))+(((IkReal(-1.00000000000000))*(cj0)*(x11291)))+(((cj6)*(r11)*(x11287)))+(((sj0)*(x11286)))+(((IkReal(-1.00000000000000))*(x11290)*(x11292)))))+IKsqr(((((sj0)*(x11291)))+(((IkReal(-1.00000000000000))*(r11)*(x11289)*(x11290)))+(((IkReal(-1.00000000000000))*(x11287)*(x11292)))+(((IkReal(-1.00000000000000))*(r01)*(x11287)*(x11289)))+(((IkReal(-1.00000000000000))*(x11288)*(x11290)))+(((cj0)*(x11286)))))-1) <= IKFAST_SINCOS_THRESH )
    continue;
j3array[0]=IKatan2(((((x11287)*(x11288)))+(((IkReal(-1.00000000000000))*(r01)*(x11289)*(x11290)))+(((IkReal(-1.00000000000000))*(cj0)*(x11291)))+(((cj6)*(r11)*(x11287)))+(((sj0)*(x11286)))+(((IkReal(-1.00000000000000))*(x11290)*(x11292)))), ((((sj0)*(x11291)))+(((IkReal(-1.00000000000000))*(r11)*(x11289)*(x11290)))+(((IkReal(-1.00000000000000))*(x11287)*(x11292)))+(((IkReal(-1.00000000000000))*(r01)*(x11287)*(x11289)))+(((IkReal(-1.00000000000000))*(x11288)*(x11290)))+(((cj0)*(x11286)))));
sj3array[0]=IKsin(j3array[0]);
cj3array[0]=IKcos(j3array[0]);
if( j3array[0] > IKPI )
{
    j3array[0]-=IK2PI;
}
else if( j3array[0] < -IKPI )
{    j3array[0]+=IK2PI;
}
j3valid[0] = true;
for(int ij3 = 0; ij3 < 1; ++ij3)
{
if( !j3valid[ij3] )
{
    continue;
}
_ij3[0] = ij3; _ij3[1] = -1;
for(int iij3 = ij3+1; iij3 < 1; ++iij3)
{
if( j3valid[iij3] && IKabs(cj3array[ij3]-cj3array[iij3]) < IKFAST_SOLUTION_THRESH && IKabs(sj3array[ij3]-sj3array[iij3]) < IKFAST_SOLUTION_THRESH )
{
    j3valid[iij3]=false; _ij3[1] = iij3; break; 
}
}
j3 = j3array[ij3]; cj3 = cj3array[ij3]; sj3 = sj3array[ij3];
{
IkReal evalcond[4];
IkReal x11293=IKsin(j3);
IkReal x11294=((sj0)*(sj5));
IkReal x11295=((r00)*(sj6));
IkReal x11296=((IkReal(1.00000000000000))*(cj4));
IkReal x11297=((cj6)*(sj0));
IkReal x11298=((r00)*(sj4));
IkReal x11299=((cj0)*(cj5));
IkReal x11300=((cj6)*(r01));
IkReal x11301=((cj5)*(sj0));
IkReal x11302=((cj0)*(sj5));
IkReal x11303=((cj6)*(r11));
IkReal x11304=((r10)*(sj6));
IkReal x11305=((r10)*(sj4));
IkReal x11306=((IkReal(1.00000000000000))*(IKcos(j3)));
IkReal x11307=((cj0)*(sj4)*(sj6));
IkReal x11308=((sj0)*(sj4)*(sj6));
IkReal x11309=((IkReal(1.00000000000000))*(cj0)*(cj6));
evalcond[0]=((((x11294)*(x11300)))+(((IkReal(-1.00000000000000))*(x11302)*(x11303)))+(((r12)*(x11299)))+(((IkReal(-1.00000000000000))*(x11302)*(x11304)))+(((x11294)*(x11295)))+(x11293)+(((IkReal(-1.00000000000000))*(r02)*(x11301))));
evalcond[1]=((((IkReal(-1.00000000000000))*(x11294)*(x11304)))+(((IkReal(-1.00000000000000))*(x11300)*(x11302)))+(((IkReal(-1.00000000000000))*(x11295)*(x11302)))+(((IkReal(-1.00000000000000))*(x11294)*(x11303)))+(((r02)*(x11299)))+(((r12)*(x11301)))+(((IkReal(-1.00000000000000))*(x11306))));
evalcond[2]=((((cj4)*(r02)*(x11294)))+(((cj4)*(x11295)*(x11301)))+(((IkReal(-1.00000000000000))*(x11296)*(x11299)*(x11303)))+(((cj4)*(cj5)*(r01)*(x11297)))+(((IkReal(-1.00000000000000))*(x11305)*(x11309)))+(((IkReal(-1.00000000000000))*(x11296)*(x11299)*(x11304)))+(((IkReal(-1.00000000000000))*(r12)*(x11296)*(x11302)))+(((IkReal(-1.00000000000000))*(r01)*(x11308)))+(((r11)*(x11307)))+(((IkReal(-1.00000000000000))*(x11306)))+(((x11297)*(x11298))));
evalcond[3]=((((r11)*(x11308)))+(((IkReal(-1.00000000000000))*(x11297)*(x11305)))+(((r01)*(x11307)))+(((IkReal(-1.00000000000000))*(x11298)*(x11309)))+(((IkReal(-1.00000000000000))*(x11293)))+(((IkReal(-1.00000000000000))*(x11296)*(x11299)*(x11300)))+(((IkReal(-1.00000000000000))*(cj5)*(r11)*(x11296)*(x11297)))+(((IkReal(-1.00000000000000))*(x11296)*(x11301)*(x11304)))+(((IkReal(-1.00000000000000))*(x11295)*(x11296)*(x11299)))+(((IkReal(-1.00000000000000))*(r02)*(x11296)*(x11302)))+(((IkReal(-1.00000000000000))*(r12)*(x11294)*(x11296))));
if( IKabs(evalcond[0]) > 0.000001  || IKabs(evalcond[1]) > 0.000001  || IKabs(evalcond[2]) > 0.000001  || IKabs(evalcond[3]) > 0.000001  )
{
continue;
}
}

{
std::vector<IkSingleDOFSolutionBase<IkReal> > vinfos(7);
vinfos[0].jointtype = 1;
vinfos[0].foffset = j0;
vinfos[0].indices[0] = _ij0[0];
vinfos[0].indices[1] = _ij0[1];
vinfos[0].maxsolutions = _nj0;
vinfos[1].jointtype = 1;
vinfos[1].foffset = j1;
vinfos[1].indices[0] = _ij1[0];
vinfos[1].indices[1] = _ij1[1];
vinfos[1].maxsolutions = _nj1;
vinfos[2].jointtype = 1;
vinfos[2].foffset = j2;
vinfos[2].indices[0] = _ij2[0];
vinfos[2].indices[1] = _ij2[1];
vinfos[2].maxsolutions = _nj2;
vinfos[3].jointtype = 1;
vinfos[3].foffset = j3;
vinfos[3].indices[0] = _ij3[0];
vinfos[3].indices[1] = _ij3[1];
vinfos[3].maxsolutions = _nj3;
vinfos[4].jointtype = 1;
vinfos[4].foffset = j4;
vinfos[4].indices[0] = _ij4[0];
vinfos[4].indices[1] = _ij4[1];
vinfos[4].maxsolutions = _nj4;
vinfos[5].jointtype = 1;
vinfos[5].foffset = j5;
vinfos[5].indices[0] = _ij5[0];
vinfos[5].indices[1] = _ij5[1];
vinfos[5].maxsolutions = _nj5;
vinfos[6].jointtype = 1;
vinfos[6].foffset = j6;
vinfos[6].indices[0] = _ij6[0];
vinfos[6].indices[1] = _ij6[1];
vinfos[6].maxsolutions = _nj6;
std::vector<int> vfree(0);
solutions.AddSolution(vinfos,vfree);
}
}
}

} else
{
if( 1 )
{
continue;

} else
{
}
}
}
}
}
}

} else
{
{
IkReal j3array[1], cj3array[1], sj3array[1];
bool j3valid[1]={false};
_nj3 = 1;
IkReal x11310=((cj0)*(cj5));
IkReal x11311=((IkReal(1.00000000000000))*(cj0));
IkReal x11312=((cj6)*(r11));
IkReal x11313=((r10)*(sj6));
IkReal x11314=((cj5)*(sj0));
IkReal x11315=((r00)*(sj5)*(sj6));
IkReal x11316=((cj6)*(r01)*(sj5));
IkReal x11317=((IkReal(1.00000000000000))*(sj0)*(sj5));
if( IKabs(((((IKabs(sj2) != 0)?((IkReal)1/(sj2)):(IkReal)1.0e30))*(((((r12)*(x11310)))+(((IkReal(-1.00000000000000))*(r02)*(x11314)))+(((IkReal(-1.00000000000000))*(sj5)*(x11311)*(x11312)))+(((IkReal(-1.00000000000000))*(sj5)*(x11311)*(x11313)))+(((sj0)*(x11315)))+(((sj0)*(x11316))))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(((((IkReal(-1.00000000000000))*(x11312)*(x11317)))+(((r02)*(x11310)))+(((IkReal(-1.00000000000000))*(x11313)*(x11317)))+(((IkReal(-1.00000000000000))*(x11311)*(x11315)))+(((IkReal(-1.00000000000000))*(x11311)*(x11316)))+(((r12)*(x11314))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(IKsqr(((((IKabs(sj2) != 0)?((IkReal)1/(sj2)):(IkReal)1.0e30))*(((((r12)*(x11310)))+(((IkReal(-1.00000000000000))*(r02)*(x11314)))+(((IkReal(-1.00000000000000))*(sj5)*(x11311)*(x11312)))+(((IkReal(-1.00000000000000))*(sj5)*(x11311)*(x11313)))+(((sj0)*(x11315)))+(((sj0)*(x11316)))))))+IKsqr(((((IkReal(-1.00000000000000))*(x11312)*(x11317)))+(((r02)*(x11310)))+(((IkReal(-1.00000000000000))*(x11313)*(x11317)))+(((IkReal(-1.00000000000000))*(x11311)*(x11315)))+(((IkReal(-1.00000000000000))*(x11311)*(x11316)))+(((r12)*(x11314)))))-1) <= IKFAST_SINCOS_THRESH )
    continue;
j3array[0]=IKatan2(((((IKabs(sj2) != 0)?((IkReal)1/(sj2)):(IkReal)1.0e30))*(((((r12)*(x11310)))+(((IkReal(-1.00000000000000))*(r02)*(x11314)))+(((IkReal(-1.00000000000000))*(sj5)*(x11311)*(x11312)))+(((IkReal(-1.00000000000000))*(sj5)*(x11311)*(x11313)))+(((sj0)*(x11315)))+(((sj0)*(x11316)))))), ((((IkReal(-1.00000000000000))*(x11312)*(x11317)))+(((r02)*(x11310)))+(((IkReal(-1.00000000000000))*(x11313)*(x11317)))+(((IkReal(-1.00000000000000))*(x11311)*(x11315)))+(((IkReal(-1.00000000000000))*(x11311)*(x11316)))+(((r12)*(x11314)))));
sj3array[0]=IKsin(j3array[0]);
cj3array[0]=IKcos(j3array[0]);
if( j3array[0] > IKPI )
{
    j3array[0]-=IK2PI;
}
else if( j3array[0] < -IKPI )
{    j3array[0]+=IK2PI;
}
j3valid[0] = true;
for(int ij3 = 0; ij3 < 1; ++ij3)
{
if( !j3valid[ij3] )
{
    continue;
}
_ij3[0] = ij3; _ij3[1] = -1;
for(int iij3 = ij3+1; iij3 < 1; ++iij3)
{
if( j3valid[iij3] && IKabs(cj3array[ij3]-cj3array[iij3]) < IKFAST_SOLUTION_THRESH && IKabs(sj3array[ij3]-sj3array[iij3]) < IKFAST_SOLUTION_THRESH )
{
    j3valid[iij3]=false; _ij3[1] = iij3; break; 
}
}
j3 = j3array[ij3]; cj3 = cj3array[ij3]; sj3 = sj3array[ij3];
{
IkReal evalcond[6];
IkReal x11318=IKsin(j3);
IkReal x11319=IKcos(j3);
IkReal x11320=((sj0)*(sj5));
IkReal x11321=((r00)*(sj6));
IkReal x11322=((IkReal(1.00000000000000))*(cj4));
IkReal x11323=((cj6)*(r01));
IkReal x11324=((cj0)*(cj5));
IkReal x11325=((cj5)*(sj0));
IkReal x11326=((cj6)*(r11));
IkReal x11327=((cj0)*(sj5));
IkReal x11328=((cj6)*(sj4));
IkReal x11329=((cj4)*(cj5));
IkReal x11330=((cj6)*(r21));
IkReal x11331=((r20)*(sj6));
IkReal x11332=((r10)*(sj6));
IkReal x11333=((IkReal(1.00000000000000))*(cj0));
IkReal x11334=((IkReal(1.00000000000000))*(x11318));
IkReal x11335=((cj0)*(sj4)*(sj6));
IkReal x11336=((sj0)*(sj4)*(sj6));
evalcond[0]=((((IkReal(-1.00000000000000))*(cj2)*(x11334)))+(((sj5)*(x11331)))+(((sj5)*(x11330)))+(((IkReal(-1.00000000000000))*(cj5)*(r22))));
evalcond[1]=((((IkReal(-1.00000000000000))*(r21)*(sj4)*(sj6)))+(((cj4)*(r22)*(sj5)))+(((r20)*(x11328)))+(((x11329)*(x11331)))+(((cj2)*(x11319)))+(((x11329)*(x11330))));
evalcond[2]=((((x11320)*(x11323)))+(((x11320)*(x11321)))+(((r12)*(x11324)))+(((IkReal(-1.00000000000000))*(sj2)*(x11334)))+(((IkReal(-1.00000000000000))*(r02)*(x11325)))+(((IkReal(-1.00000000000000))*(x11326)*(x11327)))+(((IkReal(-1.00000000000000))*(x11327)*(x11332))));
evalcond[3]=((((r12)*(x11325)))+(((IkReal(-1.00000000000000))*(x11320)*(x11326)))+(((IkReal(-1.00000000000000))*(x11320)*(x11332)))+(((IkReal(-1.00000000000000))*(x11321)*(x11327)))+(((IkReal(-1.00000000000000))*(x11323)*(x11327)))+(((r02)*(x11324)))+(((IkReal(-1.00000000000000))*(x11319))));
evalcond[4]=((((IkReal(-1.00000000000000))*(r10)*(x11328)*(x11333)))+(((IkReal(-1.00000000000000))*(r01)*(x11336)))+(((r11)*(x11335)))+(((cj4)*(r02)*(x11320)))+(((r00)*(sj0)*(x11328)))+(((IkReal(-1.00000000000000))*(x11322)*(x11324)*(x11332)))+(((IkReal(-1.00000000000000))*(r12)*(x11322)*(x11327)))+(((sj2)*(x11319)))+(((cj4)*(x11321)*(x11325)))+(((IkReal(-1.00000000000000))*(x11322)*(x11324)*(x11326)))+(((cj4)*(x11323)*(x11325))));
evalcond[5]=((((IkReal(-1.00000000000000))*(x11322)*(x11325)*(x11332)))+(((IkReal(-1.00000000000000))*(r02)*(x11322)*(x11327)))+(((IkReal(-1.00000000000000))*(x11322)*(x11323)*(x11324)))+(((r11)*(x11336)))+(((IkReal(-1.00000000000000))*(x11322)*(x11325)*(x11326)))+(((IkReal(-1.00000000000000))*(r12)*(x11320)*(x11322)))+(((r01)*(x11335)))+(((IkReal(-1.00000000000000))*(x11334)))+(((IkReal(-1.00000000000000))*(r00)*(x11328)*(x11333)))+(((IkReal(-1.00000000000000))*(x11321)*(x11322)*(x11324)))+(((IkReal(-1.00000000000000))*(r10)*(sj0)*(x11328))));
if( IKabs(evalcond[0]) > 0.000001  || IKabs(evalcond[1]) > 0.000001  || IKabs(evalcond[2]) > 0.000001  || IKabs(evalcond[3]) > 0.000001  || IKabs(evalcond[4]) > 0.000001  || IKabs(evalcond[5]) > 0.000001  )
{
continue;
}
}

{
std::vector<IkSingleDOFSolutionBase<IkReal> > vinfos(7);
vinfos[0].jointtype = 1;
vinfos[0].foffset = j0;
vinfos[0].indices[0] = _ij0[0];
vinfos[0].indices[1] = _ij0[1];
vinfos[0].maxsolutions = _nj0;
vinfos[1].jointtype = 1;
vinfos[1].foffset = j1;
vinfos[1].indices[0] = _ij1[0];
vinfos[1].indices[1] = _ij1[1];
vinfos[1].maxsolutions = _nj1;
vinfos[2].jointtype = 1;
vinfos[2].foffset = j2;
vinfos[2].indices[0] = _ij2[0];
vinfos[2].indices[1] = _ij2[1];
vinfos[2].maxsolutions = _nj2;
vinfos[3].jointtype = 1;
vinfos[3].foffset = j3;
vinfos[3].indices[0] = _ij3[0];
vinfos[3].indices[1] = _ij3[1];
vinfos[3].maxsolutions = _nj3;
vinfos[4].jointtype = 1;
vinfos[4].foffset = j4;
vinfos[4].indices[0] = _ij4[0];
vinfos[4].indices[1] = _ij4[1];
vinfos[4].maxsolutions = _nj4;
vinfos[5].jointtype = 1;
vinfos[5].foffset = j5;
vinfos[5].indices[0] = _ij5[0];
vinfos[5].indices[1] = _ij5[1];
vinfos[5].maxsolutions = _nj5;
vinfos[6].jointtype = 1;
vinfos[6].foffset = j6;
vinfos[6].indices[0] = _ij6[0];
vinfos[6].indices[1] = _ij6[1];
vinfos[6].maxsolutions = _nj6;
std::vector<int> vfree(0);
solutions.AddSolution(vinfos,vfree);
}
}
}

}

}

} else
{
{
IkReal j3array[1], cj3array[1], sj3array[1];
bool j3valid[1]={false};
_nj3 = 1;
IkReal x11337=((sj5)*(sj6));
IkReal x11338=((IkReal(1.00000000000000))*(cj6)*(sj5));
if( IKabs(((((IKabs(cj2) != 0)?((IkReal)1/(cj2)):(IkReal)1.0e30))*(((((r20)*(x11337)))+(((cj6)*(r21)*(sj5)))+(((IkReal(-1.00000000000000))*(cj5)*(r22))))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(((((cj0)*(cj5)*(r02)))+(((cj5)*(r12)*(sj0)))+(((IkReal(-1.00000000000000))*(cj0)*(r00)*(x11337)))+(((IkReal(-1.00000000000000))*(r11)*(sj0)*(x11338)))+(((IkReal(-1.00000000000000))*(r10)*(sj0)*(x11337)))+(((IkReal(-1.00000000000000))*(cj0)*(r01)*(x11338))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(IKsqr(((((IKabs(cj2) != 0)?((IkReal)1/(cj2)):(IkReal)1.0e30))*(((((r20)*(x11337)))+(((cj6)*(r21)*(sj5)))+(((IkReal(-1.00000000000000))*(cj5)*(r22)))))))+IKsqr(((((cj0)*(cj5)*(r02)))+(((cj5)*(r12)*(sj0)))+(((IkReal(-1.00000000000000))*(cj0)*(r00)*(x11337)))+(((IkReal(-1.00000000000000))*(r11)*(sj0)*(x11338)))+(((IkReal(-1.00000000000000))*(r10)*(sj0)*(x11337)))+(((IkReal(-1.00000000000000))*(cj0)*(r01)*(x11338)))))-1) <= IKFAST_SINCOS_THRESH )
    continue;
j3array[0]=IKatan2(((((IKabs(cj2) != 0)?((IkReal)1/(cj2)):(IkReal)1.0e30))*(((((r20)*(x11337)))+(((cj6)*(r21)*(sj5)))+(((IkReal(-1.00000000000000))*(cj5)*(r22)))))), ((((cj0)*(cj5)*(r02)))+(((cj5)*(r12)*(sj0)))+(((IkReal(-1.00000000000000))*(cj0)*(r00)*(x11337)))+(((IkReal(-1.00000000000000))*(r11)*(sj0)*(x11338)))+(((IkReal(-1.00000000000000))*(r10)*(sj0)*(x11337)))+(((IkReal(-1.00000000000000))*(cj0)*(r01)*(x11338)))));
sj3array[0]=IKsin(j3array[0]);
cj3array[0]=IKcos(j3array[0]);
if( j3array[0] > IKPI )
{
    j3array[0]-=IK2PI;
}
else if( j3array[0] < -IKPI )
{    j3array[0]+=IK2PI;
}
j3valid[0] = true;
for(int ij3 = 0; ij3 < 1; ++ij3)
{
if( !j3valid[ij3] )
{
    continue;
}
_ij3[0] = ij3; _ij3[1] = -1;
for(int iij3 = ij3+1; iij3 < 1; ++iij3)
{
if( j3valid[iij3] && IKabs(cj3array[ij3]-cj3array[iij3]) < IKFAST_SOLUTION_THRESH && IKabs(sj3array[ij3]-sj3array[iij3]) < IKFAST_SOLUTION_THRESH )
{
    j3valid[iij3]=false; _ij3[1] = iij3; break; 
}
}
j3 = j3array[ij3]; cj3 = cj3array[ij3]; sj3 = sj3array[ij3];
{
IkReal evalcond[6];
IkReal x11339=IKsin(j3);
IkReal x11340=IKcos(j3);
IkReal x11341=((sj0)*(sj5));
IkReal x11342=((r00)*(sj6));
IkReal x11343=((IkReal(1.00000000000000))*(cj4));
IkReal x11344=((cj6)*(r01));
IkReal x11345=((cj0)*(cj5));
IkReal x11346=((cj5)*(sj0));
IkReal x11347=((cj6)*(r11));
IkReal x11348=((cj0)*(sj5));
IkReal x11349=((cj6)*(sj4));
IkReal x11350=((cj4)*(cj5));
IkReal x11351=((cj6)*(r21));
IkReal x11352=((r20)*(sj6));
IkReal x11353=((r10)*(sj6));
IkReal x11354=((IkReal(1.00000000000000))*(cj0));
IkReal x11355=((IkReal(1.00000000000000))*(x11339));
IkReal x11356=((cj0)*(sj4)*(sj6));
IkReal x11357=((sj0)*(sj4)*(sj6));
evalcond[0]=((((IkReal(-1.00000000000000))*(cj5)*(r22)))+(((IkReal(-1.00000000000000))*(cj2)*(x11355)))+(((sj5)*(x11351)))+(((sj5)*(x11352))));
evalcond[1]=((((IkReal(-1.00000000000000))*(r21)*(sj4)*(sj6)))+(((x11350)*(x11352)))+(((cj4)*(r22)*(sj5)))+(((r20)*(x11349)))+(((x11350)*(x11351)))+(((cj2)*(x11340))));
evalcond[2]=((((x11341)*(x11342)))+(((r12)*(x11345)))+(((IkReal(-1.00000000000000))*(x11347)*(x11348)))+(((IkReal(-1.00000000000000))*(r02)*(x11346)))+(((IkReal(-1.00000000000000))*(sj2)*(x11355)))+(((x11341)*(x11344)))+(((IkReal(-1.00000000000000))*(x11348)*(x11353))));
evalcond[3]=((((IkReal(-1.00000000000000))*(x11342)*(x11348)))+(((IkReal(-1.00000000000000))*(x11340)))+(((IkReal(-1.00000000000000))*(x11341)*(x11353)))+(((IkReal(-1.00000000000000))*(x11344)*(x11348)))+(((IkReal(-1.00000000000000))*(x11341)*(x11347)))+(((r12)*(x11346)))+(((r02)*(x11345))));
evalcond[4]=((((IkReal(-1.00000000000000))*(r10)*(x11349)*(x11354)))+(((IkReal(-1.00000000000000))*(x11343)*(x11345)*(x11347)))+(((cj4)*(x11344)*(x11346)))+(((cj4)*(r02)*(x11341)))+(((sj2)*(x11340)))+(((IkReal(-1.00000000000000))*(x11343)*(x11345)*(x11353)))+(((IkReal(-1.00000000000000))*(r01)*(x11357)))+(((r00)*(sj0)*(x11349)))+(((r11)*(x11356)))+(((cj4)*(x11342)*(x11346)))+(((IkReal(-1.00000000000000))*(r12)*(x11343)*(x11348))));
evalcond[5]=((((IkReal(-1.00000000000000))*(x11343)*(x11346)*(x11347)))+(((IkReal(-1.00000000000000))*(x11355)))+(((r01)*(x11356)))+(((IkReal(-1.00000000000000))*(x11343)*(x11344)*(x11345)))+(((IkReal(-1.00000000000000))*(r12)*(x11341)*(x11343)))+(((IkReal(-1.00000000000000))*(r02)*(x11343)*(x11348)))+(((IkReal(-1.00000000000000))*(r10)*(sj0)*(x11349)))+(((IkReal(-1.00000000000000))*(x11343)*(x11346)*(x11353)))+(((IkReal(-1.00000000000000))*(x11342)*(x11343)*(x11345)))+(((r11)*(x11357)))+(((IkReal(-1.00000000000000))*(r00)*(x11349)*(x11354))));
if( IKabs(evalcond[0]) > 0.000001  || IKabs(evalcond[1]) > 0.000001  || IKabs(evalcond[2]) > 0.000001  || IKabs(evalcond[3]) > 0.000001  || IKabs(evalcond[4]) > 0.000001  || IKabs(evalcond[5]) > 0.000001  )
{
continue;
}
}

{
std::vector<IkSingleDOFSolutionBase<IkReal> > vinfos(7);
vinfos[0].jointtype = 1;
vinfos[0].foffset = j0;
vinfos[0].indices[0] = _ij0[0];
vinfos[0].indices[1] = _ij0[1];
vinfos[0].maxsolutions = _nj0;
vinfos[1].jointtype = 1;
vinfos[1].foffset = j1;
vinfos[1].indices[0] = _ij1[0];
vinfos[1].indices[1] = _ij1[1];
vinfos[1].maxsolutions = _nj1;
vinfos[2].jointtype = 1;
vinfos[2].foffset = j2;
vinfos[2].indices[0] = _ij2[0];
vinfos[2].indices[1] = _ij2[1];
vinfos[2].maxsolutions = _nj2;
vinfos[3].jointtype = 1;
vinfos[3].foffset = j3;
vinfos[3].indices[0] = _ij3[0];
vinfos[3].indices[1] = _ij3[1];
vinfos[3].maxsolutions = _nj3;
vinfos[4].jointtype = 1;
vinfos[4].foffset = j4;
vinfos[4].indices[0] = _ij4[0];
vinfos[4].indices[1] = _ij4[1];
vinfos[4].maxsolutions = _nj4;
vinfos[5].jointtype = 1;
vinfos[5].foffset = j5;
vinfos[5].indices[0] = _ij5[0];
vinfos[5].indices[1] = _ij5[1];
vinfos[5].maxsolutions = _nj5;
vinfos[6].jointtype = 1;
vinfos[6].foffset = j6;
vinfos[6].indices[0] = _ij6[0];
vinfos[6].indices[1] = _ij6[1];
vinfos[6].maxsolutions = _nj6;
std::vector<int> vfree(0);
solutions.AddSolution(vinfos,vfree);
}
}
}

}

}

} else
{
{
IkReal j3array[1], cj3array[1], sj3array[1];
bool j3valid[1]={false};
_nj3 = 1;
IkReal x11358=((IkReal(1.00000000000000))*(cj4));
IkReal x11359=((cj6)*(r21));
IkReal x11360=((r20)*(sj6));
if( IKabs(((gconst9)*(((((sj5)*(x11360)))+(((IkReal(-1.00000000000000))*(cj5)*(r22)))+(((sj5)*(x11359))))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(((gconst9)*(((((IkReal(-1.00000000000000))*(cj5)*(x11358)*(x11360)))+(((IkReal(-1.00000000000000))*(cj5)*(x11358)*(x11359)))+(((r21)*(sj4)*(sj6)))+(((IkReal(-1.00000000000000))*(r22)*(sj5)*(x11358)))+(((IkReal(-1.00000000000000))*(cj6)*(r20)*(sj4))))))) < IKFAST_ATAN2_MAGTHRESH )
    continue;
j3array[0]=IKatan2(((gconst9)*(((((sj5)*(x11360)))+(((IkReal(-1.00000000000000))*(cj5)*(r22)))+(((sj5)*(x11359)))))), ((gconst9)*(((((IkReal(-1.00000000000000))*(cj5)*(x11358)*(x11360)))+(((IkReal(-1.00000000000000))*(cj5)*(x11358)*(x11359)))+(((r21)*(sj4)*(sj6)))+(((IkReal(-1.00000000000000))*(r22)*(sj5)*(x11358)))+(((IkReal(-1.00000000000000))*(cj6)*(r20)*(sj4)))))));
sj3array[0]=IKsin(j3array[0]);
cj3array[0]=IKcos(j3array[0]);
if( j3array[0] > IKPI )
{
    j3array[0]-=IK2PI;
}
else if( j3array[0] < -IKPI )
{    j3array[0]+=IK2PI;
}
j3valid[0] = true;
for(int ij3 = 0; ij3 < 1; ++ij3)
{
if( !j3valid[ij3] )
{
    continue;
}
_ij3[0] = ij3; _ij3[1] = -1;
for(int iij3 = ij3+1; iij3 < 1; ++iij3)
{
if( j3valid[iij3] && IKabs(cj3array[ij3]-cj3array[iij3]) < IKFAST_SOLUTION_THRESH && IKabs(sj3array[ij3]-sj3array[iij3]) < IKFAST_SOLUTION_THRESH )
{
    j3valid[iij3]=false; _ij3[1] = iij3; break; 
}
}
j3 = j3array[ij3]; cj3 = cj3array[ij3]; sj3 = sj3array[ij3];
{
IkReal evalcond[6];
IkReal x11361=IKsin(j3);
IkReal x11362=IKcos(j3);
IkReal x11363=((sj0)*(sj5));
IkReal x11364=((r00)*(sj6));
IkReal x11365=((IkReal(1.00000000000000))*(cj4));
IkReal x11366=((cj6)*(r01));
IkReal x11367=((cj0)*(cj5));
IkReal x11368=((cj5)*(sj0));
IkReal x11369=((cj6)*(r11));
IkReal x11370=((cj0)*(sj5));
IkReal x11371=((cj6)*(sj4));
IkReal x11372=((cj4)*(cj5));
IkReal x11373=((cj6)*(r21));
IkReal x11374=((r20)*(sj6));
IkReal x11375=((r10)*(sj6));
IkReal x11376=((IkReal(1.00000000000000))*(cj0));
IkReal x11377=((IkReal(1.00000000000000))*(x11361));
IkReal x11378=((cj0)*(sj4)*(sj6));
IkReal x11379=((sj0)*(sj4)*(sj6));
evalcond[0]=((((IkReal(-1.00000000000000))*(cj5)*(r22)))+(((IkReal(-1.00000000000000))*(cj2)*(x11377)))+(((sj5)*(x11374)))+(((sj5)*(x11373))));
evalcond[1]=((((x11372)*(x11374)))+(((IkReal(-1.00000000000000))*(r21)*(sj4)*(sj6)))+(((cj2)*(x11362)))+(((cj4)*(r22)*(sj5)))+(((r20)*(x11371)))+(((x11372)*(x11373))));
evalcond[2]=((((IkReal(-1.00000000000000))*(sj2)*(x11377)))+(((r12)*(x11367)))+(((IkReal(-1.00000000000000))*(x11370)*(x11375)))+(((x11363)*(x11366)))+(((x11363)*(x11364)))+(((IkReal(-1.00000000000000))*(x11369)*(x11370)))+(((IkReal(-1.00000000000000))*(r02)*(x11368))));
evalcond[3]=((((IkReal(-1.00000000000000))*(x11363)*(x11369)))+(((IkReal(-1.00000000000000))*(x11362)))+(((IkReal(-1.00000000000000))*(x11366)*(x11370)))+(((r02)*(x11367)))+(((r12)*(x11368)))+(((IkReal(-1.00000000000000))*(x11363)*(x11375)))+(((IkReal(-1.00000000000000))*(x11364)*(x11370))));
evalcond[4]=((((IkReal(-1.00000000000000))*(x11365)*(x11367)*(x11369)))+(((r11)*(x11378)))+(((IkReal(-1.00000000000000))*(x11365)*(x11367)*(x11375)))+(((IkReal(-1.00000000000000))*(r01)*(x11379)))+(((cj4)*(x11364)*(x11368)))+(((cj4)*(r02)*(x11363)))+(((r00)*(sj0)*(x11371)))+(((sj2)*(x11362)))+(((IkReal(-1.00000000000000))*(r12)*(x11365)*(x11370)))+(((cj4)*(x11366)*(x11368)))+(((IkReal(-1.00000000000000))*(r10)*(x11371)*(x11376))));
evalcond[5]=((((IkReal(-1.00000000000000))*(x11365)*(x11368)*(x11369)))+(((IkReal(-1.00000000000000))*(r02)*(x11365)*(x11370)))+(((IkReal(-1.00000000000000))*(r12)*(x11363)*(x11365)))+(((r11)*(x11379)))+(((IkReal(-1.00000000000000))*(x11365)*(x11368)*(x11375)))+(((IkReal(-1.00000000000000))*(x11364)*(x11365)*(x11367)))+(((IkReal(-1.00000000000000))*(x11377)))+(((r01)*(x11378)))+(((IkReal(-1.00000000000000))*(x11365)*(x11366)*(x11367)))+(((IkReal(-1.00000000000000))*(r00)*(x11371)*(x11376)))+(((IkReal(-1.00000000000000))*(r10)*(sj0)*(x11371))));
if( IKabs(evalcond[0]) > 0.000001  || IKabs(evalcond[1]) > 0.000001  || IKabs(evalcond[2]) > 0.000001  || IKabs(evalcond[3]) > 0.000001  || IKabs(evalcond[4]) > 0.000001  || IKabs(evalcond[5]) > 0.000001  )
{
continue;
}
}

{
std::vector<IkSingleDOFSolutionBase<IkReal> > vinfos(7);
vinfos[0].jointtype = 1;
vinfos[0].foffset = j0;
vinfos[0].indices[0] = _ij0[0];
vinfos[0].indices[1] = _ij0[1];
vinfos[0].maxsolutions = _nj0;
vinfos[1].jointtype = 1;
vinfos[1].foffset = j1;
vinfos[1].indices[0] = _ij1[0];
vinfos[1].indices[1] = _ij1[1];
vinfos[1].maxsolutions = _nj1;
vinfos[2].jointtype = 1;
vinfos[2].foffset = j2;
vinfos[2].indices[0] = _ij2[0];
vinfos[2].indices[1] = _ij2[1];
vinfos[2].maxsolutions = _nj2;
vinfos[3].jointtype = 1;
vinfos[3].foffset = j3;
vinfos[3].indices[0] = _ij3[0];
vinfos[3].indices[1] = _ij3[1];
vinfos[3].maxsolutions = _nj3;
vinfos[4].jointtype = 1;
vinfos[4].foffset = j4;
vinfos[4].indices[0] = _ij4[0];
vinfos[4].indices[1] = _ij4[1];
vinfos[4].maxsolutions = _nj4;
vinfos[5].jointtype = 1;
vinfos[5].foffset = j5;
vinfos[5].indices[0] = _ij5[0];
vinfos[5].indices[1] = _ij5[1];
vinfos[5].maxsolutions = _nj5;
vinfos[6].jointtype = 1;
vinfos[6].foffset = j6;
vinfos[6].indices[0] = _ij6[0];
vinfos[6].indices[1] = _ij6[1];
vinfos[6].maxsolutions = _nj6;
std::vector<int> vfree(0);
solutions.AddSolution(vinfos,vfree);
}
}
}

}

}

} else
{
IkReal x11380=((IkReal(1.00000000000000))*(cj0));
IkReal x11381=((cj4)*(sj6));
IkReal x11382=((sj0)*(sj4));
IkReal x11383=((cj5)*(sj6));
IkReal x11384=((sj4)*(sj5));
IkReal x11385=((r12)*(sj5));
IkReal x11386=((IkReal(0.374290000000000))*(cj5));
IkReal x11387=((r02)*(sj0));
IkReal x11388=((IkReal(1.00000000000000))*(sj0));
IkReal x11389=((cj0)*(r10));
IkReal x11390=((cj4)*(cj6));
IkReal x11391=((r00)*(sj0));
IkReal x11392=((cj6)*(r21));
IkReal x11393=((IkReal(0.374290000000000))*(sj5));
IkReal x11394=((cj0)*(r00));
IkReal x11395=((IkReal(0.0100000000000000))*(sj5));
IkReal x11396=((cj0)*(r02));
IkReal x11397=((cj5)*(sj4));
IkReal x11398=((cj6)*(r01));
IkReal x11399=((cj6)*(r11));
IkReal x11400=((r01)*(sj0));
IkReal x11401=((r10)*(sj0));
IkReal x11402=((IkReal(0.0100000000000000))*(cj5)*(cj6));
IkReal x11403=((sj6)*(x11393));
IkReal x11404=((cj0)*(cj6)*(x11393));
evalcond[0]=((IkReal(-3.14159265358979))+(IKfmod(j1, IkReal(6.28318530717959))));
evalcond[1]=((((x11392)*(x11397)))+(((r22)*(x11384)))+(sj2)+(((r21)*(x11381)))+(((r20)*(sj4)*(x11383)))+(((IkReal(-1.00000000000000))*(r20)*(x11390))));
evalcond[2]=((((x11392)*(x11393)))+(((IkReal(-0.0100000000000000))*(cj5)*(x11392)))+(((IkReal(-0.0690000000000000))*(cj2)))+(((IkReal(-1.00000000000000))*(r22)*(x11386)))+(((IkReal(-0.0100000000000000))*(r20)*(x11383)))+(pz)+(((r20)*(x11403)))+(((IkReal(-1.00000000000000))*(r22)*(x11395))));
evalcond[3]=((((r00)*(x11382)*(x11383)))+(((IkReal(-1.00000000000000))*(x11380)*(x11397)*(x11399)))+(((x11389)*(x11390)))+(((IkReal(-1.00000000000000))*(r10)*(sj4)*(x11380)*(x11383)))+(((IkReal(-1.00000000000000))*(r12)*(x11380)*(x11384)))+(((IkReal(-1.00000000000000))*(r11)*(x11380)*(x11381)))+(((x11381)*(x11400)))+(((r02)*(sj5)*(x11382)))+(((cj5)*(x11382)*(x11398)))+(cj2)+(((IkReal(-1.00000000000000))*(r00)*(x11388)*(x11390))));
evalcond[4]=((((x11390)*(x11394)))+(((x11390)*(x11401)))+(((IkReal(-1.00000000000000))*(r10)*(x11382)*(x11383)))+(((IkReal(-1.00000000000000))*(r00)*(sj4)*(x11380)*(x11383)))+(((IkReal(-1.00000000000000))*(r02)*(x11380)*(x11384)))+(((IkReal(-1.00000000000000))*(x11382)*(x11385)))+(((IkReal(-1.00000000000000))*(cj5)*(x11382)*(x11399)))+(((IkReal(-1.00000000000000))*(r11)*(x11381)*(x11388)))+(((IkReal(-1.00000000000000))*(x11380)*(x11397)*(x11398)))+(((IkReal(-1.00000000000000))*(r01)*(x11380)*(x11381))));
evalcond[5]=((((IkReal(-1.00000000000000))*(x11389)*(x11403)))+(((IkReal(0.0100000000000000))*(x11383)*(x11389)))+(((IkReal(-1.00000000000000))*(py)*(x11380)))+(((IkReal(-0.0100000000000000))*(x11383)*(x11391)))+(((IkReal(0.0100000000000000))*(cj0)*(cj5)*(x11399)))+(((cj0)*(r12)*(x11386)))+(((IkReal(0.0100000000000000))*(cj0)*(x11385)))+(((IkReal(0.0690000000000000))*(sj2)))+(((IkReal(-1.00000000000000))*(cj0)*(x11393)*(x11399)))+(((x11391)*(x11403)))+(((sj0)*(x11393)*(x11398)))+(((IkReal(-1.00000000000000))*(x11387)*(x11395)))+(((px)*(sj0)))+(((IkReal(-1.00000000000000))*(x11386)*(x11387)))+(((IkReal(-0.0100000000000000))*(cj5)*(sj0)*(x11398))));
evalcond[6]=((IkReal(-0.295420000000000))+(((r12)*(sj0)*(x11386)))+(((IkReal(-1.00000000000000))*(x11401)*(x11403)))+(((IkReal(0.0100000000000000))*(x11383)*(x11394)))+(((IkReal(0.0100000000000000))*(cj0)*(cj5)*(x11398)))+(((IkReal(0.0100000000000000))*(x11383)*(x11401)))+(((IkReal(-1.00000000000000))*(px)*(x11380)))+(((x11395)*(x11396)))+(((IkReal(0.0100000000000000))*(cj5)*(sj0)*(x11399)))+(((IkReal(-1.00000000000000))*(x11394)*(x11403)))+(((x11386)*(x11396)))+(((IkReal(-1.00000000000000))*(cj0)*(x11393)*(x11398)))+(((IkReal(-1.00000000000000))*(py)*(x11388)))+(((IkReal(0.0100000000000000))*(sj0)*(x11385)))+(((IkReal(-1.00000000000000))*(sj0)*(x11393)*(x11399))));
if( IKabs(evalcond[0]) < 0.0000010000000000  && IKabs(evalcond[1]) < 0.0000010000000000  && IKabs(evalcond[2]) < 0.0000010000000000  && IKabs(evalcond[3]) < 0.0000010000000000  && IKabs(evalcond[4]) < 0.0000010000000000  && IKabs(evalcond[5]) < 0.0000010000000000  && IKabs(evalcond[6]) < 0.0000010000000000  )
{
{
IkReal dummyeval[1];
IkReal gconst10;
gconst10=IKsign(cj2);
dummyeval[0]=cj2;
if( IKabs(dummyeval[0]) < 0.0000010000000000  )
{
{
IkReal dummyeval[1];
dummyeval[0]=cj2;
if( IKabs(dummyeval[0]) < 0.0000010000000000  )
{
{
IkReal dummyeval[1];
dummyeval[0]=sj2;
if( IKabs(dummyeval[0]) < 0.0000010000000000  )
{
{
IkReal evalcond[9];
IkReal x11405=((cj5)*(sj4));
IkReal x11406=((IkReal(1.00000000000000))*(sj6));
IkReal x11407=((r10)*(sj0));
IkReal x11408=((sj4)*(sj5));
IkReal x11409=((cj5)*(cj6));
IkReal x11410=((r01)*(sj0));
IkReal x11411=((IkReal(1.00000000000000))*(r02));
IkReal x11412=((IkReal(0.374290000000000))*(cj0));
IkReal x11413=((cj5)*(r12));
IkReal x11414=((cj6)*(sj5));
IkReal x11415=((cj0)*(r11));
IkReal x11416=((cj5)*(sj0));
IkReal x11417=((r20)*(sj6));
IkReal x11418=((IkReal(1.00000000000000))*(sj0));
IkReal x11419=((cj4)*(cj5));
IkReal x11420=((IkReal(1.00000000000000))*(cj6));
IkReal x11421=((IkReal(0.0100000000000000))*(sj5));
IkReal x11422=((sj5)*(sj6));
IkReal x11423=((cj0)*(r10));
IkReal x11424=((cj4)*(cj6));
IkReal x11425=((cj0)*(r01));
IkReal x11426=((IkReal(1.00000000000000))*(cj4));
IkReal x11427=((cj0)*(r00));
IkReal x11428=((IkReal(0.374290000000000))*(sj0));
IkReal x11429=((cj0)*(r12));
IkReal x11430=((IkReal(0.374290000000000))*(sj5));
IkReal x11431=((cj4)*(sj6));
IkReal x11432=((IkReal(1.00000000000000))*(cj0));
IkReal x11433=((r02)*(sj0));
IkReal x11434=((IkReal(0.0100000000000000))*(cj5));
IkReal x11435=((r11)*(sj0));
IkReal x11436=((r00)*(sj0)*(sj6));
IkReal x11437=((r00)*(x11424));
IkReal x11438=((sj6)*(x11434));
evalcond[0]=((IkReal(-3.14159265358979))+(IKfmod(((IkReal(3.14159265358979))+(j2)), IkReal(6.28318530717959))));
evalcond[1]=((((cj6)*(r21)*(x11405)))+(((r22)*(x11408)))+(((r21)*(x11431)))+(((IkReal(-1.00000000000000))*(cj4)*(r20)*(x11420)))+(((x11405)*(x11417))));
evalcond[2]=((IkReal(-0.0690000000000000))+(((IkReal(0.374290000000000))*(r21)*(x11414)))+(((IkReal(-0.374290000000000))*(cj5)*(r22)))+(((x11417)*(x11430)))+(((IkReal(-1.00000000000000))*(r22)*(x11421)))+(((IkReal(-0.0100000000000000))*(r21)*(x11409)))+(pz)+(((IkReal(-1.00000000000000))*(x11417)*(x11434))));
evalcond[3]=((((IkReal(-1.00000000000000))*(sj5)*(x11406)*(x11423)))+(((IkReal(-1.00000000000000))*(x11411)*(x11416)))+(((IkReal(-1.00000000000000))*(x11414)*(x11415)))+(((r00)*(sj0)*(x11422)))+(((x11410)*(x11414)))+(((cj0)*(x11413))));
evalcond[4]=((IkReal(1.00000000000000))+(((IkReal(-1.00000000000000))*(x11418)*(x11437)))+(((IkReal(-1.00000000000000))*(x11405)*(x11415)*(x11420)))+(((x11405)*(x11436)))+(((IkReal(-1.00000000000000))*(x11408)*(x11429)))+(((IkReal(-1.00000000000000))*(x11405)*(x11406)*(x11423)))+(((IkReal(-1.00000000000000))*(cj4)*(x11406)*(x11415)))+(((x11408)*(x11433)))+(((x11423)*(x11424)))+(((x11410)*(x11431)))+(((cj6)*(x11405)*(x11410))));
evalcond[5]=((((IkReal(-1.00000000000000))*(x11406)*(x11419)*(x11423)))+(((cj4)*(sj5)*(x11433)))+(((IkReal(-1.00000000000000))*(sj4)*(x11420)*(x11423)))+(((cj6)*(r00)*(sj0)*(sj4)))+(((cj4)*(x11409)*(x11410)))+(((IkReal(-1.00000000000000))*(sj4)*(x11406)*(x11410)))+(((r00)*(x11416)*(x11431)))+(((IkReal(-1.00000000000000))*(x11409)*(x11415)*(x11426)))+(((sj4)*(sj6)*(x11415)))+(((IkReal(-1.00000000000000))*(sj5)*(x11426)*(x11429))));
evalcond[6]=((((IkReal(-1.00000000000000))*(cj4)*(x11406)*(x11435)))+(((x11424)*(x11427)))+(((IkReal(-1.00000000000000))*(cj6)*(r11)*(x11405)*(x11418)))+(((IkReal(-1.00000000000000))*(r12)*(x11408)*(x11418)))+(((x11407)*(x11424)))+(((IkReal(-1.00000000000000))*(cj0)*(x11408)*(x11411)))+(((IkReal(-1.00000000000000))*(x11405)*(x11406)*(x11427)))+(((IkReal(-1.00000000000000))*(x11405)*(x11406)*(x11407)))+(((IkReal(-1.00000000000000))*(cj4)*(x11406)*(x11425)))+(((IkReal(-1.00000000000000))*(x11405)*(x11420)*(x11425))));
evalcond[7]=((((IkReal(-1.00000000000000))*(r11)*(x11412)*(x11414)))+(((x11423)*(x11438)))+(((IkReal(0.374290000000000))*(x11410)*(x11414)))+(((IkReal(-1.00000000000000))*(r10)*(x11412)*(x11422)))+(((IkReal(-0.0100000000000000))*(x11409)*(x11410)))+(((r00)*(x11422)*(x11428)))+(((IkReal(-1.00000000000000))*(x11421)*(x11433)))+(((IkReal(-0.374290000000000))*(r02)*(x11416)))+(((IkReal(0.0100000000000000))*(x11409)*(x11415)))+(((IkReal(-0.0100000000000000))*(r00)*(sj6)*(x11416)))+(((px)*(sj0)))+(((x11412)*(x11413)))+(((x11421)*(x11429)))+(((IkReal(-1.00000000000000))*(py)*(x11432))));
evalcond[8]=((IkReal(-0.295420000000000))+(((x11427)*(x11438)))+(((IkReal(-1.00000000000000))*(r11)*(x11414)*(x11428)))+(((IkReal(-1.00000000000000))*(py)*(x11418)))+(((cj0)*(r02)*(x11421)))+(((IkReal(0.0100000000000000))*(x11409)*(x11425)))+(((IkReal(-1.00000000000000))*(r00)*(x11412)*(x11422)))+(((r12)*(sj0)*(x11421)))+(((x11413)*(x11428)))+(((IkReal(0.0100000000000000))*(x11409)*(x11435)))+(((IkReal(-1.00000000000000))*(px)*(x11432)))+(((cj5)*(r02)*(x11412)))+(((x11407)*(x11438)))+(((IkReal(-0.374290000000000))*(x11407)*(x11422)))+(((IkReal(-1.00000000000000))*(r01)*(x11412)*(x11414))));
if( IKabs(evalcond[0]) < 0.0000010000000000  && IKabs(evalcond[1]) < 0.0000010000000000  && IKabs(evalcond[2]) < 0.0000010000000000  && IKabs(evalcond[3]) < 0.0000010000000000  && IKabs(evalcond[4]) < 0.0000010000000000  && IKabs(evalcond[5]) < 0.0000010000000000  && IKabs(evalcond[6]) < 0.0000010000000000  && IKabs(evalcond[7]) < 0.0000010000000000  && IKabs(evalcond[8]) < 0.0000010000000000  )
{
{
IkReal j3array[1], cj3array[1], sj3array[1];
bool j3valid[1]={false};
_nj3 = 1;
IkReal x11439=((IkReal(1.00000000000000))*(r21));
IkReal x11440=((cj4)*(cj5));
IkReal x11441=((r20)*(sj6));
if( IKabs(((((IkReal(-1.00000000000000))*(cj6)*(sj5)*(x11439)))+(((IkReal(-1.00000000000000))*(sj5)*(x11441)))+(((cj5)*(r22))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(((((cj6)*(r21)*(x11440)))+(((cj6)*(r20)*(sj4)))+(((cj4)*(r22)*(sj5)))+(((IkReal(-1.00000000000000))*(sj4)*(sj6)*(x11439)))+(((x11440)*(x11441))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(IKsqr(((((IkReal(-1.00000000000000))*(cj6)*(sj5)*(x11439)))+(((IkReal(-1.00000000000000))*(sj5)*(x11441)))+(((cj5)*(r22)))))+IKsqr(((((cj6)*(r21)*(x11440)))+(((cj6)*(r20)*(sj4)))+(((cj4)*(r22)*(sj5)))+(((IkReal(-1.00000000000000))*(sj4)*(sj6)*(x11439)))+(((x11440)*(x11441)))))-1) <= IKFAST_SINCOS_THRESH )
    continue;
j3array[0]=IKatan2(((((IkReal(-1.00000000000000))*(cj6)*(sj5)*(x11439)))+(((IkReal(-1.00000000000000))*(sj5)*(x11441)))+(((cj5)*(r22)))), ((((cj6)*(r21)*(x11440)))+(((cj6)*(r20)*(sj4)))+(((cj4)*(r22)*(sj5)))+(((IkReal(-1.00000000000000))*(sj4)*(sj6)*(x11439)))+(((x11440)*(x11441)))));
sj3array[0]=IKsin(j3array[0]);
cj3array[0]=IKcos(j3array[0]);
if( j3array[0] > IKPI )
{
    j3array[0]-=IK2PI;
}
else if( j3array[0] < -IKPI )
{    j3array[0]+=IK2PI;
}
j3valid[0] = true;
for(int ij3 = 0; ij3 < 1; ++ij3)
{
if( !j3valid[ij3] )
{
    continue;
}
_ij3[0] = ij3; _ij3[1] = -1;
for(int iij3 = ij3+1; iij3 < 1; ++iij3)
{
if( j3valid[iij3] && IKabs(cj3array[ij3]-cj3array[iij3]) < IKFAST_SOLUTION_THRESH && IKabs(sj3array[ij3]-sj3array[iij3]) < IKFAST_SOLUTION_THRESH )
{
    j3valid[iij3]=false; _ij3[1] = iij3; break; 
}
}
j3 = j3array[ij3]; cj3 = cj3array[ij3]; sj3 = sj3array[ij3];
{
IkReal evalcond[4];
IkReal x11442=IKcos(j3);
IkReal x11443=IKsin(j3);
IkReal x11444=((IkReal(1.00000000000000))*(cj4));
IkReal x11445=((sj0)*(sj5));
IkReal x11446=((cj0)*(cj5));
IkReal x11447=((cj6)*(r01));
IkReal x11448=((r00)*(sj6));
IkReal x11449=((cj6)*(r11));
IkReal x11450=((cj5)*(sj0));
IkReal x11451=((cj6)*(sj4));
IkReal x11452=((sj4)*(sj6));
IkReal x11453=((cj4)*(cj5));
IkReal x11454=((cj6)*(r21));
IkReal x11455=((r20)*(sj6));
IkReal x11456=((r10)*(sj6));
IkReal x11457=((IkReal(1.00000000000000))*(cj0)*(sj5));
evalcond[0]=((((sj5)*(x11454)))+(((IkReal(-1.00000000000000))*(cj5)*(r22)))+(((sj5)*(x11455)))+(x11443));
evalcond[1]=((((IkReal(-1.00000000000000))*(r21)*(x11452)))+(((IkReal(-1.00000000000000))*(x11442)))+(((cj4)*(r22)*(sj5)))+(((x11453)*(x11454)))+(((r20)*(x11451)))+(((x11453)*(x11455))));
evalcond[2]=((((r02)*(x11446)))+(((IkReal(-1.00000000000000))*(x11447)*(x11457)))+(((IkReal(-1.00000000000000))*(x11445)*(x11449)))+(((IkReal(-1.00000000000000))*(x11448)*(x11457)))+(((r12)*(x11450)))+(x11442)+(((IkReal(-1.00000000000000))*(x11445)*(x11456))));
evalcond[3]=((((IkReal(-1.00000000000000))*(x11444)*(x11446)*(x11447)))+(((cj0)*(r01)*(x11452)))+(((IkReal(-1.00000000000000))*(cj0)*(r00)*(x11451)))+(((IkReal(-1.00000000000000))*(x11444)*(x11446)*(x11448)))+(((IkReal(-1.00000000000000))*(x11444)*(x11449)*(x11450)))+(((IkReal(-1.00000000000000))*(r10)*(sj0)*(x11451)))+(((IkReal(-1.00000000000000))*(x11444)*(x11450)*(x11456)))+(((IkReal(-1.00000000000000))*(cj0)*(r02)*(sj5)*(x11444)))+(((IkReal(-1.00000000000000))*(r12)*(x11444)*(x11445)))+(((r11)*(sj0)*(x11452)))+(x11443));
if( IKabs(evalcond[0]) > 0.000001  || IKabs(evalcond[1]) > 0.000001  || IKabs(evalcond[2]) > 0.000001  || IKabs(evalcond[3]) > 0.000001  )
{
continue;
}
}

{
std::vector<IkSingleDOFSolutionBase<IkReal> > vinfos(7);
vinfos[0].jointtype = 1;
vinfos[0].foffset = j0;
vinfos[0].indices[0] = _ij0[0];
vinfos[0].indices[1] = _ij0[1];
vinfos[0].maxsolutions = _nj0;
vinfos[1].jointtype = 1;
vinfos[1].foffset = j1;
vinfos[1].indices[0] = _ij1[0];
vinfos[1].indices[1] = _ij1[1];
vinfos[1].maxsolutions = _nj1;
vinfos[2].jointtype = 1;
vinfos[2].foffset = j2;
vinfos[2].indices[0] = _ij2[0];
vinfos[2].indices[1] = _ij2[1];
vinfos[2].maxsolutions = _nj2;
vinfos[3].jointtype = 1;
vinfos[3].foffset = j3;
vinfos[3].indices[0] = _ij3[0];
vinfos[3].indices[1] = _ij3[1];
vinfos[3].maxsolutions = _nj3;
vinfos[4].jointtype = 1;
vinfos[4].foffset = j4;
vinfos[4].indices[0] = _ij4[0];
vinfos[4].indices[1] = _ij4[1];
vinfos[4].maxsolutions = _nj4;
vinfos[5].jointtype = 1;
vinfos[5].foffset = j5;
vinfos[5].indices[0] = _ij5[0];
vinfos[5].indices[1] = _ij5[1];
vinfos[5].maxsolutions = _nj5;
vinfos[6].jointtype = 1;
vinfos[6].foffset = j6;
vinfos[6].indices[0] = _ij6[0];
vinfos[6].indices[1] = _ij6[1];
vinfos[6].maxsolutions = _nj6;
std::vector<int> vfree(0);
solutions.AddSolution(vinfos,vfree);
}
}
}

} else
{
IkReal x11458=((cj5)*(sj4));
IkReal x11459=((IkReal(1.00000000000000))*(sj6));
IkReal x11460=((r10)*(sj0));
IkReal x11461=((sj4)*(sj5));
IkReal x11462=((cj5)*(cj6));
IkReal x11463=((r01)*(sj0));
IkReal x11464=((IkReal(1.00000000000000))*(r02));
IkReal x11465=((IkReal(0.374290000000000))*(cj0));
IkReal x11466=((cj5)*(r12));
IkReal x11467=((cj6)*(sj5));
IkReal x11468=((cj0)*(r11));
IkReal x11469=((cj5)*(sj0));
IkReal x11470=((r20)*(sj6));
IkReal x11471=((IkReal(1.00000000000000))*(sj0));
IkReal x11472=((cj4)*(cj5));
IkReal x11473=((IkReal(1.00000000000000))*(cj6));
IkReal x11474=((IkReal(0.0100000000000000))*(sj5));
IkReal x11475=((sj5)*(sj6));
IkReal x11476=((cj0)*(r10));
IkReal x11477=((cj4)*(cj6));
IkReal x11478=((cj0)*(r01));
IkReal x11479=((IkReal(1.00000000000000))*(cj4));
IkReal x11480=((cj0)*(r00));
IkReal x11481=((IkReal(0.374290000000000))*(sj0));
IkReal x11482=((cj0)*(r12));
IkReal x11483=((IkReal(0.374290000000000))*(sj5));
IkReal x11484=((cj4)*(sj6));
IkReal x11485=((IkReal(1.00000000000000))*(cj0));
IkReal x11486=((r02)*(sj0));
IkReal x11487=((IkReal(0.0100000000000000))*(cj5));
IkReal x11488=((r11)*(sj0));
IkReal x11489=((r00)*(sj0)*(sj6));
IkReal x11490=((r00)*(x11477));
IkReal x11491=((sj6)*(x11487));
evalcond[0]=((IkReal(-3.14159265358979))+(IKfmod(j2, IkReal(6.28318530717959))));
evalcond[1]=((((cj6)*(r21)*(x11458)))+(((r21)*(x11484)))+(((x11458)*(x11470)))+(((r22)*(x11461)))+(((IkReal(-1.00000000000000))*(cj4)*(r20)*(x11473))));
evalcond[2]=((IkReal(0.0690000000000000))+(((IkReal(0.374290000000000))*(r21)*(x11467)))+(((x11470)*(x11483)))+(((IkReal(-1.00000000000000))*(r22)*(x11474)))+(((IkReal(-0.374290000000000))*(cj5)*(r22)))+(pz)+(((IkReal(-1.00000000000000))*(x11470)*(x11487)))+(((IkReal(-0.0100000000000000))*(r21)*(x11462))));
evalcond[3]=((((IkReal(-1.00000000000000))*(x11464)*(x11469)))+(((IkReal(-1.00000000000000))*(x11467)*(x11468)))+(((x11463)*(x11467)))+(((IkReal(-1.00000000000000))*(sj5)*(x11459)*(x11476)))+(((cj0)*(x11466)))+(((r00)*(sj0)*(x11475))));
evalcond[4]=((IkReal(-1.00000000000000))+(((x11461)*(x11486)))+(((IkReal(-1.00000000000000))*(x11461)*(x11482)))+(((x11463)*(x11484)))+(((cj6)*(x11458)*(x11463)))+(((IkReal(-1.00000000000000))*(cj4)*(x11459)*(x11468)))+(((IkReal(-1.00000000000000))*(x11458)*(x11459)*(x11476)))+(((IkReal(-1.00000000000000))*(x11471)*(x11490)))+(((x11458)*(x11489)))+(((x11476)*(x11477)))+(((IkReal(-1.00000000000000))*(x11458)*(x11468)*(x11473))));
evalcond[5]=((((IkReal(-1.00000000000000))*(sj4)*(x11459)*(x11463)))+(((r00)*(x11469)*(x11484)))+(((cj6)*(r00)*(sj0)*(sj4)))+(((IkReal(-1.00000000000000))*(x11462)*(x11468)*(x11479)))+(((cj4)*(sj5)*(x11486)))+(((IkReal(-1.00000000000000))*(sj5)*(x11479)*(x11482)))+(((sj4)*(sj6)*(x11468)))+(((IkReal(-1.00000000000000))*(x11459)*(x11472)*(x11476)))+(((cj4)*(x11462)*(x11463)))+(((IkReal(-1.00000000000000))*(sj4)*(x11473)*(x11476))));
evalcond[6]=((((x11477)*(x11480)))+(((IkReal(-1.00000000000000))*(x11458)*(x11473)*(x11478)))+(((x11460)*(x11477)))+(((IkReal(-1.00000000000000))*(x11458)*(x11459)*(x11460)))+(((IkReal(-1.00000000000000))*(x11458)*(x11459)*(x11480)))+(((IkReal(-1.00000000000000))*(cj0)*(x11461)*(x11464)))+(((IkReal(-1.00000000000000))*(r12)*(x11461)*(x11471)))+(((IkReal(-1.00000000000000))*(cj4)*(x11459)*(x11488)))+(((IkReal(-1.00000000000000))*(cj4)*(x11459)*(x11478)))+(((IkReal(-1.00000000000000))*(cj6)*(r11)*(x11458)*(x11471))));
evalcond[7]=((((IkReal(-1.00000000000000))*(x11474)*(x11486)))+(((x11474)*(x11482)))+(((IkReal(-1.00000000000000))*(py)*(x11485)))+(((IkReal(-0.0100000000000000))*(r00)*(sj6)*(x11469)))+(((IkReal(-1.00000000000000))*(r11)*(x11465)*(x11467)))+(((IkReal(-0.374290000000000))*(r02)*(x11469)))+(((IkReal(-1.00000000000000))*(r10)*(x11465)*(x11475)))+(((IkReal(0.374290000000000))*(x11463)*(x11467)))+(((IkReal(0.0100000000000000))*(x11462)*(x11468)))+(((x11465)*(x11466)))+(((px)*(sj0)))+(((x11476)*(x11491)))+(((r00)*(x11475)*(x11481)))+(((IkReal(-0.0100000000000000))*(x11462)*(x11463))));
evalcond[8]=((IkReal(-0.295420000000000))+(((IkReal(-1.00000000000000))*(r01)*(x11465)*(x11467)))+(((cj0)*(r02)*(x11474)))+(((cj5)*(r02)*(x11465)))+(((IkReal(-1.00000000000000))*(px)*(x11485)))+(((x11460)*(x11491)))+(((IkReal(0.0100000000000000))*(x11462)*(x11478)))+(((r12)*(sj0)*(x11474)))+(((IkReal(-1.00000000000000))*(py)*(x11471)))+(((IkReal(-1.00000000000000))*(r00)*(x11465)*(x11475)))+(((x11466)*(x11481)))+(((IkReal(-1.00000000000000))*(r11)*(x11467)*(x11481)))+(((IkReal(0.0100000000000000))*(x11462)*(x11488)))+(((IkReal(-0.374290000000000))*(x11460)*(x11475)))+(((x11480)*(x11491))));
if( IKabs(evalcond[0]) < 0.0000010000000000  && IKabs(evalcond[1]) < 0.0000010000000000  && IKabs(evalcond[2]) < 0.0000010000000000  && IKabs(evalcond[3]) < 0.0000010000000000  && IKabs(evalcond[4]) < 0.0000010000000000  && IKabs(evalcond[5]) < 0.0000010000000000  && IKabs(evalcond[6]) < 0.0000010000000000  && IKabs(evalcond[7]) < 0.0000010000000000  && IKabs(evalcond[8]) < 0.0000010000000000  )
{
{
IkReal j3array[1], cj3array[1], sj3array[1];
bool j3valid[1]={false};
_nj3 = 1;
IkReal x11492=((IkReal(1.00000000000000))*(cj4));
IkReal x11493=((cj6)*(r21));
IkReal x11494=((r20)*(sj6));
if( IKabs(((((sj5)*(x11493)))+(((sj5)*(x11494)))+(((IkReal(-1.00000000000000))*(cj5)*(r22))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(((((IkReal(-1.00000000000000))*(cj5)*(x11492)*(x11493)))+(((r21)*(sj4)*(sj6)))+(((IkReal(-1.00000000000000))*(r22)*(sj5)*(x11492)))+(((IkReal(-1.00000000000000))*(cj5)*(x11492)*(x11494)))+(((IkReal(-1.00000000000000))*(cj6)*(r20)*(sj4))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(IKsqr(((((sj5)*(x11493)))+(((sj5)*(x11494)))+(((IkReal(-1.00000000000000))*(cj5)*(r22)))))+IKsqr(((((IkReal(-1.00000000000000))*(cj5)*(x11492)*(x11493)))+(((r21)*(sj4)*(sj6)))+(((IkReal(-1.00000000000000))*(r22)*(sj5)*(x11492)))+(((IkReal(-1.00000000000000))*(cj5)*(x11492)*(x11494)))+(((IkReal(-1.00000000000000))*(cj6)*(r20)*(sj4)))))-1) <= IKFAST_SINCOS_THRESH )
    continue;
j3array[0]=IKatan2(((((sj5)*(x11493)))+(((sj5)*(x11494)))+(((IkReal(-1.00000000000000))*(cj5)*(r22)))), ((((IkReal(-1.00000000000000))*(cj5)*(x11492)*(x11493)))+(((r21)*(sj4)*(sj6)))+(((IkReal(-1.00000000000000))*(r22)*(sj5)*(x11492)))+(((IkReal(-1.00000000000000))*(cj5)*(x11492)*(x11494)))+(((IkReal(-1.00000000000000))*(cj6)*(r20)*(sj4)))));
sj3array[0]=IKsin(j3array[0]);
cj3array[0]=IKcos(j3array[0]);
if( j3array[0] > IKPI )
{
    j3array[0]-=IK2PI;
}
else if( j3array[0] < -IKPI )
{    j3array[0]+=IK2PI;
}
j3valid[0] = true;
for(int ij3 = 0; ij3 < 1; ++ij3)
{
if( !j3valid[ij3] )
{
    continue;
}
_ij3[0] = ij3; _ij3[1] = -1;
for(int iij3 = ij3+1; iij3 < 1; ++iij3)
{
if( j3valid[iij3] && IKabs(cj3array[ij3]-cj3array[iij3]) < IKFAST_SOLUTION_THRESH && IKabs(sj3array[ij3]-sj3array[iij3]) < IKFAST_SOLUTION_THRESH )
{
    j3valid[iij3]=false; _ij3[1] = iij3; break; 
}
}
j3 = j3array[ij3]; cj3 = cj3array[ij3]; sj3 = sj3array[ij3];
{
IkReal evalcond[4];
IkReal x11495=IKcos(j3);
IkReal x11496=IKsin(j3);
IkReal x11497=((IkReal(1.00000000000000))*(cj4));
IkReal x11498=((sj0)*(sj5));
IkReal x11499=((cj0)*(cj5));
IkReal x11500=((cj6)*(r01));
IkReal x11501=((r00)*(sj6));
IkReal x11502=((cj6)*(r11));
IkReal x11503=((cj5)*(sj0));
IkReal x11504=((cj6)*(sj4));
IkReal x11505=((sj4)*(sj6));
IkReal x11506=((cj4)*(cj5));
IkReal x11507=((cj6)*(r21));
IkReal x11508=((r20)*(sj6));
IkReal x11509=((r10)*(sj6));
IkReal x11510=((IkReal(1.00000000000000))*(cj0)*(sj5));
evalcond[0]=((((sj5)*(x11507)))+(((IkReal(-1.00000000000000))*(x11496)))+(((IkReal(-1.00000000000000))*(cj5)*(r22)))+(((sj5)*(x11508))));
evalcond[1]=((((cj4)*(r22)*(sj5)))+(((x11506)*(x11507)))+(((IkReal(-1.00000000000000))*(r21)*(x11505)))+(x11495)+(((r20)*(x11504)))+(((x11506)*(x11508))));
evalcond[2]=((((IkReal(-1.00000000000000))*(x11498)*(x11509)))+(((r12)*(x11503)))+(((IkReal(-1.00000000000000))*(x11500)*(x11510)))+(((IkReal(-1.00000000000000))*(x11501)*(x11510)))+(((IkReal(-1.00000000000000))*(x11498)*(x11502)))+(((r02)*(x11499)))+(x11495));
evalcond[3]=((((IkReal(-1.00000000000000))*(cj0)*(r02)*(sj5)*(x11497)))+(((IkReal(-1.00000000000000))*(r10)*(sj0)*(x11504)))+(((r11)*(sj0)*(x11505)))+(((IkReal(-1.00000000000000))*(x11497)*(x11499)*(x11500)))+(((IkReal(-1.00000000000000))*(r12)*(x11497)*(x11498)))+(((IkReal(-1.00000000000000))*(cj0)*(r00)*(x11504)))+(((IkReal(-1.00000000000000))*(x11497)*(x11502)*(x11503)))+(((cj0)*(r01)*(x11505)))+(((IkReal(-1.00000000000000))*(x11497)*(x11499)*(x11501)))+(x11496)+(((IkReal(-1.00000000000000))*(x11497)*(x11503)*(x11509))));
if( IKabs(evalcond[0]) > 0.000001  || IKabs(evalcond[1]) > 0.000001  || IKabs(evalcond[2]) > 0.000001  || IKabs(evalcond[3]) > 0.000001  )
{
continue;
}
}

{
std::vector<IkSingleDOFSolutionBase<IkReal> > vinfos(7);
vinfos[0].jointtype = 1;
vinfos[0].foffset = j0;
vinfos[0].indices[0] = _ij0[0];
vinfos[0].indices[1] = _ij0[1];
vinfos[0].maxsolutions = _nj0;
vinfos[1].jointtype = 1;
vinfos[1].foffset = j1;
vinfos[1].indices[0] = _ij1[0];
vinfos[1].indices[1] = _ij1[1];
vinfos[1].maxsolutions = _nj1;
vinfos[2].jointtype = 1;
vinfos[2].foffset = j2;
vinfos[2].indices[0] = _ij2[0];
vinfos[2].indices[1] = _ij2[1];
vinfos[2].maxsolutions = _nj2;
vinfos[3].jointtype = 1;
vinfos[3].foffset = j3;
vinfos[3].indices[0] = _ij3[0];
vinfos[3].indices[1] = _ij3[1];
vinfos[3].maxsolutions = _nj3;
vinfos[4].jointtype = 1;
vinfos[4].foffset = j4;
vinfos[4].indices[0] = _ij4[0];
vinfos[4].indices[1] = _ij4[1];
vinfos[4].maxsolutions = _nj4;
vinfos[5].jointtype = 1;
vinfos[5].foffset = j5;
vinfos[5].indices[0] = _ij5[0];
vinfos[5].indices[1] = _ij5[1];
vinfos[5].maxsolutions = _nj5;
vinfos[6].jointtype = 1;
vinfos[6].foffset = j6;
vinfos[6].indices[0] = _ij6[0];
vinfos[6].indices[1] = _ij6[1];
vinfos[6].maxsolutions = _nj6;
std::vector<int> vfree(0);
solutions.AddSolution(vinfos,vfree);
}
}
}

} else
{
IkReal x11511=((IkReal(1.00000000000000))*(cj0));
IkReal x11512=((cj4)*(sj6));
IkReal x11513=((sj0)*(sj4));
IkReal x11514=((cj5)*(sj6));
IkReal x11515=((sj4)*(sj5));
IkReal x11516=((r12)*(sj5));
IkReal x11517=((IkReal(0.374290000000000))*(cj5));
IkReal x11518=((r02)*(sj0));
IkReal x11519=((r20)*(sj4));
IkReal x11520=((IkReal(1.00000000000000))*(sj0));
IkReal x11521=((IkReal(1.00000000000000))*(cj5));
IkReal x11522=((cj0)*(r10));
IkReal x11523=((cj4)*(cj6));
IkReal x11524=((r00)*(sj0));
IkReal x11525=((cj6)*(r21));
IkReal x11526=((IkReal(0.374290000000000))*(sj5));
IkReal x11527=((cj0)*(r00));
IkReal x11528=((IkReal(0.0100000000000000))*(sj5));
IkReal x11529=((cj0)*(r02));
IkReal x11530=((cj5)*(sj4));
IkReal x11531=((cj6)*(r01));
IkReal x11532=((cj6)*(r11));
IkReal x11533=((r01)*(sj0));
IkReal x11534=((r10)*(sj0));
IkReal x11535=((IkReal(0.0100000000000000))*(cj5)*(cj6));
IkReal x11536=((sj6)*(x11526));
IkReal x11537=((cj0)*(cj6)*(x11526));
evalcond[0]=((IkReal(-3.14159265358979))+(IKfmod(((IkReal(1.57079632679490))+(j2)), IkReal(6.28318530717959))));
evalcond[1]=((((sj5)*(x11525)))+(((IkReal(-1.00000000000000))*(r22)*(x11521)))+(((r20)*(sj5)*(sj6))));
evalcond[2]=((IkReal(1.00000000000000))+(((IkReal(-1.00000000000000))*(r20)*(x11523)))+(((x11514)*(x11519)))+(((r21)*(x11512)))+(((r22)*(x11515)))+(((x11525)*(x11530))));
evalcond[3]=((((x11525)*(x11526)))+(((r20)*(x11536)))+(((IkReal(-0.0100000000000000))*(r20)*(x11514)))+(pz)+(((IkReal(-1.00000000000000))*(r22)*(x11517)))+(((IkReal(-0.0100000000000000))*(cj5)*(x11525)))+(((IkReal(-1.00000000000000))*(r22)*(x11528))));
evalcond[4]=((((IkReal(-1.00000000000000))*(r21)*(sj4)*(sj6)))+(((cj4)*(r22)*(sj5)))+(((cj5)*(r21)*(x11523)))+(((cj6)*(x11519)))+(((cj5)*(r20)*(x11512))));
evalcond[5]=((((cj5)*(x11513)*(x11531)))+(((x11512)*(x11533)))+(((IkReal(-1.00000000000000))*(r12)*(x11511)*(x11515)))+(((r02)*(sj5)*(x11513)))+(((IkReal(-1.00000000000000))*(x11511)*(x11530)*(x11532)))+(((x11522)*(x11523)))+(((r00)*(x11513)*(x11514)))+(((IkReal(-1.00000000000000))*(r11)*(x11511)*(x11512)))+(((IkReal(-1.00000000000000))*(r10)*(sj4)*(x11511)*(x11514)))+(((IkReal(-1.00000000000000))*(r00)*(x11520)*(x11523))));
evalcond[6]=((((IkReal(-1.00000000000000))*(r00)*(sj4)*(x11511)*(x11514)))+(((IkReal(-1.00000000000000))*(x11513)*(x11516)))+(((IkReal(-1.00000000000000))*(r10)*(x11513)*(x11514)))+(((x11523)*(x11527)))+(((IkReal(-1.00000000000000))*(x11511)*(x11530)*(x11531)))+(((IkReal(-1.00000000000000))*(x11513)*(x11521)*(x11532)))+(((IkReal(-1.00000000000000))*(r11)*(x11512)*(x11520)))+(((x11523)*(x11534)))+(((IkReal(-1.00000000000000))*(r02)*(x11511)*(x11515)))+(((IkReal(-1.00000000000000))*(r01)*(x11511)*(x11512))));
evalcond[7]=((IkReal(0.0690000000000000))+(((x11524)*(x11536)))+(((IkReal(0.0100000000000000))*(cj0)*(x11516)))+(((IkReal(-1.00000000000000))*(x11522)*(x11536)))+(((IkReal(-1.00000000000000))*(py)*(x11511)))+(((sj0)*(x11526)*(x11531)))+(((IkReal(0.0100000000000000))*(x11514)*(x11522)))+(((IkReal(-1.00000000000000))*(x11518)*(x11528)))+(((px)*(sj0)))+(((cj0)*(r12)*(x11517)))+(((IkReal(-0.0100000000000000))*(x11514)*(x11524)))+(((IkReal(-1.00000000000000))*(cj0)*(x11526)*(x11532)))+(((IkReal(-1.00000000000000))*(x11517)*(x11518)))+(((IkReal(-0.0100000000000000))*(cj5)*(sj0)*(x11531)))+(((IkReal(0.0100000000000000))*(cj0)*(cj5)*(x11532))));
evalcond[8]=((IkReal(-0.295420000000000))+(((IkReal(-1.00000000000000))*(x11534)*(x11536)))+(((IkReal(-1.00000000000000))*(x11527)*(x11536)))+(((IkReal(0.0100000000000000))*(x11514)*(x11527)))+(((x11528)*(x11529)))+(((IkReal(-1.00000000000000))*(cj0)*(x11526)*(x11531)))+(((IkReal(-1.00000000000000))*(sj0)*(x11526)*(x11532)))+(((IkReal(-1.00000000000000))*(px)*(x11511)))+(((IkReal(0.0100000000000000))*(sj0)*(x11516)))+(((x11517)*(x11529)))+(((IkReal(0.0100000000000000))*(x11514)*(x11534)))+(((IkReal(-1.00000000000000))*(py)*(x11520)))+(((r12)*(sj0)*(x11517)))+(((IkReal(0.0100000000000000))*(cj5)*(sj0)*(x11532)))+(((IkReal(0.0100000000000000))*(cj0)*(cj5)*(x11531))));
if( IKabs(evalcond[0]) < 0.0000010000000000  && IKabs(evalcond[1]) < 0.0000010000000000  && IKabs(evalcond[2]) < 0.0000010000000000  && IKabs(evalcond[3]) < 0.0000010000000000  && IKabs(evalcond[4]) < 0.0000010000000000  && IKabs(evalcond[5]) < 0.0000010000000000  && IKabs(evalcond[6]) < 0.0000010000000000  && IKabs(evalcond[7]) < 0.0000010000000000  && IKabs(evalcond[8]) < 0.0000010000000000  )
{
{
IkReal j3array[1], cj3array[1], sj3array[1];
bool j3valid[1]={false};
_nj3 = 1;
IkReal x11538=((sj0)*(sj5));
IkReal x11539=((r00)*(sj6));
IkReal x11540=((IkReal(1.00000000000000))*(cj5));
IkReal x11541=((cj6)*(r11));
IkReal x11542=((cj6)*(r01));
IkReal x11543=((r10)*(sj6));
IkReal x11544=((cj0)*(sj5));
if( IKabs(((((IkReal(-1.00000000000000))*(x11541)*(x11544)))+(((IkReal(-1.00000000000000))*(x11543)*(x11544)))+(((x11538)*(x11542)))+(((cj0)*(cj5)*(r12)))+(((IkReal(-1.00000000000000))*(r02)*(sj0)*(x11540)))+(((x11538)*(x11539))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(((((x11538)*(x11541)))+(((IkReal(-1.00000000000000))*(r12)*(sj0)*(x11540)))+(((x11538)*(x11543)))+(((IkReal(-1.00000000000000))*(cj0)*(r02)*(x11540)))+(((x11542)*(x11544)))+(((x11539)*(x11544))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(IKsqr(((((IkReal(-1.00000000000000))*(x11541)*(x11544)))+(((IkReal(-1.00000000000000))*(x11543)*(x11544)))+(((x11538)*(x11542)))+(((cj0)*(cj5)*(r12)))+(((IkReal(-1.00000000000000))*(r02)*(sj0)*(x11540)))+(((x11538)*(x11539)))))+IKsqr(((((x11538)*(x11541)))+(((IkReal(-1.00000000000000))*(r12)*(sj0)*(x11540)))+(((x11538)*(x11543)))+(((IkReal(-1.00000000000000))*(cj0)*(r02)*(x11540)))+(((x11542)*(x11544)))+(((x11539)*(x11544)))))-1) <= IKFAST_SINCOS_THRESH )
    continue;
j3array[0]=IKatan2(((((IkReal(-1.00000000000000))*(x11541)*(x11544)))+(((IkReal(-1.00000000000000))*(x11543)*(x11544)))+(((x11538)*(x11542)))+(((cj0)*(cj5)*(r12)))+(((IkReal(-1.00000000000000))*(r02)*(sj0)*(x11540)))+(((x11538)*(x11539)))), ((((x11538)*(x11541)))+(((IkReal(-1.00000000000000))*(r12)*(sj0)*(x11540)))+(((x11538)*(x11543)))+(((IkReal(-1.00000000000000))*(cj0)*(r02)*(x11540)))+(((x11542)*(x11544)))+(((x11539)*(x11544)))));
sj3array[0]=IKsin(j3array[0]);
cj3array[0]=IKcos(j3array[0]);
if( j3array[0] > IKPI )
{
    j3array[0]-=IK2PI;
}
else if( j3array[0] < -IKPI )
{    j3array[0]+=IK2PI;
}
j3valid[0] = true;
for(int ij3 = 0; ij3 < 1; ++ij3)
{
if( !j3valid[ij3] )
{
    continue;
}
_ij3[0] = ij3; _ij3[1] = -1;
for(int iij3 = ij3+1; iij3 < 1; ++iij3)
{
if( j3valid[iij3] && IKabs(cj3array[ij3]-cj3array[iij3]) < IKFAST_SOLUTION_THRESH && IKabs(sj3array[ij3]-sj3array[iij3]) < IKFAST_SOLUTION_THRESH )
{
    j3valid[iij3]=false; _ij3[1] = iij3; break; 
}
}
j3 = j3array[ij3]; cj3 = cj3array[ij3]; sj3 = sj3array[ij3];
{
IkReal evalcond[4];
IkReal x11545=IKcos(j3);
IkReal x11546=IKsin(j3);
IkReal x11547=((sj0)*(sj5));
IkReal x11548=((r00)*(sj6));
IkReal x11549=((cj6)*(sj0));
IkReal x11550=((IkReal(1.00000000000000))*(cj4));
IkReal x11551=((r00)*(sj4));
IkReal x11552=((cj0)*(cj5));
IkReal x11553=((cj5)*(sj0));
IkReal x11554=((cj6)*(r11));
IkReal x11555=((r10)*(sj6));
IkReal x11556=((cj0)*(sj5));
IkReal x11557=((r10)*(sj4));
IkReal x11558=((cj4)*(cj5)*(r01));
IkReal x11559=((IkReal(1.00000000000000))*(cj0)*(cj6));
IkReal x11560=((cj0)*(sj4)*(sj6));
IkReal x11561=((sj0)*(sj4)*(sj6));
evalcond[0]=((((r12)*(x11552)))+(((cj6)*(r01)*(x11547)))+(((x11547)*(x11548)))+(((IkReal(-1.00000000000000))*(x11546)))+(((IkReal(-1.00000000000000))*(r02)*(x11553)))+(((IkReal(-1.00000000000000))*(x11555)*(x11556)))+(((IkReal(-1.00000000000000))*(x11554)*(x11556))));
evalcond[1]=((((IkReal(-1.00000000000000))*(x11548)*(x11556)))+(((IkReal(-1.00000000000000))*(cj6)*(r01)*(x11556)))+(((IkReal(-1.00000000000000))*(x11547)*(x11554)))+(x11545)+(((IkReal(-1.00000000000000))*(x11547)*(x11555)))+(((r12)*(x11553)))+(((r02)*(x11552))));
evalcond[2]=((((cj4)*(x11548)*(x11553)))+(((IkReal(-1.00000000000000))*(r12)*(x11550)*(x11556)))+(((x11549)*(x11551)))+(((IkReal(-1.00000000000000))*(x11550)*(x11552)*(x11555)))+(((r11)*(x11560)))+(x11545)+(((IkReal(-1.00000000000000))*(r01)*(x11561)))+(((IkReal(-1.00000000000000))*(x11557)*(x11559)))+(((cj4)*(r02)*(x11547)))+(((x11549)*(x11558)))+(((IkReal(-1.00000000000000))*(x11550)*(x11552)*(x11554))));
evalcond[3]=((((IkReal(-1.00000000000000))*(r02)*(x11550)*(x11556)))+(((r11)*(x11561)))+(((IkReal(-1.00000000000000))*(cj6)*(r01)*(x11550)*(x11552)))+(((IkReal(-1.00000000000000))*(x11549)*(x11557)))+(x11546)+(((IkReal(-1.00000000000000))*(cj5)*(r11)*(x11549)*(x11550)))+(((IkReal(-1.00000000000000))*(x11550)*(x11553)*(x11555)))+(((r01)*(x11560)))+(((IkReal(-1.00000000000000))*(x11548)*(x11550)*(x11552)))+(((IkReal(-1.00000000000000))*(r12)*(x11547)*(x11550)))+(((IkReal(-1.00000000000000))*(x11551)*(x11559))));
if( IKabs(evalcond[0]) > 0.000001  || IKabs(evalcond[1]) > 0.000001  || IKabs(evalcond[2]) > 0.000001  || IKabs(evalcond[3]) > 0.000001  )
{
continue;
}
}

{
std::vector<IkSingleDOFSolutionBase<IkReal> > vinfos(7);
vinfos[0].jointtype = 1;
vinfos[0].foffset = j0;
vinfos[0].indices[0] = _ij0[0];
vinfos[0].indices[1] = _ij0[1];
vinfos[0].maxsolutions = _nj0;
vinfos[1].jointtype = 1;
vinfos[1].foffset = j1;
vinfos[1].indices[0] = _ij1[0];
vinfos[1].indices[1] = _ij1[1];
vinfos[1].maxsolutions = _nj1;
vinfos[2].jointtype = 1;
vinfos[2].foffset = j2;
vinfos[2].indices[0] = _ij2[0];
vinfos[2].indices[1] = _ij2[1];
vinfos[2].maxsolutions = _nj2;
vinfos[3].jointtype = 1;
vinfos[3].foffset = j3;
vinfos[3].indices[0] = _ij3[0];
vinfos[3].indices[1] = _ij3[1];
vinfos[3].maxsolutions = _nj3;
vinfos[4].jointtype = 1;
vinfos[4].foffset = j4;
vinfos[4].indices[0] = _ij4[0];
vinfos[4].indices[1] = _ij4[1];
vinfos[4].maxsolutions = _nj4;
vinfos[5].jointtype = 1;
vinfos[5].foffset = j5;
vinfos[5].indices[0] = _ij5[0];
vinfos[5].indices[1] = _ij5[1];
vinfos[5].maxsolutions = _nj5;
vinfos[6].jointtype = 1;
vinfos[6].foffset = j6;
vinfos[6].indices[0] = _ij6[0];
vinfos[6].indices[1] = _ij6[1];
vinfos[6].maxsolutions = _nj6;
std::vector<int> vfree(0);
solutions.AddSolution(vinfos,vfree);
}
}
}

} else
{
IkReal x11562=((IkReal(1.00000000000000))*(cj0));
IkReal x11563=((cj4)*(sj6));
IkReal x11564=((sj0)*(sj4));
IkReal x11565=((cj5)*(sj6));
IkReal x11566=((sj4)*(sj5));
IkReal x11567=((r12)*(sj5));
IkReal x11568=((IkReal(0.374290000000000))*(cj5));
IkReal x11569=((r02)*(sj0));
IkReal x11570=((r20)*(sj4));
IkReal x11571=((IkReal(1.00000000000000))*(sj0));
IkReal x11572=((IkReal(1.00000000000000))*(cj5));
IkReal x11573=((cj0)*(r10));
IkReal x11574=((cj4)*(cj6));
IkReal x11575=((r00)*(sj0));
IkReal x11576=((cj6)*(r21));
IkReal x11577=((IkReal(0.374290000000000))*(sj5));
IkReal x11578=((cj0)*(r00));
IkReal x11579=((IkReal(0.0100000000000000))*(sj5));
IkReal x11580=((cj0)*(r02));
IkReal x11581=((cj5)*(sj4));
IkReal x11582=((cj6)*(r01));
IkReal x11583=((cj6)*(r11));
IkReal x11584=((r01)*(sj0));
IkReal x11585=((r10)*(sj0));
IkReal x11586=((IkReal(0.0100000000000000))*(cj5)*(cj6));
IkReal x11587=((sj6)*(x11577));
IkReal x11588=((cj0)*(cj6)*(x11577));
evalcond[0]=((IkReal(-3.14159265358979))+(IKfmod(((IkReal(4.71238898038469))+(j2)), IkReal(6.28318530717959))));
evalcond[1]=((((sj5)*(x11576)))+(((IkReal(-1.00000000000000))*(r22)*(x11572)))+(((r20)*(sj5)*(sj6))));
evalcond[2]=((IkReal(-1.00000000000000))+(((r21)*(x11563)))+(((IkReal(-1.00000000000000))*(r20)*(x11574)))+(((x11565)*(x11570)))+(((r22)*(x11566)))+(((x11576)*(x11581))));
evalcond[3]=((((IkReal(-0.0100000000000000))*(cj5)*(x11576)))+(((IkReal(-1.00000000000000))*(r22)*(x11579)))+(((IkReal(-1.00000000000000))*(r22)*(x11568)))+(((x11576)*(x11577)))+(pz)+(((IkReal(-0.0100000000000000))*(r20)*(x11565)))+(((r20)*(x11587))));
evalcond[4]=((((IkReal(-1.00000000000000))*(r21)*(sj4)*(sj6)))+(((cj5)*(r20)*(x11563)))+(((cj4)*(r22)*(sj5)))+(((cj6)*(x11570)))+(((cj5)*(r21)*(x11574))));
evalcond[5]=((((x11573)*(x11574)))+(((r00)*(x11564)*(x11565)))+(((IkReal(-1.00000000000000))*(r12)*(x11562)*(x11566)))+(((IkReal(-1.00000000000000))*(r10)*(sj4)*(x11562)*(x11565)))+(((cj5)*(x11564)*(x11582)))+(((x11563)*(x11584)))+(((IkReal(-1.00000000000000))*(r11)*(x11562)*(x11563)))+(((IkReal(-1.00000000000000))*(x11562)*(x11581)*(x11583)))+(((r02)*(sj5)*(x11564)))+(((IkReal(-1.00000000000000))*(r00)*(x11571)*(x11574))));
evalcond[6]=((((x11574)*(x11585)))+(((IkReal(-1.00000000000000))*(r11)*(x11563)*(x11571)))+(((IkReal(-1.00000000000000))*(x11564)*(x11572)*(x11583)))+(((x11574)*(x11578)))+(((IkReal(-1.00000000000000))*(r10)*(x11564)*(x11565)))+(((IkReal(-1.00000000000000))*(r00)*(sj4)*(x11562)*(x11565)))+(((IkReal(-1.00000000000000))*(r01)*(x11562)*(x11563)))+(((IkReal(-1.00000000000000))*(x11564)*(x11567)))+(((IkReal(-1.00000000000000))*(r02)*(x11562)*(x11566)))+(((IkReal(-1.00000000000000))*(x11562)*(x11581)*(x11582))));
evalcond[7]=((IkReal(-0.0690000000000000))+(((IkReal(-1.00000000000000))*(x11573)*(x11587)))+(((sj0)*(x11577)*(x11582)))+(((IkReal(0.0100000000000000))*(cj0)*(cj5)*(x11583)))+(((IkReal(-1.00000000000000))*(x11568)*(x11569)))+(((IkReal(0.0100000000000000))*(x11565)*(x11573)))+(((IkReal(-1.00000000000000))*(cj0)*(x11577)*(x11583)))+(((IkReal(-0.0100000000000000))*(x11565)*(x11575)))+(((cj0)*(r12)*(x11568)))+(((IkReal(-0.0100000000000000))*(cj5)*(sj0)*(x11582)))+(((IkReal(-1.00000000000000))*(x11569)*(x11579)))+(((IkReal(0.0100000000000000))*(cj0)*(x11567)))+(((px)*(sj0)))+(((IkReal(-1.00000000000000))*(py)*(x11562)))+(((x11575)*(x11587))));
evalcond[8]=((IkReal(-0.295420000000000))+(((x11568)*(x11580)))+(((IkReal(-1.00000000000000))*(cj0)*(x11577)*(x11582)))+(((IkReal(-1.00000000000000))*(px)*(x11562)))+(((IkReal(-1.00000000000000))*(sj0)*(x11577)*(x11583)))+(((IkReal(-1.00000000000000))*(x11585)*(x11587)))+(((IkReal(0.0100000000000000))*(x11565)*(x11578)))+(((IkReal(0.0100000000000000))*(cj0)*(cj5)*(x11582)))+(((r12)*(sj0)*(x11568)))+(((IkReal(-1.00000000000000))*(x11578)*(x11587)))+(((IkReal(0.0100000000000000))*(sj0)*(x11567)))+(((x11579)*(x11580)))+(((IkReal(-1.00000000000000))*(py)*(x11571)))+(((IkReal(0.0100000000000000))*(x11565)*(x11585)))+(((IkReal(0.0100000000000000))*(cj5)*(sj0)*(x11583))));
if( IKabs(evalcond[0]) < 0.0000010000000000  && IKabs(evalcond[1]) < 0.0000010000000000  && IKabs(evalcond[2]) < 0.0000010000000000  && IKabs(evalcond[3]) < 0.0000010000000000  && IKabs(evalcond[4]) < 0.0000010000000000  && IKabs(evalcond[5]) < 0.0000010000000000  && IKabs(evalcond[6]) < 0.0000010000000000  && IKabs(evalcond[7]) < 0.0000010000000000  && IKabs(evalcond[8]) < 0.0000010000000000  )
{
{
IkReal j3array[1], cj3array[1], sj3array[1];
bool j3valid[1]={false};
_nj3 = 1;
IkReal x11589=((IkReal(1.00000000000000))*(cj5));
IkReal x11590=((r10)*(sj5)*(sj6));
IkReal x11591=((cj6)*(sj0)*(sj5));
IkReal x11592=((r00)*(sj5)*(sj6));
IkReal x11593=((cj0)*(cj6)*(sj5));
if( IKabs(((((IkReal(-1.00000000000000))*(r01)*(x11591)))+(((IkReal(-1.00000000000000))*(cj0)*(r12)*(x11589)))+(((cj5)*(r02)*(sj0)))+(((r11)*(x11593)))+(((cj0)*(x11590)))+(((IkReal(-1.00000000000000))*(sj0)*(x11592))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(((((cj0)*(x11592)))+(((IkReal(-1.00000000000000))*(r12)*(sj0)*(x11589)))+(((sj0)*(x11590)))+(((r01)*(x11593)))+(((r11)*(x11591)))+(((IkReal(-1.00000000000000))*(cj0)*(r02)*(x11589))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(IKsqr(((((IkReal(-1.00000000000000))*(r01)*(x11591)))+(((IkReal(-1.00000000000000))*(cj0)*(r12)*(x11589)))+(((cj5)*(r02)*(sj0)))+(((r11)*(x11593)))+(((cj0)*(x11590)))+(((IkReal(-1.00000000000000))*(sj0)*(x11592)))))+IKsqr(((((cj0)*(x11592)))+(((IkReal(-1.00000000000000))*(r12)*(sj0)*(x11589)))+(((sj0)*(x11590)))+(((r01)*(x11593)))+(((r11)*(x11591)))+(((IkReal(-1.00000000000000))*(cj0)*(r02)*(x11589)))))-1) <= IKFAST_SINCOS_THRESH )
    continue;
j3array[0]=IKatan2(((((IkReal(-1.00000000000000))*(r01)*(x11591)))+(((IkReal(-1.00000000000000))*(cj0)*(r12)*(x11589)))+(((cj5)*(r02)*(sj0)))+(((r11)*(x11593)))+(((cj0)*(x11590)))+(((IkReal(-1.00000000000000))*(sj0)*(x11592)))), ((((cj0)*(x11592)))+(((IkReal(-1.00000000000000))*(r12)*(sj0)*(x11589)))+(((sj0)*(x11590)))+(((r01)*(x11593)))+(((r11)*(x11591)))+(((IkReal(-1.00000000000000))*(cj0)*(r02)*(x11589)))));
sj3array[0]=IKsin(j3array[0]);
cj3array[0]=IKcos(j3array[0]);
if( j3array[0] > IKPI )
{
    j3array[0]-=IK2PI;
}
else if( j3array[0] < -IKPI )
{    j3array[0]+=IK2PI;
}
j3valid[0] = true;
for(int ij3 = 0; ij3 < 1; ++ij3)
{
if( !j3valid[ij3] )
{
    continue;
}
_ij3[0] = ij3; _ij3[1] = -1;
for(int iij3 = ij3+1; iij3 < 1; ++iij3)
{
if( j3valid[iij3] && IKabs(cj3array[ij3]-cj3array[iij3]) < IKFAST_SOLUTION_THRESH && IKabs(sj3array[ij3]-sj3array[iij3]) < IKFAST_SOLUTION_THRESH )
{
    j3valid[iij3]=false; _ij3[1] = iij3; break; 
}
}
j3 = j3array[ij3]; cj3 = cj3array[ij3]; sj3 = sj3array[ij3];
{
IkReal evalcond[4];
IkReal x11594=IKcos(j3);
IkReal x11595=IKsin(j3);
IkReal x11596=((sj0)*(sj5));
IkReal x11597=((r00)*(sj6));
IkReal x11598=((IkReal(1.00000000000000))*(cj4));
IkReal x11599=((cj6)*(sj0));
IkReal x11600=((r00)*(sj4));
IkReal x11601=((cj0)*(cj5));
IkReal x11602=((cj6)*(r01));
IkReal x11603=((cj5)*(sj0));
IkReal x11604=((cj0)*(sj5));
IkReal x11605=((cj6)*(r11));
IkReal x11606=((r10)*(sj6));
IkReal x11607=((r10)*(sj4));
IkReal x11608=((cj0)*(sj4)*(sj6));
IkReal x11609=((sj0)*(sj4)*(sj6));
IkReal x11610=((IkReal(1.00000000000000))*(cj0)*(cj6));
evalcond[0]=((x11595)+(((r12)*(x11601)))+(((x11596)*(x11602)))+(((IkReal(-1.00000000000000))*(x11604)*(x11605)))+(((IkReal(-1.00000000000000))*(x11604)*(x11606)))+(((IkReal(-1.00000000000000))*(r02)*(x11603)))+(((x11596)*(x11597))));
evalcond[1]=((x11594)+(((IkReal(-1.00000000000000))*(x11602)*(x11604)))+(((r02)*(x11601)))+(((IkReal(-1.00000000000000))*(x11597)*(x11604)))+(((IkReal(-1.00000000000000))*(x11596)*(x11605)))+(((r12)*(x11603)))+(((IkReal(-1.00000000000000))*(x11596)*(x11606))));
evalcond[2]=((((cj4)*(x11597)*(x11603)))+(((cj4)*(cj5)*(r01)*(x11599)))+(((IkReal(-1.00000000000000))*(x11607)*(x11610)))+(((IkReal(-1.00000000000000))*(r12)*(x11598)*(x11604)))+(((x11599)*(x11600)))+(((IkReal(-1.00000000000000))*(x11594)))+(((IkReal(-1.00000000000000))*(x11598)*(x11601)*(x11606)))+(((IkReal(-1.00000000000000))*(r01)*(x11609)))+(((r11)*(x11608)))+(((IkReal(-1.00000000000000))*(x11598)*(x11601)*(x11605)))+(((cj4)*(r02)*(x11596))));
evalcond[3]=((((IkReal(-1.00000000000000))*(cj5)*(r11)*(x11598)*(x11599)))+(x11595)+(((IkReal(-1.00000000000000))*(x11600)*(x11610)))+(((IkReal(-1.00000000000000))*(x11598)*(x11603)*(x11606)))+(((IkReal(-1.00000000000000))*(x11597)*(x11598)*(x11601)))+(((IkReal(-1.00000000000000))*(r02)*(x11598)*(x11604)))+(((IkReal(-1.00000000000000))*(r12)*(x11596)*(x11598)))+(((r11)*(x11609)))+(((IkReal(-1.00000000000000))*(x11599)*(x11607)))+(((IkReal(-1.00000000000000))*(x11598)*(x11601)*(x11602)))+(((r01)*(x11608))));
if( IKabs(evalcond[0]) > 0.000001  || IKabs(evalcond[1]) > 0.000001  || IKabs(evalcond[2]) > 0.000001  || IKabs(evalcond[3]) > 0.000001  )
{
continue;
}
}

{
std::vector<IkSingleDOFSolutionBase<IkReal> > vinfos(7);
vinfos[0].jointtype = 1;
vinfos[0].foffset = j0;
vinfos[0].indices[0] = _ij0[0];
vinfos[0].indices[1] = _ij0[1];
vinfos[0].maxsolutions = _nj0;
vinfos[1].jointtype = 1;
vinfos[1].foffset = j1;
vinfos[1].indices[0] = _ij1[0];
vinfos[1].indices[1] = _ij1[1];
vinfos[1].maxsolutions = _nj1;
vinfos[2].jointtype = 1;
vinfos[2].foffset = j2;
vinfos[2].indices[0] = _ij2[0];
vinfos[2].indices[1] = _ij2[1];
vinfos[2].maxsolutions = _nj2;
vinfos[3].jointtype = 1;
vinfos[3].foffset = j3;
vinfos[3].indices[0] = _ij3[0];
vinfos[3].indices[1] = _ij3[1];
vinfos[3].maxsolutions = _nj3;
vinfos[4].jointtype = 1;
vinfos[4].foffset = j4;
vinfos[4].indices[0] = _ij4[0];
vinfos[4].indices[1] = _ij4[1];
vinfos[4].maxsolutions = _nj4;
vinfos[5].jointtype = 1;
vinfos[5].foffset = j5;
vinfos[5].indices[0] = _ij5[0];
vinfos[5].indices[1] = _ij5[1];
vinfos[5].maxsolutions = _nj5;
vinfos[6].jointtype = 1;
vinfos[6].foffset = j6;
vinfos[6].indices[0] = _ij6[0];
vinfos[6].indices[1] = _ij6[1];
vinfos[6].maxsolutions = _nj6;
std::vector<int> vfree(0);
solutions.AddSolution(vinfos,vfree);
}
}
}

} else
{
if( 1 )
{
continue;

} else
{
}
}
}
}
}
}

} else
{
{
IkReal j3array[1], cj3array[1], sj3array[1];
bool j3valid[1]={false};
_nj3 = 1;
IkReal x11611=((sj0)*(sj5));
IkReal x11612=((r00)*(sj6));
IkReal x11613=((IkReal(1.00000000000000))*(cj5));
IkReal x11614=((cj6)*(r11));
IkReal x11615=((cj6)*(r01));
IkReal x11616=((cj0)*(sj5));
IkReal x11617=((r10)*(sj6));
if( IKabs(((((IKabs(sj2) != 0)?((IkReal)1/(sj2)):(IkReal)1.0e30))*(((((IkReal(-1.00000000000000))*(r02)*(sj0)*(x11613)))+(((IkReal(-1.00000000000000))*(x11614)*(x11616)))+(((x11611)*(x11615)))+(((cj0)*(cj5)*(r12)))+(((x11611)*(x11612)))+(((IkReal(-1.00000000000000))*(x11616)*(x11617))))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(((((x11615)*(x11616)))+(((IkReal(-1.00000000000000))*(cj0)*(r02)*(x11613)))+(((x11611)*(x11614)))+(((x11611)*(x11617)))+(((x11612)*(x11616)))+(((IkReal(-1.00000000000000))*(r12)*(sj0)*(x11613))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(IKsqr(((((IKabs(sj2) != 0)?((IkReal)1/(sj2)):(IkReal)1.0e30))*(((((IkReal(-1.00000000000000))*(r02)*(sj0)*(x11613)))+(((IkReal(-1.00000000000000))*(x11614)*(x11616)))+(((x11611)*(x11615)))+(((cj0)*(cj5)*(r12)))+(((x11611)*(x11612)))+(((IkReal(-1.00000000000000))*(x11616)*(x11617)))))))+IKsqr(((((x11615)*(x11616)))+(((IkReal(-1.00000000000000))*(cj0)*(r02)*(x11613)))+(((x11611)*(x11614)))+(((x11611)*(x11617)))+(((x11612)*(x11616)))+(((IkReal(-1.00000000000000))*(r12)*(sj0)*(x11613)))))-1) <= IKFAST_SINCOS_THRESH )
    continue;
j3array[0]=IKatan2(((((IKabs(sj2) != 0)?((IkReal)1/(sj2)):(IkReal)1.0e30))*(((((IkReal(-1.00000000000000))*(r02)*(sj0)*(x11613)))+(((IkReal(-1.00000000000000))*(x11614)*(x11616)))+(((x11611)*(x11615)))+(((cj0)*(cj5)*(r12)))+(((x11611)*(x11612)))+(((IkReal(-1.00000000000000))*(x11616)*(x11617)))))), ((((x11615)*(x11616)))+(((IkReal(-1.00000000000000))*(cj0)*(r02)*(x11613)))+(((x11611)*(x11614)))+(((x11611)*(x11617)))+(((x11612)*(x11616)))+(((IkReal(-1.00000000000000))*(r12)*(sj0)*(x11613)))));
sj3array[0]=IKsin(j3array[0]);
cj3array[0]=IKcos(j3array[0]);
if( j3array[0] > IKPI )
{
    j3array[0]-=IK2PI;
}
else if( j3array[0] < -IKPI )
{    j3array[0]+=IK2PI;
}
j3valid[0] = true;
for(int ij3 = 0; ij3 < 1; ++ij3)
{
if( !j3valid[ij3] )
{
    continue;
}
_ij3[0] = ij3; _ij3[1] = -1;
for(int iij3 = ij3+1; iij3 < 1; ++iij3)
{
if( j3valid[iij3] && IKabs(cj3array[ij3]-cj3array[iij3]) < IKFAST_SOLUTION_THRESH && IKabs(sj3array[ij3]-sj3array[iij3]) < IKFAST_SOLUTION_THRESH )
{
    j3valid[iij3]=false; _ij3[1] = iij3; break; 
}
}
j3 = j3array[ij3]; cj3 = cj3array[ij3]; sj3 = sj3array[ij3];
{
IkReal evalcond[6];
IkReal x11618=IKsin(j3);
IkReal x11619=IKcos(j3);
IkReal x11620=((sj0)*(sj5));
IkReal x11621=((r00)*(sj6));
IkReal x11622=((IkReal(1.00000000000000))*(cj4));
IkReal x11623=((cj6)*(r01));
IkReal x11624=((cj0)*(cj5));
IkReal x11625=((cj5)*(sj0));
IkReal x11626=((cj6)*(r11));
IkReal x11627=((cj6)*(sj4));
IkReal x11628=((cj0)*(sj5));
IkReal x11629=((cj4)*(cj5));
IkReal x11630=((cj6)*(r21));
IkReal x11631=((r20)*(sj6));
IkReal x11632=((r10)*(sj6));
IkReal x11633=((IkReal(1.00000000000000))*(cj0));
IkReal x11634=((cj0)*(sj4)*(sj6));
IkReal x11635=((sj0)*(sj4)*(sj6));
evalcond[0]=((((sj5)*(x11631)))+(((IkReal(-1.00000000000000))*(cj5)*(r22)))+(((sj5)*(x11630)))+(((cj2)*(x11618))));
evalcond[1]=((((IkReal(-1.00000000000000))*(r21)*(sj4)*(sj6)))+(((x11629)*(x11631)))+(((x11629)*(x11630)))+(((cj4)*(r22)*(sj5)))+(((IkReal(-1.00000000000000))*(cj2)*(x11619)))+(((r20)*(x11627))));
evalcond[2]=((((x11620)*(x11623)))+(((IkReal(-1.00000000000000))*(r02)*(x11625)))+(((r12)*(x11624)))+(((IkReal(-1.00000000000000))*(sj2)*(x11618)))+(((x11620)*(x11621)))+(((IkReal(-1.00000000000000))*(x11628)*(x11632)))+(((IkReal(-1.00000000000000))*(x11626)*(x11628))));
evalcond[3]=((((IkReal(-1.00000000000000))*(x11623)*(x11628)))+(((IkReal(-1.00000000000000))*(x11621)*(x11628)))+(((IkReal(-1.00000000000000))*(x11620)*(x11626)))+(((r12)*(x11625)))+(((r02)*(x11624)))+(((IkReal(-1.00000000000000))*(x11620)*(x11632)))+(x11619));
evalcond[4]=((((cj4)*(x11621)*(x11625)))+(((cj4)*(r02)*(x11620)))+(((IkReal(-1.00000000000000))*(r12)*(x11622)*(x11628)))+(((IkReal(-1.00000000000000))*(x11622)*(x11624)*(x11632)))+(((IkReal(-1.00000000000000))*(r01)*(x11635)))+(((sj2)*(x11619)))+(((cj4)*(x11623)*(x11625)))+(((IkReal(-1.00000000000000))*(r10)*(x11627)*(x11633)))+(((r11)*(x11634)))+(((r00)*(sj0)*(x11627)))+(((IkReal(-1.00000000000000))*(x11622)*(x11624)*(x11626))));
evalcond[5]=((((IkReal(-1.00000000000000))*(x11621)*(x11622)*(x11624)))+(((IkReal(-1.00000000000000))*(r00)*(x11627)*(x11633)))+(((IkReal(-1.00000000000000))*(x11622)*(x11625)*(x11632)))+(((r01)*(x11634)))+(((IkReal(-1.00000000000000))*(r12)*(x11620)*(x11622)))+(((IkReal(-1.00000000000000))*(x11622)*(x11625)*(x11626)))+(((IkReal(-1.00000000000000))*(r10)*(sj0)*(x11627)))+(((r11)*(x11635)))+(((IkReal(-1.00000000000000))*(x11622)*(x11623)*(x11624)))+(((IkReal(-1.00000000000000))*(r02)*(x11622)*(x11628)))+(x11618));
if( IKabs(evalcond[0]) > 0.000001  || IKabs(evalcond[1]) > 0.000001  || IKabs(evalcond[2]) > 0.000001  || IKabs(evalcond[3]) > 0.000001  || IKabs(evalcond[4]) > 0.000001  || IKabs(evalcond[5]) > 0.000001  )
{
continue;
}
}

{
std::vector<IkSingleDOFSolutionBase<IkReal> > vinfos(7);
vinfos[0].jointtype = 1;
vinfos[0].foffset = j0;
vinfos[0].indices[0] = _ij0[0];
vinfos[0].indices[1] = _ij0[1];
vinfos[0].maxsolutions = _nj0;
vinfos[1].jointtype = 1;
vinfos[1].foffset = j1;
vinfos[1].indices[0] = _ij1[0];
vinfos[1].indices[1] = _ij1[1];
vinfos[1].maxsolutions = _nj1;
vinfos[2].jointtype = 1;
vinfos[2].foffset = j2;
vinfos[2].indices[0] = _ij2[0];
vinfos[2].indices[1] = _ij2[1];
vinfos[2].maxsolutions = _nj2;
vinfos[3].jointtype = 1;
vinfos[3].foffset = j3;
vinfos[3].indices[0] = _ij3[0];
vinfos[3].indices[1] = _ij3[1];
vinfos[3].maxsolutions = _nj3;
vinfos[4].jointtype = 1;
vinfos[4].foffset = j4;
vinfos[4].indices[0] = _ij4[0];
vinfos[4].indices[1] = _ij4[1];
vinfos[4].maxsolutions = _nj4;
vinfos[5].jointtype = 1;
vinfos[5].foffset = j5;
vinfos[5].indices[0] = _ij5[0];
vinfos[5].indices[1] = _ij5[1];
vinfos[5].maxsolutions = _nj5;
vinfos[6].jointtype = 1;
vinfos[6].foffset = j6;
vinfos[6].indices[0] = _ij6[0];
vinfos[6].indices[1] = _ij6[1];
vinfos[6].maxsolutions = _nj6;
std::vector<int> vfree(0);
solutions.AddSolution(vinfos,vfree);
}
}
}

}

}

} else
{
{
IkReal j3array[1], cj3array[1], sj3array[1];
bool j3valid[1]={false};
_nj3 = 1;
IkReal x11636=((cj6)*(sj5));
IkReal x11637=((IkReal(1.00000000000000))*(cj5));
IkReal x11638=((sj5)*(sj6));
if( IKabs(((((IKabs(cj2) != 0)?((IkReal)1/(cj2)):(IkReal)1.0e30))*(((((IkReal(-1.00000000000000))*(r20)*(x11638)))+(((cj5)*(r22)))+(((IkReal(-1.00000000000000))*(r21)*(x11636))))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(((((cj0)*(r01)*(x11636)))+(((IkReal(-1.00000000000000))*(r12)*(sj0)*(x11637)))+(((IkReal(-1.00000000000000))*(cj0)*(r02)*(x11637)))+(((r11)*(sj0)*(x11636)))+(((r10)*(sj0)*(x11638)))+(((cj0)*(r00)*(x11638))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(IKsqr(((((IKabs(cj2) != 0)?((IkReal)1/(cj2)):(IkReal)1.0e30))*(((((IkReal(-1.00000000000000))*(r20)*(x11638)))+(((cj5)*(r22)))+(((IkReal(-1.00000000000000))*(r21)*(x11636)))))))+IKsqr(((((cj0)*(r01)*(x11636)))+(((IkReal(-1.00000000000000))*(r12)*(sj0)*(x11637)))+(((IkReal(-1.00000000000000))*(cj0)*(r02)*(x11637)))+(((r11)*(sj0)*(x11636)))+(((r10)*(sj0)*(x11638)))+(((cj0)*(r00)*(x11638)))))-1) <= IKFAST_SINCOS_THRESH )
    continue;
j3array[0]=IKatan2(((((IKabs(cj2) != 0)?((IkReal)1/(cj2)):(IkReal)1.0e30))*(((((IkReal(-1.00000000000000))*(r20)*(x11638)))+(((cj5)*(r22)))+(((IkReal(-1.00000000000000))*(r21)*(x11636)))))), ((((cj0)*(r01)*(x11636)))+(((IkReal(-1.00000000000000))*(r12)*(sj0)*(x11637)))+(((IkReal(-1.00000000000000))*(cj0)*(r02)*(x11637)))+(((r11)*(sj0)*(x11636)))+(((r10)*(sj0)*(x11638)))+(((cj0)*(r00)*(x11638)))));
sj3array[0]=IKsin(j3array[0]);
cj3array[0]=IKcos(j3array[0]);
if( j3array[0] > IKPI )
{
    j3array[0]-=IK2PI;
}
else if( j3array[0] < -IKPI )
{    j3array[0]+=IK2PI;
}
j3valid[0] = true;
for(int ij3 = 0; ij3 < 1; ++ij3)
{
if( !j3valid[ij3] )
{
    continue;
}
_ij3[0] = ij3; _ij3[1] = -1;
for(int iij3 = ij3+1; iij3 < 1; ++iij3)
{
if( j3valid[iij3] && IKabs(cj3array[ij3]-cj3array[iij3]) < IKFAST_SOLUTION_THRESH && IKabs(sj3array[ij3]-sj3array[iij3]) < IKFAST_SOLUTION_THRESH )
{
    j3valid[iij3]=false; _ij3[1] = iij3; break; 
}
}
j3 = j3array[ij3]; cj3 = cj3array[ij3]; sj3 = sj3array[ij3];
{
IkReal evalcond[6];
IkReal x11639=IKsin(j3);
IkReal x11640=IKcos(j3);
IkReal x11641=((sj0)*(sj5));
IkReal x11642=((r00)*(sj6));
IkReal x11643=((IkReal(1.00000000000000))*(cj4));
IkReal x11644=((cj6)*(r01));
IkReal x11645=((cj0)*(cj5));
IkReal x11646=((cj5)*(sj0));
IkReal x11647=((cj6)*(r11));
IkReal x11648=((cj6)*(sj4));
IkReal x11649=((cj0)*(sj5));
IkReal x11650=((cj4)*(cj5));
IkReal x11651=((cj6)*(r21));
IkReal x11652=((r20)*(sj6));
IkReal x11653=((r10)*(sj6));
IkReal x11654=((IkReal(1.00000000000000))*(cj0));
IkReal x11655=((cj0)*(sj4)*(sj6));
IkReal x11656=((sj0)*(sj4)*(sj6));
evalcond[0]=((((sj5)*(x11651)))+(((sj5)*(x11652)))+(((IkReal(-1.00000000000000))*(cj5)*(r22)))+(((cj2)*(x11639))));
evalcond[1]=((((IkReal(-1.00000000000000))*(cj2)*(x11640)))+(((IkReal(-1.00000000000000))*(r21)*(sj4)*(sj6)))+(((r20)*(x11648)))+(((cj4)*(r22)*(sj5)))+(((x11650)*(x11651)))+(((x11650)*(x11652))));
evalcond[2]=((((r12)*(x11645)))+(((IkReal(-1.00000000000000))*(x11647)*(x11649)))+(((IkReal(-1.00000000000000))*(x11649)*(x11653)))+(((IkReal(-1.00000000000000))*(r02)*(x11646)))+(((x11641)*(x11642)))+(((x11641)*(x11644)))+(((IkReal(-1.00000000000000))*(sj2)*(x11639))));
evalcond[3]=((((r12)*(x11646)))+(((IkReal(-1.00000000000000))*(x11642)*(x11649)))+(((IkReal(-1.00000000000000))*(x11641)*(x11653)))+(((IkReal(-1.00000000000000))*(x11644)*(x11649)))+(((IkReal(-1.00000000000000))*(x11641)*(x11647)))+(x11640)+(((r02)*(x11645))));
evalcond[4]=((((IkReal(-1.00000000000000))*(x11643)*(x11645)*(x11647)))+(((cj4)*(x11642)*(x11646)))+(((cj4)*(x11644)*(x11646)))+(((IkReal(-1.00000000000000))*(r12)*(x11643)*(x11649)))+(((cj4)*(r02)*(x11641)))+(((IkReal(-1.00000000000000))*(r01)*(x11656)))+(((sj2)*(x11640)))+(((IkReal(-1.00000000000000))*(r10)*(x11648)*(x11654)))+(((r11)*(x11655)))+(((IkReal(-1.00000000000000))*(x11643)*(x11645)*(x11653)))+(((r00)*(sj0)*(x11648))));
evalcond[5]=((((IkReal(-1.00000000000000))*(x11643)*(x11646)*(x11653)))+(((IkReal(-1.00000000000000))*(r00)*(x11648)*(x11654)))+(((IkReal(-1.00000000000000))*(r02)*(x11643)*(x11649)))+(x11639)+(((IkReal(-1.00000000000000))*(x11642)*(x11643)*(x11645)))+(((r11)*(x11656)))+(((IkReal(-1.00000000000000))*(x11643)*(x11646)*(x11647)))+(((IkReal(-1.00000000000000))*(r10)*(sj0)*(x11648)))+(((IkReal(-1.00000000000000))*(x11643)*(x11644)*(x11645)))+(((IkReal(-1.00000000000000))*(r12)*(x11641)*(x11643)))+(((r01)*(x11655))));
if( IKabs(evalcond[0]) > 0.000001  || IKabs(evalcond[1]) > 0.000001  || IKabs(evalcond[2]) > 0.000001  || IKabs(evalcond[3]) > 0.000001  || IKabs(evalcond[4]) > 0.000001  || IKabs(evalcond[5]) > 0.000001  )
{
continue;
}
}

{
std::vector<IkSingleDOFSolutionBase<IkReal> > vinfos(7);
vinfos[0].jointtype = 1;
vinfos[0].foffset = j0;
vinfos[0].indices[0] = _ij0[0];
vinfos[0].indices[1] = _ij0[1];
vinfos[0].maxsolutions = _nj0;
vinfos[1].jointtype = 1;
vinfos[1].foffset = j1;
vinfos[1].indices[0] = _ij1[0];
vinfos[1].indices[1] = _ij1[1];
vinfos[1].maxsolutions = _nj1;
vinfos[2].jointtype = 1;
vinfos[2].foffset = j2;
vinfos[2].indices[0] = _ij2[0];
vinfos[2].indices[1] = _ij2[1];
vinfos[2].maxsolutions = _nj2;
vinfos[3].jointtype = 1;
vinfos[3].foffset = j3;
vinfos[3].indices[0] = _ij3[0];
vinfos[3].indices[1] = _ij3[1];
vinfos[3].maxsolutions = _nj3;
vinfos[4].jointtype = 1;
vinfos[4].foffset = j4;
vinfos[4].indices[0] = _ij4[0];
vinfos[4].indices[1] = _ij4[1];
vinfos[4].maxsolutions = _nj4;
vinfos[5].jointtype = 1;
vinfos[5].foffset = j5;
vinfos[5].indices[0] = _ij5[0];
vinfos[5].indices[1] = _ij5[1];
vinfos[5].maxsolutions = _nj5;
vinfos[6].jointtype = 1;
vinfos[6].foffset = j6;
vinfos[6].indices[0] = _ij6[0];
vinfos[6].indices[1] = _ij6[1];
vinfos[6].maxsolutions = _nj6;
std::vector<int> vfree(0);
solutions.AddSolution(vinfos,vfree);
}
}
}

}

}

} else
{
{
IkReal j3array[1], cj3array[1], sj3array[1];
bool j3valid[1]={false};
_nj3 = 1;
IkReal x11657=((IkReal(1.00000000000000))*(r21));
IkReal x11658=((cj4)*(cj5));
IkReal x11659=((r20)*(sj6));
if( IKabs(((gconst10)*(((((IkReal(-1.00000000000000))*(sj5)*(x11659)))+(((IkReal(-1.00000000000000))*(cj6)*(sj5)*(x11657)))+(((cj5)*(r22))))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(((gconst10)*(((((cj6)*(r20)*(sj4)))+(((IkReal(-1.00000000000000))*(sj4)*(sj6)*(x11657)))+(((cj4)*(r22)*(sj5)))+(((x11658)*(x11659)))+(((cj6)*(r21)*(x11658))))))) < IKFAST_ATAN2_MAGTHRESH )
    continue;
j3array[0]=IKatan2(((gconst10)*(((((IkReal(-1.00000000000000))*(sj5)*(x11659)))+(((IkReal(-1.00000000000000))*(cj6)*(sj5)*(x11657)))+(((cj5)*(r22)))))), ((gconst10)*(((((cj6)*(r20)*(sj4)))+(((IkReal(-1.00000000000000))*(sj4)*(sj6)*(x11657)))+(((cj4)*(r22)*(sj5)))+(((x11658)*(x11659)))+(((cj6)*(r21)*(x11658)))))));
sj3array[0]=IKsin(j3array[0]);
cj3array[0]=IKcos(j3array[0]);
if( j3array[0] > IKPI )
{
    j3array[0]-=IK2PI;
}
else if( j3array[0] < -IKPI )
{    j3array[0]+=IK2PI;
}
j3valid[0] = true;
for(int ij3 = 0; ij3 < 1; ++ij3)
{
if( !j3valid[ij3] )
{
    continue;
}
_ij3[0] = ij3; _ij3[1] = -1;
for(int iij3 = ij3+1; iij3 < 1; ++iij3)
{
if( j3valid[iij3] && IKabs(cj3array[ij3]-cj3array[iij3]) < IKFAST_SOLUTION_THRESH && IKabs(sj3array[ij3]-sj3array[iij3]) < IKFAST_SOLUTION_THRESH )
{
    j3valid[iij3]=false; _ij3[1] = iij3; break; 
}
}
j3 = j3array[ij3]; cj3 = cj3array[ij3]; sj3 = sj3array[ij3];
{
IkReal evalcond[6];
IkReal x11660=IKsin(j3);
IkReal x11661=IKcos(j3);
IkReal x11662=((sj0)*(sj5));
IkReal x11663=((r00)*(sj6));
IkReal x11664=((IkReal(1.00000000000000))*(cj4));
IkReal x11665=((cj6)*(r01));
IkReal x11666=((cj0)*(cj5));
IkReal x11667=((cj5)*(sj0));
IkReal x11668=((cj6)*(r11));
IkReal x11669=((cj6)*(sj4));
IkReal x11670=((cj0)*(sj5));
IkReal x11671=((cj4)*(cj5));
IkReal x11672=((cj6)*(r21));
IkReal x11673=((r20)*(sj6));
IkReal x11674=((r10)*(sj6));
IkReal x11675=((IkReal(1.00000000000000))*(cj0));
IkReal x11676=((cj0)*(sj4)*(sj6));
IkReal x11677=((sj0)*(sj4)*(sj6));
evalcond[0]=((((sj5)*(x11673)))+(((sj5)*(x11672)))+(((IkReal(-1.00000000000000))*(cj5)*(r22)))+(((cj2)*(x11660))));
evalcond[1]=((((x11671)*(x11673)))+(((r20)*(x11669)))+(((IkReal(-1.00000000000000))*(r21)*(sj4)*(sj6)))+(((cj4)*(r22)*(sj5)))+(((IkReal(-1.00000000000000))*(cj2)*(x11661)))+(((x11671)*(x11672))));
evalcond[2]=((((x11662)*(x11663)))+(((IkReal(-1.00000000000000))*(x11670)*(x11674)))+(((x11662)*(x11665)))+(((IkReal(-1.00000000000000))*(x11668)*(x11670)))+(((r12)*(x11666)))+(((IkReal(-1.00000000000000))*(r02)*(x11667)))+(((IkReal(-1.00000000000000))*(sj2)*(x11660))));
evalcond[3]=((x11661)+(((IkReal(-1.00000000000000))*(x11663)*(x11670)))+(((r12)*(x11667)))+(((IkReal(-1.00000000000000))*(x11662)*(x11668)))+(((IkReal(-1.00000000000000))*(x11665)*(x11670)))+(((IkReal(-1.00000000000000))*(x11662)*(x11674)))+(((r02)*(x11666))));
evalcond[4]=((((cj4)*(r02)*(x11662)))+(((r00)*(sj0)*(x11669)))+(((cj4)*(x11665)*(x11667)))+(((sj2)*(x11661)))+(((cj4)*(x11663)*(x11667)))+(((IkReal(-1.00000000000000))*(x11664)*(x11666)*(x11674)))+(((IkReal(-1.00000000000000))*(r01)*(x11677)))+(((IkReal(-1.00000000000000))*(r10)*(x11669)*(x11675)))+(((r11)*(x11676)))+(((IkReal(-1.00000000000000))*(x11664)*(x11666)*(x11668)))+(((IkReal(-1.00000000000000))*(r12)*(x11664)*(x11670))));
evalcond[5]=((((r01)*(x11676)))+(((IkReal(-1.00000000000000))*(x11664)*(x11667)*(x11668)))+(x11660)+(((IkReal(-1.00000000000000))*(x11663)*(x11664)*(x11666)))+(((IkReal(-1.00000000000000))*(r12)*(x11662)*(x11664)))+(((IkReal(-1.00000000000000))*(r10)*(sj0)*(x11669)))+(((r11)*(x11677)))+(((IkReal(-1.00000000000000))*(x11664)*(x11665)*(x11666)))+(((IkReal(-1.00000000000000))*(r00)*(x11669)*(x11675)))+(((IkReal(-1.00000000000000))*(x11664)*(x11667)*(x11674)))+(((IkReal(-1.00000000000000))*(r02)*(x11664)*(x11670))));
if( IKabs(evalcond[0]) > 0.000001  || IKabs(evalcond[1]) > 0.000001  || IKabs(evalcond[2]) > 0.000001  || IKabs(evalcond[3]) > 0.000001  || IKabs(evalcond[4]) > 0.000001  || IKabs(evalcond[5]) > 0.000001  )
{
continue;
}
}

{
std::vector<IkSingleDOFSolutionBase<IkReal> > vinfos(7);
vinfos[0].jointtype = 1;
vinfos[0].foffset = j0;
vinfos[0].indices[0] = _ij0[0];
vinfos[0].indices[1] = _ij0[1];
vinfos[0].maxsolutions = _nj0;
vinfos[1].jointtype = 1;
vinfos[1].foffset = j1;
vinfos[1].indices[0] = _ij1[0];
vinfos[1].indices[1] = _ij1[1];
vinfos[1].maxsolutions = _nj1;
vinfos[2].jointtype = 1;
vinfos[2].foffset = j2;
vinfos[2].indices[0] = _ij2[0];
vinfos[2].indices[1] = _ij2[1];
vinfos[2].maxsolutions = _nj2;
vinfos[3].jointtype = 1;
vinfos[3].foffset = j3;
vinfos[3].indices[0] = _ij3[0];
vinfos[3].indices[1] = _ij3[1];
vinfos[3].maxsolutions = _nj3;
vinfos[4].jointtype = 1;
vinfos[4].foffset = j4;
vinfos[4].indices[0] = _ij4[0];
vinfos[4].indices[1] = _ij4[1];
vinfos[4].maxsolutions = _nj4;
vinfos[5].jointtype = 1;
vinfos[5].foffset = j5;
vinfos[5].indices[0] = _ij5[0];
vinfos[5].indices[1] = _ij5[1];
vinfos[5].maxsolutions = _nj5;
vinfos[6].jointtype = 1;
vinfos[6].foffset = j6;
vinfos[6].indices[0] = _ij6[0];
vinfos[6].indices[1] = _ij6[1];
vinfos[6].maxsolutions = _nj6;
std::vector<int> vfree(0);
solutions.AddSolution(vinfos,vfree);
}
}
}

}

}

} else
{
IkReal x11678=((IkReal(1.00000000000000))*(cj0));
IkReal x11679=((cj4)*(sj6));
IkReal x11680=((sj0)*(sj4));
IkReal x11681=((cj5)*(sj6));
IkReal x11682=((sj4)*(sj5));
IkReal x11683=((r12)*(sj5));
IkReal x11684=((IkReal(0.374290000000000))*(cj5));
IkReal x11685=((r02)*(sj0));
IkReal x11686=((IkReal(1.00000000000000))*(sj0));
IkReal x11687=((cj0)*(r10));
IkReal x11688=((cj4)*(cj6));
IkReal x11689=((r00)*(sj0));
IkReal x11690=((cj6)*(r21));
IkReal x11691=((IkReal(0.374290000000000))*(sj5));
IkReal x11692=((IkReal(0.0100000000000000))*(sj5));
IkReal x11693=((cj0)*(r02));
IkReal x11694=((cj5)*(sj4));
IkReal x11695=((cj6)*(r01));
IkReal x11696=((cj0)*(r00));
IkReal x11697=((cj6)*(r11));
IkReal x11698=((r01)*(sj0));
IkReal x11699=((r10)*(sj0));
IkReal x11700=((IkReal(0.0100000000000000))*(cj5)*(cj6));
IkReal x11701=((sj6)*(x11691));
IkReal x11702=((cj0)*(cj6)*(x11691));
evalcond[0]=((IkReal(-3.14159265358979))+(IKfmod(((IkReal(1.57079632679490))+(j2)), IkReal(6.28318530717959))));
evalcond[1]=((((IkReal(-1.00000000000000))*(r20)*(x11688)))+(((x11690)*(x11694)))+(((r20)*(sj4)*(x11681)))+(((IkReal(-1.00000000000000))*(cj1)))+(((r21)*(x11679)))+(((r22)*(x11682))));
evalcond[2]=((((IkReal(-0.0100000000000000))*(r20)*(x11681)))+(((IkReal(0.364420000000000))*(sj1)))+(((IkReal(-1.00000000000000))*(r22)*(x11692)))+(((IkReal(-1.00000000000000))*(r22)*(x11684)))+(((r20)*(x11701)))+(((IkReal(-0.0100000000000000))*(cj5)*(x11690)))+(((x11690)*(x11691)))+(pz));
evalcond[3]=((((IkReal(-1.00000000000000))*(x11678)*(x11694)*(x11697)))+(((IkReal(-1.00000000000000))*(r11)*(x11678)*(x11679)))+(((IkReal(-1.00000000000000))*(r00)*(x11686)*(x11688)))+(((r00)*(x11680)*(x11681)))+(((r02)*(sj5)*(x11680)))+(((IkReal(-1.00000000000000))*(r10)*(sj4)*(x11678)*(x11681)))+(((x11687)*(x11688)))+(((IkReal(-1.00000000000000))*(r12)*(x11678)*(x11682)))+(((x11679)*(x11698)))+(((cj5)*(x11680)*(x11695))));
evalcond[4]=((((IkReal(-1.00000000000000))*(x11678)*(x11694)*(x11695)))+(((IkReal(-1.00000000000000))*(r00)*(sj4)*(x11678)*(x11681)))+(sj1)+(((x11688)*(x11696)))+(((IkReal(-1.00000000000000))*(r02)*(x11678)*(x11682)))+(((IkReal(-1.00000000000000))*(r10)*(x11680)*(x11681)))+(((IkReal(-1.00000000000000))*(r11)*(x11679)*(x11686)))+(((IkReal(-1.00000000000000))*(r01)*(x11678)*(x11679)))+(((IkReal(-1.00000000000000))*(cj5)*(x11680)*(x11697)))+(((x11688)*(x11699)))+(((IkReal(-1.00000000000000))*(x11680)*(x11683))));
evalcond[5]=((IkReal(0.0690000000000000))+(((x11689)*(x11701)))+(((IkReal(-1.00000000000000))*(x11685)*(x11692)))+(((IkReal(-0.0100000000000000))*(x11681)*(x11689)))+(((sj0)*(x11691)*(x11695)))+(((IkReal(-1.00000000000000))*(cj0)*(x11691)*(x11697)))+(((IkReal(-1.00000000000000))*(x11684)*(x11685)))+(((IkReal(-0.0100000000000000))*(cj5)*(sj0)*(x11695)))+(((IkReal(0.0100000000000000))*(x11681)*(x11687)))+(((IkReal(-1.00000000000000))*(x11687)*(x11701)))+(((IkReal(-1.00000000000000))*(py)*(x11678)))+(((IkReal(0.0100000000000000))*(cj0)*(x11683)))+(((cj0)*(r12)*(x11684)))+(((IkReal(0.0100000000000000))*(cj0)*(cj5)*(x11697)))+(((px)*(sj0))));
evalcond[6]=((IkReal(0.0690000000000000))+(((IkReal(0.0100000000000000))*(x11681)*(x11699)))+(((IkReal(-1.00000000000000))*(x11699)*(x11701)))+(((x11692)*(x11693)))+(((IkReal(-1.00000000000000))*(px)*(x11678)))+(((IkReal(0.0100000000000000))*(cj5)*(sj0)*(x11697)))+(((IkReal(-1.00000000000000))*(cj0)*(x11691)*(x11695)))+(((IkReal(-1.00000000000000))*(sj0)*(x11691)*(x11697)))+(((IkReal(0.0100000000000000))*(cj0)*(cj5)*(x11695)))+(((IkReal(0.0100000000000000))*(sj0)*(x11683)))+(((IkReal(-1.00000000000000))*(x11696)*(x11701)))+(((IkReal(-1.00000000000000))*(py)*(x11686)))+(((IkReal(0.0100000000000000))*(x11681)*(x11696)))+(((x11684)*(x11693)))+(((IkReal(0.364420000000000))*(cj1)))+(((r12)*(sj0)*(x11684))));
if( IKabs(evalcond[0]) < 0.0000010000000000  && IKabs(evalcond[1]) < 0.0000010000000000  && IKabs(evalcond[2]) < 0.0000010000000000  && IKabs(evalcond[3]) < 0.0000010000000000  && IKabs(evalcond[4]) < 0.0000010000000000  && IKabs(evalcond[5]) < 0.0000010000000000  && IKabs(evalcond[6]) < 0.0000010000000000  )
{
{
IkReal dummyeval[1];
IkReal gconst11;
gconst11=IKsign(sj1);
dummyeval[0]=sj1;
if( IKabs(dummyeval[0]) < 0.0000010000000000  )
{
{
IkReal dummyeval[1];
dummyeval[0]=sj1;
if( IKabs(dummyeval[0]) < 0.0000010000000000  )
{
{
IkReal dummyeval[1];
dummyeval[0]=cj1;
if( IKabs(dummyeval[0]) < 0.0000010000000000  )
{
{
IkReal evalcond[9];
IkReal x11703=((IkReal(1.00000000000000))*(cj0));
IkReal x11704=((cj4)*(sj6));
IkReal x11705=((sj0)*(sj6));
IkReal x11706=((cj5)*(sj4));
IkReal x11707=((IkReal(0.374290000000000))*(sj5));
IkReal x11708=((sj4)*(sj5));
IkReal x11709=((cj0)*(cj6));
IkReal x11710=((IkReal(0.0100000000000000))*(cj5));
IkReal x11711=((cj4)*(sj5));
IkReal x11712=((cj5)*(sj0));
IkReal x11713=((IkReal(0.374290000000000))*(r02));
IkReal x11714=((r20)*(sj6));
IkReal x11715=((cj6)*(r21));
IkReal x11716=((IkReal(1.00000000000000))*(sj0));
IkReal x11717=((cj0)*(sj6));
IkReal x11718=((cj4)*(cj6));
IkReal x11719=((IkReal(0.374290000000000))*(r12));
IkReal x11720=((cj0)*(cj5));
IkReal x11721=((cj6)*(sj5));
IkReal x11722=((cj6)*(r01));
IkReal x11723=((r00)*(sj6));
IkReal x11724=((IkReal(0.0100000000000000))*(sj5));
IkReal x11725=((cj6)*(r11));
IkReal x11726=((IkReal(1.00000000000000))*(r10));
IkReal x11727=((r02)*(sj0));
IkReal x11728=((cj6)*(sj4));
IkReal x11729=((r12)*(x11716));
evalcond[0]=((IkReal(-3.14159265358979))+(IKfmod(((IkReal(1.57079632679490))+(j1)), IkReal(6.28318530717959))));
evalcond[1]=((((x11706)*(x11714)))+(((r21)*(x11704)))+(((r22)*(x11708)))+(((x11706)*(x11715)))+(((IkReal(-1.00000000000000))*(r20)*(x11718))));
evalcond[2]=((IkReal(0.364420000000000))+(((x11707)*(x11715)))+(((IkReal(-1.00000000000000))*(x11710)*(x11714)))+(((IkReal(-0.374290000000000))*(cj5)*(r22)))+(pz)+(((x11707)*(x11714)))+(((IkReal(-1.00000000000000))*(r22)*(x11724)))+(((IkReal(-1.00000000000000))*(x11710)*(x11715))));
evalcond[3]=((((IkReal(-1.00000000000000))*(r11)*(x11716)*(x11721)))+(((IkReal(-1.00000000000000))*(r01)*(x11703)*(x11721)))+(((r12)*(x11712)))+(((IkReal(-1.00000000000000))*(sj5)*(x11703)*(x11723)))+(((IkReal(-1.00000000000000))*(sj5)*(x11705)*(x11726)))+(((r02)*(x11720))));
evalcond[4]=((((IkReal(-1.00000000000000))*(x11703)*(x11706)*(x11725)))+(((IkReal(-1.00000000000000))*(r00)*(x11716)*(x11718)))+(((r01)*(sj0)*(x11704)))+(((cj4)*(r10)*(x11709)))+(((sj0)*(x11706)*(x11722)))+(((IkReal(-1.00000000000000))*(r10)*(sj6)*(x11703)*(x11706)))+(((r00)*(x11705)*(x11706)))+(((IkReal(-1.00000000000000))*(r11)*(x11703)*(x11704)))+(((x11708)*(x11727)))+(((IkReal(-1.00000000000000))*(r12)*(x11703)*(x11708))));
evalcond[5]=((IkReal(1.00000000000000))+(((IkReal(-1.00000000000000))*(x11708)*(x11729)))+(((cj4)*(r00)*(x11709)))+(((IkReal(-1.00000000000000))*(x11706)*(x11716)*(x11725)))+(((IkReal(-1.00000000000000))*(x11705)*(x11706)*(x11726)))+(((IkReal(-1.00000000000000))*(r02)*(x11703)*(x11708)))+(((IkReal(-1.00000000000000))*(x11703)*(x11706)*(x11723)))+(((IkReal(-1.00000000000000))*(r11)*(x11704)*(x11716)))+(((IkReal(-1.00000000000000))*(x11703)*(x11706)*(x11722)))+(((r10)*(sj0)*(x11718)))+(((IkReal(-1.00000000000000))*(r01)*(x11703)*(x11704))));
evalcond[6]=((IkReal(0.0690000000000000))+(((IkReal(-1.00000000000000))*(sj0)*(x11710)*(x11722)))+(((IkReal(-1.00000000000000))*(r00)*(x11705)*(x11710)))+(((x11719)*(x11720)))+(((IkReal(-1.00000000000000))*(r10)*(x11707)*(x11717)))+(((r11)*(x11709)*(x11710)))+(((sj0)*(x11707)*(x11722)))+(((r10)*(x11710)*(x11717)))+(((IkReal(-1.00000000000000))*(x11712)*(x11713)))+(((IkReal(-1.00000000000000))*(r11)*(x11707)*(x11709)))+(((IkReal(-1.00000000000000))*(py)*(x11703)))+(((cj0)*(r12)*(x11724)))+(((IkReal(-1.00000000000000))*(x11724)*(x11727)))+(((px)*(sj0)))+(((r00)*(x11705)*(x11707))));
evalcond[7]=((((IkReal(-1.00000000000000))*(cj5)*(r00)*(x11703)*(x11704)))+(((IkReal(-1.00000000000000))*(x11704)*(x11712)*(x11726)))+(((r11)*(sj4)*(x11705)))+(((IkReal(-1.00000000000000))*(r10)*(x11716)*(x11728)))+(((IkReal(-1.00000000000000))*(r00)*(x11703)*(x11728)))+(((IkReal(-1.00000000000000))*(cj5)*(r01)*(x11703)*(x11718)))+(((r01)*(sj4)*(x11717)))+(((IkReal(-1.00000000000000))*(r11)*(x11712)*(x11718)))+(((IkReal(-1.00000000000000))*(r02)*(x11703)*(x11711)))+(((IkReal(-1.00000000000000))*(x11711)*(x11729))));
evalcond[8]=((IkReal(0.0690000000000000))+(((IkReal(-1.00000000000000))*(sj0)*(x11707)*(x11725)))+(((IkReal(-1.00000000000000))*(r00)*(x11707)*(x11717)))+(((sj0)*(x11710)*(x11725)))+(((x11712)*(x11719)))+(((IkReal(-1.00000000000000))*(px)*(x11703)))+(((r10)*(x11705)*(x11710)))+(((IkReal(-1.00000000000000))*(r01)*(x11707)*(x11709)))+(((x11713)*(x11720)))+(((IkReal(-1.00000000000000))*(py)*(x11716)))+(((r00)*(x11710)*(x11717)))+(((IkReal(-1.00000000000000))*(r10)*(x11705)*(x11707)))+(((cj0)*(r02)*(x11724)))+(((r01)*(x11709)*(x11710)))+(((r12)*(sj0)*(x11724))));
if( IKabs(evalcond[0]) < 0.0000010000000000  && IKabs(evalcond[1]) < 0.0000010000000000  && IKabs(evalcond[2]) < 0.0000010000000000  && IKabs(evalcond[3]) < 0.0000010000000000  && IKabs(evalcond[4]) < 0.0000010000000000  && IKabs(evalcond[5]) < 0.0000010000000000  && IKabs(evalcond[6]) < 0.0000010000000000  && IKabs(evalcond[7]) < 0.0000010000000000  && IKabs(evalcond[8]) < 0.0000010000000000  )
{
{
IkReal j3array[1], cj3array[1], sj3array[1];
bool j3valid[1]={false};
_nj3 = 1;
IkReal x11730=((r20)*(sj6));
IkReal x11731=((cj4)*(cj5));
IkReal x11732=((cj6)*(r21));
if( IKabs(((((IkReal(-1.00000000000000))*(r21)*(sj4)*(sj6)))+(((x11730)*(x11731)))+(((x11731)*(x11732)))+(((cj6)*(r20)*(sj4)))+(((cj4)*(r22)*(sj5))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(((((sj5)*(x11732)))+(((IkReal(-1.00000000000000))*(cj5)*(r22)))+(((sj5)*(x11730))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(IKsqr(((((IkReal(-1.00000000000000))*(r21)*(sj4)*(sj6)))+(((x11730)*(x11731)))+(((x11731)*(x11732)))+(((cj6)*(r20)*(sj4)))+(((cj4)*(r22)*(sj5)))))+IKsqr(((((sj5)*(x11732)))+(((IkReal(-1.00000000000000))*(cj5)*(r22)))+(((sj5)*(x11730)))))-1) <= IKFAST_SINCOS_THRESH )
    continue;
j3array[0]=IKatan2(((((IkReal(-1.00000000000000))*(r21)*(sj4)*(sj6)))+(((x11730)*(x11731)))+(((x11731)*(x11732)))+(((cj6)*(r20)*(sj4)))+(((cj4)*(r22)*(sj5)))), ((((sj5)*(x11732)))+(((IkReal(-1.00000000000000))*(cj5)*(r22)))+(((sj5)*(x11730)))));
sj3array[0]=IKsin(j3array[0]);
cj3array[0]=IKcos(j3array[0]);
if( j3array[0] > IKPI )
{
    j3array[0]-=IK2PI;
}
else if( j3array[0] < -IKPI )
{    j3array[0]+=IK2PI;
}
j3valid[0] = true;
for(int ij3 = 0; ij3 < 1; ++ij3)
{
if( !j3valid[ij3] )
{
    continue;
}
_ij3[0] = ij3; _ij3[1] = -1;
for(int iij3 = ij3+1; iij3 < 1; ++iij3)
{
if( j3valid[iij3] && IKabs(cj3array[ij3]-cj3array[iij3]) < IKFAST_SOLUTION_THRESH && IKabs(sj3array[ij3]-sj3array[iij3]) < IKFAST_SOLUTION_THRESH )
{
    j3valid[iij3]=false; _ij3[1] = iij3; break; 
}
}
j3 = j3array[ij3]; cj3 = cj3array[ij3]; sj3 = sj3array[ij3];
{
IkReal evalcond[4];
IkReal x11733=IKcos(j3);
IkReal x11734=((sj0)*(sj5));
IkReal x11735=((r00)*(sj6));
IkReal x11736=((cj6)*(r01));
IkReal x11737=((cj5)*(sj0));
IkReal x11738=((cj0)*(cj5));
IkReal x11739=((cj6)*(sj4));
IkReal x11740=((sj4)*(sj6));
IkReal x11741=((cj0)*(r11));
IkReal x11742=((cj4)*(cj6));
IkReal x11743=((cj4)*(sj6));
IkReal x11744=((IkReal(1.00000000000000))*(cj0));
IkReal x11745=((cj4)*(sj5));
IkReal x11746=((sj5)*(sj6));
IkReal x11747=((cj6)*(sj5));
IkReal x11748=((IkReal(1.00000000000000))*(IKsin(j3)));
evalcond[0]=((((r20)*(x11746)))+(((IkReal(-1.00000000000000))*(x11733)))+(((r21)*(x11747)))+(((IkReal(-1.00000000000000))*(cj5)*(r22))));
evalcond[1]=((((cj5)*(r21)*(x11742)))+(((IkReal(-1.00000000000000))*(r21)*(x11740)))+(((cj5)*(r20)*(x11743)))+(((r22)*(x11745)))+(((IkReal(-1.00000000000000))*(x11748)))+(((r20)*(x11739))));
evalcond[2]=((((x11734)*(x11735)))+(((x11734)*(x11736)))+(((IkReal(-1.00000000000000))*(r10)*(x11744)*(x11746)))+(((r12)*(x11738)))+(((IkReal(-1.00000000000000))*(r02)*(x11737)))+(((IkReal(-1.00000000000000))*(x11748)))+(((IkReal(-1.00000000000000))*(x11741)*(x11747))));
evalcond[3]=((((IkReal(-1.00000000000000))*(r11)*(x11738)*(x11742)))+(((cj4)*(x11736)*(x11737)))+(((IkReal(-1.00000000000000))*(r01)*(sj0)*(x11740)))+(((r00)*(sj0)*(x11739)))+(((IkReal(-1.00000000000000))*(r10)*(x11738)*(x11743)))+(((x11740)*(x11741)))+(((cj4)*(r02)*(x11734)))+(x11733)+(((IkReal(-1.00000000000000))*(r10)*(x11739)*(x11744)))+(((IkReal(-1.00000000000000))*(r12)*(x11744)*(x11745)))+(((cj4)*(x11735)*(x11737))));
if( IKabs(evalcond[0]) > 0.000001  || IKabs(evalcond[1]) > 0.000001  || IKabs(evalcond[2]) > 0.000001  || IKabs(evalcond[3]) > 0.000001  )
{
continue;
}
}

{
std::vector<IkSingleDOFSolutionBase<IkReal> > vinfos(7);
vinfos[0].jointtype = 1;
vinfos[0].foffset = j0;
vinfos[0].indices[0] = _ij0[0];
vinfos[0].indices[1] = _ij0[1];
vinfos[0].maxsolutions = _nj0;
vinfos[1].jointtype = 1;
vinfos[1].foffset = j1;
vinfos[1].indices[0] = _ij1[0];
vinfos[1].indices[1] = _ij1[1];
vinfos[1].maxsolutions = _nj1;
vinfos[2].jointtype = 1;
vinfos[2].foffset = j2;
vinfos[2].indices[0] = _ij2[0];
vinfos[2].indices[1] = _ij2[1];
vinfos[2].maxsolutions = _nj2;
vinfos[3].jointtype = 1;
vinfos[3].foffset = j3;
vinfos[3].indices[0] = _ij3[0];
vinfos[3].indices[1] = _ij3[1];
vinfos[3].maxsolutions = _nj3;
vinfos[4].jointtype = 1;
vinfos[4].foffset = j4;
vinfos[4].indices[0] = _ij4[0];
vinfos[4].indices[1] = _ij4[1];
vinfos[4].maxsolutions = _nj4;
vinfos[5].jointtype = 1;
vinfos[5].foffset = j5;
vinfos[5].indices[0] = _ij5[0];
vinfos[5].indices[1] = _ij5[1];
vinfos[5].maxsolutions = _nj5;
vinfos[6].jointtype = 1;
vinfos[6].foffset = j6;
vinfos[6].indices[0] = _ij6[0];
vinfos[6].indices[1] = _ij6[1];
vinfos[6].maxsolutions = _nj6;
std::vector<int> vfree(0);
solutions.AddSolution(vinfos,vfree);
}
}
}

} else
{
IkReal x11749=((IkReal(1.00000000000000))*(cj0));
IkReal x11750=((cj4)*(sj6));
IkReal x11751=((sj0)*(sj6));
IkReal x11752=((cj5)*(sj4));
IkReal x11753=((IkReal(0.374290000000000))*(sj5));
IkReal x11754=((sj4)*(sj5));
IkReal x11755=((cj0)*(cj6));
IkReal x11756=((IkReal(0.0100000000000000))*(cj5));
IkReal x11757=((cj4)*(sj5));
IkReal x11758=((cj5)*(sj0));
IkReal x11759=((IkReal(0.374290000000000))*(r02));
IkReal x11760=((r20)*(sj6));
IkReal x11761=((cj6)*(r21));
IkReal x11762=((IkReal(1.00000000000000))*(sj0));
IkReal x11763=((cj0)*(sj6));
IkReal x11764=((cj4)*(cj6));
IkReal x11765=((IkReal(0.374290000000000))*(r12));
IkReal x11766=((cj0)*(cj5));
IkReal x11767=((cj6)*(sj5));
IkReal x11768=((cj6)*(r01));
IkReal x11769=((r00)*(sj6));
IkReal x11770=((IkReal(0.0100000000000000))*(sj5));
IkReal x11771=((cj6)*(r11));
IkReal x11772=((IkReal(1.00000000000000))*(r10));
IkReal x11773=((r02)*(sj0));
IkReal x11774=((cj6)*(sj4));
IkReal x11775=((r12)*(x11762));
evalcond[0]=((IkReal(-3.14159265358979))+(IKfmod(((IkReal(4.71238898038469))+(j1)), IkReal(6.28318530717959))));
evalcond[1]=((((r22)*(x11754)))+(((x11752)*(x11760)))+(((r21)*(x11750)))+(((x11752)*(x11761)))+(((IkReal(-1.00000000000000))*(r20)*(x11764))));
evalcond[2]=((IkReal(-0.364420000000000))+(((x11753)*(x11761)))+(((IkReal(-1.00000000000000))*(x11756)*(x11761)))+(((x11753)*(x11760)))+(((IkReal(-1.00000000000000))*(x11756)*(x11760)))+(((IkReal(-1.00000000000000))*(r22)*(x11770)))+(((IkReal(-0.374290000000000))*(cj5)*(r22)))+(pz));
evalcond[3]=((((IkReal(-1.00000000000000))*(r01)*(x11749)*(x11767)))+(((IkReal(-1.00000000000000))*(sj5)*(x11749)*(x11769)))+(((IkReal(-1.00000000000000))*(r11)*(x11762)*(x11767)))+(((r12)*(x11758)))+(((r02)*(x11766)))+(((IkReal(-1.00000000000000))*(sj5)*(x11751)*(x11772))));
evalcond[4]=((((IkReal(-1.00000000000000))*(r12)*(x11749)*(x11754)))+(((r00)*(x11751)*(x11752)))+(((IkReal(-1.00000000000000))*(r00)*(x11762)*(x11764)))+(((IkReal(-1.00000000000000))*(r10)*(sj6)*(x11749)*(x11752)))+(((x11754)*(x11773)))+(((cj4)*(r10)*(x11755)))+(((IkReal(-1.00000000000000))*(r11)*(x11749)*(x11750)))+(((IkReal(-1.00000000000000))*(x11749)*(x11752)*(x11771)))+(((r01)*(sj0)*(x11750)))+(((sj0)*(x11752)*(x11768))));
evalcond[5]=((IkReal(-1.00000000000000))+(((IkReal(-1.00000000000000))*(r02)*(x11749)*(x11754)))+(((IkReal(-1.00000000000000))*(x11754)*(x11775)))+(((cj4)*(r00)*(x11755)))+(((IkReal(-1.00000000000000))*(r01)*(x11749)*(x11750)))+(((IkReal(-1.00000000000000))*(x11749)*(x11752)*(x11769)))+(((r10)*(sj0)*(x11764)))+(((IkReal(-1.00000000000000))*(x11749)*(x11752)*(x11768)))+(((IkReal(-1.00000000000000))*(x11751)*(x11752)*(x11772)))+(((IkReal(-1.00000000000000))*(r11)*(x11750)*(x11762)))+(((IkReal(-1.00000000000000))*(x11752)*(x11762)*(x11771))));
evalcond[6]=((IkReal(0.0690000000000000))+(((sj0)*(x11753)*(x11768)))+(((r11)*(x11755)*(x11756)))+(((r10)*(x11756)*(x11763)))+(((IkReal(-1.00000000000000))*(r00)*(x11751)*(x11756)))+(((cj0)*(r12)*(x11770)))+(((IkReal(-1.00000000000000))*(sj0)*(x11756)*(x11768)))+(((x11765)*(x11766)))+(((IkReal(-1.00000000000000))*(x11770)*(x11773)))+(((IkReal(-1.00000000000000))*(r11)*(x11753)*(x11755)))+(((px)*(sj0)))+(((IkReal(-1.00000000000000))*(r10)*(x11753)*(x11763)))+(((IkReal(-1.00000000000000))*(x11758)*(x11759)))+(((r00)*(x11751)*(x11753)))+(((IkReal(-1.00000000000000))*(py)*(x11749))));
evalcond[7]=((((IkReal(-1.00000000000000))*(x11757)*(x11775)))+(((r11)*(sj4)*(x11751)))+(((IkReal(-1.00000000000000))*(r02)*(x11749)*(x11757)))+(((IkReal(-1.00000000000000))*(r11)*(x11758)*(x11764)))+(((IkReal(-1.00000000000000))*(cj5)*(r01)*(x11749)*(x11764)))+(((IkReal(-1.00000000000000))*(r10)*(x11762)*(x11774)))+(((r01)*(sj4)*(x11763)))+(((IkReal(-1.00000000000000))*(cj5)*(r00)*(x11749)*(x11750)))+(((IkReal(-1.00000000000000))*(r00)*(x11749)*(x11774)))+(((IkReal(-1.00000000000000))*(x11750)*(x11758)*(x11772))));
evalcond[8]=((IkReal(0.0690000000000000))+(((cj0)*(r02)*(x11770)))+(((IkReal(-1.00000000000000))*(r01)*(x11753)*(x11755)))+(((IkReal(-1.00000000000000))*(r10)*(x11751)*(x11753)))+(((r10)*(x11751)*(x11756)))+(((IkReal(-1.00000000000000))*(sj0)*(x11753)*(x11771)))+(((IkReal(-1.00000000000000))*(r00)*(x11753)*(x11763)))+(((IkReal(-1.00000000000000))*(px)*(x11749)))+(((r01)*(x11755)*(x11756)))+(((sj0)*(x11756)*(x11771)))+(((r00)*(x11756)*(x11763)))+(((x11758)*(x11765)))+(((x11759)*(x11766)))+(((r12)*(sj0)*(x11770)))+(((IkReal(-1.00000000000000))*(py)*(x11762))));
if( IKabs(evalcond[0]) < 0.0000010000000000  && IKabs(evalcond[1]) < 0.0000010000000000  && IKabs(evalcond[2]) < 0.0000010000000000  && IKabs(evalcond[3]) < 0.0000010000000000  && IKabs(evalcond[4]) < 0.0000010000000000  && IKabs(evalcond[5]) < 0.0000010000000000  && IKabs(evalcond[6]) < 0.0000010000000000  && IKabs(evalcond[7]) < 0.0000010000000000  && IKabs(evalcond[8]) < 0.0000010000000000  )
{
{
IkReal j3array[1], cj3array[1], sj3array[1];
bool j3valid[1]={false};
_nj3 = 1;
IkReal x11776=((IkReal(1.00000000000000))*(sj5));
IkReal x11777=((cj6)*(r21));
IkReal x11778=((r20)*(sj6));
IkReal x11779=((IkReal(1.00000000000000))*(cj4)*(cj5));
if( IKabs(((((IkReal(-1.00000000000000))*(x11777)*(x11779)))+(((IkReal(-1.00000000000000))*(x11778)*(x11779)))+(((IkReal(-1.00000000000000))*(cj4)*(r22)*(x11776)))+(((r21)*(sj4)*(sj6)))+(((IkReal(-1.00000000000000))*(cj6)*(r20)*(sj4))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(((((IkReal(-1.00000000000000))*(x11776)*(x11778)))+(((IkReal(-1.00000000000000))*(x11776)*(x11777)))+(((cj5)*(r22))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(IKsqr(((((IkReal(-1.00000000000000))*(x11777)*(x11779)))+(((IkReal(-1.00000000000000))*(x11778)*(x11779)))+(((IkReal(-1.00000000000000))*(cj4)*(r22)*(x11776)))+(((r21)*(sj4)*(sj6)))+(((IkReal(-1.00000000000000))*(cj6)*(r20)*(sj4)))))+IKsqr(((((IkReal(-1.00000000000000))*(x11776)*(x11778)))+(((IkReal(-1.00000000000000))*(x11776)*(x11777)))+(((cj5)*(r22)))))-1) <= IKFAST_SINCOS_THRESH )
    continue;
j3array[0]=IKatan2(((((IkReal(-1.00000000000000))*(x11777)*(x11779)))+(((IkReal(-1.00000000000000))*(x11778)*(x11779)))+(((IkReal(-1.00000000000000))*(cj4)*(r22)*(x11776)))+(((r21)*(sj4)*(sj6)))+(((IkReal(-1.00000000000000))*(cj6)*(r20)*(sj4)))), ((((IkReal(-1.00000000000000))*(x11776)*(x11778)))+(((IkReal(-1.00000000000000))*(x11776)*(x11777)))+(((cj5)*(r22)))));
sj3array[0]=IKsin(j3array[0]);
cj3array[0]=IKcos(j3array[0]);
if( j3array[0] > IKPI )
{
    j3array[0]-=IK2PI;
}
else if( j3array[0] < -IKPI )
{    j3array[0]+=IK2PI;
}
j3valid[0] = true;
for(int ij3 = 0; ij3 < 1; ++ij3)
{
if( !j3valid[ij3] )
{
    continue;
}
_ij3[0] = ij3; _ij3[1] = -1;
for(int iij3 = ij3+1; iij3 < 1; ++iij3)
{
if( j3valid[iij3] && IKabs(cj3array[ij3]-cj3array[iij3]) < IKFAST_SOLUTION_THRESH && IKabs(sj3array[ij3]-sj3array[iij3]) < IKFAST_SOLUTION_THRESH )
{
    j3valid[iij3]=false; _ij3[1] = iij3; break; 
}
}
j3 = j3array[ij3]; cj3 = cj3array[ij3]; sj3 = sj3array[ij3];
{
IkReal evalcond[4];
IkReal x11780=IKsin(j3);
IkReal x11781=IKcos(j3);
IkReal x11782=((sj0)*(sj5));
IkReal x11783=((r00)*(sj6));
IkReal x11784=((cj6)*(r01));
IkReal x11785=((cj5)*(sj0));
IkReal x11786=((cj0)*(cj5));
IkReal x11787=((cj6)*(sj4));
IkReal x11788=((sj4)*(sj6));
IkReal x11789=((cj0)*(r11));
IkReal x11790=((cj4)*(cj6));
IkReal x11791=((cj4)*(sj6));
IkReal x11792=((IkReal(1.00000000000000))*(cj0));
IkReal x11793=((cj4)*(sj5));
IkReal x11794=((sj5)*(sj6));
IkReal x11795=((cj6)*(sj5));
evalcond[0]=((x11781)+(((r20)*(x11794)))+(((IkReal(-1.00000000000000))*(cj5)*(r22)))+(((r21)*(x11795))));
evalcond[1]=((x11780)+(((IkReal(-1.00000000000000))*(r21)*(x11788)))+(((cj5)*(r21)*(x11790)))+(((cj5)*(r20)*(x11791)))+(((r20)*(x11787)))+(((r22)*(x11793))));
evalcond[2]=((((x11782)*(x11784)))+(((IkReal(-1.00000000000000))*(r02)*(x11785)))+(((IkReal(-1.00000000000000))*(x11780)))+(((x11782)*(x11783)))+(((r12)*(x11786)))+(((IkReal(-1.00000000000000))*(r10)*(x11792)*(x11794)))+(((IkReal(-1.00000000000000))*(x11789)*(x11795))));
evalcond[3]=((x11781)+(((IkReal(-1.00000000000000))*(r10)*(x11786)*(x11791)))+(((r00)*(sj0)*(x11787)))+(((IkReal(-1.00000000000000))*(r01)*(sj0)*(x11788)))+(((IkReal(-1.00000000000000))*(r12)*(x11792)*(x11793)))+(((x11788)*(x11789)))+(((cj4)*(x11784)*(x11785)))+(((cj4)*(x11783)*(x11785)))+(((IkReal(-1.00000000000000))*(r10)*(x11787)*(x11792)))+(((IkReal(-1.00000000000000))*(r11)*(x11786)*(x11790)))+(((cj4)*(r02)*(x11782))));
if( IKabs(evalcond[0]) > 0.000001  || IKabs(evalcond[1]) > 0.000001  || IKabs(evalcond[2]) > 0.000001  || IKabs(evalcond[3]) > 0.000001  )
{
continue;
}
}

{
std::vector<IkSingleDOFSolutionBase<IkReal> > vinfos(7);
vinfos[0].jointtype = 1;
vinfos[0].foffset = j0;
vinfos[0].indices[0] = _ij0[0];
vinfos[0].indices[1] = _ij0[1];
vinfos[0].maxsolutions = _nj0;
vinfos[1].jointtype = 1;
vinfos[1].foffset = j1;
vinfos[1].indices[0] = _ij1[0];
vinfos[1].indices[1] = _ij1[1];
vinfos[1].maxsolutions = _nj1;
vinfos[2].jointtype = 1;
vinfos[2].foffset = j2;
vinfos[2].indices[0] = _ij2[0];
vinfos[2].indices[1] = _ij2[1];
vinfos[2].maxsolutions = _nj2;
vinfos[3].jointtype = 1;
vinfos[3].foffset = j3;
vinfos[3].indices[0] = _ij3[0];
vinfos[3].indices[1] = _ij3[1];
vinfos[3].maxsolutions = _nj3;
vinfos[4].jointtype = 1;
vinfos[4].foffset = j4;
vinfos[4].indices[0] = _ij4[0];
vinfos[4].indices[1] = _ij4[1];
vinfos[4].maxsolutions = _nj4;
vinfos[5].jointtype = 1;
vinfos[5].foffset = j5;
vinfos[5].indices[0] = _ij5[0];
vinfos[5].indices[1] = _ij5[1];
vinfos[5].maxsolutions = _nj5;
vinfos[6].jointtype = 1;
vinfos[6].foffset = j6;
vinfos[6].indices[0] = _ij6[0];
vinfos[6].indices[1] = _ij6[1];
vinfos[6].maxsolutions = _nj6;
std::vector<int> vfree(0);
solutions.AddSolution(vinfos,vfree);
}
}
}

} else
{
if( 1 )
{
continue;

} else
{
}
}
}
}

} else
{
{
IkReal j3array[1], cj3array[1], sj3array[1];
bool j3valid[1]={false};
_nj3 = 1;
IkReal x11796=((cj0)*(cj5));
IkReal x11797=((IkReal(1.00000000000000))*(cj0));
IkReal x11798=((cj6)*(r11));
IkReal x11799=((r10)*(sj6));
IkReal x11800=((cj5)*(sj0));
IkReal x11801=((r00)*(sj5)*(sj6));
IkReal x11802=((cj6)*(r01)*(sj5));
IkReal x11803=((IkReal(1.00000000000000))*(sj0)*(sj5));
if( IKabs(((((IkReal(-1.00000000000000))*(sj5)*(x11797)*(x11799)))+(((r12)*(x11796)))+(((IkReal(-1.00000000000000))*(sj5)*(x11797)*(x11798)))+(((sj0)*(x11802)))+(((IkReal(-1.00000000000000))*(r02)*(x11800)))+(((sj0)*(x11801))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(((((IKabs(cj1) != 0)?((IkReal)1/(cj1)):(IkReal)1.0e30))*(((((r02)*(x11796)))+(((IkReal(-1.00000000000000))*(x11797)*(x11802)))+(((IkReal(-1.00000000000000))*(x11799)*(x11803)))+(((IkReal(-1.00000000000000))*(x11797)*(x11801)))+(((r12)*(x11800)))+(((IkReal(-1.00000000000000))*(x11798)*(x11803))))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(IKsqr(((((IkReal(-1.00000000000000))*(sj5)*(x11797)*(x11799)))+(((r12)*(x11796)))+(((IkReal(-1.00000000000000))*(sj5)*(x11797)*(x11798)))+(((sj0)*(x11802)))+(((IkReal(-1.00000000000000))*(r02)*(x11800)))+(((sj0)*(x11801)))))+IKsqr(((((IKabs(cj1) != 0)?((IkReal)1/(cj1)):(IkReal)1.0e30))*(((((r02)*(x11796)))+(((IkReal(-1.00000000000000))*(x11797)*(x11802)))+(((IkReal(-1.00000000000000))*(x11799)*(x11803)))+(((IkReal(-1.00000000000000))*(x11797)*(x11801)))+(((r12)*(x11800)))+(((IkReal(-1.00000000000000))*(x11798)*(x11803)))))))-1) <= IKFAST_SINCOS_THRESH )
    continue;
j3array[0]=IKatan2(((((IkReal(-1.00000000000000))*(sj5)*(x11797)*(x11799)))+(((r12)*(x11796)))+(((IkReal(-1.00000000000000))*(sj5)*(x11797)*(x11798)))+(((sj0)*(x11802)))+(((IkReal(-1.00000000000000))*(r02)*(x11800)))+(((sj0)*(x11801)))), ((((IKabs(cj1) != 0)?((IkReal)1/(cj1)):(IkReal)1.0e30))*(((((r02)*(x11796)))+(((IkReal(-1.00000000000000))*(x11797)*(x11802)))+(((IkReal(-1.00000000000000))*(x11799)*(x11803)))+(((IkReal(-1.00000000000000))*(x11797)*(x11801)))+(((r12)*(x11800)))+(((IkReal(-1.00000000000000))*(x11798)*(x11803)))))));
sj3array[0]=IKsin(j3array[0]);
cj3array[0]=IKcos(j3array[0]);
if( j3array[0] > IKPI )
{
    j3array[0]-=IK2PI;
}
else if( j3array[0] < -IKPI )
{    j3array[0]+=IK2PI;
}
j3valid[0] = true;
for(int ij3 = 0; ij3 < 1; ++ij3)
{
if( !j3valid[ij3] )
{
    continue;
}
_ij3[0] = ij3; _ij3[1] = -1;
for(int iij3 = ij3+1; iij3 < 1; ++iij3)
{
if( j3valid[iij3] && IKabs(cj3array[ij3]-cj3array[iij3]) < IKFAST_SOLUTION_THRESH && IKabs(sj3array[ij3]-sj3array[iij3]) < IKFAST_SOLUTION_THRESH )
{
    j3valid[iij3]=false; _ij3[1] = iij3; break; 
}
}
j3 = j3array[ij3]; cj3 = cj3array[ij3]; sj3 = sj3array[ij3];
{
IkReal evalcond[6];
IkReal x11804=IKsin(j3);
IkReal x11805=IKcos(j3);
IkReal x11806=((sj0)*(sj5));
IkReal x11807=((r00)*(sj6));
IkReal x11808=((cj6)*(r01));
IkReal x11809=((cj4)*(cj5));
IkReal x11810=((IkReal(1.00000000000000))*(cj0));
IkReal x11811=((cj5)*(r12));
IkReal x11812=((IkReal(1.00000000000000))*(sj0));
IkReal x11813=((cj6)*(r11));
IkReal x11814=((cj5)*(r02));
IkReal x11815=((IkReal(1.00000000000000))*(cj1));
IkReal x11816=((cj6)*(sj4));
IkReal x11817=((cj6)*(r21));
IkReal x11818=((r20)*(sj6));
IkReal x11819=((r10)*(sj6));
IkReal x11820=((sj4)*(sj6));
IkReal x11821=((cj4)*(r02));
IkReal x11822=((IkReal(1.00000000000000))*(cj4)*(r12));
IkReal x11823=((IkReal(1.00000000000000))*(x11804));
IkReal x11824=((cj0)*(x11820));
evalcond[0]=((((sj5)*(x11817)))+(((sj5)*(x11818)))+(((IkReal(-1.00000000000000))*(sj1)*(x11805)))+(((IkReal(-1.00000000000000))*(cj5)*(r22))));
evalcond[1]=((((IkReal(-1.00000000000000))*(r21)*(x11820)))+(((IkReal(-1.00000000000000))*(sj1)*(x11823)))+(((cj4)*(r22)*(sj5)))+(((x11809)*(x11818)))+(((x11809)*(x11817)))+(((r20)*(x11816))));
evalcond[2]=((((IkReal(-1.00000000000000))*(sj5)*(x11810)*(x11813)))+(((IkReal(-1.00000000000000))*(sj5)*(x11810)*(x11819)))+(((cj0)*(x11811)))+(((x11806)*(x11808)))+(((IkReal(-1.00000000000000))*(x11823)))+(((IkReal(-1.00000000000000))*(x11812)*(x11814)))+(((x11806)*(x11807))));
evalcond[3]=((((IkReal(-1.00000000000000))*(sj5)*(x11808)*(x11810)))+(((sj0)*(x11811)))+(((IkReal(-1.00000000000000))*(sj5)*(x11807)*(x11810)))+(((cj0)*(x11814)))+(((IkReal(-1.00000000000000))*(x11806)*(x11819)))+(((IkReal(-1.00000000000000))*(x11806)*(x11813)))+(((IkReal(-1.00000000000000))*(x11805)*(x11815))));
evalcond[4]=((((r11)*(x11824)))+(((x11806)*(x11821)))+(((IkReal(-1.00000000000000))*(r01)*(x11812)*(x11820)))+(((sj0)*(x11807)*(x11809)))+(((r00)*(sj0)*(x11816)))+(((sj0)*(x11808)*(x11809)))+(((IkReal(-1.00000000000000))*(r10)*(x11810)*(x11816)))+(((IkReal(-1.00000000000000))*(cj4)*(r12)*(sj5)*(x11810)))+(((IkReal(-1.00000000000000))*(x11809)*(x11810)*(x11819)))+(x11805)+(((IkReal(-1.00000000000000))*(x11809)*(x11810)*(x11813))));
evalcond[5]=((((IkReal(-1.00000000000000))*(sj5)*(x11810)*(x11821)))+(((IkReal(-1.00000000000000))*(x11808)*(x11809)*(x11810)))+(((r11)*(sj0)*(x11820)))+(((IkReal(-1.00000000000000))*(x11806)*(x11822)))+(((IkReal(-1.00000000000000))*(r00)*(x11810)*(x11816)))+(((IkReal(-1.00000000000000))*(r10)*(x11812)*(x11816)))+(((IkReal(-1.00000000000000))*(x11804)*(x11815)))+(((IkReal(-1.00000000000000))*(x11807)*(x11809)*(x11810)))+(((IkReal(-1.00000000000000))*(x11809)*(x11812)*(x11819)))+(((IkReal(-1.00000000000000))*(x11809)*(x11812)*(x11813)))+(((r01)*(x11824))));
if( IKabs(evalcond[0]) > 0.000001  || IKabs(evalcond[1]) > 0.000001  || IKabs(evalcond[2]) > 0.000001  || IKabs(evalcond[3]) > 0.000001  || IKabs(evalcond[4]) > 0.000001  || IKabs(evalcond[5]) > 0.000001  )
{
continue;
}
}

{
std::vector<IkSingleDOFSolutionBase<IkReal> > vinfos(7);
vinfos[0].jointtype = 1;
vinfos[0].foffset = j0;
vinfos[0].indices[0] = _ij0[0];
vinfos[0].indices[1] = _ij0[1];
vinfos[0].maxsolutions = _nj0;
vinfos[1].jointtype = 1;
vinfos[1].foffset = j1;
vinfos[1].indices[0] = _ij1[0];
vinfos[1].indices[1] = _ij1[1];
vinfos[1].maxsolutions = _nj1;
vinfos[2].jointtype = 1;
vinfos[2].foffset = j2;
vinfos[2].indices[0] = _ij2[0];
vinfos[2].indices[1] = _ij2[1];
vinfos[2].maxsolutions = _nj2;
vinfos[3].jointtype = 1;
vinfos[3].foffset = j3;
vinfos[3].indices[0] = _ij3[0];
vinfos[3].indices[1] = _ij3[1];
vinfos[3].maxsolutions = _nj3;
vinfos[4].jointtype = 1;
vinfos[4].foffset = j4;
vinfos[4].indices[0] = _ij4[0];
vinfos[4].indices[1] = _ij4[1];
vinfos[4].maxsolutions = _nj4;
vinfos[5].jointtype = 1;
vinfos[5].foffset = j5;
vinfos[5].indices[0] = _ij5[0];
vinfos[5].indices[1] = _ij5[1];
vinfos[5].maxsolutions = _nj5;
vinfos[6].jointtype = 1;
vinfos[6].foffset = j6;
vinfos[6].indices[0] = _ij6[0];
vinfos[6].indices[1] = _ij6[1];
vinfos[6].maxsolutions = _nj6;
std::vector<int> vfree(0);
solutions.AddSolution(vinfos,vfree);
}
}
}

}

}

} else
{
{
IkReal j3array[1], cj3array[1], sj3array[1];
bool j3valid[1]={false};
_nj3 = 1;
IkReal x11825=((sj5)*(sj6));
IkReal x11826=((cj6)*(sj5));
IkReal x11827=((IkReal(1.00000000000000))*(cj0));
IkReal x11828=((IkReal(1.00000000000000))*(cj5));
if( IKabs(((((r01)*(sj0)*(x11826)))+(((r00)*(sj0)*(x11825)))+(((IkReal(-1.00000000000000))*(r02)*(sj0)*(x11828)))+(((IkReal(-1.00000000000000))*(r11)*(x11826)*(x11827)))+(((cj0)*(cj5)*(r12)))+(((IkReal(-1.00000000000000))*(r10)*(x11825)*(x11827))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(((((IKabs(sj1) != 0)?((IkReal)1/(sj1)):(IkReal)1.0e30))*(((((r21)*(x11826)))+(((IkReal(-1.00000000000000))*(r22)*(x11828)))+(((r20)*(x11825))))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(IKsqr(((((r01)*(sj0)*(x11826)))+(((r00)*(sj0)*(x11825)))+(((IkReal(-1.00000000000000))*(r02)*(sj0)*(x11828)))+(((IkReal(-1.00000000000000))*(r11)*(x11826)*(x11827)))+(((cj0)*(cj5)*(r12)))+(((IkReal(-1.00000000000000))*(r10)*(x11825)*(x11827)))))+IKsqr(((((IKabs(sj1) != 0)?((IkReal)1/(sj1)):(IkReal)1.0e30))*(((((r21)*(x11826)))+(((IkReal(-1.00000000000000))*(r22)*(x11828)))+(((r20)*(x11825)))))))-1) <= IKFAST_SINCOS_THRESH )
    continue;
j3array[0]=IKatan2(((((r01)*(sj0)*(x11826)))+(((r00)*(sj0)*(x11825)))+(((IkReal(-1.00000000000000))*(r02)*(sj0)*(x11828)))+(((IkReal(-1.00000000000000))*(r11)*(x11826)*(x11827)))+(((cj0)*(cj5)*(r12)))+(((IkReal(-1.00000000000000))*(r10)*(x11825)*(x11827)))), ((((IKabs(sj1) != 0)?((IkReal)1/(sj1)):(IkReal)1.0e30))*(((((r21)*(x11826)))+(((IkReal(-1.00000000000000))*(r22)*(x11828)))+(((r20)*(x11825)))))));
sj3array[0]=IKsin(j3array[0]);
cj3array[0]=IKcos(j3array[0]);
if( j3array[0] > IKPI )
{
    j3array[0]-=IK2PI;
}
else if( j3array[0] < -IKPI )
{    j3array[0]+=IK2PI;
}
j3valid[0] = true;
for(int ij3 = 0; ij3 < 1; ++ij3)
{
if( !j3valid[ij3] )
{
    continue;
}
_ij3[0] = ij3; _ij3[1] = -1;
for(int iij3 = ij3+1; iij3 < 1; ++iij3)
{
if( j3valid[iij3] && IKabs(cj3array[ij3]-cj3array[iij3]) < IKFAST_SOLUTION_THRESH && IKabs(sj3array[ij3]-sj3array[iij3]) < IKFAST_SOLUTION_THRESH )
{
    j3valid[iij3]=false; _ij3[1] = iij3; break; 
}
}
j3 = j3array[ij3]; cj3 = cj3array[ij3]; sj3 = sj3array[ij3];
{
IkReal evalcond[6];
IkReal x11829=IKsin(j3);
IkReal x11830=IKcos(j3);
IkReal x11831=((sj0)*(sj5));
IkReal x11832=((r00)*(sj6));
IkReal x11833=((cj6)*(r01));
IkReal x11834=((cj4)*(cj5));
IkReal x11835=((IkReal(1.00000000000000))*(cj0));
IkReal x11836=((cj5)*(r12));
IkReal x11837=((IkReal(1.00000000000000))*(sj0));
IkReal x11838=((cj6)*(r11));
IkReal x11839=((cj5)*(r02));
IkReal x11840=((IkReal(1.00000000000000))*(cj1));
IkReal x11841=((cj6)*(sj4));
IkReal x11842=((cj6)*(r21));
IkReal x11843=((r20)*(sj6));
IkReal x11844=((r10)*(sj6));
IkReal x11845=((sj4)*(sj6));
IkReal x11846=((cj4)*(r02));
IkReal x11847=((IkReal(1.00000000000000))*(cj4)*(r12));
IkReal x11848=((IkReal(1.00000000000000))*(x11829));
IkReal x11849=((cj0)*(x11845));
evalcond[0]=((((sj5)*(x11842)))+(((IkReal(-1.00000000000000))*(cj5)*(r22)))+(((IkReal(-1.00000000000000))*(sj1)*(x11830)))+(((sj5)*(x11843))));
evalcond[1]=((((r20)*(x11841)))+(((IkReal(-1.00000000000000))*(sj1)*(x11848)))+(((x11834)*(x11843)))+(((cj4)*(r22)*(sj5)))+(((x11834)*(x11842)))+(((IkReal(-1.00000000000000))*(r21)*(x11845))));
evalcond[2]=((((IkReal(-1.00000000000000))*(sj5)*(x11835)*(x11844)))+(((IkReal(-1.00000000000000))*(sj5)*(x11835)*(x11838)))+(((x11831)*(x11833)))+(((IkReal(-1.00000000000000))*(x11837)*(x11839)))+(((x11831)*(x11832)))+(((IkReal(-1.00000000000000))*(x11848)))+(((cj0)*(x11836))));
evalcond[3]=((((IkReal(-1.00000000000000))*(x11830)*(x11840)))+(((IkReal(-1.00000000000000))*(sj5)*(x11833)*(x11835)))+(((cj0)*(x11839)))+(((IkReal(-1.00000000000000))*(x11831)*(x11838)))+(((IkReal(-1.00000000000000))*(sj5)*(x11832)*(x11835)))+(((sj0)*(x11836)))+(((IkReal(-1.00000000000000))*(x11831)*(x11844))));
evalcond[4]=((((IkReal(-1.00000000000000))*(cj4)*(r12)*(sj5)*(x11835)))+(((IkReal(-1.00000000000000))*(r10)*(x11835)*(x11841)))+(((sj0)*(x11833)*(x11834)))+(((x11831)*(x11846)))+(((IkReal(-1.00000000000000))*(r01)*(x11837)*(x11845)))+(((r11)*(x11849)))+(((IkReal(-1.00000000000000))*(x11834)*(x11835)*(x11838)))+(((IkReal(-1.00000000000000))*(x11834)*(x11835)*(x11844)))+(x11830)+(((sj0)*(x11832)*(x11834)))+(((r00)*(sj0)*(x11841))));
evalcond[5]=((((IkReal(-1.00000000000000))*(x11834)*(x11837)*(x11844)))+(((IkReal(-1.00000000000000))*(x11832)*(x11834)*(x11835)))+(((IkReal(-1.00000000000000))*(x11834)*(x11837)*(x11838)))+(((r01)*(x11849)))+(((IkReal(-1.00000000000000))*(x11831)*(x11847)))+(((IkReal(-1.00000000000000))*(r10)*(x11837)*(x11841)))+(((IkReal(-1.00000000000000))*(x11833)*(x11834)*(x11835)))+(((IkReal(-1.00000000000000))*(r00)*(x11835)*(x11841)))+(((r11)*(sj0)*(x11845)))+(((IkReal(-1.00000000000000))*(sj5)*(x11835)*(x11846)))+(((IkReal(-1.00000000000000))*(x11829)*(x11840))));
if( IKabs(evalcond[0]) > 0.000001  || IKabs(evalcond[1]) > 0.000001  || IKabs(evalcond[2]) > 0.000001  || IKabs(evalcond[3]) > 0.000001  || IKabs(evalcond[4]) > 0.000001  || IKabs(evalcond[5]) > 0.000001  )
{
continue;
}
}

{
std::vector<IkSingleDOFSolutionBase<IkReal> > vinfos(7);
vinfos[0].jointtype = 1;
vinfos[0].foffset = j0;
vinfos[0].indices[0] = _ij0[0];
vinfos[0].indices[1] = _ij0[1];
vinfos[0].maxsolutions = _nj0;
vinfos[1].jointtype = 1;
vinfos[1].foffset = j1;
vinfos[1].indices[0] = _ij1[0];
vinfos[1].indices[1] = _ij1[1];
vinfos[1].maxsolutions = _nj1;
vinfos[2].jointtype = 1;
vinfos[2].foffset = j2;
vinfos[2].indices[0] = _ij2[0];
vinfos[2].indices[1] = _ij2[1];
vinfos[2].maxsolutions = _nj2;
vinfos[3].jointtype = 1;
vinfos[3].foffset = j3;
vinfos[3].indices[0] = _ij3[0];
vinfos[3].indices[1] = _ij3[1];
vinfos[3].maxsolutions = _nj3;
vinfos[4].jointtype = 1;
vinfos[4].foffset = j4;
vinfos[4].indices[0] = _ij4[0];
vinfos[4].indices[1] = _ij4[1];
vinfos[4].maxsolutions = _nj4;
vinfos[5].jointtype = 1;
vinfos[5].foffset = j5;
vinfos[5].indices[0] = _ij5[0];
vinfos[5].indices[1] = _ij5[1];
vinfos[5].maxsolutions = _nj5;
vinfos[6].jointtype = 1;
vinfos[6].foffset = j6;
vinfos[6].indices[0] = _ij6[0];
vinfos[6].indices[1] = _ij6[1];
vinfos[6].maxsolutions = _nj6;
std::vector<int> vfree(0);
solutions.AddSolution(vinfos,vfree);
}
}
}

}

}

} else
{
{
IkReal j3array[1], cj3array[1], sj3array[1];
bool j3valid[1]={false};
_nj3 = 1;
IkReal x11850=((r20)*(sj6));
IkReal x11851=((cj4)*(cj5));
IkReal x11852=((cj6)*(r21));
if( IKabs(((gconst11)*(((((IkReal(-1.00000000000000))*(r21)*(sj4)*(sj6)))+(((x11851)*(x11852)))+(((x11850)*(x11851)))+(((cj6)*(r20)*(sj4)))+(((cj4)*(r22)*(sj5))))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(((gconst11)*(((((IkReal(-1.00000000000000))*(cj5)*(r22)))+(((sj5)*(x11850)))+(((sj5)*(x11852))))))) < IKFAST_ATAN2_MAGTHRESH )
    continue;
j3array[0]=IKatan2(((gconst11)*(((((IkReal(-1.00000000000000))*(r21)*(sj4)*(sj6)))+(((x11851)*(x11852)))+(((x11850)*(x11851)))+(((cj6)*(r20)*(sj4)))+(((cj4)*(r22)*(sj5)))))), ((gconst11)*(((((IkReal(-1.00000000000000))*(cj5)*(r22)))+(((sj5)*(x11850)))+(((sj5)*(x11852)))))));
sj3array[0]=IKsin(j3array[0]);
cj3array[0]=IKcos(j3array[0]);
if( j3array[0] > IKPI )
{
    j3array[0]-=IK2PI;
}
else if( j3array[0] < -IKPI )
{    j3array[0]+=IK2PI;
}
j3valid[0] = true;
for(int ij3 = 0; ij3 < 1; ++ij3)
{
if( !j3valid[ij3] )
{
    continue;
}
_ij3[0] = ij3; _ij3[1] = -1;
for(int iij3 = ij3+1; iij3 < 1; ++iij3)
{
if( j3valid[iij3] && IKabs(cj3array[ij3]-cj3array[iij3]) < IKFAST_SOLUTION_THRESH && IKabs(sj3array[ij3]-sj3array[iij3]) < IKFAST_SOLUTION_THRESH )
{
    j3valid[iij3]=false; _ij3[1] = iij3; break; 
}
}
j3 = j3array[ij3]; cj3 = cj3array[ij3]; sj3 = sj3array[ij3];
{
IkReal evalcond[6];
IkReal x11853=IKsin(j3);
IkReal x11854=IKcos(j3);
IkReal x11855=((sj0)*(sj5));
IkReal x11856=((r00)*(sj6));
IkReal x11857=((cj6)*(r01));
IkReal x11858=((cj4)*(cj5));
IkReal x11859=((IkReal(1.00000000000000))*(cj0));
IkReal x11860=((cj5)*(r12));
IkReal x11861=((IkReal(1.00000000000000))*(sj0));
IkReal x11862=((cj6)*(r11));
IkReal x11863=((cj5)*(r02));
IkReal x11864=((IkReal(1.00000000000000))*(cj1));
IkReal x11865=((cj6)*(sj4));
IkReal x11866=((cj6)*(r21));
IkReal x11867=((r20)*(sj6));
IkReal x11868=((r10)*(sj6));
IkReal x11869=((sj4)*(sj6));
IkReal x11870=((cj4)*(r02));
IkReal x11871=((IkReal(1.00000000000000))*(cj4)*(r12));
IkReal x11872=((IkReal(1.00000000000000))*(x11853));
IkReal x11873=((cj0)*(x11869));
evalcond[0]=((((sj5)*(x11866)))+(((IkReal(-1.00000000000000))*(cj5)*(r22)))+(((sj5)*(x11867)))+(((IkReal(-1.00000000000000))*(sj1)*(x11854))));
evalcond[1]=((((IkReal(-1.00000000000000))*(r21)*(x11869)))+(((cj4)*(r22)*(sj5)))+(((x11858)*(x11866)))+(((x11858)*(x11867)))+(((r20)*(x11865)))+(((IkReal(-1.00000000000000))*(sj1)*(x11872))));
evalcond[2]=((((IkReal(-1.00000000000000))*(sj5)*(x11859)*(x11862)))+(((IkReal(-1.00000000000000))*(sj5)*(x11859)*(x11868)))+(((cj0)*(x11860)))+(((IkReal(-1.00000000000000))*(x11872)))+(((x11855)*(x11857)))+(((IkReal(-1.00000000000000))*(x11861)*(x11863)))+(((x11855)*(x11856))));
evalcond[3]=((((IkReal(-1.00000000000000))*(sj5)*(x11857)*(x11859)))+(((IkReal(-1.00000000000000))*(x11854)*(x11864)))+(((IkReal(-1.00000000000000))*(x11855)*(x11862)))+(((IkReal(-1.00000000000000))*(sj5)*(x11856)*(x11859)))+(((IkReal(-1.00000000000000))*(x11855)*(x11868)))+(((sj0)*(x11860)))+(((cj0)*(x11863))));
evalcond[4]=((((r00)*(sj0)*(x11865)))+(((IkReal(-1.00000000000000))*(x11858)*(x11859)*(x11868)))+(((sj0)*(x11857)*(x11858)))+(((IkReal(-1.00000000000000))*(x11858)*(x11859)*(x11862)))+(((r11)*(x11873)))+(((x11855)*(x11870)))+(((IkReal(-1.00000000000000))*(r01)*(x11861)*(x11869)))+(((IkReal(-1.00000000000000))*(r10)*(x11859)*(x11865)))+(((IkReal(-1.00000000000000))*(cj4)*(r12)*(sj5)*(x11859)))+(x11854)+(((sj0)*(x11856)*(x11858))));
evalcond[5]=((((r01)*(x11873)))+(((IkReal(-1.00000000000000))*(x11858)*(x11861)*(x11862)))+(((IkReal(-1.00000000000000))*(x11855)*(x11871)))+(((IkReal(-1.00000000000000))*(x11856)*(x11858)*(x11859)))+(((IkReal(-1.00000000000000))*(x11857)*(x11858)*(x11859)))+(((r11)*(sj0)*(x11869)))+(((IkReal(-1.00000000000000))*(x11858)*(x11861)*(x11868)))+(((IkReal(-1.00000000000000))*(r00)*(x11859)*(x11865)))+(((IkReal(-1.00000000000000))*(r10)*(x11861)*(x11865)))+(((IkReal(-1.00000000000000))*(sj5)*(x11859)*(x11870)))+(((IkReal(-1.00000000000000))*(x11853)*(x11864))));
if( IKabs(evalcond[0]) > 0.000001  || IKabs(evalcond[1]) > 0.000001  || IKabs(evalcond[2]) > 0.000001  || IKabs(evalcond[3]) > 0.000001  || IKabs(evalcond[4]) > 0.000001  || IKabs(evalcond[5]) > 0.000001  )
{
continue;
}
}

{
std::vector<IkSingleDOFSolutionBase<IkReal> > vinfos(7);
vinfos[0].jointtype = 1;
vinfos[0].foffset = j0;
vinfos[0].indices[0] = _ij0[0];
vinfos[0].indices[1] = _ij0[1];
vinfos[0].maxsolutions = _nj0;
vinfos[1].jointtype = 1;
vinfos[1].foffset = j1;
vinfos[1].indices[0] = _ij1[0];
vinfos[1].indices[1] = _ij1[1];
vinfos[1].maxsolutions = _nj1;
vinfos[2].jointtype = 1;
vinfos[2].foffset = j2;
vinfos[2].indices[0] = _ij2[0];
vinfos[2].indices[1] = _ij2[1];
vinfos[2].maxsolutions = _nj2;
vinfos[3].jointtype = 1;
vinfos[3].foffset = j3;
vinfos[3].indices[0] = _ij3[0];
vinfos[3].indices[1] = _ij3[1];
vinfos[3].maxsolutions = _nj3;
vinfos[4].jointtype = 1;
vinfos[4].foffset = j4;
vinfos[4].indices[0] = _ij4[0];
vinfos[4].indices[1] = _ij4[1];
vinfos[4].maxsolutions = _nj4;
vinfos[5].jointtype = 1;
vinfos[5].foffset = j5;
vinfos[5].indices[0] = _ij5[0];
vinfos[5].indices[1] = _ij5[1];
vinfos[5].maxsolutions = _nj5;
vinfos[6].jointtype = 1;
vinfos[6].foffset = j6;
vinfos[6].indices[0] = _ij6[0];
vinfos[6].indices[1] = _ij6[1];
vinfos[6].maxsolutions = _nj6;
std::vector<int> vfree(0);
solutions.AddSolution(vinfos,vfree);
}
}
}

}

}

} else
{
IkReal x11874=((IkReal(1.00000000000000))*(cj0));
IkReal x11875=((cj4)*(sj6));
IkReal x11876=((sj0)*(sj4));
IkReal x11877=((cj5)*(sj6));
IkReal x11878=((sj4)*(sj5));
IkReal x11879=((r12)*(sj5));
IkReal x11880=((IkReal(0.374290000000000))*(cj5));
IkReal x11881=((r02)*(sj0));
IkReal x11882=((IkReal(1.00000000000000))*(sj0));
IkReal x11883=((cj0)*(r10));
IkReal x11884=((cj4)*(cj6));
IkReal x11885=((r00)*(sj0));
IkReal x11886=((cj6)*(r21));
IkReal x11887=((IkReal(0.374290000000000))*(sj5));
IkReal x11888=((cj0)*(r00));
IkReal x11889=((IkReal(0.0100000000000000))*(sj5));
IkReal x11890=((cj0)*(r02));
IkReal x11891=((cj5)*(sj4));
IkReal x11892=((cj6)*(r01));
IkReal x11893=((cj6)*(r11));
IkReal x11894=((r01)*(sj0));
IkReal x11895=((r10)*(sj0));
IkReal x11896=((IkReal(0.0100000000000000))*(cj5)*(cj6));
IkReal x11897=((sj6)*(x11887));
IkReal x11898=((cj0)*(cj6)*(x11887));
evalcond[0]=((IkReal(-3.14159265358979))+(IKfmod(((IkReal(4.71238898038469))+(j2)), IkReal(6.28318530717959))));
evalcond[1]=((((r22)*(x11878)))+(((r21)*(x11875)))+(((x11886)*(x11891)))+(cj1)+(((IkReal(-1.00000000000000))*(r20)*(x11884)))+(((r20)*(sj4)*(x11877))));
evalcond[2]=((((IkReal(-1.00000000000000))*(r22)*(x11880)))+(((IkReal(0.364420000000000))*(sj1)))+(((IkReal(-0.0100000000000000))*(r20)*(x11877)))+(((IkReal(-0.0100000000000000))*(cj5)*(x11886)))+(((r20)*(x11897)))+(pz)+(((IkReal(-1.00000000000000))*(r22)*(x11889)))+(((x11886)*(x11887))));
evalcond[3]=((((r02)*(sj5)*(x11876)))+(((IkReal(-1.00000000000000))*(r10)*(sj4)*(x11874)*(x11877)))+(((IkReal(-1.00000000000000))*(r11)*(x11874)*(x11875)))+(((IkReal(-1.00000000000000))*(r00)*(x11882)*(x11884)))+(((x11883)*(x11884)))+(((IkReal(-1.00000000000000))*(r12)*(x11874)*(x11878)))+(((r00)*(x11876)*(x11877)))+(((IkReal(-1.00000000000000))*(x11874)*(x11891)*(x11893)))+(((x11875)*(x11894)))+(((cj5)*(x11876)*(x11892))));
evalcond[4]=((((x11884)*(x11895)))+(((IkReal(-1.00000000000000))*(x11876)*(x11879)))+(((IkReal(-1.00000000000000))*(cj5)*(x11876)*(x11893)))+(((IkReal(-1.00000000000000))*(x11874)*(x11891)*(x11892)))+(((IkReal(-1.00000000000000))*(r01)*(x11874)*(x11875)))+(((x11884)*(x11888)))+(((IkReal(-1.00000000000000))*(sj1)))+(((IkReal(-1.00000000000000))*(r10)*(x11876)*(x11877)))+(((IkReal(-1.00000000000000))*(r00)*(sj4)*(x11874)*(x11877)))+(((IkReal(-1.00000000000000))*(r11)*(x11875)*(x11882)))+(((IkReal(-1.00000000000000))*(r02)*(x11874)*(x11878))));
evalcond[5]=((IkReal(-0.0690000000000000))+(((IkReal(-1.00000000000000))*(py)*(x11874)))+(((IkReal(-1.00000000000000))*(cj0)*(x11887)*(x11893)))+(((IkReal(-0.0100000000000000))*(x11877)*(x11885)))+(((IkReal(-1.00000000000000))*(x11880)*(x11881)))+(((cj0)*(r12)*(x11880)))+(((IkReal(0.0100000000000000))*(cj0)*(x11879)))+(((IkReal(-1.00000000000000))*(x11881)*(x11889)))+(((x11885)*(x11897)))+(((IkReal(0.0100000000000000))*(x11877)*(x11883)))+(((sj0)*(x11887)*(x11892)))+(((IkReal(0.0100000000000000))*(cj0)*(cj5)*(x11893)))+(((IkReal(-1.00000000000000))*(x11883)*(x11897)))+(((px)*(sj0)))+(((IkReal(-0.0100000000000000))*(cj5)*(sj0)*(x11892))));
evalcond[6]=((IkReal(0.0690000000000000))+(((IkReal(-1.00000000000000))*(cj0)*(x11887)*(x11892)))+(((x11889)*(x11890)))+(((IkReal(-1.00000000000000))*(sj0)*(x11887)*(x11893)))+(((IkReal(0.0100000000000000))*(cj5)*(sj0)*(x11893)))+(((IkReal(0.0100000000000000))*(sj0)*(x11879)))+(((r12)*(sj0)*(x11880)))+(((IkReal(-1.00000000000000))*(x11895)*(x11897)))+(((IkReal(0.0100000000000000))*(x11877)*(x11895)))+(((IkReal(-1.00000000000000))*(py)*(x11882)))+(((IkReal(-1.00000000000000))*(x11888)*(x11897)))+(((x11880)*(x11890)))+(((IkReal(0.0100000000000000))*(cj0)*(cj5)*(x11892)))+(((IkReal(0.0100000000000000))*(x11877)*(x11888)))+(((IkReal(-1.00000000000000))*(px)*(x11874)))+(((IkReal(0.364420000000000))*(cj1))));
if( IKabs(evalcond[0]) < 0.0000010000000000  && IKabs(evalcond[1]) < 0.0000010000000000  && IKabs(evalcond[2]) < 0.0000010000000000  && IKabs(evalcond[3]) < 0.0000010000000000  && IKabs(evalcond[4]) < 0.0000010000000000  && IKabs(evalcond[5]) < 0.0000010000000000  && IKabs(evalcond[6]) < 0.0000010000000000  )
{
{
IkReal dummyeval[1];
IkReal gconst12;
gconst12=IKsign(sj1);
dummyeval[0]=sj1;
if( IKabs(dummyeval[0]) < 0.0000010000000000  )
{
{
IkReal dummyeval[1];
dummyeval[0]=sj1;
if( IKabs(dummyeval[0]) < 0.0000010000000000  )
{
{
IkReal dummyeval[1];
dummyeval[0]=cj1;
if( IKabs(dummyeval[0]) < 0.0000010000000000  )
{
{
IkReal evalcond[9];
IkReal x11899=((IkReal(1.00000000000000))*(cj0));
IkReal x11900=((cj4)*(sj6));
IkReal x11901=((sj0)*(sj6));
IkReal x11902=((cj5)*(sj4));
IkReal x11903=((IkReal(0.374290000000000))*(sj5));
IkReal x11904=((sj4)*(sj5));
IkReal x11905=((cj0)*(cj6));
IkReal x11906=((IkReal(0.0100000000000000))*(cj5));
IkReal x11907=((cj4)*(sj5));
IkReal x11908=((cj5)*(sj0));
IkReal x11909=((IkReal(0.374290000000000))*(r02));
IkReal x11910=((r20)*(sj6));
IkReal x11911=((cj6)*(r21));
IkReal x11912=((IkReal(1.00000000000000))*(sj0));
IkReal x11913=((cj0)*(sj6));
IkReal x11914=((cj4)*(cj6));
IkReal x11915=((IkReal(0.374290000000000))*(r12));
IkReal x11916=((cj0)*(cj5));
IkReal x11917=((cj6)*(sj5));
IkReal x11918=((cj6)*(r01));
IkReal x11919=((r00)*(sj6));
IkReal x11920=((IkReal(0.0100000000000000))*(sj5));
IkReal x11921=((cj6)*(r11));
IkReal x11922=((IkReal(1.00000000000000))*(r10));
IkReal x11923=((r02)*(sj0));
IkReal x11924=((cj6)*(sj4));
IkReal x11925=((r12)*(x11912));
evalcond[0]=((IkReal(-3.14159265358979))+(IKfmod(((IkReal(1.57079632679490))+(j1)), IkReal(6.28318530717959))));
evalcond[1]=((((IkReal(-1.00000000000000))*(r20)*(x11914)))+(((r21)*(x11900)))+(((x11902)*(x11911)))+(((x11902)*(x11910)))+(((r22)*(x11904))));
evalcond[2]=((IkReal(0.364420000000000))+(((IkReal(-1.00000000000000))*(x11906)*(x11910)))+(((x11903)*(x11911)))+(((IkReal(-0.374290000000000))*(cj5)*(r22)))+(((x11903)*(x11910)))+(pz)+(((IkReal(-1.00000000000000))*(x11906)*(x11911)))+(((IkReal(-1.00000000000000))*(r22)*(x11920))));
evalcond[3]=((((r12)*(x11908)))+(((IkReal(-1.00000000000000))*(r11)*(x11912)*(x11917)))+(((IkReal(-1.00000000000000))*(r01)*(x11899)*(x11917)))+(((IkReal(-1.00000000000000))*(sj5)*(x11901)*(x11922)))+(((IkReal(-1.00000000000000))*(sj5)*(x11899)*(x11919)))+(((r02)*(x11916))));
evalcond[4]=((((IkReal(-1.00000000000000))*(x11899)*(x11902)*(x11921)))+(((sj0)*(x11902)*(x11918)))+(((cj4)*(r10)*(x11905)))+(((IkReal(-1.00000000000000))*(r12)*(x11899)*(x11904)))+(((r01)*(sj0)*(x11900)))+(((x11904)*(x11923)))+(((IkReal(-1.00000000000000))*(r10)*(sj6)*(x11899)*(x11902)))+(((r00)*(x11901)*(x11902)))+(((IkReal(-1.00000000000000))*(r00)*(x11912)*(x11914)))+(((IkReal(-1.00000000000000))*(r11)*(x11899)*(x11900))));
evalcond[5]=((IkReal(-1.00000000000000))+(((IkReal(-1.00000000000000))*(x11904)*(x11925)))+(((cj4)*(r00)*(x11905)))+(((IkReal(-1.00000000000000))*(r01)*(x11899)*(x11900)))+(((IkReal(-1.00000000000000))*(x11899)*(x11902)*(x11918)))+(((IkReal(-1.00000000000000))*(r02)*(x11899)*(x11904)))+(((IkReal(-1.00000000000000))*(x11902)*(x11912)*(x11921)))+(((IkReal(-1.00000000000000))*(x11899)*(x11902)*(x11919)))+(((IkReal(-1.00000000000000))*(x11901)*(x11902)*(x11922)))+(((r10)*(sj0)*(x11914)))+(((IkReal(-1.00000000000000))*(r11)*(x11900)*(x11912))));
evalcond[6]=((IkReal(-0.0690000000000000))+(((sj0)*(x11903)*(x11918)))+(((IkReal(-1.00000000000000))*(x11908)*(x11909)))+(((IkReal(-1.00000000000000))*(r10)*(x11903)*(x11913)))+(((IkReal(-1.00000000000000))*(py)*(x11899)))+(((IkReal(-1.00000000000000))*(x11920)*(x11923)))+(((IkReal(-1.00000000000000))*(r11)*(x11903)*(x11905)))+(((r11)*(x11905)*(x11906)))+(((IkReal(-1.00000000000000))*(r00)*(x11901)*(x11906)))+(((IkReal(-1.00000000000000))*(sj0)*(x11906)*(x11918)))+(((cj0)*(r12)*(x11920)))+(((px)*(sj0)))+(((r10)*(x11906)*(x11913)))+(((x11915)*(x11916)))+(((r00)*(x11901)*(x11903))));
evalcond[7]=((((IkReal(-1.00000000000000))*(cj5)*(r00)*(x11899)*(x11900)))+(((IkReal(-1.00000000000000))*(x11900)*(x11908)*(x11922)))+(((IkReal(-1.00000000000000))*(r00)*(x11899)*(x11924)))+(((r11)*(sj4)*(x11901)))+(((r01)*(sj4)*(x11913)))+(((IkReal(-1.00000000000000))*(r11)*(x11908)*(x11914)))+(((IkReal(-1.00000000000000))*(r02)*(x11899)*(x11907)))+(((IkReal(-1.00000000000000))*(cj5)*(r01)*(x11899)*(x11914)))+(((IkReal(-1.00000000000000))*(x11907)*(x11925)))+(((IkReal(-1.00000000000000))*(r10)*(x11912)*(x11924))));
evalcond[8]=((IkReal(0.0690000000000000))+(((r12)*(sj0)*(x11920)))+(((IkReal(-1.00000000000000))*(px)*(x11899)))+(((IkReal(-1.00000000000000))*(r10)*(x11901)*(x11903)))+(((IkReal(-1.00000000000000))*(r00)*(x11903)*(x11913)))+(((cj0)*(r02)*(x11920)))+(((r00)*(x11906)*(x11913)))+(((r10)*(x11901)*(x11906)))+(((IkReal(-1.00000000000000))*(py)*(x11912)))+(((IkReal(-1.00000000000000))*(r01)*(x11903)*(x11905)))+(((x11909)*(x11916)))+(((r01)*(x11905)*(x11906)))+(((IkReal(-1.00000000000000))*(sj0)*(x11903)*(x11921)))+(((sj0)*(x11906)*(x11921)))+(((x11908)*(x11915))));
if( IKabs(evalcond[0]) < 0.0000010000000000  && IKabs(evalcond[1]) < 0.0000010000000000  && IKabs(evalcond[2]) < 0.0000010000000000  && IKabs(evalcond[3]) < 0.0000010000000000  && IKabs(evalcond[4]) < 0.0000010000000000  && IKabs(evalcond[5]) < 0.0000010000000000  && IKabs(evalcond[6]) < 0.0000010000000000  && IKabs(evalcond[7]) < 0.0000010000000000  && IKabs(evalcond[8]) < 0.0000010000000000  )
{
{
IkReal j3array[1], cj3array[1], sj3array[1];
bool j3valid[1]={false};
_nj3 = 1;
IkReal x11926=((r20)*(sj6));
IkReal x11927=((cj4)*(cj5));
IkReal x11928=((cj6)*(r21));
if( IKabs(((((IkReal(-1.00000000000000))*(r21)*(sj4)*(sj6)))+(((x11927)*(x11928)))+(((x11926)*(x11927)))+(((cj6)*(r20)*(sj4)))+(((cj4)*(r22)*(sj5))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(((((sj5)*(x11926)))+(((sj5)*(x11928)))+(((IkReal(-1.00000000000000))*(cj5)*(r22))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(IKsqr(((((IkReal(-1.00000000000000))*(r21)*(sj4)*(sj6)))+(((x11927)*(x11928)))+(((x11926)*(x11927)))+(((cj6)*(r20)*(sj4)))+(((cj4)*(r22)*(sj5)))))+IKsqr(((((sj5)*(x11926)))+(((sj5)*(x11928)))+(((IkReal(-1.00000000000000))*(cj5)*(r22)))))-1) <= IKFAST_SINCOS_THRESH )
    continue;
j3array[0]=IKatan2(((((IkReal(-1.00000000000000))*(r21)*(sj4)*(sj6)))+(((x11927)*(x11928)))+(((x11926)*(x11927)))+(((cj6)*(r20)*(sj4)))+(((cj4)*(r22)*(sj5)))), ((((sj5)*(x11926)))+(((sj5)*(x11928)))+(((IkReal(-1.00000000000000))*(cj5)*(r22)))));
sj3array[0]=IKsin(j3array[0]);
cj3array[0]=IKcos(j3array[0]);
if( j3array[0] > IKPI )
{
    j3array[0]-=IK2PI;
}
else if( j3array[0] < -IKPI )
{    j3array[0]+=IK2PI;
}
j3valid[0] = true;
for(int ij3 = 0; ij3 < 1; ++ij3)
{
if( !j3valid[ij3] )
{
    continue;
}
_ij3[0] = ij3; _ij3[1] = -1;
for(int iij3 = ij3+1; iij3 < 1; ++iij3)
{
if( j3valid[iij3] && IKabs(cj3array[ij3]-cj3array[iij3]) < IKFAST_SOLUTION_THRESH && IKabs(sj3array[ij3]-sj3array[iij3]) < IKFAST_SOLUTION_THRESH )
{
    j3valid[iij3]=false; _ij3[1] = iij3; break; 
}
}
j3 = j3array[ij3]; cj3 = cj3array[ij3]; sj3 = sj3array[ij3];
{
IkReal evalcond[4];
IkReal x11929=IKsin(j3);
IkReal x11930=((sj0)*(sj5));
IkReal x11931=((r00)*(sj6));
IkReal x11932=((cj6)*(r01));
IkReal x11933=((cj5)*(sj0));
IkReal x11934=((cj0)*(cj5));
IkReal x11935=((cj6)*(sj4));
IkReal x11936=((sj4)*(sj6));
IkReal x11937=((cj0)*(r11));
IkReal x11938=((cj4)*(cj6));
IkReal x11939=((cj4)*(sj6));
IkReal x11940=((IkReal(1.00000000000000))*(cj0));
IkReal x11941=((cj4)*(sj5));
IkReal x11942=((sj5)*(sj6));
IkReal x11943=((cj6)*(sj5));
IkReal x11944=((IkReal(1.00000000000000))*(IKcos(j3)));
evalcond[0]=((((r21)*(x11943)))+(((IkReal(-1.00000000000000))*(cj5)*(r22)))+(((r20)*(x11942)))+(((IkReal(-1.00000000000000))*(x11944))));
evalcond[1]=((((r22)*(x11941)))+(((r20)*(x11935)))+(((IkReal(-1.00000000000000))*(r21)*(x11936)))+(((IkReal(-1.00000000000000))*(x11929)))+(((cj5)*(r20)*(x11939)))+(((cj5)*(r21)*(x11938))));
evalcond[2]=((((r12)*(x11934)))+(((x11930)*(x11932)))+(((IkReal(-1.00000000000000))*(x11937)*(x11943)))+(((x11930)*(x11931)))+(x11929)+(((IkReal(-1.00000000000000))*(r02)*(x11933)))+(((IkReal(-1.00000000000000))*(r10)*(x11940)*(x11942))));
evalcond[3]=((((IkReal(-1.00000000000000))*(r01)*(sj0)*(x11936)))+(((cj4)*(x11931)*(x11933)))+(((x11936)*(x11937)))+(((cj4)*(x11932)*(x11933)))+(((cj4)*(r02)*(x11930)))+(((IkReal(-1.00000000000000))*(r11)*(x11934)*(x11938)))+(((r00)*(sj0)*(x11935)))+(((IkReal(-1.00000000000000))*(r10)*(x11934)*(x11939)))+(((IkReal(-1.00000000000000))*(x11944)))+(((IkReal(-1.00000000000000))*(r10)*(x11935)*(x11940)))+(((IkReal(-1.00000000000000))*(r12)*(x11940)*(x11941))));
if( IKabs(evalcond[0]) > 0.000001  || IKabs(evalcond[1]) > 0.000001  || IKabs(evalcond[2]) > 0.000001  || IKabs(evalcond[3]) > 0.000001  )
{
continue;
}
}

{
std::vector<IkSingleDOFSolutionBase<IkReal> > vinfos(7);
vinfos[0].jointtype = 1;
vinfos[0].foffset = j0;
vinfos[0].indices[0] = _ij0[0];
vinfos[0].indices[1] = _ij0[1];
vinfos[0].maxsolutions = _nj0;
vinfos[1].jointtype = 1;
vinfos[1].foffset = j1;
vinfos[1].indices[0] = _ij1[0];
vinfos[1].indices[1] = _ij1[1];
vinfos[1].maxsolutions = _nj1;
vinfos[2].jointtype = 1;
vinfos[2].foffset = j2;
vinfos[2].indices[0] = _ij2[0];
vinfos[2].indices[1] = _ij2[1];
vinfos[2].maxsolutions = _nj2;
vinfos[3].jointtype = 1;
vinfos[3].foffset = j3;
vinfos[3].indices[0] = _ij3[0];
vinfos[3].indices[1] = _ij3[1];
vinfos[3].maxsolutions = _nj3;
vinfos[4].jointtype = 1;
vinfos[4].foffset = j4;
vinfos[4].indices[0] = _ij4[0];
vinfos[4].indices[1] = _ij4[1];
vinfos[4].maxsolutions = _nj4;
vinfos[5].jointtype = 1;
vinfos[5].foffset = j5;
vinfos[5].indices[0] = _ij5[0];
vinfos[5].indices[1] = _ij5[1];
vinfos[5].maxsolutions = _nj5;
vinfos[6].jointtype = 1;
vinfos[6].foffset = j6;
vinfos[6].indices[0] = _ij6[0];
vinfos[6].indices[1] = _ij6[1];
vinfos[6].maxsolutions = _nj6;
std::vector<int> vfree(0);
solutions.AddSolution(vinfos,vfree);
}
}
}

} else
{
IkReal x11945=((IkReal(1.00000000000000))*(cj0));
IkReal x11946=((cj4)*(sj6));
IkReal x11947=((sj0)*(sj6));
IkReal x11948=((cj5)*(sj4));
IkReal x11949=((IkReal(0.374290000000000))*(sj5));
IkReal x11950=((sj4)*(sj5));
IkReal x11951=((cj0)*(cj6));
IkReal x11952=((IkReal(0.0100000000000000))*(cj5));
IkReal x11953=((cj4)*(sj5));
IkReal x11954=((cj5)*(sj0));
IkReal x11955=((IkReal(0.374290000000000))*(r02));
IkReal x11956=((r20)*(sj6));
IkReal x11957=((cj6)*(r21));
IkReal x11958=((IkReal(1.00000000000000))*(sj0));
IkReal x11959=((cj0)*(sj6));
IkReal x11960=((cj4)*(cj6));
IkReal x11961=((IkReal(0.374290000000000))*(r12));
IkReal x11962=((cj0)*(cj5));
IkReal x11963=((cj6)*(sj5));
IkReal x11964=((cj6)*(r01));
IkReal x11965=((r00)*(sj6));
IkReal x11966=((IkReal(0.0100000000000000))*(sj5));
IkReal x11967=((cj6)*(r11));
IkReal x11968=((IkReal(1.00000000000000))*(r10));
IkReal x11969=((r02)*(sj0));
IkReal x11970=((cj6)*(sj4));
IkReal x11971=((r12)*(x11958));
evalcond[0]=((IkReal(-3.14159265358979))+(IKfmod(((IkReal(4.71238898038469))+(j1)), IkReal(6.28318530717959))));
evalcond[1]=((((IkReal(-1.00000000000000))*(r20)*(x11960)))+(((r21)*(x11946)))+(((x11948)*(x11956)))+(((r22)*(x11950)))+(((x11948)*(x11957))));
evalcond[2]=((IkReal(-0.364420000000000))+(((x11949)*(x11956)))+(((IkReal(-1.00000000000000))*(r22)*(x11966)))+(((IkReal(-1.00000000000000))*(x11952)*(x11956)))+(((IkReal(-0.374290000000000))*(cj5)*(r22)))+(pz)+(((IkReal(-1.00000000000000))*(x11952)*(x11957)))+(((x11949)*(x11957))));
evalcond[3]=((((r02)*(x11962)))+(((IkReal(-1.00000000000000))*(sj5)*(x11945)*(x11965)))+(((IkReal(-1.00000000000000))*(sj5)*(x11947)*(x11968)))+(((r12)*(x11954)))+(((IkReal(-1.00000000000000))*(r01)*(x11945)*(x11963)))+(((IkReal(-1.00000000000000))*(r11)*(x11958)*(x11963))));
evalcond[4]=((((sj0)*(x11948)*(x11964)))+(((r01)*(sj0)*(x11946)))+(((x11950)*(x11969)))+(((cj4)*(r10)*(x11951)))+(((IkReal(-1.00000000000000))*(r10)*(sj6)*(x11945)*(x11948)))+(((r00)*(x11947)*(x11948)))+(((IkReal(-1.00000000000000))*(r11)*(x11945)*(x11946)))+(((IkReal(-1.00000000000000))*(x11945)*(x11948)*(x11967)))+(((IkReal(-1.00000000000000))*(r12)*(x11945)*(x11950)))+(((IkReal(-1.00000000000000))*(r00)*(x11958)*(x11960))));
evalcond[5]=((IkReal(1.00000000000000))+(((IkReal(-1.00000000000000))*(r01)*(x11945)*(x11946)))+(((IkReal(-1.00000000000000))*(x11945)*(x11948)*(x11965)))+(((IkReal(-1.00000000000000))*(x11947)*(x11948)*(x11968)))+(((r10)*(sj0)*(x11960)))+(((IkReal(-1.00000000000000))*(r02)*(x11945)*(x11950)))+(((IkReal(-1.00000000000000))*(x11950)*(x11971)))+(((cj4)*(r00)*(x11951)))+(((IkReal(-1.00000000000000))*(x11948)*(x11958)*(x11967)))+(((IkReal(-1.00000000000000))*(x11945)*(x11948)*(x11964)))+(((IkReal(-1.00000000000000))*(r11)*(x11946)*(x11958))));
evalcond[6]=((IkReal(-0.0690000000000000))+(((IkReal(-1.00000000000000))*(py)*(x11945)))+(((IkReal(-1.00000000000000))*(r11)*(x11949)*(x11951)))+(((sj0)*(x11949)*(x11964)))+(((x11961)*(x11962)))+(((IkReal(-1.00000000000000))*(r00)*(x11947)*(x11952)))+(((r00)*(x11947)*(x11949)))+(((IkReal(-1.00000000000000))*(x11954)*(x11955)))+(((r10)*(x11952)*(x11959)))+(((IkReal(-1.00000000000000))*(r10)*(x11949)*(x11959)))+(((px)*(sj0)))+(((cj0)*(r12)*(x11966)))+(((r11)*(x11951)*(x11952)))+(((IkReal(-1.00000000000000))*(sj0)*(x11952)*(x11964)))+(((IkReal(-1.00000000000000))*(x11966)*(x11969))));
evalcond[7]=((((r11)*(sj4)*(x11947)))+(((IkReal(-1.00000000000000))*(x11946)*(x11954)*(x11968)))+(((r01)*(sj4)*(x11959)))+(((IkReal(-1.00000000000000))*(r10)*(x11958)*(x11970)))+(((IkReal(-1.00000000000000))*(cj5)*(r00)*(x11945)*(x11946)))+(((IkReal(-1.00000000000000))*(r00)*(x11945)*(x11970)))+(((IkReal(-1.00000000000000))*(r11)*(x11954)*(x11960)))+(((IkReal(-1.00000000000000))*(r02)*(x11945)*(x11953)))+(((IkReal(-1.00000000000000))*(cj5)*(r01)*(x11945)*(x11960)))+(((IkReal(-1.00000000000000))*(x11953)*(x11971))));
evalcond[8]=((IkReal(0.0690000000000000))+(((x11955)*(x11962)))+(((r01)*(x11951)*(x11952)))+(((r00)*(x11952)*(x11959)))+(((cj0)*(r02)*(x11966)))+(((IkReal(-1.00000000000000))*(sj0)*(x11949)*(x11967)))+(((r10)*(x11947)*(x11952)))+(((IkReal(-1.00000000000000))*(r01)*(x11949)*(x11951)))+(((sj0)*(x11952)*(x11967)))+(((x11954)*(x11961)))+(((IkReal(-1.00000000000000))*(r10)*(x11947)*(x11949)))+(((IkReal(-1.00000000000000))*(r00)*(x11949)*(x11959)))+(((r12)*(sj0)*(x11966)))+(((IkReal(-1.00000000000000))*(px)*(x11945)))+(((IkReal(-1.00000000000000))*(py)*(x11958))));
if( IKabs(evalcond[0]) < 0.0000010000000000  && IKabs(evalcond[1]) < 0.0000010000000000  && IKabs(evalcond[2]) < 0.0000010000000000  && IKabs(evalcond[3]) < 0.0000010000000000  && IKabs(evalcond[4]) < 0.0000010000000000  && IKabs(evalcond[5]) < 0.0000010000000000  && IKabs(evalcond[6]) < 0.0000010000000000  && IKabs(evalcond[7]) < 0.0000010000000000  && IKabs(evalcond[8]) < 0.0000010000000000  )
{
{
IkReal j3array[1], cj3array[1], sj3array[1];
bool j3valid[1]={false};
_nj3 = 1;
IkReal x11972=((IkReal(1.00000000000000))*(sj5));
IkReal x11973=((cj6)*(r21));
IkReal x11974=((r20)*(sj6));
IkReal x11975=((IkReal(1.00000000000000))*(cj4)*(cj5));
if( IKabs(((((IkReal(-1.00000000000000))*(cj4)*(r22)*(x11972)))+(((r21)*(sj4)*(sj6)))+(((IkReal(-1.00000000000000))*(x11973)*(x11975)))+(((IkReal(-1.00000000000000))*(x11974)*(x11975)))+(((IkReal(-1.00000000000000))*(cj6)*(r20)*(sj4))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(((((IkReal(-1.00000000000000))*(x11972)*(x11973)))+(((IkReal(-1.00000000000000))*(x11972)*(x11974)))+(((cj5)*(r22))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(IKsqr(((((IkReal(-1.00000000000000))*(cj4)*(r22)*(x11972)))+(((r21)*(sj4)*(sj6)))+(((IkReal(-1.00000000000000))*(x11973)*(x11975)))+(((IkReal(-1.00000000000000))*(x11974)*(x11975)))+(((IkReal(-1.00000000000000))*(cj6)*(r20)*(sj4)))))+IKsqr(((((IkReal(-1.00000000000000))*(x11972)*(x11973)))+(((IkReal(-1.00000000000000))*(x11972)*(x11974)))+(((cj5)*(r22)))))-1) <= IKFAST_SINCOS_THRESH )
    continue;
j3array[0]=IKatan2(((((IkReal(-1.00000000000000))*(cj4)*(r22)*(x11972)))+(((r21)*(sj4)*(sj6)))+(((IkReal(-1.00000000000000))*(x11973)*(x11975)))+(((IkReal(-1.00000000000000))*(x11974)*(x11975)))+(((IkReal(-1.00000000000000))*(cj6)*(r20)*(sj4)))), ((((IkReal(-1.00000000000000))*(x11972)*(x11973)))+(((IkReal(-1.00000000000000))*(x11972)*(x11974)))+(((cj5)*(r22)))));
sj3array[0]=IKsin(j3array[0]);
cj3array[0]=IKcos(j3array[0]);
if( j3array[0] > IKPI )
{
    j3array[0]-=IK2PI;
}
else if( j3array[0] < -IKPI )
{    j3array[0]+=IK2PI;
}
j3valid[0] = true;
for(int ij3 = 0; ij3 < 1; ++ij3)
{
if( !j3valid[ij3] )
{
    continue;
}
_ij3[0] = ij3; _ij3[1] = -1;
for(int iij3 = ij3+1; iij3 < 1; ++iij3)
{
if( j3valid[iij3] && IKabs(cj3array[ij3]-cj3array[iij3]) < IKFAST_SOLUTION_THRESH && IKabs(sj3array[ij3]-sj3array[iij3]) < IKFAST_SOLUTION_THRESH )
{
    j3valid[iij3]=false; _ij3[1] = iij3; break; 
}
}
j3 = j3array[ij3]; cj3 = cj3array[ij3]; sj3 = sj3array[ij3];
{
IkReal evalcond[4];
IkReal x11976=IKsin(j3);
IkReal x11977=IKcos(j3);
IkReal x11978=((sj0)*(sj5));
IkReal x11979=((r00)*(sj6));
IkReal x11980=((cj6)*(r01));
IkReal x11981=((cj0)*(cj5));
IkReal x11982=((IkReal(1.00000000000000))*(cj5));
IkReal x11983=((cj4)*(cj5));
IkReal x11984=((cj6)*(sj4));
IkReal x11985=((sj4)*(sj6));
IkReal x11986=((cj0)*(r11));
IkReal x11987=((IkReal(1.00000000000000))*(cj4));
IkReal x11988=((cj6)*(r21));
IkReal x11989=((r20)*(sj6));
IkReal x11990=((cj0)*(sj5));
IkReal x11991=((r10)*(sj6));
evalcond[0]=((((sj5)*(x11988)))+(((sj5)*(x11989)))+(x11977)+(((IkReal(-1.00000000000000))*(r22)*(x11982))));
evalcond[1]=((((IkReal(-1.00000000000000))*(r21)*(x11985)))+(((r20)*(x11984)))+(((x11983)*(x11989)))+(x11976)+(((cj4)*(r22)*(sj5)))+(((x11983)*(x11988))));
evalcond[2]=((((IkReal(-1.00000000000000))*(cj6)*(sj5)*(x11986)))+(((r12)*(x11981)))+(((IkReal(-1.00000000000000))*(x11990)*(x11991)))+(((x11978)*(x11979)))+(x11976)+(((x11978)*(x11980)))+(((IkReal(-1.00000000000000))*(r02)*(sj0)*(x11982))));
evalcond[3]=((((IkReal(-1.00000000000000))*(r01)*(sj0)*(x11985)))+(((IkReal(-1.00000000000000))*(r12)*(x11987)*(x11990)))+(((IkReal(-1.00000000000000))*(cj0)*(r10)*(x11984)))+(((IkReal(-1.00000000000000))*(x11981)*(x11987)*(x11991)))+(((sj0)*(x11979)*(x11983)))+(((x11985)*(x11986)))+(((cj4)*(r02)*(x11978)))+(((IkReal(-1.00000000000000))*(x11977)))+(((sj0)*(x11980)*(x11983)))+(((IkReal(-1.00000000000000))*(cj6)*(r11)*(x11981)*(x11987)))+(((r00)*(sj0)*(x11984))));
if( IKabs(evalcond[0]) > 0.000001  || IKabs(evalcond[1]) > 0.000001  || IKabs(evalcond[2]) > 0.000001  || IKabs(evalcond[3]) > 0.000001  )
{
continue;
}
}

{
std::vector<IkSingleDOFSolutionBase<IkReal> > vinfos(7);
vinfos[0].jointtype = 1;
vinfos[0].foffset = j0;
vinfos[0].indices[0] = _ij0[0];
vinfos[0].indices[1] = _ij0[1];
vinfos[0].maxsolutions = _nj0;
vinfos[1].jointtype = 1;
vinfos[1].foffset = j1;
vinfos[1].indices[0] = _ij1[0];
vinfos[1].indices[1] = _ij1[1];
vinfos[1].maxsolutions = _nj1;
vinfos[2].jointtype = 1;
vinfos[2].foffset = j2;
vinfos[2].indices[0] = _ij2[0];
vinfos[2].indices[1] = _ij2[1];
vinfos[2].maxsolutions = _nj2;
vinfos[3].jointtype = 1;
vinfos[3].foffset = j3;
vinfos[3].indices[0] = _ij3[0];
vinfos[3].indices[1] = _ij3[1];
vinfos[3].maxsolutions = _nj3;
vinfos[4].jointtype = 1;
vinfos[4].foffset = j4;
vinfos[4].indices[0] = _ij4[0];
vinfos[4].indices[1] = _ij4[1];
vinfos[4].maxsolutions = _nj4;
vinfos[5].jointtype = 1;
vinfos[5].foffset = j5;
vinfos[5].indices[0] = _ij5[0];
vinfos[5].indices[1] = _ij5[1];
vinfos[5].maxsolutions = _nj5;
vinfos[6].jointtype = 1;
vinfos[6].foffset = j6;
vinfos[6].indices[0] = _ij6[0];
vinfos[6].indices[1] = _ij6[1];
vinfos[6].maxsolutions = _nj6;
std::vector<int> vfree(0);
solutions.AddSolution(vinfos,vfree);
}
}
}

} else
{
if( 1 )
{
continue;

} else
{
}
}
}
}

} else
{
{
IkReal j3array[1], cj3array[1], sj3array[1];
bool j3valid[1]={false};
_nj3 = 1;
IkReal x11992=((cj5)*(r02));
IkReal x11993=((cj0)*(sj5));
IkReal x11994=((r10)*(sj6));
IkReal x11995=((IkReal(1.00000000000000))*(cj6));
IkReal x11996=((sj0)*(sj5));
IkReal x11997=((cj5)*(r12));
IkReal x11998=((IkReal(1.00000000000000))*(r00)*(sj6));
if( IKabs(((((sj0)*(x11992)))+(((x11993)*(x11994)))+(((IkReal(-1.00000000000000))*(cj0)*(x11997)))+(((IkReal(-1.00000000000000))*(r01)*(x11995)*(x11996)))+(((IkReal(-1.00000000000000))*(x11996)*(x11998)))+(((cj6)*(r11)*(x11993))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(((((IKabs(cj1) != 0)?((IkReal)1/(cj1)):(IkReal)1.0e30))*(((((IkReal(-1.00000000000000))*(x11993)*(x11998)))+(((IkReal(-1.00000000000000))*(r11)*(x11995)*(x11996)))+(((cj0)*(x11992)))+(((sj0)*(x11997)))+(((IkReal(-1.00000000000000))*(r01)*(x11993)*(x11995)))+(((IkReal(-1.00000000000000))*(x11994)*(x11996))))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(IKsqr(((((sj0)*(x11992)))+(((x11993)*(x11994)))+(((IkReal(-1.00000000000000))*(cj0)*(x11997)))+(((IkReal(-1.00000000000000))*(r01)*(x11995)*(x11996)))+(((IkReal(-1.00000000000000))*(x11996)*(x11998)))+(((cj6)*(r11)*(x11993)))))+IKsqr(((((IKabs(cj1) != 0)?((IkReal)1/(cj1)):(IkReal)1.0e30))*(((((IkReal(-1.00000000000000))*(x11993)*(x11998)))+(((IkReal(-1.00000000000000))*(r11)*(x11995)*(x11996)))+(((cj0)*(x11992)))+(((sj0)*(x11997)))+(((IkReal(-1.00000000000000))*(r01)*(x11993)*(x11995)))+(((IkReal(-1.00000000000000))*(x11994)*(x11996)))))))-1) <= IKFAST_SINCOS_THRESH )
    continue;
j3array[0]=IKatan2(((((sj0)*(x11992)))+(((x11993)*(x11994)))+(((IkReal(-1.00000000000000))*(cj0)*(x11997)))+(((IkReal(-1.00000000000000))*(r01)*(x11995)*(x11996)))+(((IkReal(-1.00000000000000))*(x11996)*(x11998)))+(((cj6)*(r11)*(x11993)))), ((((IKabs(cj1) != 0)?((IkReal)1/(cj1)):(IkReal)1.0e30))*(((((IkReal(-1.00000000000000))*(x11993)*(x11998)))+(((IkReal(-1.00000000000000))*(r11)*(x11995)*(x11996)))+(((cj0)*(x11992)))+(((sj0)*(x11997)))+(((IkReal(-1.00000000000000))*(r01)*(x11993)*(x11995)))+(((IkReal(-1.00000000000000))*(x11994)*(x11996)))))));
sj3array[0]=IKsin(j3array[0]);
cj3array[0]=IKcos(j3array[0]);
if( j3array[0] > IKPI )
{
    j3array[0]-=IK2PI;
}
else if( j3array[0] < -IKPI )
{    j3array[0]+=IK2PI;
}
j3valid[0] = true;
for(int ij3 = 0; ij3 < 1; ++ij3)
{
if( !j3valid[ij3] )
{
    continue;
}
_ij3[0] = ij3; _ij3[1] = -1;
for(int iij3 = ij3+1; iij3 < 1; ++iij3)
{
if( j3valid[iij3] && IKabs(cj3array[ij3]-cj3array[iij3]) < IKFAST_SOLUTION_THRESH && IKabs(sj3array[ij3]-sj3array[iij3]) < IKFAST_SOLUTION_THRESH )
{
    j3valid[iij3]=false; _ij3[1] = iij3; break; 
}
}
j3 = j3array[ij3]; cj3 = cj3array[ij3]; sj3 = sj3array[ij3];
{
IkReal evalcond[6];
IkReal x11999=IKsin(j3);
IkReal x12000=IKcos(j3);
IkReal x12001=((sj0)*(sj5));
IkReal x12002=((r00)*(sj6));
IkReal x12003=((IkReal(1.00000000000000))*(cj4));
IkReal x12004=((cj6)*(r01));
IkReal x12005=((cj0)*(cj5));
IkReal x12006=((cj5)*(sj0));
IkReal x12007=((cj6)*(r11));
IkReal x12008=((cj0)*(sj5));
IkReal x12009=((IkReal(1.00000000000000))*(cj1));
IkReal x12010=((cj6)*(sj4));
IkReal x12011=((IkReal(1.00000000000000))*(sj1));
IkReal x12012=((cj4)*(cj5));
IkReal x12013=((cj6)*(r21));
IkReal x12014=((r20)*(sj6));
IkReal x12015=((r10)*(sj6));
IkReal x12016=((IkReal(1.00000000000000))*(cj0));
IkReal x12017=((cj0)*(sj4)*(sj6));
IkReal x12018=((sj0)*(sj4)*(sj6));
evalcond[0]=((((sj5)*(x12014)))+(((IkReal(-1.00000000000000))*(cj5)*(r22)))+(((IkReal(-1.00000000000000))*(x12000)*(x12011)))+(((sj5)*(x12013))));
evalcond[1]=((((IkReal(-1.00000000000000))*(r21)*(sj4)*(sj6)))+(((x12012)*(x12013)))+(((cj4)*(r22)*(sj5)))+(((IkReal(-1.00000000000000))*(x11999)*(x12011)))+(((r20)*(x12010)))+(((x12012)*(x12014))));
evalcond[2]=((((IkReal(-1.00000000000000))*(x12008)*(x12015)))+(((IkReal(-1.00000000000000))*(x12007)*(x12008)))+(((x12001)*(x12002)))+(((r12)*(x12005)))+(((IkReal(-1.00000000000000))*(r02)*(x12006)))+(x11999)+(((x12001)*(x12004))));
evalcond[3]=((((IkReal(-1.00000000000000))*(x12001)*(x12007)))+(((IkReal(-1.00000000000000))*(x12001)*(x12015)))+(((IkReal(-1.00000000000000))*(x12004)*(x12008)))+(((r02)*(x12005)))+(((r12)*(x12006)))+(((IkReal(-1.00000000000000))*(x12000)*(x12009)))+(((IkReal(-1.00000000000000))*(x12002)*(x12008))));
evalcond[4]=((((IkReal(-1.00000000000000))*(r10)*(x12010)*(x12016)))+(((IkReal(-1.00000000000000))*(x12003)*(x12005)*(x12015)))+(((IkReal(-1.00000000000000))*(r01)*(x12018)))+(((cj4)*(x12004)*(x12006)))+(((r11)*(x12017)))+(((cj4)*(x12002)*(x12006)))+(((IkReal(-1.00000000000000))*(x12003)*(x12005)*(x12007)))+(((IkReal(-1.00000000000000))*(x12000)))+(((IkReal(-1.00000000000000))*(r12)*(x12003)*(x12008)))+(((r00)*(sj0)*(x12010)))+(((cj4)*(r02)*(x12001))));
evalcond[5]=((((IkReal(-1.00000000000000))*(x12003)*(x12006)*(x12007)))+(((IkReal(-1.00000000000000))*(x11999)*(x12009)))+(((IkReal(-1.00000000000000))*(r10)*(sj0)*(x12010)))+(((IkReal(-1.00000000000000))*(r12)*(x12001)*(x12003)))+(((IkReal(-1.00000000000000))*(x12002)*(x12003)*(x12005)))+(((IkReal(-1.00000000000000))*(x12003)*(x12006)*(x12015)))+(((r01)*(x12017)))+(((IkReal(-1.00000000000000))*(r00)*(x12010)*(x12016)))+(((r11)*(x12018)))+(((IkReal(-1.00000000000000))*(r02)*(x12003)*(x12008)))+(((IkReal(-1.00000000000000))*(x12003)*(x12004)*(x12005))));
if( IKabs(evalcond[0]) > 0.000001  || IKabs(evalcond[1]) > 0.000001  || IKabs(evalcond[2]) > 0.000001  || IKabs(evalcond[3]) > 0.000001  || IKabs(evalcond[4]) > 0.000001  || IKabs(evalcond[5]) > 0.000001  )
{
continue;
}
}

{
std::vector<IkSingleDOFSolutionBase<IkReal> > vinfos(7);
vinfos[0].jointtype = 1;
vinfos[0].foffset = j0;
vinfos[0].indices[0] = _ij0[0];
vinfos[0].indices[1] = _ij0[1];
vinfos[0].maxsolutions = _nj0;
vinfos[1].jointtype = 1;
vinfos[1].foffset = j1;
vinfos[1].indices[0] = _ij1[0];
vinfos[1].indices[1] = _ij1[1];
vinfos[1].maxsolutions = _nj1;
vinfos[2].jointtype = 1;
vinfos[2].foffset = j2;
vinfos[2].indices[0] = _ij2[0];
vinfos[2].indices[1] = _ij2[1];
vinfos[2].maxsolutions = _nj2;
vinfos[3].jointtype = 1;
vinfos[3].foffset = j3;
vinfos[3].indices[0] = _ij3[0];
vinfos[3].indices[1] = _ij3[1];
vinfos[3].maxsolutions = _nj3;
vinfos[4].jointtype = 1;
vinfos[4].foffset = j4;
vinfos[4].indices[0] = _ij4[0];
vinfos[4].indices[1] = _ij4[1];
vinfos[4].maxsolutions = _nj4;
vinfos[5].jointtype = 1;
vinfos[5].foffset = j5;
vinfos[5].indices[0] = _ij5[0];
vinfos[5].indices[1] = _ij5[1];
vinfos[5].maxsolutions = _nj5;
vinfos[6].jointtype = 1;
vinfos[6].foffset = j6;
vinfos[6].indices[0] = _ij6[0];
vinfos[6].indices[1] = _ij6[1];
vinfos[6].maxsolutions = _nj6;
std::vector<int> vfree(0);
solutions.AddSolution(vinfos,vfree);
}
}
}

}

}

} else
{
{
IkReal j3array[1], cj3array[1], sj3array[1];
bool j3valid[1]={false};
_nj3 = 1;
IkReal x12019=((sj5)*(sj6));
IkReal x12020=((IkReal(1.00000000000000))*(sj0));
IkReal x12021=((cj6)*(sj5));
IkReal x12022=((IkReal(1.00000000000000))*(cj5));
if( IKabs(((((cj0)*(r10)*(x12019)))+(((IkReal(-1.00000000000000))*(r00)*(x12019)*(x12020)))+(((IkReal(-1.00000000000000))*(cj0)*(r12)*(x12022)))+(((cj5)*(r02)*(sj0)))+(((cj0)*(r11)*(x12021)))+(((IkReal(-1.00000000000000))*(r01)*(x12020)*(x12021))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(((((IKabs(sj1) != 0)?((IkReal)1/(sj1)):(IkReal)1.0e30))*(((((IkReal(-1.00000000000000))*(r22)*(x12022)))+(((r21)*(x12021)))+(((r20)*(x12019))))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(IKsqr(((((cj0)*(r10)*(x12019)))+(((IkReal(-1.00000000000000))*(r00)*(x12019)*(x12020)))+(((IkReal(-1.00000000000000))*(cj0)*(r12)*(x12022)))+(((cj5)*(r02)*(sj0)))+(((cj0)*(r11)*(x12021)))+(((IkReal(-1.00000000000000))*(r01)*(x12020)*(x12021)))))+IKsqr(((((IKabs(sj1) != 0)?((IkReal)1/(sj1)):(IkReal)1.0e30))*(((((IkReal(-1.00000000000000))*(r22)*(x12022)))+(((r21)*(x12021)))+(((r20)*(x12019)))))))-1) <= IKFAST_SINCOS_THRESH )
    continue;
j3array[0]=IKatan2(((((cj0)*(r10)*(x12019)))+(((IkReal(-1.00000000000000))*(r00)*(x12019)*(x12020)))+(((IkReal(-1.00000000000000))*(cj0)*(r12)*(x12022)))+(((cj5)*(r02)*(sj0)))+(((cj0)*(r11)*(x12021)))+(((IkReal(-1.00000000000000))*(r01)*(x12020)*(x12021)))), ((((IKabs(sj1) != 0)?((IkReal)1/(sj1)):(IkReal)1.0e30))*(((((IkReal(-1.00000000000000))*(r22)*(x12022)))+(((r21)*(x12021)))+(((r20)*(x12019)))))));
sj3array[0]=IKsin(j3array[0]);
cj3array[0]=IKcos(j3array[0]);
if( j3array[0] > IKPI )
{
    j3array[0]-=IK2PI;
}
else if( j3array[0] < -IKPI )
{    j3array[0]+=IK2PI;
}
j3valid[0] = true;
for(int ij3 = 0; ij3 < 1; ++ij3)
{
if( !j3valid[ij3] )
{
    continue;
}
_ij3[0] = ij3; _ij3[1] = -1;
for(int iij3 = ij3+1; iij3 < 1; ++iij3)
{
if( j3valid[iij3] && IKabs(cj3array[ij3]-cj3array[iij3]) < IKFAST_SOLUTION_THRESH && IKabs(sj3array[ij3]-sj3array[iij3]) < IKFAST_SOLUTION_THRESH )
{
    j3valid[iij3]=false; _ij3[1] = iij3; break; 
}
}
j3 = j3array[ij3]; cj3 = cj3array[ij3]; sj3 = sj3array[ij3];
{
IkReal evalcond[6];
IkReal x12023=IKsin(j3);
IkReal x12024=IKcos(j3);
IkReal x12025=((sj0)*(sj5));
IkReal x12026=((r00)*(sj6));
IkReal x12027=((IkReal(1.00000000000000))*(cj4));
IkReal x12028=((cj6)*(r01));
IkReal x12029=((cj0)*(cj5));
IkReal x12030=((cj5)*(sj0));
IkReal x12031=((cj6)*(r11));
IkReal x12032=((cj0)*(sj5));
IkReal x12033=((IkReal(1.00000000000000))*(cj1));
IkReal x12034=((cj6)*(sj4));
IkReal x12035=((IkReal(1.00000000000000))*(sj1));
IkReal x12036=((cj4)*(cj5));
IkReal x12037=((cj6)*(r21));
IkReal x12038=((r20)*(sj6));
IkReal x12039=((r10)*(sj6));
IkReal x12040=((IkReal(1.00000000000000))*(cj0));
IkReal x12041=((cj0)*(sj4)*(sj6));
IkReal x12042=((sj0)*(sj4)*(sj6));
evalcond[0]=((((sj5)*(x12037)))+(((IkReal(-1.00000000000000))*(cj5)*(r22)))+(((sj5)*(x12038)))+(((IkReal(-1.00000000000000))*(x12024)*(x12035))));
evalcond[1]=((((x12036)*(x12038)))+(((IkReal(-1.00000000000000))*(r21)*(sj4)*(sj6)))+(((IkReal(-1.00000000000000))*(x12023)*(x12035)))+(((cj4)*(r22)*(sj5)))+(((x12036)*(x12037)))+(((r20)*(x12034))));
evalcond[2]=((((IkReal(-1.00000000000000))*(x12032)*(x12039)))+(((x12025)*(x12028)))+(((x12025)*(x12026)))+(x12023)+(((r12)*(x12029)))+(((IkReal(-1.00000000000000))*(r02)*(x12030)))+(((IkReal(-1.00000000000000))*(x12031)*(x12032))));
evalcond[3]=((((IkReal(-1.00000000000000))*(x12028)*(x12032)))+(((IkReal(-1.00000000000000))*(x12026)*(x12032)))+(((IkReal(-1.00000000000000))*(x12025)*(x12039)))+(((r02)*(x12029)))+(((IkReal(-1.00000000000000))*(x12024)*(x12033)))+(((IkReal(-1.00000000000000))*(x12025)*(x12031)))+(((r12)*(x12030))));
evalcond[4]=((((cj4)*(x12028)*(x12030)))+(((IkReal(-1.00000000000000))*(r12)*(x12027)*(x12032)))+(((r11)*(x12041)))+(((IkReal(-1.00000000000000))*(r01)*(x12042)))+(((IkReal(-1.00000000000000))*(r10)*(x12034)*(x12040)))+(((r00)*(sj0)*(x12034)))+(((IkReal(-1.00000000000000))*(x12024)))+(((IkReal(-1.00000000000000))*(x12027)*(x12029)*(x12031)))+(((cj4)*(x12026)*(x12030)))+(((cj4)*(r02)*(x12025)))+(((IkReal(-1.00000000000000))*(x12027)*(x12029)*(x12039))));
evalcond[5]=((((IkReal(-1.00000000000000))*(x12027)*(x12028)*(x12029)))+(((IkReal(-1.00000000000000))*(x12023)*(x12033)))+(((IkReal(-1.00000000000000))*(x12026)*(x12027)*(x12029)))+(((IkReal(-1.00000000000000))*(x12027)*(x12030)*(x12031)))+(((IkReal(-1.00000000000000))*(r02)*(x12027)*(x12032)))+(((IkReal(-1.00000000000000))*(r00)*(x12034)*(x12040)))+(((r11)*(x12042)))+(((IkReal(-1.00000000000000))*(r10)*(sj0)*(x12034)))+(((r01)*(x12041)))+(((IkReal(-1.00000000000000))*(x12027)*(x12030)*(x12039)))+(((IkReal(-1.00000000000000))*(r12)*(x12025)*(x12027))));
if( IKabs(evalcond[0]) > 0.000001  || IKabs(evalcond[1]) > 0.000001  || IKabs(evalcond[2]) > 0.000001  || IKabs(evalcond[3]) > 0.000001  || IKabs(evalcond[4]) > 0.000001  || IKabs(evalcond[5]) > 0.000001  )
{
continue;
}
}

{
std::vector<IkSingleDOFSolutionBase<IkReal> > vinfos(7);
vinfos[0].jointtype = 1;
vinfos[0].foffset = j0;
vinfos[0].indices[0] = _ij0[0];
vinfos[0].indices[1] = _ij0[1];
vinfos[0].maxsolutions = _nj0;
vinfos[1].jointtype = 1;
vinfos[1].foffset = j1;
vinfos[1].indices[0] = _ij1[0];
vinfos[1].indices[1] = _ij1[1];
vinfos[1].maxsolutions = _nj1;
vinfos[2].jointtype = 1;
vinfos[2].foffset = j2;
vinfos[2].indices[0] = _ij2[0];
vinfos[2].indices[1] = _ij2[1];
vinfos[2].maxsolutions = _nj2;
vinfos[3].jointtype = 1;
vinfos[3].foffset = j3;
vinfos[3].indices[0] = _ij3[0];
vinfos[3].indices[1] = _ij3[1];
vinfos[3].maxsolutions = _nj3;
vinfos[4].jointtype = 1;
vinfos[4].foffset = j4;
vinfos[4].indices[0] = _ij4[0];
vinfos[4].indices[1] = _ij4[1];
vinfos[4].maxsolutions = _nj4;
vinfos[5].jointtype = 1;
vinfos[5].foffset = j5;
vinfos[5].indices[0] = _ij5[0];
vinfos[5].indices[1] = _ij5[1];
vinfos[5].maxsolutions = _nj5;
vinfos[6].jointtype = 1;
vinfos[6].foffset = j6;
vinfos[6].indices[0] = _ij6[0];
vinfos[6].indices[1] = _ij6[1];
vinfos[6].maxsolutions = _nj6;
std::vector<int> vfree(0);
solutions.AddSolution(vinfos,vfree);
}
}
}

}

}

} else
{
{
IkReal j3array[1], cj3array[1], sj3array[1];
bool j3valid[1]={false};
_nj3 = 1;
IkReal x12043=((r20)*(sj6));
IkReal x12044=((cj4)*(cj5));
IkReal x12045=((cj6)*(r21));
if( IKabs(((gconst12)*(((((x12043)*(x12044)))+(((IkReal(-1.00000000000000))*(r21)*(sj4)*(sj6)))+(((x12044)*(x12045)))+(((cj6)*(r20)*(sj4)))+(((cj4)*(r22)*(sj5))))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(((gconst12)*(((((sj5)*(x12043)))+(((IkReal(-1.00000000000000))*(cj5)*(r22)))+(((sj5)*(x12045))))))) < IKFAST_ATAN2_MAGTHRESH )
    continue;
j3array[0]=IKatan2(((gconst12)*(((((x12043)*(x12044)))+(((IkReal(-1.00000000000000))*(r21)*(sj4)*(sj6)))+(((x12044)*(x12045)))+(((cj6)*(r20)*(sj4)))+(((cj4)*(r22)*(sj5)))))), ((gconst12)*(((((sj5)*(x12043)))+(((IkReal(-1.00000000000000))*(cj5)*(r22)))+(((sj5)*(x12045)))))));
sj3array[0]=IKsin(j3array[0]);
cj3array[0]=IKcos(j3array[0]);
if( j3array[0] > IKPI )
{
    j3array[0]-=IK2PI;
}
else if( j3array[0] < -IKPI )
{    j3array[0]+=IK2PI;
}
j3valid[0] = true;
for(int ij3 = 0; ij3 < 1; ++ij3)
{
if( !j3valid[ij3] )
{
    continue;
}
_ij3[0] = ij3; _ij3[1] = -1;
for(int iij3 = ij3+1; iij3 < 1; ++iij3)
{
if( j3valid[iij3] && IKabs(cj3array[ij3]-cj3array[iij3]) < IKFAST_SOLUTION_THRESH && IKabs(sj3array[ij3]-sj3array[iij3]) < IKFAST_SOLUTION_THRESH )
{
    j3valid[iij3]=false; _ij3[1] = iij3; break; 
}
}
j3 = j3array[ij3]; cj3 = cj3array[ij3]; sj3 = sj3array[ij3];
{
IkReal evalcond[6];
IkReal x12046=IKsin(j3);
IkReal x12047=IKcos(j3);
IkReal x12048=((sj0)*(sj5));
IkReal x12049=((r00)*(sj6));
IkReal x12050=((IkReal(1.00000000000000))*(cj4));
IkReal x12051=((cj6)*(r01));
IkReal x12052=((cj0)*(cj5));
IkReal x12053=((cj5)*(sj0));
IkReal x12054=((cj6)*(r11));
IkReal x12055=((cj0)*(sj5));
IkReal x12056=((IkReal(1.00000000000000))*(cj1));
IkReal x12057=((cj6)*(sj4));
IkReal x12058=((IkReal(1.00000000000000))*(sj1));
IkReal x12059=((cj4)*(cj5));
IkReal x12060=((cj6)*(r21));
IkReal x12061=((r20)*(sj6));
IkReal x12062=((r10)*(sj6));
IkReal x12063=((IkReal(1.00000000000000))*(cj0));
IkReal x12064=((cj0)*(sj4)*(sj6));
IkReal x12065=((sj0)*(sj4)*(sj6));
evalcond[0]=((((IkReal(-1.00000000000000))*(x12047)*(x12058)))+(((IkReal(-1.00000000000000))*(cj5)*(r22)))+(((sj5)*(x12061)))+(((sj5)*(x12060))));
evalcond[1]=((((x12059)*(x12061)))+(((IkReal(-1.00000000000000))*(r21)*(sj4)*(sj6)))+(((IkReal(-1.00000000000000))*(x12046)*(x12058)))+(((cj4)*(r22)*(sj5)))+(((r20)*(x12057)))+(((x12059)*(x12060))));
evalcond[2]=((((x12048)*(x12049)))+(x12046)+(((IkReal(-1.00000000000000))*(x12054)*(x12055)))+(((IkReal(-1.00000000000000))*(x12055)*(x12062)))+(((r12)*(x12052)))+(((IkReal(-1.00000000000000))*(r02)*(x12053)))+(((x12048)*(x12051))));
evalcond[3]=((((IkReal(-1.00000000000000))*(x12047)*(x12056)))+(((r12)*(x12053)))+(((IkReal(-1.00000000000000))*(x12049)*(x12055)))+(((IkReal(-1.00000000000000))*(x12051)*(x12055)))+(((r02)*(x12052)))+(((IkReal(-1.00000000000000))*(x12048)*(x12054)))+(((IkReal(-1.00000000000000))*(x12048)*(x12062))));
evalcond[4]=((((r11)*(x12064)))+(((cj4)*(r02)*(x12048)))+(((IkReal(-1.00000000000000))*(x12050)*(x12052)*(x12062)))+(((cj4)*(x12049)*(x12053)))+(((IkReal(-1.00000000000000))*(x12050)*(x12052)*(x12054)))+(((IkReal(-1.00000000000000))*(x12047)))+(((IkReal(-1.00000000000000))*(r01)*(x12065)))+(((IkReal(-1.00000000000000))*(r12)*(x12050)*(x12055)))+(((IkReal(-1.00000000000000))*(r10)*(x12057)*(x12063)))+(((r00)*(sj0)*(x12057)))+(((cj4)*(x12051)*(x12053))));
evalcond[5]=((((r11)*(x12065)))+(((r01)*(x12064)))+(((IkReal(-1.00000000000000))*(r02)*(x12050)*(x12055)))+(((IkReal(-1.00000000000000))*(x12050)*(x12053)*(x12062)))+(((IkReal(-1.00000000000000))*(x12050)*(x12053)*(x12054)))+(((IkReal(-1.00000000000000))*(r10)*(sj0)*(x12057)))+(((IkReal(-1.00000000000000))*(r00)*(x12057)*(x12063)))+(((IkReal(-1.00000000000000))*(r12)*(x12048)*(x12050)))+(((IkReal(-1.00000000000000))*(x12049)*(x12050)*(x12052)))+(((IkReal(-1.00000000000000))*(x12046)*(x12056)))+(((IkReal(-1.00000000000000))*(x12050)*(x12051)*(x12052))));
if( IKabs(evalcond[0]) > 0.000001  || IKabs(evalcond[1]) > 0.000001  || IKabs(evalcond[2]) > 0.000001  || IKabs(evalcond[3]) > 0.000001  || IKabs(evalcond[4]) > 0.000001  || IKabs(evalcond[5]) > 0.000001  )
{
continue;
}
}

{
std::vector<IkSingleDOFSolutionBase<IkReal> > vinfos(7);
vinfos[0].jointtype = 1;
vinfos[0].foffset = j0;
vinfos[0].indices[0] = _ij0[0];
vinfos[0].indices[1] = _ij0[1];
vinfos[0].maxsolutions = _nj0;
vinfos[1].jointtype = 1;
vinfos[1].foffset = j1;
vinfos[1].indices[0] = _ij1[0];
vinfos[1].indices[1] = _ij1[1];
vinfos[1].maxsolutions = _nj1;
vinfos[2].jointtype = 1;
vinfos[2].foffset = j2;
vinfos[2].indices[0] = _ij2[0];
vinfos[2].indices[1] = _ij2[1];
vinfos[2].maxsolutions = _nj2;
vinfos[3].jointtype = 1;
vinfos[3].foffset = j3;
vinfos[3].indices[0] = _ij3[0];
vinfos[3].indices[1] = _ij3[1];
vinfos[3].maxsolutions = _nj3;
vinfos[4].jointtype = 1;
vinfos[4].foffset = j4;
vinfos[4].indices[0] = _ij4[0];
vinfos[4].indices[1] = _ij4[1];
vinfos[4].maxsolutions = _nj4;
vinfos[5].jointtype = 1;
vinfos[5].foffset = j5;
vinfos[5].indices[0] = _ij5[0];
vinfos[5].indices[1] = _ij5[1];
vinfos[5].maxsolutions = _nj5;
vinfos[6].jointtype = 1;
vinfos[6].foffset = j6;
vinfos[6].indices[0] = _ij6[0];
vinfos[6].indices[1] = _ij6[1];
vinfos[6].maxsolutions = _nj6;
std::vector<int> vfree(0);
solutions.AddSolution(vinfos,vfree);
}
}
}

}

}

} else
{
if( 1 )
{
continue;

} else
{
}
}
}
}
}
}
}
}

} else
{
{
IkReal j3array[1], cj3array[1], sj3array[1];
bool j3valid[1]={false};
_nj3 = 1;
IkReal x12066=((IKabs(sj2) != 0)?((IkReal)1/(sj2)):(IkReal)1.0e30);
IkReal x12067=((sj5)*(sj6));
IkReal x12068=((r00)*(sj0));
IkReal x12069=((cj1)*(cj2));
IkReal x12070=((cj0)*(r10));
IkReal x12071=((cj6)*(sj5));
IkReal x12072=((r01)*(sj0));
IkReal x12073=((IkReal(1.00000000000000))*(cj0));
IkReal x12074=((cj5)*(r12));
IkReal x12075=((IkReal(1.00000000000000))*(cj5));
IkReal x12076=((r02)*(sj0));
if( IKabs(((x12066)*(((((IkReal(-1.00000000000000))*(x12067)*(x12070)))+(((IkReal(-1.00000000000000))*(r11)*(x12071)*(x12073)))+(((x12071)*(x12072)))+(((cj0)*(x12074)))+(((IkReal(-1.00000000000000))*(x12075)*(x12076)))+(((x12067)*(x12068))))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(((x12066)*(((IKabs(sj1) != 0)?((IkReal)1/(sj1)):(IkReal)1.0e30))*(((((IkReal(-1.00000000000000))*(r22)*(sj2)*(x12075)))+(((IkReal(-1.00000000000000))*(x12069)*(x12071)*(x12072)))+(((cj5)*(x12069)*(x12076)))+(((r21)*(sj2)*(x12071)))+(((x12067)*(x12069)*(x12070)))+(((IkReal(-1.00000000000000))*(x12067)*(x12068)*(x12069)))+(((r20)*(sj2)*(x12067)))+(((IkReal(-1.00000000000000))*(x12069)*(x12073)*(x12074)))+(((cj0)*(r11)*(x12069)*(x12071))))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(IKsqr(((x12066)*(((((IkReal(-1.00000000000000))*(x12067)*(x12070)))+(((IkReal(-1.00000000000000))*(r11)*(x12071)*(x12073)))+(((x12071)*(x12072)))+(((cj0)*(x12074)))+(((IkReal(-1.00000000000000))*(x12075)*(x12076)))+(((x12067)*(x12068)))))))+IKsqr(((x12066)*(((IKabs(sj1) != 0)?((IkReal)1/(sj1)):(IkReal)1.0e30))*(((((IkReal(-1.00000000000000))*(r22)*(sj2)*(x12075)))+(((IkReal(-1.00000000000000))*(x12069)*(x12071)*(x12072)))+(((cj5)*(x12069)*(x12076)))+(((r21)*(sj2)*(x12071)))+(((x12067)*(x12069)*(x12070)))+(((IkReal(-1.00000000000000))*(x12067)*(x12068)*(x12069)))+(((r20)*(sj2)*(x12067)))+(((IkReal(-1.00000000000000))*(x12069)*(x12073)*(x12074)))+(((cj0)*(r11)*(x12069)*(x12071)))))))-1) <= IKFAST_SINCOS_THRESH )
    continue;
j3array[0]=IKatan2(((x12066)*(((((IkReal(-1.00000000000000))*(x12067)*(x12070)))+(((IkReal(-1.00000000000000))*(r11)*(x12071)*(x12073)))+(((x12071)*(x12072)))+(((cj0)*(x12074)))+(((IkReal(-1.00000000000000))*(x12075)*(x12076)))+(((x12067)*(x12068)))))), ((x12066)*(((IKabs(sj1) != 0)?((IkReal)1/(sj1)):(IkReal)1.0e30))*(((((IkReal(-1.00000000000000))*(r22)*(sj2)*(x12075)))+(((IkReal(-1.00000000000000))*(x12069)*(x12071)*(x12072)))+(((cj5)*(x12069)*(x12076)))+(((r21)*(sj2)*(x12071)))+(((x12067)*(x12069)*(x12070)))+(((IkReal(-1.00000000000000))*(x12067)*(x12068)*(x12069)))+(((r20)*(sj2)*(x12067)))+(((IkReal(-1.00000000000000))*(x12069)*(x12073)*(x12074)))+(((cj0)*(r11)*(x12069)*(x12071)))))));
sj3array[0]=IKsin(j3array[0]);
cj3array[0]=IKcos(j3array[0]);
if( j3array[0] > IKPI )
{
    j3array[0]-=IK2PI;
}
else if( j3array[0] < -IKPI )
{    j3array[0]+=IK2PI;
}
j3valid[0] = true;
for(int ij3 = 0; ij3 < 1; ++ij3)
{
if( !j3valid[ij3] )
{
    continue;
}
_ij3[0] = ij3; _ij3[1] = -1;
for(int iij3 = ij3+1; iij3 < 1; ++iij3)
{
if( j3valid[iij3] && IKabs(cj3array[ij3]-cj3array[iij3]) < IKFAST_SOLUTION_THRESH && IKabs(sj3array[ij3]-sj3array[iij3]) < IKFAST_SOLUTION_THRESH )
{
    j3valid[iij3]=false; _ij3[1] = iij3; break; 
}
}
j3 = j3array[ij3]; cj3 = cj3array[ij3]; sj3 = sj3array[ij3];
{
IkReal evalcond[6];
IkReal x12077=IKcos(j3);
IkReal x12078=IKsin(j3);
IkReal x12079=((sj0)*(sj5));
IkReal x12080=((r00)*(sj6));
IkReal x12081=((IkReal(1.00000000000000))*(cj4));
IkReal x12082=((cj6)*(r01));
IkReal x12083=((cj0)*(cj5));
IkReal x12084=((cj5)*(sj0));
IkReal x12085=((cj6)*(r11));
IkReal x12086=((cj6)*(sj4));
IkReal x12087=((IkReal(1.00000000000000))*(cj1));
IkReal x12088=((cj4)*(cj5));
IkReal x12089=((cj6)*(r21));
IkReal x12090=((r20)*(sj6));
IkReal x12091=((r10)*(sj6));
IkReal x12092=((cj0)*(sj5));
IkReal x12093=((IkReal(1.00000000000000))*(cj0));
IkReal x12094=((IkReal(1.00000000000000))*(x12092));
IkReal x12095=((IkReal(1.00000000000000))*(x12078));
IkReal x12096=((cj0)*(sj4)*(sj6));
IkReal x12097=((cj2)*(x12078));
IkReal x12098=((sj0)*(sj4)*(sj6));
IkReal x12099=((IkReal(1.00000000000000))*(sj1)*(x12077));
evalcond[0]=((((sj5)*(x12090)))+(((IkReal(-1.00000000000000))*(x12087)*(x12097)))+(((IkReal(-1.00000000000000))*(x12099)))+(((sj5)*(x12089)))+(((IkReal(-1.00000000000000))*(cj5)*(r22))));
evalcond[1]=((((IkReal(-1.00000000000000))*(r21)*(sj4)*(sj6)))+(((cj4)*(r22)*(sj5)))+(((r20)*(x12086)))+(((x12088)*(x12089)))+(((IkReal(-1.00000000000000))*(sj1)*(x12095)))+(((cj1)*(cj2)*(x12077)))+(((x12088)*(x12090))));
evalcond[2]=((((r12)*(x12083)))+(((x12079)*(x12080)))+(((IkReal(-1.00000000000000))*(x12091)*(x12094)))+(((x12079)*(x12082)))+(((IkReal(-1.00000000000000))*(r02)*(x12084)))+(((IkReal(-1.00000000000000))*(sj2)*(x12095)))+(((IkReal(-1.00000000000000))*(x12085)*(x12094))));
evalcond[3]=((((r12)*(x12084)))+(((IkReal(-1.00000000000000))*(x12079)*(x12085)))+(((IkReal(-1.00000000000000))*(x12077)*(x12087)))+(((IkReal(-1.00000000000000))*(x12082)*(x12094)))+(((r02)*(x12083)))+(((IkReal(-1.00000000000000))*(x12079)*(x12091)))+(((IkReal(-1.00000000000000))*(x12080)*(x12094)))+(((sj1)*(x12097))));
evalcond[4]=((((sj2)*(x12077)))+(((cj4)*(r02)*(x12079)))+(((IkReal(-1.00000000000000))*(x12081)*(x12083)*(x12085)))+(((IkReal(-1.00000000000000))*(x12081)*(x12083)*(x12091)))+(((r00)*(sj0)*(x12086)))+(((IkReal(-1.00000000000000))*(r12)*(x12081)*(x12092)))+(((cj4)*(x12082)*(x12084)))+(((cj4)*(x12080)*(x12084)))+(((r11)*(x12096)))+(((IkReal(-1.00000000000000))*(r01)*(x12098)))+(((IkReal(-1.00000000000000))*(r10)*(x12086)*(x12093))));
evalcond[5]=((((IkReal(-1.00000000000000))*(r02)*(x12081)*(x12092)))+(((IkReal(-1.00000000000000))*(cj2)*(x12099)))+(((IkReal(-1.00000000000000))*(r00)*(x12086)*(x12093)))+(((IkReal(-1.00000000000000))*(x12081)*(x12082)*(x12083)))+(((IkReal(-1.00000000000000))*(x12078)*(x12087)))+(((IkReal(-1.00000000000000))*(r10)*(sj0)*(x12086)))+(((IkReal(-1.00000000000000))*(x12081)*(x12084)*(x12085)))+(((r11)*(x12098)))+(((IkReal(-1.00000000000000))*(r12)*(x12079)*(x12081)))+(((IkReal(-1.00000000000000))*(x12081)*(x12084)*(x12091)))+(((IkReal(-1.00000000000000))*(x12080)*(x12081)*(x12083)))+(((r01)*(x12096))));
if( IKabs(evalcond[0]) > 0.000001  || IKabs(evalcond[1]) > 0.000001  || IKabs(evalcond[2]) > 0.000001  || IKabs(evalcond[3]) > 0.000001  || IKabs(evalcond[4]) > 0.000001  || IKabs(evalcond[5]) > 0.000001  )
{
continue;
}
}

{
std::vector<IkSingleDOFSolutionBase<IkReal> > vinfos(7);
vinfos[0].jointtype = 1;
vinfos[0].foffset = j0;
vinfos[0].indices[0] = _ij0[0];
vinfos[0].indices[1] = _ij0[1];
vinfos[0].maxsolutions = _nj0;
vinfos[1].jointtype = 1;
vinfos[1].foffset = j1;
vinfos[1].indices[0] = _ij1[0];
vinfos[1].indices[1] = _ij1[1];
vinfos[1].maxsolutions = _nj1;
vinfos[2].jointtype = 1;
vinfos[2].foffset = j2;
vinfos[2].indices[0] = _ij2[0];
vinfos[2].indices[1] = _ij2[1];
vinfos[2].maxsolutions = _nj2;
vinfos[3].jointtype = 1;
vinfos[3].foffset = j3;
vinfos[3].indices[0] = _ij3[0];
vinfos[3].indices[1] = _ij3[1];
vinfos[3].maxsolutions = _nj3;
vinfos[4].jointtype = 1;
vinfos[4].foffset = j4;
vinfos[4].indices[0] = _ij4[0];
vinfos[4].indices[1] = _ij4[1];
vinfos[4].maxsolutions = _nj4;
vinfos[5].jointtype = 1;
vinfos[5].foffset = j5;
vinfos[5].indices[0] = _ij5[0];
vinfos[5].indices[1] = _ij5[1];
vinfos[5].maxsolutions = _nj5;
vinfos[6].jointtype = 1;
vinfos[6].foffset = j6;
vinfos[6].indices[0] = _ij6[0];
vinfos[6].indices[1] = _ij6[1];
vinfos[6].maxsolutions = _nj6;
std::vector<int> vfree(0);
solutions.AddSolution(vinfos,vfree);
}
}
}

}

}

} else
{
{
IkReal j3array[1], cj3array[1], sj3array[1];
bool j3valid[1]={false};
_nj3 = 1;
IkReal x12100=(cj1)*(cj1);
IkReal x12101=(sj1)*(sj1);
IkReal x12102=((r00)*(sj6));
IkReal x12103=((cj6)*(r01));
IkReal x12104=((IkReal(1.00000000000000))*(cj1));
IkReal x12105=((cj5)*(r22));
IkReal x12106=((sj5)*(sj6));
IkReal x12107=((r10)*(sj0));
IkReal x12108=((cj1)*(cj5));
IkReal x12109=((cj0)*(r02));
IkReal x12110=((r12)*(sj0));
IkReal x12111=((IkReal(1.00000000000000))*(sj1));
IkReal x12112=((cj6)*(sj5));
IkReal x12113=((cj0)*(sj5));
IkReal x12114=((r11)*(sj0));
IkReal x12115=((sj1)*(x12113));
if( IKabs(((((IKabs(((((cj2)*(x12101)))+(((cj2)*(x12100))))) != 0)?((IkReal)1/(((((cj2)*(x12101)))+(((cj2)*(x12100)))))):(IkReal)1.0e30))*(((((IkReal(-1.00000000000000))*(cj5)*(x12109)*(x12111)))+(((cj1)*(r20)*(x12106)))+(((sj1)*(x12106)*(x12107)))+(((sj1)*(x12112)*(x12114)))+(((IkReal(-1.00000000000000))*(x12104)*(x12105)))+(((x12102)*(x12115)))+(((x12103)*(x12115)))+(((IkReal(-1.00000000000000))*(cj5)*(x12110)*(x12111)))+(((cj1)*(r21)*(x12112))))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(((((IKabs(((x12101)+(x12100))) != 0)?((IkReal)1/(((x12101)+(x12100)))):(IkReal)1.0e30))*(((((r21)*(sj1)*(x12112)))+(((IkReal(-1.00000000000000))*(x12102)*(x12104)*(x12113)))+(((IkReal(-1.00000000000000))*(x12103)*(x12104)*(x12113)))+(((x12108)*(x12109)))+(((IkReal(-1.00000000000000))*(x12105)*(x12111)))+(((IkReal(-1.00000000000000))*(x12104)*(x12112)*(x12114)))+(((x12108)*(x12110)))+(((r20)*(sj1)*(x12106)))+(((IkReal(-1.00000000000000))*(x12104)*(x12106)*(x12107))))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(IKsqr(((((IKabs(((((cj2)*(x12101)))+(((cj2)*(x12100))))) != 0)?((IkReal)1/(((((cj2)*(x12101)))+(((cj2)*(x12100)))))):(IkReal)1.0e30))*(((((IkReal(-1.00000000000000))*(cj5)*(x12109)*(x12111)))+(((cj1)*(r20)*(x12106)))+(((sj1)*(x12106)*(x12107)))+(((sj1)*(x12112)*(x12114)))+(((IkReal(-1.00000000000000))*(x12104)*(x12105)))+(((x12102)*(x12115)))+(((x12103)*(x12115)))+(((IkReal(-1.00000000000000))*(cj5)*(x12110)*(x12111)))+(((cj1)*(r21)*(x12112)))))))+IKsqr(((((IKabs(((x12101)+(x12100))) != 0)?((IkReal)1/(((x12101)+(x12100)))):(IkReal)1.0e30))*(((((r21)*(sj1)*(x12112)))+(((IkReal(-1.00000000000000))*(x12102)*(x12104)*(x12113)))+(((IkReal(-1.00000000000000))*(x12103)*(x12104)*(x12113)))+(((x12108)*(x12109)))+(((IkReal(-1.00000000000000))*(x12105)*(x12111)))+(((IkReal(-1.00000000000000))*(x12104)*(x12112)*(x12114)))+(((x12108)*(x12110)))+(((r20)*(sj1)*(x12106)))+(((IkReal(-1.00000000000000))*(x12104)*(x12106)*(x12107)))))))-1) <= IKFAST_SINCOS_THRESH )
    continue;
j3array[0]=IKatan2(((((IKabs(((((cj2)*(x12101)))+(((cj2)*(x12100))))) != 0)?((IkReal)1/(((((cj2)*(x12101)))+(((cj2)*(x12100)))))):(IkReal)1.0e30))*(((((IkReal(-1.00000000000000))*(cj5)*(x12109)*(x12111)))+(((cj1)*(r20)*(x12106)))+(((sj1)*(x12106)*(x12107)))+(((sj1)*(x12112)*(x12114)))+(((IkReal(-1.00000000000000))*(x12104)*(x12105)))+(((x12102)*(x12115)))+(((x12103)*(x12115)))+(((IkReal(-1.00000000000000))*(cj5)*(x12110)*(x12111)))+(((cj1)*(r21)*(x12112)))))), ((((IKabs(((x12101)+(x12100))) != 0)?((IkReal)1/(((x12101)+(x12100)))):(IkReal)1.0e30))*(((((r21)*(sj1)*(x12112)))+(((IkReal(-1.00000000000000))*(x12102)*(x12104)*(x12113)))+(((IkReal(-1.00000000000000))*(x12103)*(x12104)*(x12113)))+(((x12108)*(x12109)))+(((IkReal(-1.00000000000000))*(x12105)*(x12111)))+(((IkReal(-1.00000000000000))*(x12104)*(x12112)*(x12114)))+(((x12108)*(x12110)))+(((r20)*(sj1)*(x12106)))+(((IkReal(-1.00000000000000))*(x12104)*(x12106)*(x12107)))))));
sj3array[0]=IKsin(j3array[0]);
cj3array[0]=IKcos(j3array[0]);
if( j3array[0] > IKPI )
{
    j3array[0]-=IK2PI;
}
else if( j3array[0] < -IKPI )
{    j3array[0]+=IK2PI;
}
j3valid[0] = true;
for(int ij3 = 0; ij3 < 1; ++ij3)
{
if( !j3valid[ij3] )
{
    continue;
}
_ij3[0] = ij3; _ij3[1] = -1;
for(int iij3 = ij3+1; iij3 < 1; ++iij3)
{
if( j3valid[iij3] && IKabs(cj3array[ij3]-cj3array[iij3]) < IKFAST_SOLUTION_THRESH && IKabs(sj3array[ij3]-sj3array[iij3]) < IKFAST_SOLUTION_THRESH )
{
    j3valid[iij3]=false; _ij3[1] = iij3; break; 
}
}
j3 = j3array[ij3]; cj3 = cj3array[ij3]; sj3 = sj3array[ij3];
{
IkReal evalcond[6];
IkReal x12116=IKcos(j3);
IkReal x12117=IKsin(j3);
IkReal x12118=((sj0)*(sj5));
IkReal x12119=((r00)*(sj6));
IkReal x12120=((IkReal(1.00000000000000))*(cj4));
IkReal x12121=((cj6)*(r01));
IkReal x12122=((cj0)*(cj5));
IkReal x12123=((cj5)*(sj0));
IkReal x12124=((cj6)*(r11));
IkReal x12125=((cj6)*(sj4));
IkReal x12126=((IkReal(1.00000000000000))*(cj1));
IkReal x12127=((cj4)*(cj5));
IkReal x12128=((cj6)*(r21));
IkReal x12129=((r20)*(sj6));
IkReal x12130=((r10)*(sj6));
IkReal x12131=((cj0)*(sj5));
IkReal x12132=((IkReal(1.00000000000000))*(cj0));
IkReal x12133=((IkReal(1.00000000000000))*(x12131));
IkReal x12134=((IkReal(1.00000000000000))*(x12117));
IkReal x12135=((cj0)*(sj4)*(sj6));
IkReal x12136=((cj2)*(x12117));
IkReal x12137=((sj0)*(sj4)*(sj6));
IkReal x12138=((IkReal(1.00000000000000))*(sj1)*(x12116));
evalcond[0]=((((IkReal(-1.00000000000000))*(x12126)*(x12136)))+(((IkReal(-1.00000000000000))*(cj5)*(r22)))+(((sj5)*(x12128)))+(((IkReal(-1.00000000000000))*(x12138)))+(((sj5)*(x12129))));
evalcond[1]=((((cj1)*(cj2)*(x12116)))+(((IkReal(-1.00000000000000))*(r21)*(sj4)*(sj6)))+(((x12127)*(x12129)))+(((cj4)*(r22)*(sj5)))+(((IkReal(-1.00000000000000))*(sj1)*(x12134)))+(((r20)*(x12125)))+(((x12127)*(x12128))));
evalcond[2]=((((x12118)*(x12121)))+(((IkReal(-1.00000000000000))*(x12124)*(x12133)))+(((x12118)*(x12119)))+(((IkReal(-1.00000000000000))*(x12130)*(x12133)))+(((IkReal(-1.00000000000000))*(sj2)*(x12134)))+(((r12)*(x12122)))+(((IkReal(-1.00000000000000))*(r02)*(x12123))));
evalcond[3]=((((IkReal(-1.00000000000000))*(x12119)*(x12133)))+(((r02)*(x12122)))+(((r12)*(x12123)))+(((IkReal(-1.00000000000000))*(x12118)*(x12124)))+(((IkReal(-1.00000000000000))*(x12116)*(x12126)))+(((sj1)*(x12136)))+(((IkReal(-1.00000000000000))*(x12118)*(x12130)))+(((IkReal(-1.00000000000000))*(x12121)*(x12133))));
evalcond[4]=((((cj4)*(x12119)*(x12123)))+(((cj4)*(x12121)*(x12123)))+(((sj2)*(x12116)))+(((IkReal(-1.00000000000000))*(r01)*(x12137)))+(((IkReal(-1.00000000000000))*(x12120)*(x12122)*(x12124)))+(((cj4)*(r02)*(x12118)))+(((r00)*(sj0)*(x12125)))+(((IkReal(-1.00000000000000))*(r10)*(x12125)*(x12132)))+(((r11)*(x12135)))+(((IkReal(-1.00000000000000))*(r12)*(x12120)*(x12131)))+(((IkReal(-1.00000000000000))*(x12120)*(x12122)*(x12130))));
evalcond[5]=((((IkReal(-1.00000000000000))*(x12117)*(x12126)))+(((IkReal(-1.00000000000000))*(r02)*(x12120)*(x12131)))+(((r11)*(x12137)))+(((IkReal(-1.00000000000000))*(x12120)*(x12123)*(x12124)))+(((IkReal(-1.00000000000000))*(r00)*(x12125)*(x12132)))+(((IkReal(-1.00000000000000))*(x12119)*(x12120)*(x12122)))+(((IkReal(-1.00000000000000))*(r12)*(x12118)*(x12120)))+(((IkReal(-1.00000000000000))*(x12120)*(x12121)*(x12122)))+(((IkReal(-1.00000000000000))*(cj2)*(x12138)))+(((IkReal(-1.00000000000000))*(r10)*(sj0)*(x12125)))+(((r01)*(x12135)))+(((IkReal(-1.00000000000000))*(x12120)*(x12123)*(x12130))));
if( IKabs(evalcond[0]) > 0.000001  || IKabs(evalcond[1]) > 0.000001  || IKabs(evalcond[2]) > 0.000001  || IKabs(evalcond[3]) > 0.000001  || IKabs(evalcond[4]) > 0.000001  || IKabs(evalcond[5]) > 0.000001  )
{
continue;
}
}

{
std::vector<IkSingleDOFSolutionBase<IkReal> > vinfos(7);
vinfos[0].jointtype = 1;
vinfos[0].foffset = j0;
vinfos[0].indices[0] = _ij0[0];
vinfos[0].indices[1] = _ij0[1];
vinfos[0].maxsolutions = _nj0;
vinfos[1].jointtype = 1;
vinfos[1].foffset = j1;
vinfos[1].indices[0] = _ij1[0];
vinfos[1].indices[1] = _ij1[1];
vinfos[1].maxsolutions = _nj1;
vinfos[2].jointtype = 1;
vinfos[2].foffset = j2;
vinfos[2].indices[0] = _ij2[0];
vinfos[2].indices[1] = _ij2[1];
vinfos[2].maxsolutions = _nj2;
vinfos[3].jointtype = 1;
vinfos[3].foffset = j3;
vinfos[3].indices[0] = _ij3[0];
vinfos[3].indices[1] = _ij3[1];
vinfos[3].maxsolutions = _nj3;
vinfos[4].jointtype = 1;
vinfos[4].foffset = j4;
vinfos[4].indices[0] = _ij4[0];
vinfos[4].indices[1] = _ij4[1];
vinfos[4].maxsolutions = _nj4;
vinfos[5].jointtype = 1;
vinfos[5].foffset = j5;
vinfos[5].indices[0] = _ij5[0];
vinfos[5].indices[1] = _ij5[1];
vinfos[5].maxsolutions = _nj5;
vinfos[6].jointtype = 1;
vinfos[6].foffset = j6;
vinfos[6].indices[0] = _ij6[0];
vinfos[6].indices[1] = _ij6[1];
vinfos[6].maxsolutions = _nj6;
std::vector<int> vfree(0);
solutions.AddSolution(vinfos,vfree);
}
}
}

}

}

} else
{
{
IkReal j3array[1], cj3array[1], sj3array[1];
bool j3valid[1]={false};
_nj3 = 1;
IkReal x12139=((sj1)*(sj6));
IkReal x12140=((r20)*(sj5));
IkReal x12141=((IkReal(1.00000000000000))*(r21));
IkReal x12142=((cj5)*(cj6));
IkReal x12143=((r22)*(sj5));
IkReal x12144=((cj4)*(sj1));
IkReal x12145=((cj1)*(cj2));
IkReal x12146=((cj5)*(r20));
IkReal x12147=((cj4)*(x12145));
IkReal x12148=((IkReal(1.00000000000000))*(cj5)*(r22));
IkReal x12149=((cj6)*(r20)*(sj4));
IkReal x12150=((cj6)*(r21)*(sj5));
if( IKabs(((gconst4)*(((((sj6)*(x12140)*(x12145)))+(((x12143)*(x12144)))+(((x12145)*(x12150)))+(((sj1)*(x12149)))+(((cj4)*(x12139)*(x12146)))+(((r21)*(x12142)*(x12144)))+(((IkReal(-1.00000000000000))*(sj4)*(x12139)*(x12141)))+(((IkReal(-1.00000000000000))*(x12145)*(x12148))))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(((gconst4)*(((((IkReal(-1.00000000000000))*(sj6)*(x12146)*(x12147)))+(((sj1)*(x12150)))+(((x12139)*(x12140)))+(((IkReal(-1.00000000000000))*(x12141)*(x12142)*(x12147)))+(((IkReal(-1.00000000000000))*(sj1)*(x12148)))+(((IkReal(-1.00000000000000))*(x12143)*(x12147)))+(((IkReal(-1.00000000000000))*(x12145)*(x12149)))+(((r21)*(sj4)*(sj6)*(x12145))))))) < IKFAST_ATAN2_MAGTHRESH )
    continue;
j3array[0]=IKatan2(((gconst4)*(((((sj6)*(x12140)*(x12145)))+(((x12143)*(x12144)))+(((x12145)*(x12150)))+(((sj1)*(x12149)))+(((cj4)*(x12139)*(x12146)))+(((r21)*(x12142)*(x12144)))+(((IkReal(-1.00000000000000))*(sj4)*(x12139)*(x12141)))+(((IkReal(-1.00000000000000))*(x12145)*(x12148)))))), ((gconst4)*(((((IkReal(-1.00000000000000))*(sj6)*(x12146)*(x12147)))+(((sj1)*(x12150)))+(((x12139)*(x12140)))+(((IkReal(-1.00000000000000))*(x12141)*(x12142)*(x12147)))+(((IkReal(-1.00000000000000))*(sj1)*(x12148)))+(((IkReal(-1.00000000000000))*(x12143)*(x12147)))+(((IkReal(-1.00000000000000))*(x12145)*(x12149)))+(((r21)*(sj4)*(sj6)*(x12145)))))));
sj3array[0]=IKsin(j3array[0]);
cj3array[0]=IKcos(j3array[0]);
if( j3array[0] > IKPI )
{
    j3array[0]-=IK2PI;
}
else if( j3array[0] < -IKPI )
{    j3array[0]+=IK2PI;
}
j3valid[0] = true;
for(int ij3 = 0; ij3 < 1; ++ij3)
{
if( !j3valid[ij3] )
{
    continue;
}
_ij3[0] = ij3; _ij3[1] = -1;
for(int iij3 = ij3+1; iij3 < 1; ++iij3)
{
if( j3valid[iij3] && IKabs(cj3array[ij3]-cj3array[iij3]) < IKFAST_SOLUTION_THRESH && IKabs(sj3array[ij3]-sj3array[iij3]) < IKFAST_SOLUTION_THRESH )
{
    j3valid[iij3]=false; _ij3[1] = iij3; break; 
}
}
j3 = j3array[ij3]; cj3 = cj3array[ij3]; sj3 = sj3array[ij3];
{
IkReal evalcond[6];
IkReal x12151=IKcos(j3);
IkReal x12152=IKsin(j3);
IkReal x12153=((sj0)*(sj5));
IkReal x12154=((r00)*(sj6));
IkReal x12155=((IkReal(1.00000000000000))*(cj4));
IkReal x12156=((cj6)*(r01));
IkReal x12157=((cj0)*(cj5));
IkReal x12158=((cj5)*(sj0));
IkReal x12159=((cj6)*(r11));
IkReal x12160=((cj6)*(sj4));
IkReal x12161=((IkReal(1.00000000000000))*(cj1));
IkReal x12162=((cj4)*(cj5));
IkReal x12163=((cj6)*(r21));
IkReal x12164=((r20)*(sj6));
IkReal x12165=((r10)*(sj6));
IkReal x12166=((cj0)*(sj5));
IkReal x12167=((IkReal(1.00000000000000))*(cj0));
IkReal x12168=((IkReal(1.00000000000000))*(x12166));
IkReal x12169=((IkReal(1.00000000000000))*(x12152));
IkReal x12170=((cj0)*(sj4)*(sj6));
IkReal x12171=((cj2)*(x12152));
IkReal x12172=((sj0)*(sj4)*(sj6));
IkReal x12173=((IkReal(1.00000000000000))*(sj1)*(x12151));
evalcond[0]=((((IkReal(-1.00000000000000))*(x12161)*(x12171)))+(((sj5)*(x12163)))+(((IkReal(-1.00000000000000))*(x12173)))+(((IkReal(-1.00000000000000))*(cj5)*(r22)))+(((sj5)*(x12164))));
evalcond[1]=((((IkReal(-1.00000000000000))*(r21)*(sj4)*(sj6)))+(((x12162)*(x12163)))+(((IkReal(-1.00000000000000))*(sj1)*(x12169)))+(((cj4)*(r22)*(sj5)))+(((x12162)*(x12164)))+(((r20)*(x12160)))+(((cj1)*(cj2)*(x12151))));
evalcond[2]=((((IkReal(-1.00000000000000))*(x12165)*(x12168)))+(((x12153)*(x12154)))+(((IkReal(-1.00000000000000))*(sj2)*(x12169)))+(((IkReal(-1.00000000000000))*(r02)*(x12158)))+(((x12153)*(x12156)))+(((IkReal(-1.00000000000000))*(x12159)*(x12168)))+(((r12)*(x12157))));
evalcond[3]=((((IkReal(-1.00000000000000))*(x12153)*(x12165)))+(((IkReal(-1.00000000000000))*(x12151)*(x12161)))+(((r12)*(x12158)))+(((IkReal(-1.00000000000000))*(x12156)*(x12168)))+(((IkReal(-1.00000000000000))*(x12153)*(x12159)))+(((sj1)*(x12171)))+(((IkReal(-1.00000000000000))*(x12154)*(x12168)))+(((r02)*(x12157))));
evalcond[4]=((((IkReal(-1.00000000000000))*(r01)*(x12172)))+(((sj2)*(x12151)))+(((IkReal(-1.00000000000000))*(r12)*(x12155)*(x12166)))+(((cj4)*(r02)*(x12153)))+(((r00)*(sj0)*(x12160)))+(((IkReal(-1.00000000000000))*(r10)*(x12160)*(x12167)))+(((r11)*(x12170)))+(((cj4)*(x12154)*(x12158)))+(((IkReal(-1.00000000000000))*(x12155)*(x12157)*(x12165)))+(((cj4)*(x12156)*(x12158)))+(((IkReal(-1.00000000000000))*(x12155)*(x12157)*(x12159))));
evalcond[5]=((((IkReal(-1.00000000000000))*(x12154)*(x12155)*(x12157)))+(((IkReal(-1.00000000000000))*(r10)*(sj0)*(x12160)))+(((IkReal(-1.00000000000000))*(x12155)*(x12158)*(x12165)))+(((IkReal(-1.00000000000000))*(r12)*(x12153)*(x12155)))+(((IkReal(-1.00000000000000))*(r00)*(x12160)*(x12167)))+(((r11)*(x12172)))+(((IkReal(-1.00000000000000))*(x12155)*(x12156)*(x12157)))+(((IkReal(-1.00000000000000))*(x12152)*(x12161)))+(((IkReal(-1.00000000000000))*(r02)*(x12155)*(x12166)))+(((IkReal(-1.00000000000000))*(cj2)*(x12173)))+(((r01)*(x12170)))+(((IkReal(-1.00000000000000))*(x12155)*(x12158)*(x12159))));
if( IKabs(evalcond[0]) > 0.000001  || IKabs(evalcond[1]) > 0.000001  || IKabs(evalcond[2]) > 0.000001  || IKabs(evalcond[3]) > 0.000001  || IKabs(evalcond[4]) > 0.000001  || IKabs(evalcond[5]) > 0.000001  )
{
continue;
}
}

{
std::vector<IkSingleDOFSolutionBase<IkReal> > vinfos(7);
vinfos[0].jointtype = 1;
vinfos[0].foffset = j0;
vinfos[0].indices[0] = _ij0[0];
vinfos[0].indices[1] = _ij0[1];
vinfos[0].maxsolutions = _nj0;
vinfos[1].jointtype = 1;
vinfos[1].foffset = j1;
vinfos[1].indices[0] = _ij1[0];
vinfos[1].indices[1] = _ij1[1];
vinfos[1].maxsolutions = _nj1;
vinfos[2].jointtype = 1;
vinfos[2].foffset = j2;
vinfos[2].indices[0] = _ij2[0];
vinfos[2].indices[1] = _ij2[1];
vinfos[2].maxsolutions = _nj2;
vinfos[3].jointtype = 1;
vinfos[3].foffset = j3;
vinfos[3].indices[0] = _ij3[0];
vinfos[3].indices[1] = _ij3[1];
vinfos[3].maxsolutions = _nj3;
vinfos[4].jointtype = 1;
vinfos[4].foffset = j4;
vinfos[4].indices[0] = _ij4[0];
vinfos[4].indices[1] = _ij4[1];
vinfos[4].maxsolutions = _nj4;
vinfos[5].jointtype = 1;
vinfos[5].foffset = j5;
vinfos[5].indices[0] = _ij5[0];
vinfos[5].indices[1] = _ij5[1];
vinfos[5].maxsolutions = _nj5;
vinfos[6].jointtype = 1;
vinfos[6].foffset = j6;
vinfos[6].indices[0] = _ij6[0];
vinfos[6].indices[1] = _ij6[1];
vinfos[6].maxsolutions = _nj6;
std::vector<int> vfree(0);
solutions.AddSolution(vinfos,vfree);
}
}
}

}

}
}
}

}

}

} else
{
{
IkReal j4array[1], cj4array[1], sj4array[1];
bool j4valid[1]={false};
_nj4 = 1;
IkReal x12174=((cj5)*(sj0));
IkReal x12175=((cj2)*(sj6));
IkReal x12176=((IkReal(1.00000000000000))*(cj0));
IkReal x12177=((cj2)*(cj6));
IkReal x12178=((cj1)*(cj6)*(sj2));
IkReal x12179=((r10)*(x12176));
IkReal x12180=((cj1)*(sj2)*(sj6));
IkReal x12181=((cj1)*(sj2)*(sj5));
if( IKabs(((gconst0)*(((((IkReal(-1.00000000000000))*(r21)*(x12175)))+(((IkReal(-1.00000000000000))*(r01)*(sj0)*(x12180)))+(((IkReal(-1.00000000000000))*(x12178)*(x12179)))+(((cj0)*(r11)*(x12180)))+(((r00)*(sj0)*(x12178)))+(((r20)*(x12177))))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(((gconst0)*(((((IkReal(-1.00000000000000))*(cj5)*(r11)*(x12176)*(x12178)))+(((cj2)*(r22)*(sj5)))+(((r01)*(x12174)*(x12178)))+(((IkReal(-1.00000000000000))*(cj5)*(x12179)*(x12180)))+(((IkReal(-1.00000000000000))*(r12)*(x12176)*(x12181)))+(((r02)*(sj0)*(x12181)))+(((cj5)*(r20)*(x12175)))+(((cj5)*(r21)*(x12177)))+(((r00)*(x12174)*(x12180))))))) < IKFAST_ATAN2_MAGTHRESH )
    continue;
j4array[0]=IKatan2(((gconst0)*(((((IkReal(-1.00000000000000))*(r21)*(x12175)))+(((IkReal(-1.00000000000000))*(r01)*(sj0)*(x12180)))+(((IkReal(-1.00000000000000))*(x12178)*(x12179)))+(((cj0)*(r11)*(x12180)))+(((r00)*(sj0)*(x12178)))+(((r20)*(x12177)))))), ((gconst0)*(((((IkReal(-1.00000000000000))*(cj5)*(r11)*(x12176)*(x12178)))+(((cj2)*(r22)*(sj5)))+(((r01)*(x12174)*(x12178)))+(((IkReal(-1.00000000000000))*(cj5)*(x12179)*(x12180)))+(((IkReal(-1.00000000000000))*(r12)*(x12176)*(x12181)))+(((r02)*(sj0)*(x12181)))+(((cj5)*(r20)*(x12175)))+(((cj5)*(r21)*(x12177)))+(((r00)*(x12174)*(x12180)))))));
sj4array[0]=IKsin(j4array[0]);
cj4array[0]=IKcos(j4array[0]);
if( j4array[0] > IKPI )
{
    j4array[0]-=IK2PI;
}
else if( j4array[0] < -IKPI )
{    j4array[0]+=IK2PI;
}
j4valid[0] = true;
for(int ij4 = 0; ij4 < 1; ++ij4)
{
if( !j4valid[ij4] )
{
    continue;
}
_ij4[0] = ij4; _ij4[1] = -1;
for(int iij4 = ij4+1; iij4 < 1; ++iij4)
{
if( j4valid[iij4] && IKabs(cj4array[ij4]-cj4array[iij4]) < IKFAST_SOLUTION_THRESH && IKabs(sj4array[ij4]-sj4array[iij4]) < IKFAST_SOLUTION_THRESH )
{
    j4valid[iij4]=false; _ij4[1] = iij4; break; 
}
}
j4 = j4array[ij4]; cj4 = cj4array[ij4]; sj4 = sj4array[ij4];
{
IkReal evalcond[3];
IkReal x12182=IKsin(j4);
IkReal x12183=IKcos(j4);
IkReal x12184=((r00)*(sj6));
IkReal x12185=((cj6)*(r01));
IkReal x12186=((IkReal(1.00000000000000))*(cj0));
IkReal x12187=((IkReal(1.00000000000000))*(sj0));
IkReal x12188=((r10)*(sj6));
IkReal x12189=((sj5)*(x12182));
IkReal x12190=((IkReal(1.00000000000000))*(cj6)*(r11));
IkReal x12191=((cj5)*(x12182));
IkReal x12192=((cj6)*(x12183));
IkReal x12193=((sj0)*(x12191));
IkReal x12194=((r01)*(sj6)*(x12183));
IkReal x12195=((r11)*(sj6)*(x12183));
evalcond[0]=((((IkReal(-1.00000000000000))*(r20)*(x12192)))+(((IkReal(-1.00000000000000))*(cj1)*(sj2)))+(((r22)*(x12189)))+(((r20)*(sj6)*(x12191)))+(((r21)*(sj6)*(x12183)))+(((cj6)*(r21)*(x12191))));
evalcond[1]=((((IkReal(-1.00000000000000))*(r12)*(x12186)*(x12189)))+(((x12184)*(x12193)))+(((IkReal(-1.00000000000000))*(x12186)*(x12188)*(x12191)))+(((x12185)*(x12193)))+(((sj0)*(x12194)))+(((IkReal(-1.00000000000000))*(cj6)*(r11)*(x12186)*(x12191)))+(cj2)+(((IkReal(-1.00000000000000))*(x12186)*(x12195)))+(((IkReal(-1.00000000000000))*(r00)*(x12187)*(x12192)))+(((r02)*(sj0)*(x12189)))+(((cj0)*(r10)*(x12192))));
evalcond[2]=((((IkReal(-1.00000000000000))*(r12)*(x12187)*(x12189)))+(((IkReal(-1.00000000000000))*(cj6)*(r11)*(x12187)*(x12191)))+(((IkReal(-1.00000000000000))*(x12187)*(x12195)))+(((r10)*(sj0)*(x12192)))+(((IkReal(-1.00000000000000))*(x12186)*(x12194)))+(((IkReal(-1.00000000000000))*(r02)*(x12186)*(x12189)))+(((sj1)*(sj2)))+(((cj0)*(r00)*(x12192)))+(((IkReal(-1.00000000000000))*(x12187)*(x12188)*(x12191)))+(((IkReal(-1.00000000000000))*(x12185)*(x12186)*(x12191)))+(((IkReal(-1.00000000000000))*(x12184)*(x12186)*(x12191))));
if( IKabs(evalcond[0]) > 0.000001  || IKabs(evalcond[1]) > 0.000001  || IKabs(evalcond[2]) > 0.000001  )
{
continue;
}
}

{
IkReal dummyeval[1];
IkReal gconst4;
gconst4=IKsign((((sj1)*(sj1))+((((cj1)*(cj1))*((cj2)*(cj2))))));
dummyeval[0]=(((sj1)*(sj1))+((((cj1)*(cj1))*((cj2)*(cj2)))));
if( IKabs(dummyeval[0]) < 0.0000010000000000  )
{
{
IkReal dummyeval[2];
IkReal x12196=(cj1)*(cj1);
IkReal x12197=(sj1)*(sj1);
dummyeval[0]=((((cj2)*(x12196)))+(((cj2)*(x12197))));
dummyeval[1]=((x12196)+(x12197));
if( IKabs(dummyeval[0]) < 0.0000010000000000  || IKabs(dummyeval[1]) < 0.0000010000000000  )
{
{
IkReal dummyeval[2];
dummyeval[0]=sj2;
dummyeval[1]=sj1;
if( IKabs(dummyeval[0]) < 0.0000010000000000  || IKabs(dummyeval[1]) < 0.0000010000000000  )
{
{
IkReal evalcond[9];
IkReal x12198=((cj5)*(sj4));
IkReal x12199=((IkReal(1.00000000000000))*(sj6));
IkReal x12200=((r10)*(sj0));
IkReal x12201=((sj4)*(sj5));
IkReal x12202=((cj4)*(cj5));
IkReal x12203=((IkReal(1.00000000000000))*(r02));
IkReal x12204=((IkReal(0.374290000000000))*(cj0));
IkReal x12205=((cj5)*(r12));
IkReal x12206=((cj6)*(sj5));
IkReal x12207=((cj0)*(r11));
IkReal x12208=((cj5)*(sj0));
IkReal x12209=((r20)*(sj6));
IkReal x12210=((IkReal(1.00000000000000))*(sj0));
IkReal x12211=((IkReal(1.00000000000000))*(cj6));
IkReal x12212=((IkReal(0.0100000000000000))*(cj5));
IkReal x12213=((IkReal(0.0100000000000000))*(sj5));
IkReal x12214=((sj5)*(sj6));
IkReal x12215=((cj0)*(r10));
IkReal x12216=((cj4)*(cj6));
IkReal x12217=((cj0)*(r01));
IkReal x12218=((cj0)*(r00));
IkReal x12219=((cj6)*(r21));
IkReal x12220=((IkReal(0.374290000000000))*(sj0));
IkReal x12221=((IkReal(0.374290000000000))*(sj5));
IkReal x12222=((cj6)*(r11));
IkReal x12223=((sj0)*(sj4));
IkReal x12224=((cj4)*(sj5));
IkReal x12225=((cj4)*(sj6));
IkReal x12226=((IkReal(1.00000000000000))*(cj0));
IkReal x12227=((r02)*(sj0));
IkReal x12228=((r00)*(sj0)*(sj6));
IkReal x12229=((cj6)*(r01)*(sj0));
IkReal x12230=((r00)*(x12216));
IkReal x12231=((r12)*(x12226));
evalcond[0]=((IkReal(-3.14159265358979))+(IKfmod(((IkReal(3.14159265358979))+(j2)), IkReal(6.28318530717959))));
evalcond[1]=((((r21)*(x12225)))+(((x12198)*(x12219)))+(((r22)*(x12201)))+(((IkReal(-1.00000000000000))*(cj4)*(r20)*(x12211)))+(((x12198)*(x12209))));
evalcond[2]=((((IkReal(0.364420000000000))*(sj1)))+(((IkReal(-0.374290000000000))*(cj5)*(r22)))+(((IkReal(-1.00000000000000))*(x12212)*(x12219)))+(((IkReal(-1.00000000000000))*(r22)*(x12213)))+(((IkReal(0.374290000000000))*(r21)*(x12206)))+(pz)+(((x12209)*(x12221)))+(((IkReal(0.0690000000000000))*(cj1)))+(((IkReal(-1.00000000000000))*(x12209)*(x12212))));
evalcond[3]=((((cj0)*(x12205)))+(((r01)*(sj0)*(x12206)))+(((IkReal(-1.00000000000000))*(sj5)*(x12199)*(x12215)))+(((IkReal(-1.00000000000000))*(x12206)*(x12207)))+(((r00)*(sj0)*(x12214)))+(((IkReal(-1.00000000000000))*(x12203)*(x12208))));
evalcond[4]=((IkReal(1.00000000000000))+(((IkReal(-1.00000000000000))*(cj4)*(x12199)*(x12207)))+(((IkReal(-1.00000000000000))*(x12201)*(x12231)))+(((x12198)*(x12228)))+(((IkReal(-1.00000000000000))*(x12198)*(x12207)*(x12211)))+(((x12198)*(x12229)))+(((r01)*(sj0)*(x12225)))+(((x12215)*(x12216)))+(((IkReal(-1.00000000000000))*(x12198)*(x12199)*(x12215)))+(((x12201)*(x12227)))+(((IkReal(-1.00000000000000))*(x12210)*(x12230))));
evalcond[5]=((((cj6)*(r00)*(x12223)))+(((x12202)*(x12228)))+(((IkReal(-1.00000000000000))*(x12199)*(x12202)*(x12215)))+(((IkReal(-1.00000000000000))*(r01)*(x12199)*(x12223)))+(((IkReal(-1.00000000000000))*(sj4)*(x12211)*(x12215)))+(((IkReal(-1.00000000000000))*(x12202)*(x12207)*(x12211)))+(((sj4)*(sj6)*(x12207)))+(((IkReal(-1.00000000000000))*(x12224)*(x12231)))+(((x12202)*(x12229)))+(((x12224)*(x12227))));
evalcond[6]=((((IkReal(-1.00000000000000))*(x12198)*(x12199)*(x12218)))+(((x12216)*(x12218)))+(((IkReal(-1.00000000000000))*(x12198)*(x12210)*(x12222)))+(((IkReal(-1.00000000000000))*(cj4)*(x12199)*(x12217)))+(((IkReal(-1.00000000000000))*(cj4)*(r11)*(sj0)*(x12199)))+(((x12200)*(x12216)))+(((IkReal(-1.00000000000000))*(x12198)*(x12199)*(x12200)))+(((IkReal(-1.00000000000000))*(x12198)*(x12211)*(x12217)))+(((IkReal(-1.00000000000000))*(cj0)*(x12201)*(x12203)))+(((IkReal(-1.00000000000000))*(r12)*(x12201)*(x12210))));
evalcond[7]=((((IkReal(-1.00000000000000))*(x12213)*(x12227)))+(((sj6)*(x12212)*(x12215)))+(((r00)*(x12214)*(x12220)))+(((IkReal(-1.00000000000000))*(r11)*(x12204)*(x12206)))+(((IkReal(-0.374290000000000))*(r02)*(x12208)))+(((x12204)*(x12205)))+(((IkReal(-0.0100000000000000))*(r00)*(sj6)*(x12208)))+(((cj0)*(r12)*(x12213)))+(((IkReal(-1.00000000000000))*(r10)*(x12204)*(x12214)))+(((cj6)*(x12207)*(x12212)))+(((IkReal(-1.00000000000000))*(py)*(x12226)))+(((px)*(sj0)))+(((IkReal(-0.0100000000000000))*(cj6)*(r01)*(x12208)))+(((r01)*(x12206)*(x12220))));
evalcond[8]=((IkReal(0.0690000000000000))+(((cj5)*(r02)*(x12204)))+(((cj0)*(r02)*(x12213)))+(((IkReal(-0.0690000000000000))*(sj1)))+(((IkReal(-1.00000000000000))*(r01)*(x12204)*(x12206)))+(((sj6)*(x12212)*(x12218)))+(((cj6)*(x12212)*(x12217)))+(((IkReal(-1.00000000000000))*(r00)*(x12204)*(x12214)))+(((IkReal(0.0100000000000000))*(x12208)*(x12222)))+(((x12205)*(x12220)))+(((IkReal(-1.00000000000000))*(px)*(x12226)))+(((r12)*(sj0)*(x12213)))+(((sj6)*(x12200)*(x12212)))+(((IkReal(-0.374290000000000))*(x12200)*(x12214)))+(((IkReal(0.364420000000000))*(cj1)))+(((IkReal(-1.00000000000000))*(r11)*(x12206)*(x12220)))+(((IkReal(-1.00000000000000))*(py)*(x12210))));
if( IKabs(evalcond[0]) < 0.0000010000000000  && IKabs(evalcond[1]) < 0.0000010000000000  && IKabs(evalcond[2]) < 0.0000010000000000  && IKabs(evalcond[3]) < 0.0000010000000000  && IKabs(evalcond[4]) < 0.0000010000000000  && IKabs(evalcond[5]) < 0.0000010000000000  && IKabs(evalcond[6]) < 0.0000010000000000  && IKabs(evalcond[7]) < 0.0000010000000000  && IKabs(evalcond[8]) < 0.0000010000000000  )
{
{
IkReal dummyeval[1];
IkReal gconst5;
gconst5=IKsign((((cj1)*(cj1))+((sj1)*(sj1))));
dummyeval[0]=(((cj1)*(cj1))+((sj1)*(sj1)));
if( IKabs(dummyeval[0]) < 0.0000010000000000  )
{
{
IkReal dummyeval[1];
IkReal gconst6;
gconst6=IKsign((((cj1)*(cj1))+((sj1)*(sj1))));
dummyeval[0]=(((cj1)*(cj1))+((sj1)*(sj1)));
if( IKabs(dummyeval[0]) < 0.0000010000000000  )
{
continue;

} else
{
{
IkReal j3array[1], cj3array[1], sj3array[1];
bool j3valid[1]={false};
_nj3 = 1;
IkReal x12232=((sj5)*(sj6));
IkReal x12233=((IkReal(1.00000000000000))*(sj0));
IkReal x12234=((cj5)*(r12));
IkReal x12235=((cj0)*(r00));
IkReal x12236=((cj0)*(cj1));
IkReal x12237=((cj6)*(sj5));
IkReal x12238=((cj5)*(r02));
IkReal x12239=((IkReal(1.00000000000000))*(cj1));
IkReal x12240=((sj0)*(sj1));
IkReal x12241=((cj0)*(sj1));
IkReal x12242=((cj5)*(r22));
if( IKabs(((gconst6)*(((((r01)*(x12237)*(x12241)))+(((cj1)*(r20)*(x12232)))+(((r11)*(x12237)*(x12240)))+(((r10)*(x12232)*(x12240)))+(((IkReal(-1.00000000000000))*(x12239)*(x12242)))+(((IkReal(-1.00000000000000))*(x12238)*(x12241)))+(((IkReal(-1.00000000000000))*(sj1)*(x12233)*(x12234)))+(((sj1)*(x12232)*(x12235)))+(((cj1)*(r21)*(x12237))))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(((gconst6)*(((((IkReal(-1.00000000000000))*(cj1)*(r10)*(x12232)*(x12233)))+(((IkReal(-1.00000000000000))*(x12232)*(x12235)*(x12239)))+(((x12236)*(x12238)))+(((IkReal(-1.00000000000000))*(r01)*(x12236)*(x12237)))+(((IkReal(-1.00000000000000))*(cj1)*(r11)*(x12233)*(x12237)))+(((r21)*(sj1)*(x12237)))+(((IkReal(-1.00000000000000))*(sj1)*(x12242)))+(((cj1)*(sj0)*(x12234)))+(((r20)*(sj1)*(x12232))))))) < IKFAST_ATAN2_MAGTHRESH )
    continue;
j3array[0]=IKatan2(((gconst6)*(((((r01)*(x12237)*(x12241)))+(((cj1)*(r20)*(x12232)))+(((r11)*(x12237)*(x12240)))+(((r10)*(x12232)*(x12240)))+(((IkReal(-1.00000000000000))*(x12239)*(x12242)))+(((IkReal(-1.00000000000000))*(x12238)*(x12241)))+(((IkReal(-1.00000000000000))*(sj1)*(x12233)*(x12234)))+(((sj1)*(x12232)*(x12235)))+(((cj1)*(r21)*(x12237)))))), ((gconst6)*(((((IkReal(-1.00000000000000))*(cj1)*(r10)*(x12232)*(x12233)))+(((IkReal(-1.00000000000000))*(x12232)*(x12235)*(x12239)))+(((x12236)*(x12238)))+(((IkReal(-1.00000000000000))*(r01)*(x12236)*(x12237)))+(((IkReal(-1.00000000000000))*(cj1)*(r11)*(x12233)*(x12237)))+(((r21)*(sj1)*(x12237)))+(((IkReal(-1.00000000000000))*(sj1)*(x12242)))+(((cj1)*(sj0)*(x12234)))+(((r20)*(sj1)*(x12232)))))));
sj3array[0]=IKsin(j3array[0]);
cj3array[0]=IKcos(j3array[0]);
if( j3array[0] > IKPI )
{
    j3array[0]-=IK2PI;
}
else if( j3array[0] < -IKPI )
{    j3array[0]+=IK2PI;
}
j3valid[0] = true;
for(int ij3 = 0; ij3 < 1; ++ij3)
{
if( !j3valid[ij3] )
{
    continue;
}
_ij3[0] = ij3; _ij3[1] = -1;
for(int iij3 = ij3+1; iij3 < 1; ++iij3)
{
if( j3valid[iij3] && IKabs(cj3array[ij3]-cj3array[iij3]) < IKFAST_SOLUTION_THRESH && IKabs(sj3array[ij3]-sj3array[iij3]) < IKFAST_SOLUTION_THRESH )
{
    j3valid[iij3]=false; _ij3[1] = iij3; break; 
}
}
j3 = j3array[ij3]; cj3 = cj3array[ij3]; sj3 = sj3array[ij3];
{
IkReal evalcond[4];
IkReal x12243=IKcos(j3);
IkReal x12244=IKsin(j3);
IkReal x12245=((IkReal(1.00000000000000))*(cj4));
IkReal x12246=((sj0)*(sj5));
IkReal x12247=((cj0)*(cj5));
IkReal x12248=((cj6)*(r01));
IkReal x12249=((r00)*(sj6));
IkReal x12250=((cj6)*(r11));
IkReal x12251=((cj5)*(sj0));
IkReal x12252=((cj6)*(sj4));
IkReal x12253=((sj4)*(sj6));
IkReal x12254=((cj4)*(cj5));
IkReal x12255=((cj6)*(r21));
IkReal x12256=((r20)*(sj6));
IkReal x12257=((r10)*(sj6));
IkReal x12258=((cj1)*(x12243));
IkReal x12259=((IkReal(1.00000000000000))*(cj0)*(sj5));
IkReal x12260=((IkReal(1.00000000000000))*(x12244));
IkReal x12261=((IkReal(1.00000000000000))*(sj1)*(x12243));
IkReal x12262=((cj1)*(x12260));
IkReal x12263=((x12261)+(x12262));
evalcond[0]=((((IkReal(-1.00000000000000))*(x12263)))+(((IkReal(-1.00000000000000))*(cj5)*(r22)))+(((sj5)*(x12255)))+(((sj5)*(x12256))));
evalcond[1]=((x12258)+(((x12254)*(x12255)))+(((x12254)*(x12256)))+(((cj4)*(r22)*(sj5)))+(((IkReal(-1.00000000000000))*(r21)*(x12253)))+(((IkReal(-1.00000000000000))*(sj1)*(x12260)))+(((r20)*(x12252))));
evalcond[2]=((((IkReal(-1.00000000000000))*(x12249)*(x12259)))+(((r02)*(x12247)))+(((sj1)*(x12244)))+(((IkReal(-1.00000000000000))*(x12248)*(x12259)))+(((IkReal(-1.00000000000000))*(x12258)))+(((IkReal(-1.00000000000000))*(x12246)*(x12250)))+(((r12)*(x12251)))+(((IkReal(-1.00000000000000))*(x12246)*(x12257))));
evalcond[3]=((((IkReal(-1.00000000000000))*(r12)*(x12245)*(x12246)))+(((IkReal(-1.00000000000000))*(r10)*(sj0)*(x12252)))+(((cj0)*(r01)*(x12253)))+(((IkReal(-1.00000000000000))*(cj0)*(r00)*(x12252)))+(((IkReal(-1.00000000000000))*(x12245)*(x12247)*(x12249)))+(((IkReal(-1.00000000000000))*(x12245)*(x12250)*(x12251)))+(((IkReal(-1.00000000000000))*(x12263)))+(((IkReal(-1.00000000000000))*(cj0)*(r02)*(sj5)*(x12245)))+(((IkReal(-1.00000000000000))*(x12245)*(x12247)*(x12248)))+(((r11)*(sj0)*(x12253)))+(((IkReal(-1.00000000000000))*(x12245)*(x12251)*(x12257))));
if( IKabs(evalcond[0]) > 0.000001  || IKabs(evalcond[1]) > 0.000001  || IKabs(evalcond[2]) > 0.000001  || IKabs(evalcond[3]) > 0.000001  )
{
continue;
}
}

{
std::vector<IkSingleDOFSolutionBase<IkReal> > vinfos(7);
vinfos[0].jointtype = 1;
vinfos[0].foffset = j0;
vinfos[0].indices[0] = _ij0[0];
vinfos[0].indices[1] = _ij0[1];
vinfos[0].maxsolutions = _nj0;
vinfos[1].jointtype = 1;
vinfos[1].foffset = j1;
vinfos[1].indices[0] = _ij1[0];
vinfos[1].indices[1] = _ij1[1];
vinfos[1].maxsolutions = _nj1;
vinfos[2].jointtype = 1;
vinfos[2].foffset = j2;
vinfos[2].indices[0] = _ij2[0];
vinfos[2].indices[1] = _ij2[1];
vinfos[2].maxsolutions = _nj2;
vinfos[3].jointtype = 1;
vinfos[3].foffset = j3;
vinfos[3].indices[0] = _ij3[0];
vinfos[3].indices[1] = _ij3[1];
vinfos[3].maxsolutions = _nj3;
vinfos[4].jointtype = 1;
vinfos[4].foffset = j4;
vinfos[4].indices[0] = _ij4[0];
vinfos[4].indices[1] = _ij4[1];
vinfos[4].maxsolutions = _nj4;
vinfos[5].jointtype = 1;
vinfos[5].foffset = j5;
vinfos[5].indices[0] = _ij5[0];
vinfos[5].indices[1] = _ij5[1];
vinfos[5].maxsolutions = _nj5;
vinfos[6].jointtype = 1;
vinfos[6].foffset = j6;
vinfos[6].indices[0] = _ij6[0];
vinfos[6].indices[1] = _ij6[1];
vinfos[6].maxsolutions = _nj6;
std::vector<int> vfree(0);
solutions.AddSolution(vinfos,vfree);
}
}
}

}

}

} else
{
{
IkReal j3array[1], cj3array[1], sj3array[1];
bool j3valid[1]={false};
_nj3 = 1;
IkReal x12264=((sj1)*(sj5));
IkReal x12265=((r20)*(sj6));
IkReal x12266=((cj4)*(r22));
IkReal x12267=((IkReal(1.00000000000000))*(cj1));
IkReal x12268=((cj5)*(sj1));
IkReal x12269=((cj6)*(r21));
IkReal x12270=((cj1)*(sj5));
IkReal x12271=((cj4)*(cj5));
IkReal x12272=((cj6)*(r20)*(sj4));
IkReal x12273=((r21)*(sj4)*(sj6));
if( IKabs(((gconst5)*(((((cj4)*(x12265)*(x12268)))+(((IkReal(-1.00000000000000))*(cj5)*(r22)*(x12267)))+(((sj1)*(x12272)))+(((IkReal(-1.00000000000000))*(sj1)*(x12273)))+(((x12264)*(x12266)))+(((cj4)*(x12268)*(x12269)))+(((x12269)*(x12270)))+(((x12265)*(x12270))))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(((gconst5)*(((((IkReal(-1.00000000000000))*(r22)*(x12268)))+(((x12264)*(x12269)))+(((IkReal(-1.00000000000000))*(x12267)*(x12272)))+(((cj1)*(x12273)))+(((IkReal(-1.00000000000000))*(x12267)*(x12269)*(x12271)))+(((IkReal(-1.00000000000000))*(x12265)*(x12267)*(x12271)))+(((x12264)*(x12265)))+(((IkReal(-1.00000000000000))*(sj5)*(x12266)*(x12267))))))) < IKFAST_ATAN2_MAGTHRESH )
    continue;
j3array[0]=IKatan2(((gconst5)*(((((cj4)*(x12265)*(x12268)))+(((IkReal(-1.00000000000000))*(cj5)*(r22)*(x12267)))+(((sj1)*(x12272)))+(((IkReal(-1.00000000000000))*(sj1)*(x12273)))+(((x12264)*(x12266)))+(((cj4)*(x12268)*(x12269)))+(((x12269)*(x12270)))+(((x12265)*(x12270)))))), ((gconst5)*(((((IkReal(-1.00000000000000))*(r22)*(x12268)))+(((x12264)*(x12269)))+(((IkReal(-1.00000000000000))*(x12267)*(x12272)))+(((cj1)*(x12273)))+(((IkReal(-1.00000000000000))*(x12267)*(x12269)*(x12271)))+(((IkReal(-1.00000000000000))*(x12265)*(x12267)*(x12271)))+(((x12264)*(x12265)))+(((IkReal(-1.00000000000000))*(sj5)*(x12266)*(x12267)))))));
sj3array[0]=IKsin(j3array[0]);
cj3array[0]=IKcos(j3array[0]);
if( j3array[0] > IKPI )
{
    j3array[0]-=IK2PI;
}
else if( j3array[0] < -IKPI )
{    j3array[0]+=IK2PI;
}
j3valid[0] = true;
for(int ij3 = 0; ij3 < 1; ++ij3)
{
if( !j3valid[ij3] )
{
    continue;
}
_ij3[0] = ij3; _ij3[1] = -1;
for(int iij3 = ij3+1; iij3 < 1; ++iij3)
{
if( j3valid[iij3] && IKabs(cj3array[ij3]-cj3array[iij3]) < IKFAST_SOLUTION_THRESH && IKabs(sj3array[ij3]-sj3array[iij3]) < IKFAST_SOLUTION_THRESH )
{
    j3valid[iij3]=false; _ij3[1] = iij3; break; 
}
}
j3 = j3array[ij3]; cj3 = cj3array[ij3]; sj3 = sj3array[ij3];
{
IkReal evalcond[4];
IkReal x12274=IKcos(j3);
IkReal x12275=IKsin(j3);
IkReal x12276=((IkReal(1.00000000000000))*(cj4));
IkReal x12277=((sj0)*(sj5));
IkReal x12278=((cj0)*(cj5));
IkReal x12279=((cj6)*(r01));
IkReal x12280=((r00)*(sj6));
IkReal x12281=((cj6)*(r11));
IkReal x12282=((cj5)*(sj0));
IkReal x12283=((cj6)*(sj4));
IkReal x12284=((sj4)*(sj6));
IkReal x12285=((cj4)*(cj5));
IkReal x12286=((cj6)*(r21));
IkReal x12287=((r20)*(sj6));
IkReal x12288=((r10)*(sj6));
IkReal x12289=((cj1)*(x12274));
IkReal x12290=((IkReal(1.00000000000000))*(cj0)*(sj5));
IkReal x12291=((IkReal(1.00000000000000))*(x12275));
IkReal x12292=((IkReal(1.00000000000000))*(sj1)*(x12274));
IkReal x12293=((cj1)*(x12291));
IkReal x12294=((x12293)+(x12292));
evalcond[0]=((((IkReal(-1.00000000000000))*(x12294)))+(((sj5)*(x12287)))+(((IkReal(-1.00000000000000))*(cj5)*(r22)))+(((sj5)*(x12286))));
evalcond[1]=((((IkReal(-1.00000000000000))*(r21)*(x12284)))+(((x12285)*(x12286)))+(((cj4)*(r22)*(sj5)))+(((r20)*(x12283)))+(x12289)+(((x12285)*(x12287)))+(((IkReal(-1.00000000000000))*(sj1)*(x12291))));
evalcond[2]=((((r12)*(x12282)))+(((IkReal(-1.00000000000000))*(x12279)*(x12290)))+(((IkReal(-1.00000000000000))*(x12289)))+(((r02)*(x12278)))+(((IkReal(-1.00000000000000))*(x12277)*(x12288)))+(((sj1)*(x12275)))+(((IkReal(-1.00000000000000))*(x12277)*(x12281)))+(((IkReal(-1.00000000000000))*(x12280)*(x12290))));
evalcond[3]=((((IkReal(-1.00000000000000))*(x12294)))+(((r11)*(sj0)*(x12284)))+(((IkReal(-1.00000000000000))*(r12)*(x12276)*(x12277)))+(((IkReal(-1.00000000000000))*(x12276)*(x12278)*(x12280)))+(((IkReal(-1.00000000000000))*(x12276)*(x12278)*(x12279)))+(((IkReal(-1.00000000000000))*(cj0)*(r00)*(x12283)))+(((IkReal(-1.00000000000000))*(r10)*(sj0)*(x12283)))+(((cj0)*(r01)*(x12284)))+(((IkReal(-1.00000000000000))*(cj0)*(r02)*(sj5)*(x12276)))+(((IkReal(-1.00000000000000))*(x12276)*(x12282)*(x12288)))+(((IkReal(-1.00000000000000))*(x12276)*(x12281)*(x12282))));
if( IKabs(evalcond[0]) > 0.000001  || IKabs(evalcond[1]) > 0.000001  || IKabs(evalcond[2]) > 0.000001  || IKabs(evalcond[3]) > 0.000001  )
{
continue;
}
}

{
std::vector<IkSingleDOFSolutionBase<IkReal> > vinfos(7);
vinfos[0].jointtype = 1;
vinfos[0].foffset = j0;
vinfos[0].indices[0] = _ij0[0];
vinfos[0].indices[1] = _ij0[1];
vinfos[0].maxsolutions = _nj0;
vinfos[1].jointtype = 1;
vinfos[1].foffset = j1;
vinfos[1].indices[0] = _ij1[0];
vinfos[1].indices[1] = _ij1[1];
vinfos[1].maxsolutions = _nj1;
vinfos[2].jointtype = 1;
vinfos[2].foffset = j2;
vinfos[2].indices[0] = _ij2[0];
vinfos[2].indices[1] = _ij2[1];
vinfos[2].maxsolutions = _nj2;
vinfos[3].jointtype = 1;
vinfos[3].foffset = j3;
vinfos[3].indices[0] = _ij3[0];
vinfos[3].indices[1] = _ij3[1];
vinfos[3].maxsolutions = _nj3;
vinfos[4].jointtype = 1;
vinfos[4].foffset = j4;
vinfos[4].indices[0] = _ij4[0];
vinfos[4].indices[1] = _ij4[1];
vinfos[4].maxsolutions = _nj4;
vinfos[5].jointtype = 1;
vinfos[5].foffset = j5;
vinfos[5].indices[0] = _ij5[0];
vinfos[5].indices[1] = _ij5[1];
vinfos[5].maxsolutions = _nj5;
vinfos[6].jointtype = 1;
vinfos[6].foffset = j6;
vinfos[6].indices[0] = _ij6[0];
vinfos[6].indices[1] = _ij6[1];
vinfos[6].maxsolutions = _nj6;
std::vector<int> vfree(0);
solutions.AddSolution(vinfos,vfree);
}
}
}

}

}

} else
{
IkReal x12295=((cj5)*(sj4));
IkReal x12296=((IkReal(1.00000000000000))*(sj6));
IkReal x12297=((r10)*(sj0));
IkReal x12298=((sj4)*(sj5));
IkReal x12299=((cj4)*(cj5));
IkReal x12300=((IkReal(1.00000000000000))*(r02));
IkReal x12301=((IkReal(0.374290000000000))*(cj0));
IkReal x12302=((cj5)*(r12));
IkReal x12303=((cj6)*(sj5));
IkReal x12304=((cj0)*(r11));
IkReal x12305=((cj5)*(sj0));
IkReal x12306=((r20)*(sj6));
IkReal x12307=((IkReal(1.00000000000000))*(sj0));
IkReal x12308=((IkReal(1.00000000000000))*(cj6));
IkReal x12309=((IkReal(0.0100000000000000))*(cj5));
IkReal x12310=((IkReal(0.0100000000000000))*(sj5));
IkReal x12311=((sj5)*(sj6));
IkReal x12312=((cj0)*(r10));
IkReal x12313=((cj4)*(cj6));
IkReal x12314=((cj0)*(r01));
IkReal x12315=((cj0)*(r00));
IkReal x12316=((cj6)*(r21));
IkReal x12317=((IkReal(0.374290000000000))*(sj0));
IkReal x12318=((IkReal(0.374290000000000))*(sj5));
IkReal x12319=((cj6)*(r11));
IkReal x12320=((sj0)*(sj4));
IkReal x12321=((cj4)*(sj5));
IkReal x12322=((cj4)*(sj6));
IkReal x12323=((IkReal(1.00000000000000))*(cj0));
IkReal x12324=((r02)*(sj0));
IkReal x12325=((r00)*(sj0)*(sj6));
IkReal x12326=((cj6)*(r01)*(sj0));
IkReal x12327=((r00)*(x12313));
IkReal x12328=((r12)*(x12323));
evalcond[0]=((IkReal(-3.14159265358979))+(IKfmod(j2, IkReal(6.28318530717959))));
evalcond[1]=((((r22)*(x12298)))+(((x12295)*(x12306)))+(((IkReal(-1.00000000000000))*(cj4)*(r20)*(x12308)))+(((x12295)*(x12316)))+(((r21)*(x12322))));
evalcond[2]=((((x12306)*(x12318)))+(((IkReal(-1.00000000000000))*(r22)*(x12310)))+(((IkReal(0.364420000000000))*(sj1)))+(((IkReal(-0.0690000000000000))*(cj1)))+(((IkReal(-0.374290000000000))*(cj5)*(r22)))+(pz)+(((IkReal(-1.00000000000000))*(x12306)*(x12309)))+(((IkReal(0.374290000000000))*(r21)*(x12303)))+(((IkReal(-1.00000000000000))*(x12309)*(x12316))));
evalcond[3]=((((IkReal(-1.00000000000000))*(sj5)*(x12296)*(x12312)))+(((r01)*(sj0)*(x12303)))+(((IkReal(-1.00000000000000))*(x12303)*(x12304)))+(((cj0)*(x12302)))+(((r00)*(sj0)*(x12311)))+(((IkReal(-1.00000000000000))*(x12300)*(x12305))));
evalcond[4]=((IkReal(-1.00000000000000))+(((r01)*(sj0)*(x12322)))+(((IkReal(-1.00000000000000))*(x12295)*(x12304)*(x12308)))+(((IkReal(-1.00000000000000))*(x12298)*(x12328)))+(((IkReal(-1.00000000000000))*(x12295)*(x12296)*(x12312)))+(((IkReal(-1.00000000000000))*(cj4)*(x12296)*(x12304)))+(((x12298)*(x12324)))+(((x12312)*(x12313)))+(((x12295)*(x12326)))+(((IkReal(-1.00000000000000))*(x12307)*(x12327)))+(((x12295)*(x12325))));
evalcond[5]=((((IkReal(-1.00000000000000))*(x12296)*(x12299)*(x12312)))+(((IkReal(-1.00000000000000))*(r01)*(x12296)*(x12320)))+(((x12321)*(x12324)))+(((x12299)*(x12325)))+(((IkReal(-1.00000000000000))*(sj4)*(x12308)*(x12312)))+(((x12299)*(x12326)))+(((sj4)*(sj6)*(x12304)))+(((cj6)*(r00)*(x12320)))+(((IkReal(-1.00000000000000))*(x12321)*(x12328)))+(((IkReal(-1.00000000000000))*(x12299)*(x12304)*(x12308))));
evalcond[6]=((((IkReal(-1.00000000000000))*(cj4)*(r11)*(sj0)*(x12296)))+(((IkReal(-1.00000000000000))*(x12295)*(x12296)*(x12297)))+(((IkReal(-1.00000000000000))*(x12295)*(x12308)*(x12314)))+(((x12313)*(x12315)))+(((IkReal(-1.00000000000000))*(x12295)*(x12307)*(x12319)))+(((x12297)*(x12313)))+(((IkReal(-1.00000000000000))*(r12)*(x12298)*(x12307)))+(((IkReal(-1.00000000000000))*(x12295)*(x12296)*(x12315)))+(((IkReal(-1.00000000000000))*(cj4)*(x12296)*(x12314)))+(((IkReal(-1.00000000000000))*(cj0)*(x12298)*(x12300))));
evalcond[7]=((((IkReal(-0.0100000000000000))*(r00)*(sj6)*(x12305)))+(((sj6)*(x12309)*(x12312)))+(((r01)*(x12303)*(x12317)))+(((cj6)*(x12304)*(x12309)))+(((x12301)*(x12302)))+(((IkReal(-1.00000000000000))*(r11)*(x12301)*(x12303)))+(((r00)*(x12311)*(x12317)))+(((IkReal(-0.0100000000000000))*(cj6)*(r01)*(x12305)))+(((IkReal(-1.00000000000000))*(x12310)*(x12324)))+(((IkReal(-1.00000000000000))*(r10)*(x12301)*(x12311)))+(((IkReal(-1.00000000000000))*(py)*(x12323)))+(((cj0)*(r12)*(x12310)))+(((px)*(sj0)))+(((IkReal(-0.374290000000000))*(r02)*(x12305))));
evalcond[8]=((IkReal(0.0690000000000000))+(((IkReal(-1.00000000000000))*(px)*(x12323)))+(((cj0)*(r02)*(x12310)))+(((cj5)*(r02)*(x12301)))+(((IkReal(0.0690000000000000))*(sj1)))+(((x12302)*(x12317)))+(((sj6)*(x12309)*(x12315)))+(((r12)*(sj0)*(x12310)))+(((cj6)*(x12309)*(x12314)))+(((IkReal(-1.00000000000000))*(r00)*(x12301)*(x12311)))+(((IkReal(-0.374290000000000))*(x12297)*(x12311)))+(((IkReal(-1.00000000000000))*(py)*(x12307)))+(((IkReal(0.0100000000000000))*(x12305)*(x12319)))+(((IkReal(0.364420000000000))*(cj1)))+(((IkReal(-1.00000000000000))*(r11)*(x12303)*(x12317)))+(((IkReal(-1.00000000000000))*(r01)*(x12301)*(x12303)))+(((sj6)*(x12297)*(x12309))));
if( IKabs(evalcond[0]) < 0.0000010000000000  && IKabs(evalcond[1]) < 0.0000010000000000  && IKabs(evalcond[2]) < 0.0000010000000000  && IKabs(evalcond[3]) < 0.0000010000000000  && IKabs(evalcond[4]) < 0.0000010000000000  && IKabs(evalcond[5]) < 0.0000010000000000  && IKabs(evalcond[6]) < 0.0000010000000000  && IKabs(evalcond[7]) < 0.0000010000000000  && IKabs(evalcond[8]) < 0.0000010000000000  )
{
{
IkReal dummyeval[1];
IkReal gconst7;
gconst7=IKsign((((cj1)*(cj1))+((sj1)*(sj1))));
dummyeval[0]=(((cj1)*(cj1))+((sj1)*(sj1)));
if( IKabs(dummyeval[0]) < 0.0000010000000000  )
{
{
IkReal dummyeval[1];
IkReal gconst8;
gconst8=IKsign((((cj1)*(cj1))+((sj1)*(sj1))));
dummyeval[0]=(((cj1)*(cj1))+((sj1)*(sj1)));
if( IKabs(dummyeval[0]) < 0.0000010000000000  )
{
continue;

} else
{
{
IkReal j3array[1], cj3array[1], sj3array[1];
bool j3valid[1]={false};
_nj3 = 1;
IkReal x12329=((IkReal(1.00000000000000))*(sj0));
IkReal x12330=((cj6)*(r21));
IkReal x12331=((cj0)*(r00));
IkReal x12332=((cj5)*(sj1));
IkReal x12333=((r12)*(sj0));
IkReal x12334=((cj1)*(cj5));
IkReal x12335=((cj0)*(r02));
IkReal x12336=((sj1)*(sj5));
IkReal x12337=((cj6)*(r11));
IkReal x12338=((cj1)*(sj5));
IkReal x12339=((sj6)*(x12336));
IkReal x12340=((IkReal(1.00000000000000))*(x12338));
IkReal x12341=((cj0)*(cj6)*(r01));
if( IKabs(((gconst8)*(((((x12332)*(x12335)))+(((IkReal(-1.00000000000000))*(r10)*(x12329)*(x12339)))+(((IkReal(-1.00000000000000))*(x12331)*(x12339)))+(((IkReal(-1.00000000000000))*(x12336)*(x12341)))+(((IkReal(-1.00000000000000))*(r20)*(sj6)*(x12340)))+(((IkReal(-1.00000000000000))*(x12329)*(x12336)*(x12337)))+(((r22)*(x12334)))+(((IkReal(-1.00000000000000))*(x12330)*(x12340)))+(((x12332)*(x12333))))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(((gconst8)*(((((x12333)*(x12334)))+(((IkReal(-1.00000000000000))*(r22)*(x12332)))+(((IkReal(-1.00000000000000))*(r10)*(sj6)*(x12329)*(x12338)))+(((IkReal(-1.00000000000000))*(sj6)*(x12331)*(x12340)))+(((x12330)*(x12336)))+(((r20)*(x12339)))+(((IkReal(-1.00000000000000))*(x12329)*(x12337)*(x12338)))+(((x12334)*(x12335)))+(((IkReal(-1.00000000000000))*(x12340)*(x12341))))))) < IKFAST_ATAN2_MAGTHRESH )
    continue;
j3array[0]=IKatan2(((gconst8)*(((((x12332)*(x12335)))+(((IkReal(-1.00000000000000))*(r10)*(x12329)*(x12339)))+(((IkReal(-1.00000000000000))*(x12331)*(x12339)))+(((IkReal(-1.00000000000000))*(x12336)*(x12341)))+(((IkReal(-1.00000000000000))*(r20)*(sj6)*(x12340)))+(((IkReal(-1.00000000000000))*(x12329)*(x12336)*(x12337)))+(((r22)*(x12334)))+(((IkReal(-1.00000000000000))*(x12330)*(x12340)))+(((x12332)*(x12333)))))), ((gconst8)*(((((x12333)*(x12334)))+(((IkReal(-1.00000000000000))*(r22)*(x12332)))+(((IkReal(-1.00000000000000))*(r10)*(sj6)*(x12329)*(x12338)))+(((IkReal(-1.00000000000000))*(sj6)*(x12331)*(x12340)))+(((x12330)*(x12336)))+(((r20)*(x12339)))+(((IkReal(-1.00000000000000))*(x12329)*(x12337)*(x12338)))+(((x12334)*(x12335)))+(((IkReal(-1.00000000000000))*(x12340)*(x12341)))))));
sj3array[0]=IKsin(j3array[0]);
cj3array[0]=IKcos(j3array[0]);
if( j3array[0] > IKPI )
{
    j3array[0]-=IK2PI;
}
else if( j3array[0] < -IKPI )
{    j3array[0]+=IK2PI;
}
j3valid[0] = true;
for(int ij3 = 0; ij3 < 1; ++ij3)
{
if( !j3valid[ij3] )
{
    continue;
}
_ij3[0] = ij3; _ij3[1] = -1;
for(int iij3 = ij3+1; iij3 < 1; ++iij3)
{
if( j3valid[iij3] && IKabs(cj3array[ij3]-cj3array[iij3]) < IKFAST_SOLUTION_THRESH && IKabs(sj3array[ij3]-sj3array[iij3]) < IKFAST_SOLUTION_THRESH )
{
    j3valid[iij3]=false; _ij3[1] = iij3; break; 
}
}
j3 = j3array[ij3]; cj3 = cj3array[ij3]; sj3 = sj3array[ij3];
{
IkReal evalcond[4];
IkReal x12342=IKsin(j3);
IkReal x12343=IKcos(j3);
IkReal x12344=((IkReal(1.00000000000000))*(cj4));
IkReal x12345=((sj0)*(sj5));
IkReal x12346=((cj0)*(cj5));
IkReal x12347=((cj6)*(r01));
IkReal x12348=((r00)*(sj6));
IkReal x12349=((cj6)*(r11));
IkReal x12350=((cj5)*(sj0));
IkReal x12351=((cj6)*(sj4));
IkReal x12352=((sj4)*(sj6));
IkReal x12353=((cj4)*(cj5));
IkReal x12354=((cj6)*(r21));
IkReal x12355=((r20)*(sj6));
IkReal x12356=((r10)*(sj6));
IkReal x12357=((cj1)*(x12342));
IkReal x12358=((IkReal(1.00000000000000))*(cj0)*(sj5));
IkReal x12359=((IkReal(1.00000000000000))*(x12343));
IkReal x12360=((IkReal(1.00000000000000))*(sj1)*(x12342));
IkReal x12361=((cj1)*(x12359));
IkReal x12362=((x12361)+(x12360));
evalcond[0]=((((sj5)*(x12355)))+(((sj5)*(x12354)))+(((IkReal(-1.00000000000000))*(cj5)*(r22)))+(((IkReal(-1.00000000000000))*(sj1)*(x12359)))+(x12357));
evalcond[1]=((((IkReal(-1.00000000000000))*(r21)*(x12352)))+(((cj4)*(r22)*(sj5)))+(((IkReal(-1.00000000000000))*(x12362)))+(((x12353)*(x12354)))+(((r20)*(x12351)))+(((x12353)*(x12355))));
evalcond[2]=((((r02)*(x12346)))+(((IkReal(-1.00000000000000))*(x12348)*(x12358)))+(((IkReal(-1.00000000000000))*(x12362)))+(((IkReal(-1.00000000000000))*(x12345)*(x12356)))+(((r12)*(x12350)))+(((IkReal(-1.00000000000000))*(x12347)*(x12358)))+(((IkReal(-1.00000000000000))*(x12345)*(x12349))));
evalcond[3]=((((IkReal(-1.00000000000000))*(r12)*(x12344)*(x12345)))+(((sj1)*(x12343)))+(((IkReal(-1.00000000000000))*(x12357)))+(((IkReal(-1.00000000000000))*(x12344)*(x12349)*(x12350)))+(((IkReal(-1.00000000000000))*(x12344)*(x12346)*(x12348)))+(((IkReal(-1.00000000000000))*(x12344)*(x12346)*(x12347)))+(((IkReal(-1.00000000000000))*(cj0)*(r02)*(sj5)*(x12344)))+(((IkReal(-1.00000000000000))*(cj0)*(r00)*(x12351)))+(((r11)*(sj0)*(x12352)))+(((cj0)*(r01)*(x12352)))+(((IkReal(-1.00000000000000))*(r10)*(sj0)*(x12351)))+(((IkReal(-1.00000000000000))*(x12344)*(x12350)*(x12356))));
if( IKabs(evalcond[0]) > 0.000001  || IKabs(evalcond[1]) > 0.000001  || IKabs(evalcond[2]) > 0.000001  || IKabs(evalcond[3]) > 0.000001  )
{
continue;
}
}

{
std::vector<IkSingleDOFSolutionBase<IkReal> > vinfos(7);
vinfos[0].jointtype = 1;
vinfos[0].foffset = j0;
vinfos[0].indices[0] = _ij0[0];
vinfos[0].indices[1] = _ij0[1];
vinfos[0].maxsolutions = _nj0;
vinfos[1].jointtype = 1;
vinfos[1].foffset = j1;
vinfos[1].indices[0] = _ij1[0];
vinfos[1].indices[1] = _ij1[1];
vinfos[1].maxsolutions = _nj1;
vinfos[2].jointtype = 1;
vinfos[2].foffset = j2;
vinfos[2].indices[0] = _ij2[0];
vinfos[2].indices[1] = _ij2[1];
vinfos[2].maxsolutions = _nj2;
vinfos[3].jointtype = 1;
vinfos[3].foffset = j3;
vinfos[3].indices[0] = _ij3[0];
vinfos[3].indices[1] = _ij3[1];
vinfos[3].maxsolutions = _nj3;
vinfos[4].jointtype = 1;
vinfos[4].foffset = j4;
vinfos[4].indices[0] = _ij4[0];
vinfos[4].indices[1] = _ij4[1];
vinfos[4].maxsolutions = _nj4;
vinfos[5].jointtype = 1;
vinfos[5].foffset = j5;
vinfos[5].indices[0] = _ij5[0];
vinfos[5].indices[1] = _ij5[1];
vinfos[5].maxsolutions = _nj5;
vinfos[6].jointtype = 1;
vinfos[6].foffset = j6;
vinfos[6].indices[0] = _ij6[0];
vinfos[6].indices[1] = _ij6[1];
vinfos[6].maxsolutions = _nj6;
std::vector<int> vfree(0);
solutions.AddSolution(vinfos,vfree);
}
}
}

}

}

} else
{
{
IkReal j3array[1], cj3array[1], sj3array[1];
bool j3valid[1]={false};
_nj3 = 1;
IkReal x12363=((sj1)*(sj6));
IkReal x12364=((r20)*(sj5));
IkReal x12365=((IkReal(1.00000000000000))*(r21));
IkReal x12366=((cj1)*(cj6));
IkReal x12367=((r20)*(sj4));
IkReal x12368=((cj6)*(sj1));
IkReal x12369=((cj4)*(cj5));
IkReal x12370=((cj1)*(sj6));
IkReal x12371=((cj5)*(r22));
IkReal x12372=((cj4)*(r22)*(sj5));
if( IKabs(((gconst7)*(((((cj1)*(x12371)))+(((IkReal(-1.00000000000000))*(sj5)*(x12365)*(x12366)))+(((x12367)*(x12368)))+(((r21)*(x12368)*(x12369)))+(((sj1)*(x12372)))+(((r20)*(x12363)*(x12369)))+(((IkReal(-1.00000000000000))*(x12364)*(x12370)))+(((IkReal(-1.00000000000000))*(sj4)*(x12363)*(x12365))))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(((gconst7)*(((((r20)*(x12369)*(x12370)))+(((r21)*(sj5)*(x12368)))+(((x12363)*(x12364)))+(((x12366)*(x12367)))+(((IkReal(-1.00000000000000))*(sj1)*(x12371)))+(((IkReal(-1.00000000000000))*(sj4)*(x12365)*(x12370)))+(((cj1)*(x12372)))+(((r21)*(x12366)*(x12369))))))) < IKFAST_ATAN2_MAGTHRESH )
    continue;
j3array[0]=IKatan2(((gconst7)*(((((cj1)*(x12371)))+(((IkReal(-1.00000000000000))*(sj5)*(x12365)*(x12366)))+(((x12367)*(x12368)))+(((r21)*(x12368)*(x12369)))+(((sj1)*(x12372)))+(((r20)*(x12363)*(x12369)))+(((IkReal(-1.00000000000000))*(x12364)*(x12370)))+(((IkReal(-1.00000000000000))*(sj4)*(x12363)*(x12365)))))), ((gconst7)*(((((r20)*(x12369)*(x12370)))+(((r21)*(sj5)*(x12368)))+(((x12363)*(x12364)))+(((x12366)*(x12367)))+(((IkReal(-1.00000000000000))*(sj1)*(x12371)))+(((IkReal(-1.00000000000000))*(sj4)*(x12365)*(x12370)))+(((cj1)*(x12372)))+(((r21)*(x12366)*(x12369)))))));
sj3array[0]=IKsin(j3array[0]);
cj3array[0]=IKcos(j3array[0]);
if( j3array[0] > IKPI )
{
    j3array[0]-=IK2PI;
}
else if( j3array[0] < -IKPI )
{    j3array[0]+=IK2PI;
}
j3valid[0] = true;
for(int ij3 = 0; ij3 < 1; ++ij3)
{
if( !j3valid[ij3] )
{
    continue;
}
_ij3[0] = ij3; _ij3[1] = -1;
for(int iij3 = ij3+1; iij3 < 1; ++iij3)
{
if( j3valid[iij3] && IKabs(cj3array[ij3]-cj3array[iij3]) < IKFAST_SOLUTION_THRESH && IKabs(sj3array[ij3]-sj3array[iij3]) < IKFAST_SOLUTION_THRESH )
{
    j3valid[iij3]=false; _ij3[1] = iij3; break; 
}
}
j3 = j3array[ij3]; cj3 = cj3array[ij3]; sj3 = sj3array[ij3];
{
IkReal evalcond[4];
IkReal x12373=IKsin(j3);
IkReal x12374=IKcos(j3);
IkReal x12375=((IkReal(1.00000000000000))*(cj4));
IkReal x12376=((sj0)*(sj5));
IkReal x12377=((cj0)*(cj5));
IkReal x12378=((cj6)*(r01));
IkReal x12379=((r00)*(sj6));
IkReal x12380=((cj6)*(r11));
IkReal x12381=((cj5)*(sj0));
IkReal x12382=((cj6)*(sj4));
IkReal x12383=((sj4)*(sj6));
IkReal x12384=((cj4)*(cj5));
IkReal x12385=((cj6)*(r21));
IkReal x12386=((r20)*(sj6));
IkReal x12387=((r10)*(sj6));
IkReal x12388=((cj1)*(x12373));
IkReal x12389=((IkReal(1.00000000000000))*(cj0)*(sj5));
IkReal x12390=((IkReal(1.00000000000000))*(x12374));
IkReal x12391=((IkReal(1.00000000000000))*(sj1)*(x12373));
IkReal x12392=((cj1)*(x12390));
IkReal x12393=((x12391)+(x12392));
evalcond[0]=((((IkReal(-1.00000000000000))*(sj1)*(x12390)))+(((IkReal(-1.00000000000000))*(cj5)*(r22)))+(x12388)+(((sj5)*(x12386)))+(((sj5)*(x12385))));
evalcond[1]=((((IkReal(-1.00000000000000))*(r21)*(x12383)))+(((x12384)*(x12386)))+(((cj4)*(r22)*(sj5)))+(((r20)*(x12382)))+(((IkReal(-1.00000000000000))*(x12393)))+(((x12384)*(x12385))));
evalcond[2]=((((IkReal(-1.00000000000000))*(x12379)*(x12389)))+(((r12)*(x12381)))+(((IkReal(-1.00000000000000))*(x12376)*(x12380)))+(((r02)*(x12377)))+(((IkReal(-1.00000000000000))*(x12378)*(x12389)))+(((IkReal(-1.00000000000000))*(x12393)))+(((IkReal(-1.00000000000000))*(x12376)*(x12387))));
evalcond[3]=((((IkReal(-1.00000000000000))*(cj0)*(r02)*(sj5)*(x12375)))+(((IkReal(-1.00000000000000))*(x12375)*(x12377)*(x12378)))+(((IkReal(-1.00000000000000))*(x12388)))+(((cj0)*(r01)*(x12383)))+(((IkReal(-1.00000000000000))*(r10)*(sj0)*(x12382)))+(((IkReal(-1.00000000000000))*(x12375)*(x12377)*(x12379)))+(((IkReal(-1.00000000000000))*(x12375)*(x12381)*(x12387)))+(((r11)*(sj0)*(x12383)))+(((sj1)*(x12374)))+(((IkReal(-1.00000000000000))*(x12375)*(x12380)*(x12381)))+(((IkReal(-1.00000000000000))*(cj0)*(r00)*(x12382)))+(((IkReal(-1.00000000000000))*(r12)*(x12375)*(x12376))));
if( IKabs(evalcond[0]) > 0.000001  || IKabs(evalcond[1]) > 0.000001  || IKabs(evalcond[2]) > 0.000001  || IKabs(evalcond[3]) > 0.000001  )
{
continue;
}
}

{
std::vector<IkSingleDOFSolutionBase<IkReal> > vinfos(7);
vinfos[0].jointtype = 1;
vinfos[0].foffset = j0;
vinfos[0].indices[0] = _ij0[0];
vinfos[0].indices[1] = _ij0[1];
vinfos[0].maxsolutions = _nj0;
vinfos[1].jointtype = 1;
vinfos[1].foffset = j1;
vinfos[1].indices[0] = _ij1[0];
vinfos[1].indices[1] = _ij1[1];
vinfos[1].maxsolutions = _nj1;
vinfos[2].jointtype = 1;
vinfos[2].foffset = j2;
vinfos[2].indices[0] = _ij2[0];
vinfos[2].indices[1] = _ij2[1];
vinfos[2].maxsolutions = _nj2;
vinfos[3].jointtype = 1;
vinfos[3].foffset = j3;
vinfos[3].indices[0] = _ij3[0];
vinfos[3].indices[1] = _ij3[1];
vinfos[3].maxsolutions = _nj3;
vinfos[4].jointtype = 1;
vinfos[4].foffset = j4;
vinfos[4].indices[0] = _ij4[0];
vinfos[4].indices[1] = _ij4[1];
vinfos[4].maxsolutions = _nj4;
vinfos[5].jointtype = 1;
vinfos[5].foffset = j5;
vinfos[5].indices[0] = _ij5[0];
vinfos[5].indices[1] = _ij5[1];
vinfos[5].maxsolutions = _nj5;
vinfos[6].jointtype = 1;
vinfos[6].foffset = j6;
vinfos[6].indices[0] = _ij6[0];
vinfos[6].indices[1] = _ij6[1];
vinfos[6].maxsolutions = _nj6;
std::vector<int> vfree(0);
solutions.AddSolution(vinfos,vfree);
}
}
}

}

}

} else
{
IkReal x12394=((IkReal(1.00000000000000))*(cj0));
IkReal x12395=((cj4)*(sj6));
IkReal x12396=((sj0)*(sj4));
IkReal x12397=((cj5)*(sj6));
IkReal x12398=((sj4)*(sj5));
IkReal x12399=((r12)*(sj5));
IkReal x12400=((IkReal(0.374290000000000))*(cj5));
IkReal x12401=((r02)*(sj0));
IkReal x12402=((cj6)*(r21));
IkReal x12403=((IkReal(0.0100000000000000))*(cj5));
IkReal x12404=((IkReal(1.00000000000000))*(sj0));
IkReal x12405=((cj0)*(r10));
IkReal x12406=((cj4)*(cj6));
IkReal x12407=((r00)*(sj0));
IkReal x12408=((IkReal(0.374290000000000))*(sj5));
IkReal x12409=((cj0)*(r00));
IkReal x12410=((IkReal(0.0100000000000000))*(sj5));
IkReal x12411=((cj0)*(r02));
IkReal x12412=((cj5)*(sj4));
IkReal x12413=((cj6)*(r01));
IkReal x12414=((cj6)*(r11));
IkReal x12415=((r10)*(sj0));
IkReal x12416=((sj6)*(x12408));
IkReal x12417=((cj0)*(cj6)*(x12408));
evalcond[0]=((IkReal(-3.14159265358979))+(IKfmod(((IkReal(3.14159265358979))+(j1)), IkReal(6.28318530717959))));
evalcond[1]=((((IkReal(-1.00000000000000))*(sj2)))+(((x12402)*(x12412)))+(((r22)*(x12398)))+(((r20)*(sj4)*(x12397)))+(((r21)*(x12395)))+(((IkReal(-1.00000000000000))*(r20)*(x12406))));
evalcond[2]=((((x12402)*(x12408)))+(((IkReal(-1.00000000000000))*(r22)*(x12410)))+(((IkReal(-1.00000000000000))*(r22)*(x12400)))+(pz)+(((IkReal(-1.00000000000000))*(x12402)*(x12403)))+(((IkReal(0.0690000000000000))*(cj2)))+(((r20)*(x12416)))+(((IkReal(-0.0100000000000000))*(r20)*(x12397))));
evalcond[3]=((((IkReal(-1.00000000000000))*(r10)*(sj4)*(x12394)*(x12397)))+(((r02)*(sj5)*(x12396)))+(((IkReal(-1.00000000000000))*(r00)*(x12404)*(x12406)))+(cj2)+(((cj5)*(x12396)*(x12413)))+(((r01)*(sj0)*(x12395)))+(((IkReal(-1.00000000000000))*(r12)*(x12394)*(x12398)))+(((IkReal(-1.00000000000000))*(x12394)*(x12412)*(x12414)))+(((r00)*(x12396)*(x12397)))+(((x12405)*(x12406)))+(((IkReal(-1.00000000000000))*(r11)*(x12394)*(x12395))));
evalcond[4]=((((IkReal(-1.00000000000000))*(x12394)*(x12412)*(x12413)))+(((IkReal(-1.00000000000000))*(x12396)*(x12399)))+(((IkReal(-1.00000000000000))*(r01)*(x12394)*(x12395)))+(((IkReal(-1.00000000000000))*(r02)*(x12394)*(x12398)))+(((x12406)*(x12409)))+(((IkReal(-1.00000000000000))*(r11)*(x12395)*(x12404)))+(((IkReal(-1.00000000000000))*(cj5)*(x12396)*(x12414)))+(((x12406)*(x12415)))+(((IkReal(-1.00000000000000))*(r00)*(sj4)*(x12394)*(x12397)))+(((IkReal(-1.00000000000000))*(r10)*(x12396)*(x12397))));
evalcond[5]=((((IkReal(-1.00000000000000))*(py)*(x12394)))+(((IkReal(0.0100000000000000))*(x12397)*(x12405)))+(((IkReal(-0.0100000000000000))*(x12397)*(x12407)))+(((x12407)*(x12416)))+(((IkReal(-1.00000000000000))*(x12401)*(x12410)))+(((IkReal(0.0690000000000000))*(sj2)))+(((IkReal(-1.00000000000000))*(x12405)*(x12416)))+(((IkReal(-1.00000000000000))*(cj0)*(x12408)*(x12414)))+(((IkReal(-1.00000000000000))*(x12400)*(x12401)))+(((cj0)*(x12403)*(x12414)))+(((sj0)*(x12408)*(x12413)))+(((IkReal(0.0100000000000000))*(cj0)*(x12399)))+(((cj0)*(r12)*(x12400)))+(((px)*(sj0)))+(((IkReal(-1.00000000000000))*(sj0)*(x12403)*(x12413))));
evalcond[6]=((IkReal(0.433420000000000))+(((IkReal(-1.00000000000000))*(x12415)*(x12416)))+(((cj0)*(x12403)*(x12413)))+(((IkReal(-1.00000000000000))*(px)*(x12394)))+(((IkReal(0.0100000000000000))*(sj0)*(x12399)))+(((IkReal(-1.00000000000000))*(x12409)*(x12416)))+(((x12410)*(x12411)))+(((sj0)*(x12403)*(x12414)))+(((IkReal(0.0100000000000000))*(x12397)*(x12415)))+(((IkReal(0.0100000000000000))*(x12397)*(x12409)))+(((IkReal(-1.00000000000000))*(sj0)*(x12408)*(x12414)))+(((IkReal(-1.00000000000000))*(py)*(x12404)))+(((x12400)*(x12411)))+(((IkReal(-1.00000000000000))*(cj0)*(x12408)*(x12413)))+(((r12)*(sj0)*(x12400))));
if( IKabs(evalcond[0]) < 0.0000010000000000  && IKabs(evalcond[1]) < 0.0000010000000000  && IKabs(evalcond[2]) < 0.0000010000000000  && IKabs(evalcond[3]) < 0.0000010000000000  && IKabs(evalcond[4]) < 0.0000010000000000  && IKabs(evalcond[5]) < 0.0000010000000000  && IKabs(evalcond[6]) < 0.0000010000000000  )
{
{
IkReal dummyeval[1];
IkReal gconst9;
gconst9=IKsign(cj2);
dummyeval[0]=cj2;
if( IKabs(dummyeval[0]) < 0.0000010000000000  )
{
{
IkReal dummyeval[1];
dummyeval[0]=cj2;
if( IKabs(dummyeval[0]) < 0.0000010000000000  )
{
{
IkReal dummyeval[1];
dummyeval[0]=sj2;
if( IKabs(dummyeval[0]) < 0.0000010000000000  )
{
{
IkReal evalcond[9];
IkReal x12418=((cj5)*(sj4));
IkReal x12419=((IkReal(1.00000000000000))*(sj6));
IkReal x12420=((r10)*(sj0));
IkReal x12421=((sj4)*(sj5));
IkReal x12422=((cj5)*(cj6));
IkReal x12423=((r01)*(sj0));
IkReal x12424=((IkReal(1.00000000000000))*(r02));
IkReal x12425=((IkReal(0.374290000000000))*(cj0));
IkReal x12426=((cj5)*(r12));
IkReal x12427=((cj6)*(sj5));
IkReal x12428=((cj0)*(r11));
IkReal x12429=((cj5)*(sj0));
IkReal x12430=((r20)*(sj6));
IkReal x12431=((IkReal(1.00000000000000))*(sj0));
IkReal x12432=((cj4)*(cj5));
IkReal x12433=((IkReal(1.00000000000000))*(cj6));
IkReal x12434=((IkReal(0.0100000000000000))*(sj5));
IkReal x12435=((sj5)*(sj6));
IkReal x12436=((cj0)*(r10));
IkReal x12437=((cj4)*(cj6));
IkReal x12438=((cj0)*(r01));
IkReal x12439=((IkReal(1.00000000000000))*(cj4));
IkReal x12440=((cj0)*(r00));
IkReal x12441=((IkReal(0.374290000000000))*(sj0));
IkReal x12442=((cj0)*(r12));
IkReal x12443=((IkReal(0.374290000000000))*(sj5));
IkReal x12444=((cj4)*(sj6));
IkReal x12445=((IkReal(1.00000000000000))*(cj0));
IkReal x12446=((r02)*(sj0));
IkReal x12447=((IkReal(0.0100000000000000))*(cj5));
IkReal x12448=((r11)*(sj0));
IkReal x12449=((r00)*(sj0)*(sj6));
IkReal x12450=((r00)*(x12437));
IkReal x12451=((sj6)*(x12447));
evalcond[0]=((IkReal(-3.14159265358979))+(IKfmod(((IkReal(3.14159265358979))+(j2)), IkReal(6.28318530717959))));
evalcond[1]=((((x12418)*(x12430)))+(((cj6)*(r21)*(x12418)))+(((r21)*(x12444)))+(((r22)*(x12421)))+(((IkReal(-1.00000000000000))*(cj4)*(r20)*(x12433))));
evalcond[2]=((IkReal(0.0690000000000000))+(((IkReal(-1.00000000000000))*(x12430)*(x12447)))+(((IkReal(0.374290000000000))*(r21)*(x12427)))+(((IkReal(-0.0100000000000000))*(r21)*(x12422)))+(((IkReal(-0.374290000000000))*(cj5)*(r22)))+(pz)+(((x12430)*(x12443)))+(((IkReal(-1.00000000000000))*(r22)*(x12434))));
evalcond[3]=((((IkReal(-1.00000000000000))*(x12424)*(x12429)))+(((IkReal(-1.00000000000000))*(sj5)*(x12419)*(x12436)))+(((IkReal(-1.00000000000000))*(x12427)*(x12428)))+(((cj0)*(x12426)))+(((r00)*(sj0)*(x12435)))+(((x12423)*(x12427))));
evalcond[4]=((IkReal(1.00000000000000))+(((cj6)*(x12418)*(x12423)))+(((IkReal(-1.00000000000000))*(x12421)*(x12442)))+(((x12421)*(x12446)))+(((IkReal(-1.00000000000000))*(x12418)*(x12428)*(x12433)))+(((x12436)*(x12437)))+(((IkReal(-1.00000000000000))*(cj4)*(x12419)*(x12428)))+(((IkReal(-1.00000000000000))*(x12418)*(x12419)*(x12436)))+(((IkReal(-1.00000000000000))*(x12431)*(x12450)))+(((x12418)*(x12449)))+(((x12423)*(x12444))));
evalcond[5]=((((cj4)*(sj5)*(x12446)))+(((cj6)*(r00)*(sj0)*(sj4)))+(((cj4)*(x12422)*(x12423)))+(((r00)*(x12429)*(x12444)))+(((IkReal(-1.00000000000000))*(sj4)*(x12433)*(x12436)))+(((IkReal(-1.00000000000000))*(sj4)*(x12419)*(x12423)))+(((sj4)*(sj6)*(x12428)))+(((IkReal(-1.00000000000000))*(x12419)*(x12432)*(x12436)))+(((IkReal(-1.00000000000000))*(sj5)*(x12439)*(x12442)))+(((IkReal(-1.00000000000000))*(x12422)*(x12428)*(x12439))));
evalcond[6]=((((IkReal(-1.00000000000000))*(cj6)*(r11)*(x12418)*(x12431)))+(((IkReal(-1.00000000000000))*(x12418)*(x12419)*(x12420)))+(((IkReal(-1.00000000000000))*(x12418)*(x12419)*(x12440)))+(((IkReal(-1.00000000000000))*(r12)*(x12421)*(x12431)))+(((x12420)*(x12437)))+(((IkReal(-1.00000000000000))*(cj4)*(x12419)*(x12448)))+(((IkReal(-1.00000000000000))*(cj4)*(x12419)*(x12438)))+(((IkReal(-1.00000000000000))*(cj0)*(x12421)*(x12424)))+(((x12437)*(x12440)))+(((IkReal(-1.00000000000000))*(x12418)*(x12433)*(x12438))));
evalcond[7]=((((x12436)*(x12451)))+(((x12425)*(x12426)))+(((IkReal(-1.00000000000000))*(py)*(x12445)))+(((IkReal(-0.0100000000000000))*(r00)*(sj6)*(x12429)))+(((IkReal(-1.00000000000000))*(r10)*(x12425)*(x12435)))+(((IkReal(-0.0100000000000000))*(x12422)*(x12423)))+(((IkReal(-0.374290000000000))*(r02)*(x12429)))+(((IkReal(-1.00000000000000))*(x12434)*(x12446)))+(((IkReal(-1.00000000000000))*(r11)*(x12425)*(x12427)))+(((r00)*(x12435)*(x12441)))+(((x12434)*(x12442)))+(((IkReal(0.0100000000000000))*(x12422)*(x12428)))+(((px)*(sj0)))+(((IkReal(0.374290000000000))*(x12423)*(x12427))));
evalcond[8]=((IkReal(0.433420000000000))+(((x12440)*(x12451)))+(((IkReal(-1.00000000000000))*(px)*(x12445)))+(((cj0)*(r02)*(x12434)))+(((IkReal(-1.00000000000000))*(py)*(x12431)))+(((cj5)*(r02)*(x12425)))+(((x12420)*(x12451)))+(((IkReal(-1.00000000000000))*(r11)*(x12427)*(x12441)))+(((IkReal(0.0100000000000000))*(x12422)*(x12448)))+(((r12)*(sj0)*(x12434)))+(((IkReal(-1.00000000000000))*(r01)*(x12425)*(x12427)))+(((IkReal(-0.374290000000000))*(x12420)*(x12435)))+(((x12426)*(x12441)))+(((IkReal(-1.00000000000000))*(r00)*(x12425)*(x12435)))+(((IkReal(0.0100000000000000))*(x12422)*(x12438))));
if( IKabs(evalcond[0]) < 0.0000010000000000  && IKabs(evalcond[1]) < 0.0000010000000000  && IKabs(evalcond[2]) < 0.0000010000000000  && IKabs(evalcond[3]) < 0.0000010000000000  && IKabs(evalcond[4]) < 0.0000010000000000  && IKabs(evalcond[5]) < 0.0000010000000000  && IKabs(evalcond[6]) < 0.0000010000000000  && IKabs(evalcond[7]) < 0.0000010000000000  && IKabs(evalcond[8]) < 0.0000010000000000  )
{
{
IkReal j3array[1], cj3array[1], sj3array[1];
bool j3valid[1]={false};
_nj3 = 1;
IkReal x12452=((IkReal(1.00000000000000))*(cj4));
IkReal x12453=((cj6)*(r21));
IkReal x12454=((r20)*(sj6));
if( IKabs(((((IkReal(-1.00000000000000))*(cj5)*(r22)))+(((sj5)*(x12454)))+(((sj5)*(x12453))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(((((IkReal(-1.00000000000000))*(cj5)*(x12452)*(x12453)))+(((IkReal(-1.00000000000000))*(cj5)*(x12452)*(x12454)))+(((r21)*(sj4)*(sj6)))+(((IkReal(-1.00000000000000))*(r22)*(sj5)*(x12452)))+(((IkReal(-1.00000000000000))*(cj6)*(r20)*(sj4))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(IKsqr(((((IkReal(-1.00000000000000))*(cj5)*(r22)))+(((sj5)*(x12454)))+(((sj5)*(x12453)))))+IKsqr(((((IkReal(-1.00000000000000))*(cj5)*(x12452)*(x12453)))+(((IkReal(-1.00000000000000))*(cj5)*(x12452)*(x12454)))+(((r21)*(sj4)*(sj6)))+(((IkReal(-1.00000000000000))*(r22)*(sj5)*(x12452)))+(((IkReal(-1.00000000000000))*(cj6)*(r20)*(sj4)))))-1) <= IKFAST_SINCOS_THRESH )
    continue;
j3array[0]=IKatan2(((((IkReal(-1.00000000000000))*(cj5)*(r22)))+(((sj5)*(x12454)))+(((sj5)*(x12453)))), ((((IkReal(-1.00000000000000))*(cj5)*(x12452)*(x12453)))+(((IkReal(-1.00000000000000))*(cj5)*(x12452)*(x12454)))+(((r21)*(sj4)*(sj6)))+(((IkReal(-1.00000000000000))*(r22)*(sj5)*(x12452)))+(((IkReal(-1.00000000000000))*(cj6)*(r20)*(sj4)))));
sj3array[0]=IKsin(j3array[0]);
cj3array[0]=IKcos(j3array[0]);
if( j3array[0] > IKPI )
{
    j3array[0]-=IK2PI;
}
else if( j3array[0] < -IKPI )
{    j3array[0]+=IK2PI;
}
j3valid[0] = true;
for(int ij3 = 0; ij3 < 1; ++ij3)
{
if( !j3valid[ij3] )
{
    continue;
}
_ij3[0] = ij3; _ij3[1] = -1;
for(int iij3 = ij3+1; iij3 < 1; ++iij3)
{
if( j3valid[iij3] && IKabs(cj3array[ij3]-cj3array[iij3]) < IKFAST_SOLUTION_THRESH && IKabs(sj3array[ij3]-sj3array[iij3]) < IKFAST_SOLUTION_THRESH )
{
    j3valid[iij3]=false; _ij3[1] = iij3; break; 
}
}
j3 = j3array[ij3]; cj3 = cj3array[ij3]; sj3 = sj3array[ij3];
{
IkReal evalcond[4];
IkReal x12455=IKcos(j3);
IkReal x12456=((IkReal(1.00000000000000))*(cj4));
IkReal x12457=((sj0)*(sj5));
IkReal x12458=((cj0)*(cj5));
IkReal x12459=((cj6)*(r01));
IkReal x12460=((r00)*(sj6));
IkReal x12461=((cj6)*(r11));
IkReal x12462=((cj5)*(sj0));
IkReal x12463=((cj6)*(sj4));
IkReal x12464=((sj4)*(sj6));
IkReal x12465=((cj4)*(cj5));
IkReal x12466=((cj6)*(r21));
IkReal x12467=((r20)*(sj6));
IkReal x12468=((r10)*(sj6));
IkReal x12469=((IkReal(1.00000000000000))*(IKsin(j3)));
IkReal x12470=((IkReal(1.00000000000000))*(cj0)*(sj5));
evalcond[0]=((((sj5)*(x12466)))+(((IkReal(-1.00000000000000))*(cj5)*(r22)))+(((sj5)*(x12467)))+(((IkReal(-1.00000000000000))*(x12469))));
evalcond[1]=((((x12465)*(x12467)))+(((x12465)*(x12466)))+(((IkReal(-1.00000000000000))*(r21)*(x12464)))+(((r20)*(x12463)))+(((cj4)*(r22)*(sj5)))+(x12455));
evalcond[2]=((((IkReal(-1.00000000000000))*(x12457)*(x12468)))+(((IkReal(-1.00000000000000))*(x12459)*(x12470)))+(((IkReal(-1.00000000000000))*(x12457)*(x12461)))+(((IkReal(-1.00000000000000))*(x12460)*(x12470)))+(((r02)*(x12458)))+(((r12)*(x12462)))+(((IkReal(-1.00000000000000))*(x12455))));
evalcond[3]=((((IkReal(-1.00000000000000))*(x12456)*(x12461)*(x12462)))+(((IkReal(-1.00000000000000))*(r10)*(sj0)*(x12463)))+(((IkReal(-1.00000000000000))*(x12456)*(x12458)*(x12460)))+(((IkReal(-1.00000000000000))*(cj0)*(r00)*(x12463)))+(((IkReal(-1.00000000000000))*(r12)*(x12456)*(x12457)))+(((cj0)*(r01)*(x12464)))+(((IkReal(-1.00000000000000))*(x12469)))+(((IkReal(-1.00000000000000))*(x12456)*(x12462)*(x12468)))+(((IkReal(-1.00000000000000))*(cj0)*(r02)*(sj5)*(x12456)))+(((r11)*(sj0)*(x12464)))+(((IkReal(-1.00000000000000))*(x12456)*(x12458)*(x12459))));
if( IKabs(evalcond[0]) > 0.000001  || IKabs(evalcond[1]) > 0.000001  || IKabs(evalcond[2]) > 0.000001  || IKabs(evalcond[3]) > 0.000001  )
{
continue;
}
}

{
std::vector<IkSingleDOFSolutionBase<IkReal> > vinfos(7);
vinfos[0].jointtype = 1;
vinfos[0].foffset = j0;
vinfos[0].indices[0] = _ij0[0];
vinfos[0].indices[1] = _ij0[1];
vinfos[0].maxsolutions = _nj0;
vinfos[1].jointtype = 1;
vinfos[1].foffset = j1;
vinfos[1].indices[0] = _ij1[0];
vinfos[1].indices[1] = _ij1[1];
vinfos[1].maxsolutions = _nj1;
vinfos[2].jointtype = 1;
vinfos[2].foffset = j2;
vinfos[2].indices[0] = _ij2[0];
vinfos[2].indices[1] = _ij2[1];
vinfos[2].maxsolutions = _nj2;
vinfos[3].jointtype = 1;
vinfos[3].foffset = j3;
vinfos[3].indices[0] = _ij3[0];
vinfos[3].indices[1] = _ij3[1];
vinfos[3].maxsolutions = _nj3;
vinfos[4].jointtype = 1;
vinfos[4].foffset = j4;
vinfos[4].indices[0] = _ij4[0];
vinfos[4].indices[1] = _ij4[1];
vinfos[4].maxsolutions = _nj4;
vinfos[5].jointtype = 1;
vinfos[5].foffset = j5;
vinfos[5].indices[0] = _ij5[0];
vinfos[5].indices[1] = _ij5[1];
vinfos[5].maxsolutions = _nj5;
vinfos[6].jointtype = 1;
vinfos[6].foffset = j6;
vinfos[6].indices[0] = _ij6[0];
vinfos[6].indices[1] = _ij6[1];
vinfos[6].maxsolutions = _nj6;
std::vector<int> vfree(0);
solutions.AddSolution(vinfos,vfree);
}
}
}

} else
{
IkReal x12471=((cj5)*(sj4));
IkReal x12472=((IkReal(1.00000000000000))*(sj6));
IkReal x12473=((r10)*(sj0));
IkReal x12474=((sj4)*(sj5));
IkReal x12475=((cj5)*(cj6));
IkReal x12476=((r01)*(sj0));
IkReal x12477=((IkReal(1.00000000000000))*(r02));
IkReal x12478=((IkReal(0.374290000000000))*(cj0));
IkReal x12479=((cj5)*(r12));
IkReal x12480=((cj6)*(sj5));
IkReal x12481=((cj0)*(r11));
IkReal x12482=((cj5)*(sj0));
IkReal x12483=((r20)*(sj6));
IkReal x12484=((IkReal(1.00000000000000))*(sj0));
IkReal x12485=((cj4)*(cj5));
IkReal x12486=((IkReal(1.00000000000000))*(cj6));
IkReal x12487=((IkReal(0.0100000000000000))*(sj5));
IkReal x12488=((sj5)*(sj6));
IkReal x12489=((cj0)*(r10));
IkReal x12490=((cj4)*(cj6));
IkReal x12491=((cj0)*(r01));
IkReal x12492=((IkReal(1.00000000000000))*(cj4));
IkReal x12493=((cj0)*(r00));
IkReal x12494=((IkReal(0.374290000000000))*(sj0));
IkReal x12495=((cj0)*(r12));
IkReal x12496=((IkReal(0.374290000000000))*(sj5));
IkReal x12497=((cj4)*(sj6));
IkReal x12498=((IkReal(1.00000000000000))*(cj0));
IkReal x12499=((r02)*(sj0));
IkReal x12500=((IkReal(0.0100000000000000))*(cj5));
IkReal x12501=((r11)*(sj0));
IkReal x12502=((r00)*(sj0)*(sj6));
IkReal x12503=((r00)*(x12490));
IkReal x12504=((sj6)*(x12500));
evalcond[0]=((IkReal(-3.14159265358979))+(IKfmod(j2, IkReal(6.28318530717959))));
evalcond[1]=((((r21)*(x12497)))+(((r22)*(x12474)))+(((IkReal(-1.00000000000000))*(cj4)*(r20)*(x12486)))+(((x12471)*(x12483)))+(((cj6)*(r21)*(x12471))));
evalcond[2]=((IkReal(-0.0690000000000000))+(((IkReal(-1.00000000000000))*(r22)*(x12487)))+(((x12483)*(x12496)))+(((IkReal(0.374290000000000))*(r21)*(x12480)))+(((IkReal(-0.374290000000000))*(cj5)*(r22)))+(((IkReal(-0.0100000000000000))*(r21)*(x12475)))+(pz)+(((IkReal(-1.00000000000000))*(x12483)*(x12500))));
evalcond[3]=((((r00)*(sj0)*(x12488)))+(((cj0)*(x12479)))+(((x12476)*(x12480)))+(((IkReal(-1.00000000000000))*(sj5)*(x12472)*(x12489)))+(((IkReal(-1.00000000000000))*(x12480)*(x12481)))+(((IkReal(-1.00000000000000))*(x12477)*(x12482))));
evalcond[4]=((IkReal(-1.00000000000000))+(((x12476)*(x12497)))+(((cj6)*(x12471)*(x12476)))+(((x12471)*(x12502)))+(((x12474)*(x12499)))+(((x12489)*(x12490)))+(((IkReal(-1.00000000000000))*(x12471)*(x12481)*(x12486)))+(((IkReal(-1.00000000000000))*(x12471)*(x12472)*(x12489)))+(((IkReal(-1.00000000000000))*(x12474)*(x12495)))+(((IkReal(-1.00000000000000))*(cj4)*(x12472)*(x12481)))+(((IkReal(-1.00000000000000))*(x12484)*(x12503))));
evalcond[5]=((((IkReal(-1.00000000000000))*(sj4)*(x12486)*(x12489)))+(((cj4)*(sj5)*(x12499)))+(((cj4)*(x12475)*(x12476)))+(((IkReal(-1.00000000000000))*(sj5)*(x12492)*(x12495)))+(((cj6)*(r00)*(sj0)*(sj4)))+(((sj4)*(sj6)*(x12481)))+(((IkReal(-1.00000000000000))*(x12475)*(x12481)*(x12492)))+(((IkReal(-1.00000000000000))*(x12472)*(x12485)*(x12489)))+(((IkReal(-1.00000000000000))*(sj4)*(x12472)*(x12476)))+(((r00)*(x12482)*(x12497))));
evalcond[6]=((((IkReal(-1.00000000000000))*(cj4)*(x12472)*(x12501)))+(((IkReal(-1.00000000000000))*(cj4)*(x12472)*(x12491)))+(((IkReal(-1.00000000000000))*(x12471)*(x12486)*(x12491)))+(((IkReal(-1.00000000000000))*(cj0)*(x12474)*(x12477)))+(((IkReal(-1.00000000000000))*(x12471)*(x12472)*(x12493)))+(((IkReal(-1.00000000000000))*(r12)*(x12474)*(x12484)))+(((x12473)*(x12490)))+(((IkReal(-1.00000000000000))*(cj6)*(r11)*(x12471)*(x12484)))+(((IkReal(-1.00000000000000))*(x12471)*(x12472)*(x12473)))+(((x12490)*(x12493))));
evalcond[7]=((((x12489)*(x12504)))+(((x12478)*(x12479)))+(((IkReal(0.374290000000000))*(x12476)*(x12480)))+(((r00)*(x12488)*(x12494)))+(((IkReal(-0.374290000000000))*(r02)*(x12482)))+(((IkReal(-0.0100000000000000))*(x12475)*(x12476)))+(((IkReal(-1.00000000000000))*(r10)*(x12478)*(x12488)))+(((IkReal(-1.00000000000000))*(py)*(x12498)))+(((IkReal(-1.00000000000000))*(x12487)*(x12499)))+(((x12487)*(x12495)))+(((IkReal(-1.00000000000000))*(r11)*(x12478)*(x12480)))+(((px)*(sj0)))+(((IkReal(0.0100000000000000))*(x12475)*(x12481)))+(((IkReal(-0.0100000000000000))*(r00)*(sj6)*(x12482))));
evalcond[8]=((IkReal(0.433420000000000))+(((IkReal(-0.374290000000000))*(x12473)*(x12488)))+(((x12473)*(x12504)))+(((IkReal(0.0100000000000000))*(x12475)*(x12501)))+(((IkReal(0.0100000000000000))*(x12475)*(x12491)))+(((IkReal(-1.00000000000000))*(r11)*(x12480)*(x12494)))+(((IkReal(-1.00000000000000))*(px)*(x12498)))+(((IkReal(-1.00000000000000))*(r00)*(x12478)*(x12488)))+(((r12)*(sj0)*(x12487)))+(((IkReal(-1.00000000000000))*(py)*(x12484)))+(((cj5)*(r02)*(x12478)))+(((x12479)*(x12494)))+(((IkReal(-1.00000000000000))*(r01)*(x12478)*(x12480)))+(((x12493)*(x12504)))+(((cj0)*(r02)*(x12487))));
if( IKabs(evalcond[0]) < 0.0000010000000000  && IKabs(evalcond[1]) < 0.0000010000000000  && IKabs(evalcond[2]) < 0.0000010000000000  && IKabs(evalcond[3]) < 0.0000010000000000  && IKabs(evalcond[4]) < 0.0000010000000000  && IKabs(evalcond[5]) < 0.0000010000000000  && IKabs(evalcond[6]) < 0.0000010000000000  && IKabs(evalcond[7]) < 0.0000010000000000  && IKabs(evalcond[8]) < 0.0000010000000000  )
{
{
IkReal j3array[1], cj3array[1], sj3array[1];
bool j3valid[1]={false};
_nj3 = 1;
IkReal x12505=((IkReal(1.00000000000000))*(r21));
IkReal x12506=((cj4)*(cj5));
IkReal x12507=((r20)*(sj6));
if( IKabs(((((IkReal(-1.00000000000000))*(sj5)*(x12507)))+(((IkReal(-1.00000000000000))*(cj6)*(sj5)*(x12505)))+(((cj5)*(r22))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(((((cj6)*(r20)*(sj4)))+(((cj4)*(r22)*(sj5)))+(((cj6)*(r21)*(x12506)))+(((x12506)*(x12507)))+(((IkReal(-1.00000000000000))*(sj4)*(sj6)*(x12505))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(IKsqr(((((IkReal(-1.00000000000000))*(sj5)*(x12507)))+(((IkReal(-1.00000000000000))*(cj6)*(sj5)*(x12505)))+(((cj5)*(r22)))))+IKsqr(((((cj6)*(r20)*(sj4)))+(((cj4)*(r22)*(sj5)))+(((cj6)*(r21)*(x12506)))+(((x12506)*(x12507)))+(((IkReal(-1.00000000000000))*(sj4)*(sj6)*(x12505)))))-1) <= IKFAST_SINCOS_THRESH )
    continue;
j3array[0]=IKatan2(((((IkReal(-1.00000000000000))*(sj5)*(x12507)))+(((IkReal(-1.00000000000000))*(cj6)*(sj5)*(x12505)))+(((cj5)*(r22)))), ((((cj6)*(r20)*(sj4)))+(((cj4)*(r22)*(sj5)))+(((cj6)*(r21)*(x12506)))+(((x12506)*(x12507)))+(((IkReal(-1.00000000000000))*(sj4)*(sj6)*(x12505)))));
sj3array[0]=IKsin(j3array[0]);
cj3array[0]=IKcos(j3array[0]);
if( j3array[0] > IKPI )
{
    j3array[0]-=IK2PI;
}
else if( j3array[0] < -IKPI )
{    j3array[0]+=IK2PI;
}
j3valid[0] = true;
for(int ij3 = 0; ij3 < 1; ++ij3)
{
if( !j3valid[ij3] )
{
    continue;
}
_ij3[0] = ij3; _ij3[1] = -1;
for(int iij3 = ij3+1; iij3 < 1; ++iij3)
{
if( j3valid[iij3] && IKabs(cj3array[ij3]-cj3array[iij3]) < IKFAST_SOLUTION_THRESH && IKabs(sj3array[ij3]-sj3array[iij3]) < IKFAST_SOLUTION_THRESH )
{
    j3valid[iij3]=false; _ij3[1] = iij3; break; 
}
}
j3 = j3array[ij3]; cj3 = cj3array[ij3]; sj3 = sj3array[ij3];
{
IkReal evalcond[4];
IkReal x12508=IKsin(j3);
IkReal x12509=((IkReal(1.00000000000000))*(cj4));
IkReal x12510=((sj0)*(sj5));
IkReal x12511=((cj0)*(cj5));
IkReal x12512=((cj6)*(r01));
IkReal x12513=((r00)*(sj6));
IkReal x12514=((cj6)*(r11));
IkReal x12515=((cj5)*(sj0));
IkReal x12516=((cj6)*(sj4));
IkReal x12517=((sj4)*(sj6));
IkReal x12518=((cj4)*(cj5));
IkReal x12519=((cj6)*(r21));
IkReal x12520=((r20)*(sj6));
IkReal x12521=((r10)*(sj6));
IkReal x12522=((IkReal(1.00000000000000))*(IKcos(j3)));
IkReal x12523=((IkReal(1.00000000000000))*(cj0)*(sj5));
evalcond[0]=((((sj5)*(x12520)))+(((IkReal(-1.00000000000000))*(cj5)*(r22)))+(((sj5)*(x12519)))+(x12508));
evalcond[1]=((((r20)*(x12516)))+(((x12518)*(x12520)))+(((cj4)*(r22)*(sj5)))+(((x12518)*(x12519)))+(((IkReal(-1.00000000000000))*(x12522)))+(((IkReal(-1.00000000000000))*(r21)*(x12517))));
evalcond[2]=((((IkReal(-1.00000000000000))*(x12512)*(x12523)))+(((r12)*(x12515)))+(((IkReal(-1.00000000000000))*(x12510)*(x12514)))+(((IkReal(-1.00000000000000))*(x12513)*(x12523)))+(((IkReal(-1.00000000000000))*(x12510)*(x12521)))+(((IkReal(-1.00000000000000))*(x12522)))+(((r02)*(x12511))));
evalcond[3]=((((IkReal(-1.00000000000000))*(r10)*(sj0)*(x12516)))+(((r11)*(sj0)*(x12517)))+(((IkReal(-1.00000000000000))*(cj0)*(r02)*(sj5)*(x12509)))+(((IkReal(-1.00000000000000))*(x12509)*(x12515)*(x12521)))+(((IkReal(-1.00000000000000))*(cj0)*(r00)*(x12516)))+(((IkReal(-1.00000000000000))*(x12509)*(x12511)*(x12512)))+(((IkReal(-1.00000000000000))*(x12508)))+(((IkReal(-1.00000000000000))*(x12509)*(x12514)*(x12515)))+(((cj0)*(r01)*(x12517)))+(((IkReal(-1.00000000000000))*(r12)*(x12509)*(x12510)))+(((IkReal(-1.00000000000000))*(x12509)*(x12511)*(x12513))));
if( IKabs(evalcond[0]) > 0.000001  || IKabs(evalcond[1]) > 0.000001  || IKabs(evalcond[2]) > 0.000001  || IKabs(evalcond[3]) > 0.000001  )
{
continue;
}
}

{
std::vector<IkSingleDOFSolutionBase<IkReal> > vinfos(7);
vinfos[0].jointtype = 1;
vinfos[0].foffset = j0;
vinfos[0].indices[0] = _ij0[0];
vinfos[0].indices[1] = _ij0[1];
vinfos[0].maxsolutions = _nj0;
vinfos[1].jointtype = 1;
vinfos[1].foffset = j1;
vinfos[1].indices[0] = _ij1[0];
vinfos[1].indices[1] = _ij1[1];
vinfos[1].maxsolutions = _nj1;
vinfos[2].jointtype = 1;
vinfos[2].foffset = j2;
vinfos[2].indices[0] = _ij2[0];
vinfos[2].indices[1] = _ij2[1];
vinfos[2].maxsolutions = _nj2;
vinfos[3].jointtype = 1;
vinfos[3].foffset = j3;
vinfos[3].indices[0] = _ij3[0];
vinfos[3].indices[1] = _ij3[1];
vinfos[3].maxsolutions = _nj3;
vinfos[4].jointtype = 1;
vinfos[4].foffset = j4;
vinfos[4].indices[0] = _ij4[0];
vinfos[4].indices[1] = _ij4[1];
vinfos[4].maxsolutions = _nj4;
vinfos[5].jointtype = 1;
vinfos[5].foffset = j5;
vinfos[5].indices[0] = _ij5[0];
vinfos[5].indices[1] = _ij5[1];
vinfos[5].maxsolutions = _nj5;
vinfos[6].jointtype = 1;
vinfos[6].foffset = j6;
vinfos[6].indices[0] = _ij6[0];
vinfos[6].indices[1] = _ij6[1];
vinfos[6].maxsolutions = _nj6;
std::vector<int> vfree(0);
solutions.AddSolution(vinfos,vfree);
}
}
}

} else
{
IkReal x12524=((IkReal(1.00000000000000))*(cj0));
IkReal x12525=((cj4)*(sj6));
IkReal x12526=((sj0)*(sj4));
IkReal x12527=((cj5)*(sj6));
IkReal x12528=((sj4)*(sj5));
IkReal x12529=((r12)*(sj5));
IkReal x12530=((IkReal(0.374290000000000))*(cj5));
IkReal x12531=((r02)*(sj0));
IkReal x12532=((r20)*(sj4));
IkReal x12533=((IkReal(1.00000000000000))*(sj0));
IkReal x12534=((IkReal(1.00000000000000))*(cj5));
IkReal x12535=((cj0)*(r10));
IkReal x12536=((cj4)*(cj6));
IkReal x12537=((r00)*(sj0));
IkReal x12538=((cj6)*(r21));
IkReal x12539=((IkReal(0.374290000000000))*(sj5));
IkReal x12540=((cj0)*(r00));
IkReal x12541=((IkReal(0.0100000000000000))*(sj5));
IkReal x12542=((cj0)*(r02));
IkReal x12543=((cj5)*(sj4));
IkReal x12544=((cj6)*(r01));
IkReal x12545=((cj6)*(r11));
IkReal x12546=((r01)*(sj0));
IkReal x12547=((r10)*(sj0));
IkReal x12548=((IkReal(0.0100000000000000))*(cj5)*(cj6));
IkReal x12549=((sj6)*(x12539));
IkReal x12550=((cj0)*(cj6)*(x12539));
evalcond[0]=((IkReal(-3.14159265358979))+(IKfmod(((IkReal(1.57079632679490))+(j2)), IkReal(6.28318530717959))));
evalcond[1]=((((sj5)*(x12538)))+(((IkReal(-1.00000000000000))*(r22)*(x12534)))+(((r20)*(sj5)*(sj6))));
evalcond[2]=((IkReal(-1.00000000000000))+(((r22)*(x12528)))+(((x12527)*(x12532)))+(((r21)*(x12525)))+(((x12538)*(x12543)))+(((IkReal(-1.00000000000000))*(r20)*(x12536))));
evalcond[3]=((((IkReal(-1.00000000000000))*(r22)*(x12530)))+(((r20)*(x12549)))+(((IkReal(-1.00000000000000))*(r22)*(x12541)))+(((IkReal(-0.0100000000000000))*(cj5)*(x12538)))+(pz)+(((IkReal(-0.0100000000000000))*(r20)*(x12527)))+(((x12538)*(x12539))));
evalcond[4]=((((IkReal(-1.00000000000000))*(r21)*(sj4)*(sj6)))+(((cj6)*(x12532)))+(((cj4)*(r22)*(sj5)))+(((cj5)*(r21)*(x12536)))+(((cj5)*(r20)*(x12525))));
evalcond[5]=((((IkReal(-1.00000000000000))*(x12524)*(x12543)*(x12545)))+(((IkReal(-1.00000000000000))*(r00)*(x12533)*(x12536)))+(((x12525)*(x12546)))+(((x12535)*(x12536)))+(((IkReal(-1.00000000000000))*(r10)*(sj4)*(x12524)*(x12527)))+(((cj5)*(x12526)*(x12544)))+(((r00)*(x12526)*(x12527)))+(((IkReal(-1.00000000000000))*(r11)*(x12524)*(x12525)))+(((IkReal(-1.00000000000000))*(r12)*(x12524)*(x12528)))+(((r02)*(sj5)*(x12526))));
evalcond[6]=((((IkReal(-1.00000000000000))*(r02)*(x12524)*(x12528)))+(((IkReal(-1.00000000000000))*(r11)*(x12525)*(x12533)))+(((x12536)*(x12540)))+(((IkReal(-1.00000000000000))*(r10)*(x12526)*(x12527)))+(((IkReal(-1.00000000000000))*(r01)*(x12524)*(x12525)))+(((x12536)*(x12547)))+(((IkReal(-1.00000000000000))*(x12526)*(x12529)))+(((IkReal(-1.00000000000000))*(x12524)*(x12543)*(x12544)))+(((IkReal(-1.00000000000000))*(x12526)*(x12534)*(x12545)))+(((IkReal(-1.00000000000000))*(r00)*(sj4)*(x12524)*(x12527))));
evalcond[7]=((IkReal(0.0690000000000000))+(((sj0)*(x12539)*(x12544)))+(((x12537)*(x12549)))+(((IkReal(0.0100000000000000))*(cj0)*(cj5)*(x12545)))+(((cj0)*(r12)*(x12530)))+(((IkReal(-1.00000000000000))*(py)*(x12524)))+(((IkReal(0.0100000000000000))*(x12527)*(x12535)))+(((IkReal(-1.00000000000000))*(x12531)*(x12541)))+(((IkReal(-0.0100000000000000))*(x12527)*(x12537)))+(((IkReal(-1.00000000000000))*(x12530)*(x12531)))+(((IkReal(-1.00000000000000))*(x12535)*(x12549)))+(((IkReal(-1.00000000000000))*(cj0)*(x12539)*(x12545)))+(((IkReal(-0.0100000000000000))*(cj5)*(sj0)*(x12544)))+(((IkReal(0.0100000000000000))*(cj0)*(x12529)))+(((px)*(sj0))));
evalcond[8]=((IkReal(0.433420000000000))+(((IkReal(0.0100000000000000))*(cj0)*(cj5)*(x12544)))+(((IkReal(0.0100000000000000))*(cj5)*(sj0)*(x12545)))+(((r12)*(sj0)*(x12530)))+(((IkReal(0.0100000000000000))*(x12527)*(x12540)))+(((IkReal(-1.00000000000000))*(x12540)*(x12549)))+(((x12530)*(x12542)))+(((IkReal(-1.00000000000000))*(sj0)*(x12539)*(x12545)))+(((IkReal(-1.00000000000000))*(cj0)*(x12539)*(x12544)))+(((x12541)*(x12542)))+(((IkReal(-1.00000000000000))*(x12547)*(x12549)))+(((IkReal(0.0100000000000000))*(sj0)*(x12529)))+(((IkReal(-1.00000000000000))*(py)*(x12533)))+(((IkReal(-1.00000000000000))*(px)*(x12524)))+(((IkReal(0.0100000000000000))*(x12527)*(x12547))));
if( IKabs(evalcond[0]) < 0.0000010000000000  && IKabs(evalcond[1]) < 0.0000010000000000  && IKabs(evalcond[2]) < 0.0000010000000000  && IKabs(evalcond[3]) < 0.0000010000000000  && IKabs(evalcond[4]) < 0.0000010000000000  && IKabs(evalcond[5]) < 0.0000010000000000  && IKabs(evalcond[6]) < 0.0000010000000000  && IKabs(evalcond[7]) < 0.0000010000000000  && IKabs(evalcond[8]) < 0.0000010000000000  )
{
{
IkReal j3array[1], cj3array[1], sj3array[1];
bool j3valid[1]={false};
_nj3 = 1;
IkReal x12551=((cj0)*(cj5));
IkReal x12552=((IkReal(1.00000000000000))*(cj0));
IkReal x12553=((cj6)*(r11));
IkReal x12554=((r10)*(sj6));
IkReal x12555=((cj5)*(sj0));
IkReal x12556=((r00)*(sj5)*(sj6));
IkReal x12557=((cj6)*(r01)*(sj5));
IkReal x12558=((IkReal(1.00000000000000))*(sj0)*(sj5));
if( IKabs(((((sj0)*(x12557)))+(((IkReal(-1.00000000000000))*(sj5)*(x12552)*(x12553)))+(((IkReal(-1.00000000000000))*(sj5)*(x12552)*(x12554)))+(((sj0)*(x12556)))+(((IkReal(-1.00000000000000))*(r02)*(x12555)))+(((r12)*(x12551))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(((((r12)*(x12555)))+(((r02)*(x12551)))+(((IkReal(-1.00000000000000))*(x12552)*(x12557)))+(((IkReal(-1.00000000000000))*(x12553)*(x12558)))+(((IkReal(-1.00000000000000))*(x12552)*(x12556)))+(((IkReal(-1.00000000000000))*(x12554)*(x12558))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(IKsqr(((((sj0)*(x12557)))+(((IkReal(-1.00000000000000))*(sj5)*(x12552)*(x12553)))+(((IkReal(-1.00000000000000))*(sj5)*(x12552)*(x12554)))+(((sj0)*(x12556)))+(((IkReal(-1.00000000000000))*(r02)*(x12555)))+(((r12)*(x12551)))))+IKsqr(((((r12)*(x12555)))+(((r02)*(x12551)))+(((IkReal(-1.00000000000000))*(x12552)*(x12557)))+(((IkReal(-1.00000000000000))*(x12553)*(x12558)))+(((IkReal(-1.00000000000000))*(x12552)*(x12556)))+(((IkReal(-1.00000000000000))*(x12554)*(x12558)))))-1) <= IKFAST_SINCOS_THRESH )
    continue;
j3array[0]=IKatan2(((((sj0)*(x12557)))+(((IkReal(-1.00000000000000))*(sj5)*(x12552)*(x12553)))+(((IkReal(-1.00000000000000))*(sj5)*(x12552)*(x12554)))+(((sj0)*(x12556)))+(((IkReal(-1.00000000000000))*(r02)*(x12555)))+(((r12)*(x12551)))), ((((r12)*(x12555)))+(((r02)*(x12551)))+(((IkReal(-1.00000000000000))*(x12552)*(x12557)))+(((IkReal(-1.00000000000000))*(x12553)*(x12558)))+(((IkReal(-1.00000000000000))*(x12552)*(x12556)))+(((IkReal(-1.00000000000000))*(x12554)*(x12558)))));
sj3array[0]=IKsin(j3array[0]);
cj3array[0]=IKcos(j3array[0]);
if( j3array[0] > IKPI )
{
    j3array[0]-=IK2PI;
}
else if( j3array[0] < -IKPI )
{    j3array[0]+=IK2PI;
}
j3valid[0] = true;
for(int ij3 = 0; ij3 < 1; ++ij3)
{
if( !j3valid[ij3] )
{
    continue;
}
_ij3[0] = ij3; _ij3[1] = -1;
for(int iij3 = ij3+1; iij3 < 1; ++iij3)
{
if( j3valid[iij3] && IKabs(cj3array[ij3]-cj3array[iij3]) < IKFAST_SOLUTION_THRESH && IKabs(sj3array[ij3]-sj3array[iij3]) < IKFAST_SOLUTION_THRESH )
{
    j3valid[iij3]=false; _ij3[1] = iij3; break; 
}
}
j3 = j3array[ij3]; cj3 = cj3array[ij3]; sj3 = sj3array[ij3];
{
IkReal evalcond[4];
IkReal x12559=IKcos(j3);
IkReal x12560=((sj0)*(sj5));
IkReal x12561=((r00)*(sj6));
IkReal x12562=((cj6)*(sj0));
IkReal x12563=((IkReal(1.00000000000000))*(cj4));
IkReal x12564=((r00)*(sj4));
IkReal x12565=((cj0)*(cj5));
IkReal x12566=((cj5)*(sj0));
IkReal x12567=((cj6)*(r11));
IkReal x12568=((r10)*(sj6));
IkReal x12569=((cj0)*(sj5));
IkReal x12570=((r10)*(sj4));
IkReal x12571=((IkReal(1.00000000000000))*(IKsin(j3)));
IkReal x12572=((cj4)*(cj5)*(r01));
IkReal x12573=((IkReal(1.00000000000000))*(cj0)*(cj6));
IkReal x12574=((cj0)*(sj4)*(sj6));
IkReal x12575=((sj0)*(sj4)*(sj6));
evalcond[0]=((((IkReal(-1.00000000000000))*(x12567)*(x12569)))+(((x12560)*(x12561)))+(((cj6)*(r01)*(x12560)))+(((IkReal(-1.00000000000000))*(r02)*(x12566)))+(((IkReal(-1.00000000000000))*(x12568)*(x12569)))+(((IkReal(-1.00000000000000))*(x12571)))+(((r12)*(x12565))));
evalcond[1]=((((r02)*(x12565)))+(((IkReal(-1.00000000000000))*(cj6)*(r01)*(x12569)))+(((IkReal(-1.00000000000000))*(x12561)*(x12569)))+(((r12)*(x12566)))+(((IkReal(-1.00000000000000))*(x12560)*(x12568)))+(((IkReal(-1.00000000000000))*(x12560)*(x12567)))+(((IkReal(-1.00000000000000))*(x12559))));
evalcond[2]=((x12559)+(((IkReal(-1.00000000000000))*(x12563)*(x12565)*(x12567)))+(((x12562)*(x12564)))+(((cj4)*(x12561)*(x12566)))+(((IkReal(-1.00000000000000))*(x12563)*(x12565)*(x12568)))+(((x12562)*(x12572)))+(((IkReal(-1.00000000000000))*(x12570)*(x12573)))+(((r11)*(x12574)))+(((IkReal(-1.00000000000000))*(r01)*(x12575)))+(((cj4)*(r02)*(x12560)))+(((IkReal(-1.00000000000000))*(r12)*(x12563)*(x12569))));
evalcond[3]=((((r01)*(x12574)))+(((IkReal(-1.00000000000000))*(cj5)*(r11)*(x12562)*(x12563)))+(((IkReal(-1.00000000000000))*(x12561)*(x12563)*(x12565)))+(((IkReal(-1.00000000000000))*(r12)*(x12560)*(x12563)))+(((IkReal(-1.00000000000000))*(cj6)*(r01)*(x12563)*(x12565)))+(((IkReal(-1.00000000000000))*(x12563)*(x12566)*(x12568)))+(((IkReal(-1.00000000000000))*(x12562)*(x12570)))+(((IkReal(-1.00000000000000))*(r02)*(x12563)*(x12569)))+(((IkReal(-1.00000000000000))*(x12571)))+(((IkReal(-1.00000000000000))*(x12564)*(x12573)))+(((r11)*(x12575))));
if( IKabs(evalcond[0]) > 0.000001  || IKabs(evalcond[1]) > 0.000001  || IKabs(evalcond[2]) > 0.000001  || IKabs(evalcond[3]) > 0.000001  )
{
continue;
}
}

{
std::vector<IkSingleDOFSolutionBase<IkReal> > vinfos(7);
vinfos[0].jointtype = 1;
vinfos[0].foffset = j0;
vinfos[0].indices[0] = _ij0[0];
vinfos[0].indices[1] = _ij0[1];
vinfos[0].maxsolutions = _nj0;
vinfos[1].jointtype = 1;
vinfos[1].foffset = j1;
vinfos[1].indices[0] = _ij1[0];
vinfos[1].indices[1] = _ij1[1];
vinfos[1].maxsolutions = _nj1;
vinfos[2].jointtype = 1;
vinfos[2].foffset = j2;
vinfos[2].indices[0] = _ij2[0];
vinfos[2].indices[1] = _ij2[1];
vinfos[2].maxsolutions = _nj2;
vinfos[3].jointtype = 1;
vinfos[3].foffset = j3;
vinfos[3].indices[0] = _ij3[0];
vinfos[3].indices[1] = _ij3[1];
vinfos[3].maxsolutions = _nj3;
vinfos[4].jointtype = 1;
vinfos[4].foffset = j4;
vinfos[4].indices[0] = _ij4[0];
vinfos[4].indices[1] = _ij4[1];
vinfos[4].maxsolutions = _nj4;
vinfos[5].jointtype = 1;
vinfos[5].foffset = j5;
vinfos[5].indices[0] = _ij5[0];
vinfos[5].indices[1] = _ij5[1];
vinfos[5].maxsolutions = _nj5;
vinfos[6].jointtype = 1;
vinfos[6].foffset = j6;
vinfos[6].indices[0] = _ij6[0];
vinfos[6].indices[1] = _ij6[1];
vinfos[6].maxsolutions = _nj6;
std::vector<int> vfree(0);
solutions.AddSolution(vinfos,vfree);
}
}
}

} else
{
IkReal x12576=((IkReal(1.00000000000000))*(cj0));
IkReal x12577=((cj4)*(sj6));
IkReal x12578=((sj0)*(sj4));
IkReal x12579=((cj5)*(sj6));
IkReal x12580=((sj4)*(sj5));
IkReal x12581=((r12)*(sj5));
IkReal x12582=((IkReal(0.374290000000000))*(cj5));
IkReal x12583=((r02)*(sj0));
IkReal x12584=((r20)*(sj4));
IkReal x12585=((IkReal(1.00000000000000))*(sj0));
IkReal x12586=((IkReal(1.00000000000000))*(cj5));
IkReal x12587=((cj0)*(r10));
IkReal x12588=((cj4)*(cj6));
IkReal x12589=((r00)*(sj0));
IkReal x12590=((cj6)*(r21));
IkReal x12591=((IkReal(0.374290000000000))*(sj5));
IkReal x12592=((cj0)*(r00));
IkReal x12593=((IkReal(0.0100000000000000))*(sj5));
IkReal x12594=((cj0)*(r02));
IkReal x12595=((cj5)*(sj4));
IkReal x12596=((cj6)*(r01));
IkReal x12597=((cj6)*(r11));
IkReal x12598=((r01)*(sj0));
IkReal x12599=((r10)*(sj0));
IkReal x12600=((IkReal(0.0100000000000000))*(cj5)*(cj6));
IkReal x12601=((sj6)*(x12591));
IkReal x12602=((cj0)*(cj6)*(x12591));
evalcond[0]=((IkReal(-3.14159265358979))+(IKfmod(((IkReal(4.71238898038469))+(j2)), IkReal(6.28318530717959))));
evalcond[1]=((((IkReal(-1.00000000000000))*(r22)*(x12586)))+(((sj5)*(x12590)))+(((r20)*(sj5)*(sj6))));
evalcond[2]=((IkReal(1.00000000000000))+(((x12579)*(x12584)))+(((r21)*(x12577)))+(((r22)*(x12580)))+(((x12590)*(x12595)))+(((IkReal(-1.00000000000000))*(r20)*(x12588))));
evalcond[3]=((((IkReal(-1.00000000000000))*(r22)*(x12593)))+(((IkReal(-0.0100000000000000))*(cj5)*(x12590)))+(((IkReal(-0.0100000000000000))*(r20)*(x12579)))+(((x12590)*(x12591)))+(pz)+(((IkReal(-1.00000000000000))*(r22)*(x12582)))+(((r20)*(x12601))));
evalcond[4]=((((cj5)*(r20)*(x12577)))+(((IkReal(-1.00000000000000))*(r21)*(sj4)*(sj6)))+(((cj6)*(x12584)))+(((cj5)*(r21)*(x12588)))+(((cj4)*(r22)*(sj5))));
evalcond[5]=((((IkReal(-1.00000000000000))*(r10)*(sj4)*(x12576)*(x12579)))+(((IkReal(-1.00000000000000))*(r00)*(x12585)*(x12588)))+(((r02)*(sj5)*(x12578)))+(((r00)*(x12578)*(x12579)))+(((cj5)*(x12578)*(x12596)))+(((IkReal(-1.00000000000000))*(x12576)*(x12595)*(x12597)))+(((x12587)*(x12588)))+(((IkReal(-1.00000000000000))*(r12)*(x12576)*(x12580)))+(((IkReal(-1.00000000000000))*(r11)*(x12576)*(x12577)))+(((x12577)*(x12598))));
evalcond[6]=((((IkReal(-1.00000000000000))*(x12576)*(x12595)*(x12596)))+(((IkReal(-1.00000000000000))*(r11)*(x12577)*(x12585)))+(((IkReal(-1.00000000000000))*(r00)*(sj4)*(x12576)*(x12579)))+(((x12588)*(x12599)))+(((IkReal(-1.00000000000000))*(r01)*(x12576)*(x12577)))+(((IkReal(-1.00000000000000))*(x12578)*(x12581)))+(((IkReal(-1.00000000000000))*(x12578)*(x12586)*(x12597)))+(((x12588)*(x12592)))+(((IkReal(-1.00000000000000))*(r10)*(x12578)*(x12579)))+(((IkReal(-1.00000000000000))*(r02)*(x12576)*(x12580))));
evalcond[7]=((IkReal(-0.0690000000000000))+(((IkReal(-0.0100000000000000))*(x12579)*(x12589)))+(((x12589)*(x12601)))+(((IkReal(-1.00000000000000))*(x12582)*(x12583)))+(((IkReal(-1.00000000000000))*(cj0)*(x12591)*(x12597)))+(((IkReal(-1.00000000000000))*(x12583)*(x12593)))+(((IkReal(0.0100000000000000))*(cj0)*(cj5)*(x12597)))+(((IkReal(-0.0100000000000000))*(cj5)*(sj0)*(x12596)))+(((sj0)*(x12591)*(x12596)))+(((IkReal(-1.00000000000000))*(x12587)*(x12601)))+(((px)*(sj0)))+(((IkReal(0.0100000000000000))*(x12579)*(x12587)))+(((cj0)*(r12)*(x12582)))+(((IkReal(-1.00000000000000))*(py)*(x12576)))+(((IkReal(0.0100000000000000))*(cj0)*(x12581))));
evalcond[8]=((IkReal(0.433420000000000))+(((x12582)*(x12594)))+(((IkReal(0.0100000000000000))*(cj5)*(sj0)*(x12597)))+(((x12593)*(x12594)))+(((IkReal(-1.00000000000000))*(sj0)*(x12591)*(x12597)))+(((IkReal(-1.00000000000000))*(px)*(x12576)))+(((r12)*(sj0)*(x12582)))+(((IkReal(-1.00000000000000))*(cj0)*(x12591)*(x12596)))+(((IkReal(-1.00000000000000))*(py)*(x12585)))+(((IkReal(0.0100000000000000))*(sj0)*(x12581)))+(((IkReal(0.0100000000000000))*(x12579)*(x12592)))+(((IkReal(0.0100000000000000))*(cj0)*(cj5)*(x12596)))+(((IkReal(-1.00000000000000))*(x12599)*(x12601)))+(((IkReal(-1.00000000000000))*(x12592)*(x12601)))+(((IkReal(0.0100000000000000))*(x12579)*(x12599))));
if( IKabs(evalcond[0]) < 0.0000010000000000  && IKabs(evalcond[1]) < 0.0000010000000000  && IKabs(evalcond[2]) < 0.0000010000000000  && IKabs(evalcond[3]) < 0.0000010000000000  && IKabs(evalcond[4]) < 0.0000010000000000  && IKabs(evalcond[5]) < 0.0000010000000000  && IKabs(evalcond[6]) < 0.0000010000000000  && IKabs(evalcond[7]) < 0.0000010000000000  && IKabs(evalcond[8]) < 0.0000010000000000  )
{
{
IkReal j3array[1], cj3array[1], sj3array[1];
bool j3valid[1]={false};
_nj3 = 1;
IkReal x12603=((cj5)*(r02));
IkReal x12604=((cj0)*(sj5));
IkReal x12605=((r10)*(sj6));
IkReal x12606=((IkReal(1.00000000000000))*(cj6));
IkReal x12607=((sj0)*(sj5));
IkReal x12608=((cj5)*(r12));
IkReal x12609=((IkReal(1.00000000000000))*(r00)*(sj6));
if( IKabs(((((x12604)*(x12605)))+(((IkReal(-1.00000000000000))*(x12607)*(x12609)))+(((IkReal(-1.00000000000000))*(cj0)*(x12608)))+(((cj6)*(r11)*(x12604)))+(((sj0)*(x12603)))+(((IkReal(-1.00000000000000))*(r01)*(x12606)*(x12607))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(((((cj0)*(x12603)))+(((IkReal(-1.00000000000000))*(r11)*(x12606)*(x12607)))+(((IkReal(-1.00000000000000))*(x12604)*(x12609)))+(((sj0)*(x12608)))+(((IkReal(-1.00000000000000))*(r01)*(x12604)*(x12606)))+(((IkReal(-1.00000000000000))*(x12605)*(x12607))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(IKsqr(((((x12604)*(x12605)))+(((IkReal(-1.00000000000000))*(x12607)*(x12609)))+(((IkReal(-1.00000000000000))*(cj0)*(x12608)))+(((cj6)*(r11)*(x12604)))+(((sj0)*(x12603)))+(((IkReal(-1.00000000000000))*(r01)*(x12606)*(x12607)))))+IKsqr(((((cj0)*(x12603)))+(((IkReal(-1.00000000000000))*(r11)*(x12606)*(x12607)))+(((IkReal(-1.00000000000000))*(x12604)*(x12609)))+(((sj0)*(x12608)))+(((IkReal(-1.00000000000000))*(r01)*(x12604)*(x12606)))+(((IkReal(-1.00000000000000))*(x12605)*(x12607)))))-1) <= IKFAST_SINCOS_THRESH )
    continue;
j3array[0]=IKatan2(((((x12604)*(x12605)))+(((IkReal(-1.00000000000000))*(x12607)*(x12609)))+(((IkReal(-1.00000000000000))*(cj0)*(x12608)))+(((cj6)*(r11)*(x12604)))+(((sj0)*(x12603)))+(((IkReal(-1.00000000000000))*(r01)*(x12606)*(x12607)))), ((((cj0)*(x12603)))+(((IkReal(-1.00000000000000))*(r11)*(x12606)*(x12607)))+(((IkReal(-1.00000000000000))*(x12604)*(x12609)))+(((sj0)*(x12608)))+(((IkReal(-1.00000000000000))*(r01)*(x12604)*(x12606)))+(((IkReal(-1.00000000000000))*(x12605)*(x12607)))));
sj3array[0]=IKsin(j3array[0]);
cj3array[0]=IKcos(j3array[0]);
if( j3array[0] > IKPI )
{
    j3array[0]-=IK2PI;
}
else if( j3array[0] < -IKPI )
{    j3array[0]+=IK2PI;
}
j3valid[0] = true;
for(int ij3 = 0; ij3 < 1; ++ij3)
{
if( !j3valid[ij3] )
{
    continue;
}
_ij3[0] = ij3; _ij3[1] = -1;
for(int iij3 = ij3+1; iij3 < 1; ++iij3)
{
if( j3valid[iij3] && IKabs(cj3array[ij3]-cj3array[iij3]) < IKFAST_SOLUTION_THRESH && IKabs(sj3array[ij3]-sj3array[iij3]) < IKFAST_SOLUTION_THRESH )
{
    j3valid[iij3]=false; _ij3[1] = iij3; break; 
}
}
j3 = j3array[ij3]; cj3 = cj3array[ij3]; sj3 = sj3array[ij3];
{
IkReal evalcond[4];
IkReal x12610=IKsin(j3);
IkReal x12611=((sj0)*(sj5));
IkReal x12612=((r00)*(sj6));
IkReal x12613=((IkReal(1.00000000000000))*(cj4));
IkReal x12614=((cj6)*(sj0));
IkReal x12615=((r00)*(sj4));
IkReal x12616=((cj0)*(cj5));
IkReal x12617=((cj6)*(r01));
IkReal x12618=((cj5)*(sj0));
IkReal x12619=((cj0)*(sj5));
IkReal x12620=((cj6)*(r11));
IkReal x12621=((r10)*(sj6));
IkReal x12622=((r10)*(sj4));
IkReal x12623=((IkReal(1.00000000000000))*(IKcos(j3)));
IkReal x12624=((cj0)*(sj4)*(sj6));
IkReal x12625=((sj0)*(sj4)*(sj6));
IkReal x12626=((IkReal(1.00000000000000))*(cj0)*(cj6));
evalcond[0]=((((IkReal(-1.00000000000000))*(x12619)*(x12621)))+(((IkReal(-1.00000000000000))*(r02)*(x12618)))+(((x12611)*(x12612)))+(((IkReal(-1.00000000000000))*(x12619)*(x12620)))+(((x12611)*(x12617)))+(((r12)*(x12616)))+(x12610));
evalcond[1]=((((IkReal(-1.00000000000000))*(x12617)*(x12619)))+(((r12)*(x12618)))+(((IkReal(-1.00000000000000))*(x12612)*(x12619)))+(((IkReal(-1.00000000000000))*(x12623)))+(((r02)*(x12616)))+(((IkReal(-1.00000000000000))*(x12611)*(x12620)))+(((IkReal(-1.00000000000000))*(x12611)*(x12621))));
evalcond[2]=((((IkReal(-1.00000000000000))*(r12)*(x12613)*(x12619)))+(((IkReal(-1.00000000000000))*(x12622)*(x12626)))+(((IkReal(-1.00000000000000))*(x12623)))+(((x12614)*(x12615)))+(((r11)*(x12624)))+(((cj4)*(cj5)*(r01)*(x12614)))+(((cj4)*(x12612)*(x12618)))+(((IkReal(-1.00000000000000))*(r01)*(x12625)))+(((cj4)*(r02)*(x12611)))+(((IkReal(-1.00000000000000))*(x12613)*(x12616)*(x12620)))+(((IkReal(-1.00000000000000))*(x12613)*(x12616)*(x12621))));
evalcond[3]=((((IkReal(-1.00000000000000))*(x12615)*(x12626)))+(((IkReal(-1.00000000000000))*(x12614)*(x12622)))+(((IkReal(-1.00000000000000))*(x12613)*(x12618)*(x12621)))+(((IkReal(-1.00000000000000))*(x12610)))+(((IkReal(-1.00000000000000))*(cj5)*(r11)*(x12613)*(x12614)))+(((IkReal(-1.00000000000000))*(x12613)*(x12616)*(x12617)))+(((IkReal(-1.00000000000000))*(x12612)*(x12613)*(x12616)))+(((r11)*(x12625)))+(((IkReal(-1.00000000000000))*(r12)*(x12611)*(x12613)))+(((r01)*(x12624)))+(((IkReal(-1.00000000000000))*(r02)*(x12613)*(x12619))));
if( IKabs(evalcond[0]) > 0.000001  || IKabs(evalcond[1]) > 0.000001  || IKabs(evalcond[2]) > 0.000001  || IKabs(evalcond[3]) > 0.000001  )
{
continue;
}
}

{
std::vector<IkSingleDOFSolutionBase<IkReal> > vinfos(7);
vinfos[0].jointtype = 1;
vinfos[0].foffset = j0;
vinfos[0].indices[0] = _ij0[0];
vinfos[0].indices[1] = _ij0[1];
vinfos[0].maxsolutions = _nj0;
vinfos[1].jointtype = 1;
vinfos[1].foffset = j1;
vinfos[1].indices[0] = _ij1[0];
vinfos[1].indices[1] = _ij1[1];
vinfos[1].maxsolutions = _nj1;
vinfos[2].jointtype = 1;
vinfos[2].foffset = j2;
vinfos[2].indices[0] = _ij2[0];
vinfos[2].indices[1] = _ij2[1];
vinfos[2].maxsolutions = _nj2;
vinfos[3].jointtype = 1;
vinfos[3].foffset = j3;
vinfos[3].indices[0] = _ij3[0];
vinfos[3].indices[1] = _ij3[1];
vinfos[3].maxsolutions = _nj3;
vinfos[4].jointtype = 1;
vinfos[4].foffset = j4;
vinfos[4].indices[0] = _ij4[0];
vinfos[4].indices[1] = _ij4[1];
vinfos[4].maxsolutions = _nj4;
vinfos[5].jointtype = 1;
vinfos[5].foffset = j5;
vinfos[5].indices[0] = _ij5[0];
vinfos[5].indices[1] = _ij5[1];
vinfos[5].maxsolutions = _nj5;
vinfos[6].jointtype = 1;
vinfos[6].foffset = j6;
vinfos[6].indices[0] = _ij6[0];
vinfos[6].indices[1] = _ij6[1];
vinfos[6].maxsolutions = _nj6;
std::vector<int> vfree(0);
solutions.AddSolution(vinfos,vfree);
}
}
}

} else
{
if( 1 )
{
continue;

} else
{
}
}
}
}
}
}

} else
{
{
IkReal j3array[1], cj3array[1], sj3array[1];
bool j3valid[1]={false};
_nj3 = 1;
IkReal x12627=((cj0)*(cj5));
IkReal x12628=((IkReal(1.00000000000000))*(cj0));
IkReal x12629=((cj6)*(r11));
IkReal x12630=((r10)*(sj6));
IkReal x12631=((cj5)*(sj0));
IkReal x12632=((r00)*(sj5)*(sj6));
IkReal x12633=((cj6)*(r01)*(sj5));
IkReal x12634=((IkReal(1.00000000000000))*(sj0)*(sj5));
if( IKabs(((((IKabs(sj2) != 0)?((IkReal)1/(sj2)):(IkReal)1.0e30))*(((((r12)*(x12627)))+(((IkReal(-1.00000000000000))*(sj5)*(x12628)*(x12629)))+(((IkReal(-1.00000000000000))*(r02)*(x12631)))+(((IkReal(-1.00000000000000))*(sj5)*(x12628)*(x12630)))+(((sj0)*(x12632)))+(((sj0)*(x12633))))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(((((r12)*(x12631)))+(((IkReal(-1.00000000000000))*(x12630)*(x12634)))+(((IkReal(-1.00000000000000))*(x12628)*(x12633)))+(((IkReal(-1.00000000000000))*(x12629)*(x12634)))+(((IkReal(-1.00000000000000))*(x12628)*(x12632)))+(((r02)*(x12627))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(IKsqr(((((IKabs(sj2) != 0)?((IkReal)1/(sj2)):(IkReal)1.0e30))*(((((r12)*(x12627)))+(((IkReal(-1.00000000000000))*(sj5)*(x12628)*(x12629)))+(((IkReal(-1.00000000000000))*(r02)*(x12631)))+(((IkReal(-1.00000000000000))*(sj5)*(x12628)*(x12630)))+(((sj0)*(x12632)))+(((sj0)*(x12633)))))))+IKsqr(((((r12)*(x12631)))+(((IkReal(-1.00000000000000))*(x12630)*(x12634)))+(((IkReal(-1.00000000000000))*(x12628)*(x12633)))+(((IkReal(-1.00000000000000))*(x12629)*(x12634)))+(((IkReal(-1.00000000000000))*(x12628)*(x12632)))+(((r02)*(x12627)))))-1) <= IKFAST_SINCOS_THRESH )
    continue;
j3array[0]=IKatan2(((((IKabs(sj2) != 0)?((IkReal)1/(sj2)):(IkReal)1.0e30))*(((((r12)*(x12627)))+(((IkReal(-1.00000000000000))*(sj5)*(x12628)*(x12629)))+(((IkReal(-1.00000000000000))*(r02)*(x12631)))+(((IkReal(-1.00000000000000))*(sj5)*(x12628)*(x12630)))+(((sj0)*(x12632)))+(((sj0)*(x12633)))))), ((((r12)*(x12631)))+(((IkReal(-1.00000000000000))*(x12630)*(x12634)))+(((IkReal(-1.00000000000000))*(x12628)*(x12633)))+(((IkReal(-1.00000000000000))*(x12629)*(x12634)))+(((IkReal(-1.00000000000000))*(x12628)*(x12632)))+(((r02)*(x12627)))));
sj3array[0]=IKsin(j3array[0]);
cj3array[0]=IKcos(j3array[0]);
if( j3array[0] > IKPI )
{
    j3array[0]-=IK2PI;
}
else if( j3array[0] < -IKPI )
{    j3array[0]+=IK2PI;
}
j3valid[0] = true;
for(int ij3 = 0; ij3 < 1; ++ij3)
{
if( !j3valid[ij3] )
{
    continue;
}
_ij3[0] = ij3; _ij3[1] = -1;
for(int iij3 = ij3+1; iij3 < 1; ++iij3)
{
if( j3valid[iij3] && IKabs(cj3array[ij3]-cj3array[iij3]) < IKFAST_SOLUTION_THRESH && IKabs(sj3array[ij3]-sj3array[iij3]) < IKFAST_SOLUTION_THRESH )
{
    j3valid[iij3]=false; _ij3[1] = iij3; break; 
}
}
j3 = j3array[ij3]; cj3 = cj3array[ij3]; sj3 = sj3array[ij3];
{
IkReal evalcond[6];
IkReal x12635=IKsin(j3);
IkReal x12636=IKcos(j3);
IkReal x12637=((sj0)*(sj5));
IkReal x12638=((r00)*(sj6));
IkReal x12639=((IkReal(1.00000000000000))*(cj4));
IkReal x12640=((cj6)*(r01));
IkReal x12641=((cj0)*(cj5));
IkReal x12642=((cj5)*(sj0));
IkReal x12643=((cj6)*(r11));
IkReal x12644=((cj0)*(sj5));
IkReal x12645=((cj6)*(sj4));
IkReal x12646=((cj4)*(cj5));
IkReal x12647=((cj6)*(r21));
IkReal x12648=((r20)*(sj6));
IkReal x12649=((r10)*(sj6));
IkReal x12650=((IkReal(1.00000000000000))*(cj0));
IkReal x12651=((IkReal(1.00000000000000))*(x12635));
IkReal x12652=((cj0)*(sj4)*(sj6));
IkReal x12653=((sj0)*(sj4)*(sj6));
evalcond[0]=((((sj5)*(x12648)))+(((IkReal(-1.00000000000000))*(cj5)*(r22)))+(((IkReal(-1.00000000000000))*(cj2)*(x12651)))+(((sj5)*(x12647))));
evalcond[1]=((((IkReal(-1.00000000000000))*(r21)*(sj4)*(sj6)))+(((x12646)*(x12647)))+(((cj4)*(r22)*(sj5)))+(((x12646)*(x12648)))+(((cj2)*(x12636)))+(((r20)*(x12645))));
evalcond[2]=((((IkReal(-1.00000000000000))*(sj2)*(x12651)))+(((IkReal(-1.00000000000000))*(r02)*(x12642)))+(((x12637)*(x12640)))+(((x12637)*(x12638)))+(((r12)*(x12641)))+(((IkReal(-1.00000000000000))*(x12644)*(x12649)))+(((IkReal(-1.00000000000000))*(x12643)*(x12644))));
evalcond[3]=((((IkReal(-1.00000000000000))*(x12636)))+(((r02)*(x12641)))+(((r12)*(x12642)))+(((IkReal(-1.00000000000000))*(x12637)*(x12649)))+(((IkReal(-1.00000000000000))*(x12638)*(x12644)))+(((IkReal(-1.00000000000000))*(x12640)*(x12644)))+(((IkReal(-1.00000000000000))*(x12637)*(x12643))));
evalcond[4]=((((IkReal(-1.00000000000000))*(r01)*(x12653)))+(((sj2)*(x12636)))+(((cj4)*(r02)*(x12637)))+(((cj4)*(x12638)*(x12642)))+(((IkReal(-1.00000000000000))*(r12)*(x12639)*(x12644)))+(((r11)*(x12652)))+(((IkReal(-1.00000000000000))*(x12639)*(x12641)*(x12649)))+(((cj4)*(x12640)*(x12642)))+(((IkReal(-1.00000000000000))*(r10)*(x12645)*(x12650)))+(((IkReal(-1.00000000000000))*(x12639)*(x12641)*(x12643)))+(((r00)*(sj0)*(x12645))));
evalcond[5]=((((IkReal(-1.00000000000000))*(x12639)*(x12640)*(x12641)))+(((IkReal(-1.00000000000000))*(x12639)*(x12642)*(x12649)))+(((IkReal(-1.00000000000000))*(x12651)))+(((r01)*(x12652)))+(((IkReal(-1.00000000000000))*(x12638)*(x12639)*(x12641)))+(((IkReal(-1.00000000000000))*(r10)*(sj0)*(x12645)))+(((IkReal(-1.00000000000000))*(r00)*(x12645)*(x12650)))+(((IkReal(-1.00000000000000))*(r02)*(x12639)*(x12644)))+(((r11)*(x12653)))+(((IkReal(-1.00000000000000))*(r12)*(x12637)*(x12639)))+(((IkReal(-1.00000000000000))*(x12639)*(x12642)*(x12643))));
if( IKabs(evalcond[0]) > 0.000001  || IKabs(evalcond[1]) > 0.000001  || IKabs(evalcond[2]) > 0.000001  || IKabs(evalcond[3]) > 0.000001  || IKabs(evalcond[4]) > 0.000001  || IKabs(evalcond[5]) > 0.000001  )
{
continue;
}
}

{
std::vector<IkSingleDOFSolutionBase<IkReal> > vinfos(7);
vinfos[0].jointtype = 1;
vinfos[0].foffset = j0;
vinfos[0].indices[0] = _ij0[0];
vinfos[0].indices[1] = _ij0[1];
vinfos[0].maxsolutions = _nj0;
vinfos[1].jointtype = 1;
vinfos[1].foffset = j1;
vinfos[1].indices[0] = _ij1[0];
vinfos[1].indices[1] = _ij1[1];
vinfos[1].maxsolutions = _nj1;
vinfos[2].jointtype = 1;
vinfos[2].foffset = j2;
vinfos[2].indices[0] = _ij2[0];
vinfos[2].indices[1] = _ij2[1];
vinfos[2].maxsolutions = _nj2;
vinfos[3].jointtype = 1;
vinfos[3].foffset = j3;
vinfos[3].indices[0] = _ij3[0];
vinfos[3].indices[1] = _ij3[1];
vinfos[3].maxsolutions = _nj3;
vinfos[4].jointtype = 1;
vinfos[4].foffset = j4;
vinfos[4].indices[0] = _ij4[0];
vinfos[4].indices[1] = _ij4[1];
vinfos[4].maxsolutions = _nj4;
vinfos[5].jointtype = 1;
vinfos[5].foffset = j5;
vinfos[5].indices[0] = _ij5[0];
vinfos[5].indices[1] = _ij5[1];
vinfos[5].maxsolutions = _nj5;
vinfos[6].jointtype = 1;
vinfos[6].foffset = j6;
vinfos[6].indices[0] = _ij6[0];
vinfos[6].indices[1] = _ij6[1];
vinfos[6].maxsolutions = _nj6;
std::vector<int> vfree(0);
solutions.AddSolution(vinfos,vfree);
}
}
}

}

}

} else
{
{
IkReal j3array[1], cj3array[1], sj3array[1];
bool j3valid[1]={false};
_nj3 = 1;
IkReal x12654=((sj5)*(sj6));
IkReal x12655=((IkReal(1.00000000000000))*(cj6)*(sj5));
if( IKabs(((((IKabs(cj2) != 0)?((IkReal)1/(cj2)):(IkReal)1.0e30))*(((((cj6)*(r21)*(sj5)))+(((IkReal(-1.00000000000000))*(cj5)*(r22)))+(((r20)*(x12654))))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(((((cj0)*(cj5)*(r02)))+(((IkReal(-1.00000000000000))*(r10)*(sj0)*(x12654)))+(((cj5)*(r12)*(sj0)))+(((IkReal(-1.00000000000000))*(r11)*(sj0)*(x12655)))+(((IkReal(-1.00000000000000))*(cj0)*(r01)*(x12655)))+(((IkReal(-1.00000000000000))*(cj0)*(r00)*(x12654))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(IKsqr(((((IKabs(cj2) != 0)?((IkReal)1/(cj2)):(IkReal)1.0e30))*(((((cj6)*(r21)*(sj5)))+(((IkReal(-1.00000000000000))*(cj5)*(r22)))+(((r20)*(x12654)))))))+IKsqr(((((cj0)*(cj5)*(r02)))+(((IkReal(-1.00000000000000))*(r10)*(sj0)*(x12654)))+(((cj5)*(r12)*(sj0)))+(((IkReal(-1.00000000000000))*(r11)*(sj0)*(x12655)))+(((IkReal(-1.00000000000000))*(cj0)*(r01)*(x12655)))+(((IkReal(-1.00000000000000))*(cj0)*(r00)*(x12654)))))-1) <= IKFAST_SINCOS_THRESH )
    continue;
j3array[0]=IKatan2(((((IKabs(cj2) != 0)?((IkReal)1/(cj2)):(IkReal)1.0e30))*(((((cj6)*(r21)*(sj5)))+(((IkReal(-1.00000000000000))*(cj5)*(r22)))+(((r20)*(x12654)))))), ((((cj0)*(cj5)*(r02)))+(((IkReal(-1.00000000000000))*(r10)*(sj0)*(x12654)))+(((cj5)*(r12)*(sj0)))+(((IkReal(-1.00000000000000))*(r11)*(sj0)*(x12655)))+(((IkReal(-1.00000000000000))*(cj0)*(r01)*(x12655)))+(((IkReal(-1.00000000000000))*(cj0)*(r00)*(x12654)))));
sj3array[0]=IKsin(j3array[0]);
cj3array[0]=IKcos(j3array[0]);
if( j3array[0] > IKPI )
{
    j3array[0]-=IK2PI;
}
else if( j3array[0] < -IKPI )
{    j3array[0]+=IK2PI;
}
j3valid[0] = true;
for(int ij3 = 0; ij3 < 1; ++ij3)
{
if( !j3valid[ij3] )
{
    continue;
}
_ij3[0] = ij3; _ij3[1] = -1;
for(int iij3 = ij3+1; iij3 < 1; ++iij3)
{
if( j3valid[iij3] && IKabs(cj3array[ij3]-cj3array[iij3]) < IKFAST_SOLUTION_THRESH && IKabs(sj3array[ij3]-sj3array[iij3]) < IKFAST_SOLUTION_THRESH )
{
    j3valid[iij3]=false; _ij3[1] = iij3; break; 
}
}
j3 = j3array[ij3]; cj3 = cj3array[ij3]; sj3 = sj3array[ij3];
{
IkReal evalcond[6];
IkReal x12656=IKsin(j3);
IkReal x12657=IKcos(j3);
IkReal x12658=((sj0)*(sj5));
IkReal x12659=((r00)*(sj6));
IkReal x12660=((IkReal(1.00000000000000))*(cj4));
IkReal x12661=((cj6)*(r01));
IkReal x12662=((cj0)*(cj5));
IkReal x12663=((cj5)*(sj0));
IkReal x12664=((cj6)*(r11));
IkReal x12665=((cj0)*(sj5));
IkReal x12666=((cj6)*(sj4));
IkReal x12667=((cj4)*(cj5));
IkReal x12668=((cj6)*(r21));
IkReal x12669=((r20)*(sj6));
IkReal x12670=((r10)*(sj6));
IkReal x12671=((IkReal(1.00000000000000))*(cj0));
IkReal x12672=((IkReal(1.00000000000000))*(x12656));
IkReal x12673=((cj0)*(sj4)*(sj6));
IkReal x12674=((sj0)*(sj4)*(sj6));
evalcond[0]=((((IkReal(-1.00000000000000))*(cj2)*(x12672)))+(((sj5)*(x12669)))+(((IkReal(-1.00000000000000))*(cj5)*(r22)))+(((sj5)*(x12668))));
evalcond[1]=((((IkReal(-1.00000000000000))*(r21)*(sj4)*(sj6)))+(((cj2)*(x12657)))+(((x12667)*(x12668)))+(((cj4)*(r22)*(sj5)))+(((r20)*(x12666)))+(((x12667)*(x12669))));
evalcond[2]=((((x12658)*(x12661)))+(((IkReal(-1.00000000000000))*(x12664)*(x12665)))+(((x12658)*(x12659)))+(((IkReal(-1.00000000000000))*(sj2)*(x12672)))+(((r12)*(x12662)))+(((IkReal(-1.00000000000000))*(r02)*(x12663)))+(((IkReal(-1.00000000000000))*(x12665)*(x12670))));
evalcond[3]=((((r02)*(x12662)))+(((IkReal(-1.00000000000000))*(x12659)*(x12665)))+(((IkReal(-1.00000000000000))*(x12658)*(x12670)))+(((IkReal(-1.00000000000000))*(x12658)*(x12664)))+(((r12)*(x12663)))+(((IkReal(-1.00000000000000))*(x12661)*(x12665)))+(((IkReal(-1.00000000000000))*(x12657))));
evalcond[4]=((((sj2)*(x12657)))+(((cj4)*(r02)*(x12658)))+(((cj4)*(x12661)*(x12663)))+(((r11)*(x12673)))+(((cj4)*(x12659)*(x12663)))+(((IkReal(-1.00000000000000))*(r01)*(x12674)))+(((IkReal(-1.00000000000000))*(x12660)*(x12662)*(x12664)))+(((r00)*(sj0)*(x12666)))+(((IkReal(-1.00000000000000))*(r10)*(x12666)*(x12671)))+(((IkReal(-1.00000000000000))*(x12660)*(x12662)*(x12670)))+(((IkReal(-1.00000000000000))*(r12)*(x12660)*(x12665))));
evalcond[5]=((((IkReal(-1.00000000000000))*(x12672)))+(((IkReal(-1.00000000000000))*(r10)*(sj0)*(x12666)))+(((IkReal(-1.00000000000000))*(x12660)*(x12661)*(x12662)))+(((r11)*(x12674)))+(((IkReal(-1.00000000000000))*(x12660)*(x12663)*(x12664)))+(((IkReal(-1.00000000000000))*(r12)*(x12658)*(x12660)))+(((r01)*(x12673)))+(((IkReal(-1.00000000000000))*(r00)*(x12666)*(x12671)))+(((IkReal(-1.00000000000000))*(x12660)*(x12663)*(x12670)))+(((IkReal(-1.00000000000000))*(r02)*(x12660)*(x12665)))+(((IkReal(-1.00000000000000))*(x12659)*(x12660)*(x12662))));
if( IKabs(evalcond[0]) > 0.000001  || IKabs(evalcond[1]) > 0.000001  || IKabs(evalcond[2]) > 0.000001  || IKabs(evalcond[3]) > 0.000001  || IKabs(evalcond[4]) > 0.000001  || IKabs(evalcond[5]) > 0.000001  )
{
continue;
}
}

{
std::vector<IkSingleDOFSolutionBase<IkReal> > vinfos(7);
vinfos[0].jointtype = 1;
vinfos[0].foffset = j0;
vinfos[0].indices[0] = _ij0[0];
vinfos[0].indices[1] = _ij0[1];
vinfos[0].maxsolutions = _nj0;
vinfos[1].jointtype = 1;
vinfos[1].foffset = j1;
vinfos[1].indices[0] = _ij1[0];
vinfos[1].indices[1] = _ij1[1];
vinfos[1].maxsolutions = _nj1;
vinfos[2].jointtype = 1;
vinfos[2].foffset = j2;
vinfos[2].indices[0] = _ij2[0];
vinfos[2].indices[1] = _ij2[1];
vinfos[2].maxsolutions = _nj2;
vinfos[3].jointtype = 1;
vinfos[3].foffset = j3;
vinfos[3].indices[0] = _ij3[0];
vinfos[3].indices[1] = _ij3[1];
vinfos[3].maxsolutions = _nj3;
vinfos[4].jointtype = 1;
vinfos[4].foffset = j4;
vinfos[4].indices[0] = _ij4[0];
vinfos[4].indices[1] = _ij4[1];
vinfos[4].maxsolutions = _nj4;
vinfos[5].jointtype = 1;
vinfos[5].foffset = j5;
vinfos[5].indices[0] = _ij5[0];
vinfos[5].indices[1] = _ij5[1];
vinfos[5].maxsolutions = _nj5;
vinfos[6].jointtype = 1;
vinfos[6].foffset = j6;
vinfos[6].indices[0] = _ij6[0];
vinfos[6].indices[1] = _ij6[1];
vinfos[6].maxsolutions = _nj6;
std::vector<int> vfree(0);
solutions.AddSolution(vinfos,vfree);
}
}
}

}

}

} else
{
{
IkReal j3array[1], cj3array[1], sj3array[1];
bool j3valid[1]={false};
_nj3 = 1;
IkReal x12675=((IkReal(1.00000000000000))*(cj4));
IkReal x12676=((cj6)*(r21));
IkReal x12677=((r20)*(sj6));
if( IKabs(((gconst9)*(((((IkReal(-1.00000000000000))*(cj5)*(r22)))+(((sj5)*(x12677)))+(((sj5)*(x12676))))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(((gconst9)*(((((IkReal(-1.00000000000000))*(cj5)*(x12675)*(x12677)))+(((r21)*(sj4)*(sj6)))+(((IkReal(-1.00000000000000))*(cj5)*(x12675)*(x12676)))+(((IkReal(-1.00000000000000))*(r22)*(sj5)*(x12675)))+(((IkReal(-1.00000000000000))*(cj6)*(r20)*(sj4))))))) < IKFAST_ATAN2_MAGTHRESH )
    continue;
j3array[0]=IKatan2(((gconst9)*(((((IkReal(-1.00000000000000))*(cj5)*(r22)))+(((sj5)*(x12677)))+(((sj5)*(x12676)))))), ((gconst9)*(((((IkReal(-1.00000000000000))*(cj5)*(x12675)*(x12677)))+(((r21)*(sj4)*(sj6)))+(((IkReal(-1.00000000000000))*(cj5)*(x12675)*(x12676)))+(((IkReal(-1.00000000000000))*(r22)*(sj5)*(x12675)))+(((IkReal(-1.00000000000000))*(cj6)*(r20)*(sj4)))))));
sj3array[0]=IKsin(j3array[0]);
cj3array[0]=IKcos(j3array[0]);
if( j3array[0] > IKPI )
{
    j3array[0]-=IK2PI;
}
else if( j3array[0] < -IKPI )
{    j3array[0]+=IK2PI;
}
j3valid[0] = true;
for(int ij3 = 0; ij3 < 1; ++ij3)
{
if( !j3valid[ij3] )
{
    continue;
}
_ij3[0] = ij3; _ij3[1] = -1;
for(int iij3 = ij3+1; iij3 < 1; ++iij3)
{
if( j3valid[iij3] && IKabs(cj3array[ij3]-cj3array[iij3]) < IKFAST_SOLUTION_THRESH && IKabs(sj3array[ij3]-sj3array[iij3]) < IKFAST_SOLUTION_THRESH )
{
    j3valid[iij3]=false; _ij3[1] = iij3; break; 
}
}
j3 = j3array[ij3]; cj3 = cj3array[ij3]; sj3 = sj3array[ij3];
{
IkReal evalcond[6];
IkReal x12678=IKsin(j3);
IkReal x12679=IKcos(j3);
IkReal x12680=((sj0)*(sj5));
IkReal x12681=((r00)*(sj6));
IkReal x12682=((IkReal(1.00000000000000))*(cj4));
IkReal x12683=((cj6)*(r01));
IkReal x12684=((cj0)*(cj5));
IkReal x12685=((cj5)*(sj0));
IkReal x12686=((cj6)*(r11));
IkReal x12687=((cj0)*(sj5));
IkReal x12688=((cj6)*(sj4));
IkReal x12689=((cj4)*(cj5));
IkReal x12690=((cj6)*(r21));
IkReal x12691=((r20)*(sj6));
IkReal x12692=((r10)*(sj6));
IkReal x12693=((IkReal(1.00000000000000))*(cj0));
IkReal x12694=((IkReal(1.00000000000000))*(x12678));
IkReal x12695=((cj0)*(sj4)*(sj6));
IkReal x12696=((sj0)*(sj4)*(sj6));
evalcond[0]=((((sj5)*(x12691)))+(((sj5)*(x12690)))+(((IkReal(-1.00000000000000))*(cj5)*(r22)))+(((IkReal(-1.00000000000000))*(cj2)*(x12694))));
evalcond[1]=((((IkReal(-1.00000000000000))*(r21)*(sj4)*(sj6)))+(((cj4)*(r22)*(sj5)))+(((x12689)*(x12690)))+(((x12689)*(x12691)))+(((cj2)*(x12679)))+(((r20)*(x12688))));
evalcond[2]=((((IkReal(-1.00000000000000))*(sj2)*(x12694)))+(((x12680)*(x12683)))+(((r12)*(x12684)))+(((x12680)*(x12681)))+(((IkReal(-1.00000000000000))*(x12686)*(x12687)))+(((IkReal(-1.00000000000000))*(r02)*(x12685)))+(((IkReal(-1.00000000000000))*(x12687)*(x12692))));
evalcond[3]=((((IkReal(-1.00000000000000))*(x12679)))+(((r12)*(x12685)))+(((r02)*(x12684)))+(((IkReal(-1.00000000000000))*(x12680)*(x12692)))+(((IkReal(-1.00000000000000))*(x12681)*(x12687)))+(((IkReal(-1.00000000000000))*(x12680)*(x12686)))+(((IkReal(-1.00000000000000))*(x12683)*(x12687))));
evalcond[4]=((((IkReal(-1.00000000000000))*(x12682)*(x12684)*(x12692)))+(((cj4)*(x12683)*(x12685)))+(((r00)*(sj0)*(x12688)))+(((r11)*(x12695)))+(((cj4)*(x12681)*(x12685)))+(((cj4)*(r02)*(x12680)))+(((sj2)*(x12679)))+(((IkReal(-1.00000000000000))*(r10)*(x12688)*(x12693)))+(((IkReal(-1.00000000000000))*(r01)*(x12696)))+(((IkReal(-1.00000000000000))*(r12)*(x12682)*(x12687)))+(((IkReal(-1.00000000000000))*(x12682)*(x12684)*(x12686))));
evalcond[5]=((((IkReal(-1.00000000000000))*(x12681)*(x12682)*(x12684)))+(((IkReal(-1.00000000000000))*(x12682)*(x12685)*(x12692)))+(((r01)*(x12695)))+(((IkReal(-1.00000000000000))*(r10)*(sj0)*(x12688)))+(((IkReal(-1.00000000000000))*(x12682)*(x12685)*(x12686)))+(((IkReal(-1.00000000000000))*(r12)*(x12680)*(x12682)))+(((r11)*(x12696)))+(((IkReal(-1.00000000000000))*(r02)*(x12682)*(x12687)))+(((IkReal(-1.00000000000000))*(x12694)))+(((IkReal(-1.00000000000000))*(x12682)*(x12683)*(x12684)))+(((IkReal(-1.00000000000000))*(r00)*(x12688)*(x12693))));
if( IKabs(evalcond[0]) > 0.000001  || IKabs(evalcond[1]) > 0.000001  || IKabs(evalcond[2]) > 0.000001  || IKabs(evalcond[3]) > 0.000001  || IKabs(evalcond[4]) > 0.000001  || IKabs(evalcond[5]) > 0.000001  )
{
continue;
}
}

{
std::vector<IkSingleDOFSolutionBase<IkReal> > vinfos(7);
vinfos[0].jointtype = 1;
vinfos[0].foffset = j0;
vinfos[0].indices[0] = _ij0[0];
vinfos[0].indices[1] = _ij0[1];
vinfos[0].maxsolutions = _nj0;
vinfos[1].jointtype = 1;
vinfos[1].foffset = j1;
vinfos[1].indices[0] = _ij1[0];
vinfos[1].indices[1] = _ij1[1];
vinfos[1].maxsolutions = _nj1;
vinfos[2].jointtype = 1;
vinfos[2].foffset = j2;
vinfos[2].indices[0] = _ij2[0];
vinfos[2].indices[1] = _ij2[1];
vinfos[2].maxsolutions = _nj2;
vinfos[3].jointtype = 1;
vinfos[3].foffset = j3;
vinfos[3].indices[0] = _ij3[0];
vinfos[3].indices[1] = _ij3[1];
vinfos[3].maxsolutions = _nj3;
vinfos[4].jointtype = 1;
vinfos[4].foffset = j4;
vinfos[4].indices[0] = _ij4[0];
vinfos[4].indices[1] = _ij4[1];
vinfos[4].maxsolutions = _nj4;
vinfos[5].jointtype = 1;
vinfos[5].foffset = j5;
vinfos[5].indices[0] = _ij5[0];
vinfos[5].indices[1] = _ij5[1];
vinfos[5].maxsolutions = _nj5;
vinfos[6].jointtype = 1;
vinfos[6].foffset = j6;
vinfos[6].indices[0] = _ij6[0];
vinfos[6].indices[1] = _ij6[1];
vinfos[6].maxsolutions = _nj6;
std::vector<int> vfree(0);
solutions.AddSolution(vinfos,vfree);
}
}
}

}

}

} else
{
IkReal x12697=((IkReal(1.00000000000000))*(cj0));
IkReal x12698=((cj4)*(sj6));
IkReal x12699=((sj0)*(sj4));
IkReal x12700=((cj5)*(sj6));
IkReal x12701=((sj4)*(sj5));
IkReal x12702=((r12)*(sj5));
IkReal x12703=((IkReal(0.374290000000000))*(cj5));
IkReal x12704=((r02)*(sj0));
IkReal x12705=((IkReal(1.00000000000000))*(sj0));
IkReal x12706=((cj0)*(r10));
IkReal x12707=((cj4)*(cj6));
IkReal x12708=((r00)*(sj0));
IkReal x12709=((cj6)*(r21));
IkReal x12710=((IkReal(0.374290000000000))*(sj5));
IkReal x12711=((cj0)*(r00));
IkReal x12712=((IkReal(0.0100000000000000))*(sj5));
IkReal x12713=((cj0)*(r02));
IkReal x12714=((cj5)*(sj4));
IkReal x12715=((cj6)*(r01));
IkReal x12716=((cj6)*(r11));
IkReal x12717=((r01)*(sj0));
IkReal x12718=((r10)*(sj0));
IkReal x12719=((IkReal(0.0100000000000000))*(cj5)*(cj6));
IkReal x12720=((sj6)*(x12710));
IkReal x12721=((cj0)*(cj6)*(x12710));
evalcond[0]=((IkReal(-3.14159265358979))+(IKfmod(j1, IkReal(6.28318530717959))));
evalcond[1]=((sj2)+(((IkReal(-1.00000000000000))*(r20)*(x12707)))+(((r22)*(x12701)))+(((x12709)*(x12714)))+(((r21)*(x12698)))+(((r20)*(sj4)*(x12700))));
evalcond[2]=((((r20)*(x12720)))+(((IkReal(-1.00000000000000))*(r22)*(x12712)))+(((IkReal(-0.0100000000000000))*(r20)*(x12700)))+(((IkReal(-0.0690000000000000))*(cj2)))+(((IkReal(-0.0100000000000000))*(cj5)*(x12709)))+(((IkReal(-1.00000000000000))*(r22)*(x12703)))+(pz)+(((x12709)*(x12710))));
evalcond[3]=((((IkReal(-1.00000000000000))*(r11)*(x12697)*(x12698)))+(((x12698)*(x12717)))+(((IkReal(-1.00000000000000))*(r12)*(x12697)*(x12701)))+(((IkReal(-1.00000000000000))*(r10)*(sj4)*(x12697)*(x12700)))+(((x12706)*(x12707)))+(((IkReal(-1.00000000000000))*(r00)*(x12705)*(x12707)))+(((r00)*(x12699)*(x12700)))+(((IkReal(-1.00000000000000))*(x12697)*(x12714)*(x12716)))+(cj2)+(((r02)*(sj5)*(x12699)))+(((cj5)*(x12699)*(x12715))));
evalcond[4]=((((x12707)*(x12711)))+(((IkReal(-1.00000000000000))*(r00)*(sj4)*(x12697)*(x12700)))+(((IkReal(-1.00000000000000))*(x12699)*(x12702)))+(((x12707)*(x12718)))+(((IkReal(-1.00000000000000))*(r02)*(x12697)*(x12701)))+(((IkReal(-1.00000000000000))*(cj5)*(x12699)*(x12716)))+(((IkReal(-1.00000000000000))*(r01)*(x12697)*(x12698)))+(((IkReal(-1.00000000000000))*(r11)*(x12698)*(x12705)))+(((IkReal(-1.00000000000000))*(x12697)*(x12714)*(x12715)))+(((IkReal(-1.00000000000000))*(r10)*(x12699)*(x12700))));
evalcond[5]=((((IkReal(-1.00000000000000))*(py)*(x12697)))+(((IkReal(-1.00000000000000))*(x12706)*(x12720)))+(((IkReal(-1.00000000000000))*(cj0)*(x12710)*(x12716)))+(((IkReal(-1.00000000000000))*(x12704)*(x12712)))+(((x12708)*(x12720)))+(((IkReal(0.0100000000000000))*(x12700)*(x12706)))+(((sj0)*(x12710)*(x12715)))+(((IkReal(0.0690000000000000))*(sj2)))+(((IkReal(0.0100000000000000))*(cj0)*(x12702)))+(((IkReal(0.0100000000000000))*(cj0)*(cj5)*(x12716)))+(((cj0)*(r12)*(x12703)))+(((IkReal(-1.00000000000000))*(x12703)*(x12704)))+(((px)*(sj0)))+(((IkReal(-0.0100000000000000))*(x12700)*(x12708)))+(((IkReal(-0.0100000000000000))*(cj5)*(sj0)*(x12715))));
evalcond[6]=((IkReal(-0.295420000000000))+(((IkReal(0.0100000000000000))*(x12700)*(x12718)))+(((x12712)*(x12713)))+(((IkReal(0.0100000000000000))*(cj0)*(cj5)*(x12715)))+(((IkReal(0.0100000000000000))*(sj0)*(x12702)))+(((r12)*(sj0)*(x12703)))+(((IkReal(-1.00000000000000))*(x12711)*(x12720)))+(((IkReal(-1.00000000000000))*(sj0)*(x12710)*(x12716)))+(((x12703)*(x12713)))+(((IkReal(-1.00000000000000))*(x12718)*(x12720)))+(((IkReal(0.0100000000000000))*(cj5)*(sj0)*(x12716)))+(((IkReal(-1.00000000000000))*(cj0)*(x12710)*(x12715)))+(((IkReal(-1.00000000000000))*(px)*(x12697)))+(((IkReal(0.0100000000000000))*(x12700)*(x12711)))+(((IkReal(-1.00000000000000))*(py)*(x12705))));
if( IKabs(evalcond[0]) < 0.0000010000000000  && IKabs(evalcond[1]) < 0.0000010000000000  && IKabs(evalcond[2]) < 0.0000010000000000  && IKabs(evalcond[3]) < 0.0000010000000000  && IKabs(evalcond[4]) < 0.0000010000000000  && IKabs(evalcond[5]) < 0.0000010000000000  && IKabs(evalcond[6]) < 0.0000010000000000  )
{
{
IkReal dummyeval[1];
IkReal gconst10;
gconst10=IKsign(cj2);
dummyeval[0]=cj2;
if( IKabs(dummyeval[0]) < 0.0000010000000000  )
{
{
IkReal dummyeval[1];
dummyeval[0]=cj2;
if( IKabs(dummyeval[0]) < 0.0000010000000000  )
{
{
IkReal dummyeval[1];
dummyeval[0]=sj2;
if( IKabs(dummyeval[0]) < 0.0000010000000000  )
{
{
IkReal evalcond[9];
IkReal x12722=((cj5)*(sj4));
IkReal x12723=((IkReal(1.00000000000000))*(sj6));
IkReal x12724=((r10)*(sj0));
IkReal x12725=((sj4)*(sj5));
IkReal x12726=((cj5)*(cj6));
IkReal x12727=((r01)*(sj0));
IkReal x12728=((IkReal(1.00000000000000))*(r02));
IkReal x12729=((IkReal(0.374290000000000))*(cj0));
IkReal x12730=((cj5)*(r12));
IkReal x12731=((cj6)*(sj5));
IkReal x12732=((cj0)*(r11));
IkReal x12733=((cj5)*(sj0));
IkReal x12734=((r20)*(sj6));
IkReal x12735=((IkReal(1.00000000000000))*(sj0));
IkReal x12736=((cj4)*(cj5));
IkReal x12737=((IkReal(1.00000000000000))*(cj6));
IkReal x12738=((IkReal(0.0100000000000000))*(sj5));
IkReal x12739=((sj5)*(sj6));
IkReal x12740=((cj0)*(r10));
IkReal x12741=((cj4)*(cj6));
IkReal x12742=((cj0)*(r01));
IkReal x12743=((IkReal(1.00000000000000))*(cj4));
IkReal x12744=((cj0)*(r00));
IkReal x12745=((IkReal(0.374290000000000))*(sj0));
IkReal x12746=((cj0)*(r12));
IkReal x12747=((IkReal(0.374290000000000))*(sj5));
IkReal x12748=((cj4)*(sj6));
IkReal x12749=((IkReal(1.00000000000000))*(cj0));
IkReal x12750=((r02)*(sj0));
IkReal x12751=((IkReal(0.0100000000000000))*(cj5));
IkReal x12752=((r11)*(sj0));
IkReal x12753=((r00)*(sj0)*(sj6));
IkReal x12754=((r00)*(x12741));
IkReal x12755=((sj6)*(x12751));
evalcond[0]=((IkReal(-3.14159265358979))+(IKfmod(((IkReal(3.14159265358979))+(j2)), IkReal(6.28318530717959))));
evalcond[1]=((((r22)*(x12725)))+(((cj6)*(r21)*(x12722)))+(((r21)*(x12748)))+(((x12722)*(x12734)))+(((IkReal(-1.00000000000000))*(cj4)*(r20)*(x12737))));
evalcond[2]=((IkReal(-0.0690000000000000))+(((IkReal(-1.00000000000000))*(x12734)*(x12751)))+(((IkReal(-0.374290000000000))*(cj5)*(r22)))+(((x12734)*(x12747)))+(((IkReal(0.374290000000000))*(r21)*(x12731)))+(pz)+(((IkReal(-1.00000000000000))*(r22)*(x12738)))+(((IkReal(-0.0100000000000000))*(r21)*(x12726))));
evalcond[3]=((((IkReal(-1.00000000000000))*(x12731)*(x12732)))+(((x12727)*(x12731)))+(((r00)*(sj0)*(x12739)))+(((IkReal(-1.00000000000000))*(sj5)*(x12723)*(x12740)))+(((IkReal(-1.00000000000000))*(x12728)*(x12733)))+(((cj0)*(x12730))));
evalcond[4]=((IkReal(1.00000000000000))+(((IkReal(-1.00000000000000))*(x12725)*(x12746)))+(((cj6)*(x12722)*(x12727)))+(((IkReal(-1.00000000000000))*(x12722)*(x12732)*(x12737)))+(((IkReal(-1.00000000000000))*(x12722)*(x12723)*(x12740)))+(((x12725)*(x12750)))+(((x12740)*(x12741)))+(((IkReal(-1.00000000000000))*(x12735)*(x12754)))+(((x12722)*(x12753)))+(((x12727)*(x12748)))+(((IkReal(-1.00000000000000))*(cj4)*(x12723)*(x12732))));
evalcond[5]=((((IkReal(-1.00000000000000))*(sj4)*(x12723)*(x12727)))+(((IkReal(-1.00000000000000))*(sj5)*(x12743)*(x12746)))+(((cj4)*(x12726)*(x12727)))+(((cj4)*(sj5)*(x12750)))+(((IkReal(-1.00000000000000))*(sj4)*(x12737)*(x12740)))+(((cj6)*(r00)*(sj0)*(sj4)))+(((r00)*(x12733)*(x12748)))+(((sj4)*(sj6)*(x12732)))+(((IkReal(-1.00000000000000))*(x12726)*(x12732)*(x12743)))+(((IkReal(-1.00000000000000))*(x12723)*(x12736)*(x12740))));
evalcond[6]=((((IkReal(-1.00000000000000))*(cj4)*(x12723)*(x12752)))+(((IkReal(-1.00000000000000))*(cj6)*(r11)*(x12722)*(x12735)))+(((IkReal(-1.00000000000000))*(r12)*(x12725)*(x12735)))+(((IkReal(-1.00000000000000))*(x12722)*(x12723)*(x12724)))+(((IkReal(-1.00000000000000))*(cj0)*(x12725)*(x12728)))+(((IkReal(-1.00000000000000))*(x12722)*(x12723)*(x12744)))+(((x12741)*(x12744)))+(((IkReal(-1.00000000000000))*(cj4)*(x12723)*(x12742)))+(((x12724)*(x12741)))+(((IkReal(-1.00000000000000))*(x12722)*(x12737)*(x12742))));
evalcond[7]=((((IkReal(-1.00000000000000))*(x12738)*(x12750)))+(((IkReal(-1.00000000000000))*(r11)*(x12729)*(x12731)))+(((x12740)*(x12755)))+(((IkReal(-0.0100000000000000))*(r00)*(sj6)*(x12733)))+(((IkReal(-1.00000000000000))*(py)*(x12749)))+(((IkReal(-0.374290000000000))*(r02)*(x12733)))+(((IkReal(0.374290000000000))*(x12727)*(x12731)))+(((IkReal(0.0100000000000000))*(x12726)*(x12732)))+(((r00)*(x12739)*(x12745)))+(((IkReal(-1.00000000000000))*(r10)*(x12729)*(x12739)))+(((IkReal(-0.0100000000000000))*(x12726)*(x12727)))+(((x12729)*(x12730)))+(((x12738)*(x12746)))+(((px)*(sj0))));
evalcond[8]=((IkReal(-0.295420000000000))+(((cj5)*(r02)*(x12729)))+(((IkReal(-0.374290000000000))*(x12724)*(x12739)))+(((IkReal(-1.00000000000000))*(r11)*(x12731)*(x12745)))+(((r12)*(sj0)*(x12738)))+(((cj0)*(r02)*(x12738)))+(((IkReal(-1.00000000000000))*(r00)*(x12729)*(x12739)))+(((IkReal(0.0100000000000000))*(x12726)*(x12742)))+(((IkReal(-1.00000000000000))*(px)*(x12749)))+(((IkReal(-1.00000000000000))*(r01)*(x12729)*(x12731)))+(((IkReal(-1.00000000000000))*(py)*(x12735)))+(((x12744)*(x12755)))+(((x12724)*(x12755)))+(((x12730)*(x12745)))+(((IkReal(0.0100000000000000))*(x12726)*(x12752))));
if( IKabs(evalcond[0]) < 0.0000010000000000  && IKabs(evalcond[1]) < 0.0000010000000000  && IKabs(evalcond[2]) < 0.0000010000000000  && IKabs(evalcond[3]) < 0.0000010000000000  && IKabs(evalcond[4]) < 0.0000010000000000  && IKabs(evalcond[5]) < 0.0000010000000000  && IKabs(evalcond[6]) < 0.0000010000000000  && IKabs(evalcond[7]) < 0.0000010000000000  && IKabs(evalcond[8]) < 0.0000010000000000  )
{
{
IkReal j3array[1], cj3array[1], sj3array[1];
bool j3valid[1]={false};
_nj3 = 1;
IkReal x12756=((IkReal(1.00000000000000))*(r21));
IkReal x12757=((cj4)*(cj5));
IkReal x12758=((r20)*(sj6));
if( IKabs(((((IkReal(-1.00000000000000))*(sj5)*(x12758)))+(((cj5)*(r22)))+(((IkReal(-1.00000000000000))*(cj6)*(sj5)*(x12756))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(((((cj6)*(r20)*(sj4)))+(((cj4)*(r22)*(sj5)))+(((cj6)*(r21)*(x12757)))+(((x12757)*(x12758)))+(((IkReal(-1.00000000000000))*(sj4)*(sj6)*(x12756))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(IKsqr(((((IkReal(-1.00000000000000))*(sj5)*(x12758)))+(((cj5)*(r22)))+(((IkReal(-1.00000000000000))*(cj6)*(sj5)*(x12756)))))+IKsqr(((((cj6)*(r20)*(sj4)))+(((cj4)*(r22)*(sj5)))+(((cj6)*(r21)*(x12757)))+(((x12757)*(x12758)))+(((IkReal(-1.00000000000000))*(sj4)*(sj6)*(x12756)))))-1) <= IKFAST_SINCOS_THRESH )
    continue;
j3array[0]=IKatan2(((((IkReal(-1.00000000000000))*(sj5)*(x12758)))+(((cj5)*(r22)))+(((IkReal(-1.00000000000000))*(cj6)*(sj5)*(x12756)))), ((((cj6)*(r20)*(sj4)))+(((cj4)*(r22)*(sj5)))+(((cj6)*(r21)*(x12757)))+(((x12757)*(x12758)))+(((IkReal(-1.00000000000000))*(sj4)*(sj6)*(x12756)))));
sj3array[0]=IKsin(j3array[0]);
cj3array[0]=IKcos(j3array[0]);
if( j3array[0] > IKPI )
{
    j3array[0]-=IK2PI;
}
else if( j3array[0] < -IKPI )
{    j3array[0]+=IK2PI;
}
j3valid[0] = true;
for(int ij3 = 0; ij3 < 1; ++ij3)
{
if( !j3valid[ij3] )
{
    continue;
}
_ij3[0] = ij3; _ij3[1] = -1;
for(int iij3 = ij3+1; iij3 < 1; ++iij3)
{
if( j3valid[iij3] && IKabs(cj3array[ij3]-cj3array[iij3]) < IKFAST_SOLUTION_THRESH && IKabs(sj3array[ij3]-sj3array[iij3]) < IKFAST_SOLUTION_THRESH )
{
    j3valid[iij3]=false; _ij3[1] = iij3; break; 
}
}
j3 = j3array[ij3]; cj3 = cj3array[ij3]; sj3 = sj3array[ij3];
{
IkReal evalcond[4];
IkReal x12759=IKcos(j3);
IkReal x12760=IKsin(j3);
IkReal x12761=((IkReal(1.00000000000000))*(cj4));
IkReal x12762=((sj0)*(sj5));
IkReal x12763=((cj0)*(cj5));
IkReal x12764=((cj6)*(r01));
IkReal x12765=((r00)*(sj6));
IkReal x12766=((cj6)*(r11));
IkReal x12767=((cj5)*(sj0));
IkReal x12768=((cj6)*(sj4));
IkReal x12769=((sj4)*(sj6));
IkReal x12770=((cj4)*(cj5));
IkReal x12771=((cj6)*(r21));
IkReal x12772=((r20)*(sj6));
IkReal x12773=((r10)*(sj6));
IkReal x12774=((IkReal(1.00000000000000))*(cj0)*(sj5));
evalcond[0]=((x12760)+(((IkReal(-1.00000000000000))*(cj5)*(r22)))+(((sj5)*(x12771)))+(((sj5)*(x12772))));
evalcond[1]=((((r20)*(x12768)))+(((x12770)*(x12772)))+(((x12770)*(x12771)))+(((cj4)*(r22)*(sj5)))+(((IkReal(-1.00000000000000))*(r21)*(x12769)))+(((IkReal(-1.00000000000000))*(x12759))));
evalcond[2]=((((IkReal(-1.00000000000000))*(x12762)*(x12766)))+(((r02)*(x12763)))+(((r12)*(x12767)))+(((IkReal(-1.00000000000000))*(x12765)*(x12774)))+(((IkReal(-1.00000000000000))*(x12762)*(x12773)))+(((IkReal(-1.00000000000000))*(x12764)*(x12774)))+(x12759));
evalcond[3]=((((IkReal(-1.00000000000000))*(x12761)*(x12763)*(x12765)))+(((IkReal(-1.00000000000000))*(r10)*(sj0)*(x12768)))+(((IkReal(-1.00000000000000))*(cj0)*(r00)*(x12768)))+(((IkReal(-1.00000000000000))*(x12761)*(x12763)*(x12764)))+(x12760)+(((IkReal(-1.00000000000000))*(x12761)*(x12766)*(x12767)))+(((IkReal(-1.00000000000000))*(cj0)*(r02)*(sj5)*(x12761)))+(((IkReal(-1.00000000000000))*(x12761)*(x12767)*(x12773)))+(((cj0)*(r01)*(x12769)))+(((IkReal(-1.00000000000000))*(r12)*(x12761)*(x12762)))+(((r11)*(sj0)*(x12769))));
if( IKabs(evalcond[0]) > 0.000001  || IKabs(evalcond[1]) > 0.000001  || IKabs(evalcond[2]) > 0.000001  || IKabs(evalcond[3]) > 0.000001  )
{
continue;
}
}

{
std::vector<IkSingleDOFSolutionBase<IkReal> > vinfos(7);
vinfos[0].jointtype = 1;
vinfos[0].foffset = j0;
vinfos[0].indices[0] = _ij0[0];
vinfos[0].indices[1] = _ij0[1];
vinfos[0].maxsolutions = _nj0;
vinfos[1].jointtype = 1;
vinfos[1].foffset = j1;
vinfos[1].indices[0] = _ij1[0];
vinfos[1].indices[1] = _ij1[1];
vinfos[1].maxsolutions = _nj1;
vinfos[2].jointtype = 1;
vinfos[2].foffset = j2;
vinfos[2].indices[0] = _ij2[0];
vinfos[2].indices[1] = _ij2[1];
vinfos[2].maxsolutions = _nj2;
vinfos[3].jointtype = 1;
vinfos[3].foffset = j3;
vinfos[3].indices[0] = _ij3[0];
vinfos[3].indices[1] = _ij3[1];
vinfos[3].maxsolutions = _nj3;
vinfos[4].jointtype = 1;
vinfos[4].foffset = j4;
vinfos[4].indices[0] = _ij4[0];
vinfos[4].indices[1] = _ij4[1];
vinfos[4].maxsolutions = _nj4;
vinfos[5].jointtype = 1;
vinfos[5].foffset = j5;
vinfos[5].indices[0] = _ij5[0];
vinfos[5].indices[1] = _ij5[1];
vinfos[5].maxsolutions = _nj5;
vinfos[6].jointtype = 1;
vinfos[6].foffset = j6;
vinfos[6].indices[0] = _ij6[0];
vinfos[6].indices[1] = _ij6[1];
vinfos[6].maxsolutions = _nj6;
std::vector<int> vfree(0);
solutions.AddSolution(vinfos,vfree);
}
}
}

} else
{
IkReal x12775=((cj5)*(sj4));
IkReal x12776=((IkReal(1.00000000000000))*(sj6));
IkReal x12777=((r10)*(sj0));
IkReal x12778=((sj4)*(sj5));
IkReal x12779=((cj5)*(cj6));
IkReal x12780=((r01)*(sj0));
IkReal x12781=((IkReal(1.00000000000000))*(r02));
IkReal x12782=((IkReal(0.374290000000000))*(cj0));
IkReal x12783=((cj5)*(r12));
IkReal x12784=((cj6)*(sj5));
IkReal x12785=((cj0)*(r11));
IkReal x12786=((cj5)*(sj0));
IkReal x12787=((r20)*(sj6));
IkReal x12788=((IkReal(1.00000000000000))*(sj0));
IkReal x12789=((cj4)*(cj5));
IkReal x12790=((IkReal(1.00000000000000))*(cj6));
IkReal x12791=((IkReal(0.0100000000000000))*(sj5));
IkReal x12792=((sj5)*(sj6));
IkReal x12793=((cj0)*(r10));
IkReal x12794=((cj4)*(cj6));
IkReal x12795=((cj0)*(r01));
IkReal x12796=((IkReal(1.00000000000000))*(cj4));
IkReal x12797=((cj0)*(r00));
IkReal x12798=((IkReal(0.374290000000000))*(sj0));
IkReal x12799=((cj0)*(r12));
IkReal x12800=((IkReal(0.374290000000000))*(sj5));
IkReal x12801=((cj4)*(sj6));
IkReal x12802=((IkReal(1.00000000000000))*(cj0));
IkReal x12803=((r02)*(sj0));
IkReal x12804=((IkReal(0.0100000000000000))*(cj5));
IkReal x12805=((r11)*(sj0));
IkReal x12806=((r00)*(sj0)*(sj6));
IkReal x12807=((r00)*(x12794));
IkReal x12808=((sj6)*(x12804));
evalcond[0]=((IkReal(-3.14159265358979))+(IKfmod(j2, IkReal(6.28318530717959))));
evalcond[1]=((((x12775)*(x12787)))+(((IkReal(-1.00000000000000))*(cj4)*(r20)*(x12790)))+(((r21)*(x12801)))+(((r22)*(x12778)))+(((cj6)*(r21)*(x12775))));
evalcond[2]=((IkReal(0.0690000000000000))+(((IkReal(-1.00000000000000))*(x12787)*(x12804)))+(((x12787)*(x12800)))+(((IkReal(0.374290000000000))*(r21)*(x12784)))+(((IkReal(-1.00000000000000))*(r22)*(x12791)))+(((IkReal(-0.374290000000000))*(cj5)*(r22)))+(pz)+(((IkReal(-0.0100000000000000))*(r21)*(x12779))));
evalcond[3]=((((IkReal(-1.00000000000000))*(sj5)*(x12776)*(x12793)))+(((IkReal(-1.00000000000000))*(x12784)*(x12785)))+(((r00)*(sj0)*(x12792)))+(((IkReal(-1.00000000000000))*(x12781)*(x12786)))+(((x12780)*(x12784)))+(((cj0)*(x12783))));
evalcond[4]=((IkReal(-1.00000000000000))+(((IkReal(-1.00000000000000))*(x12788)*(x12807)))+(((x12778)*(x12803)))+(((IkReal(-1.00000000000000))*(cj4)*(x12776)*(x12785)))+(((IkReal(-1.00000000000000))*(x12775)*(x12776)*(x12793)))+(((x12780)*(x12801)))+(((IkReal(-1.00000000000000))*(x12778)*(x12799)))+(((x12775)*(x12806)))+(((cj6)*(x12775)*(x12780)))+(((x12793)*(x12794)))+(((IkReal(-1.00000000000000))*(x12775)*(x12785)*(x12790))));
evalcond[5]=((((IkReal(-1.00000000000000))*(sj4)*(x12776)*(x12780)))+(((IkReal(-1.00000000000000))*(x12776)*(x12789)*(x12793)))+(((IkReal(-1.00000000000000))*(sj4)*(x12790)*(x12793)))+(((cj4)*(x12779)*(x12780)))+(((r00)*(x12786)*(x12801)))+(((cj4)*(sj5)*(x12803)))+(((cj6)*(r00)*(sj0)*(sj4)))+(((sj4)*(sj6)*(x12785)))+(((IkReal(-1.00000000000000))*(x12779)*(x12785)*(x12796)))+(((IkReal(-1.00000000000000))*(sj5)*(x12796)*(x12799))));
evalcond[6]=((((x12794)*(x12797)))+(((IkReal(-1.00000000000000))*(cj4)*(x12776)*(x12795)))+(((IkReal(-1.00000000000000))*(x12775)*(x12776)*(x12777)))+(((IkReal(-1.00000000000000))*(x12775)*(x12776)*(x12797)))+(((IkReal(-1.00000000000000))*(cj0)*(x12778)*(x12781)))+(((IkReal(-1.00000000000000))*(x12775)*(x12790)*(x12795)))+(((x12777)*(x12794)))+(((IkReal(-1.00000000000000))*(cj4)*(x12776)*(x12805)))+(((IkReal(-1.00000000000000))*(cj6)*(r11)*(x12775)*(x12788)))+(((IkReal(-1.00000000000000))*(r12)*(x12778)*(x12788))));
evalcond[7]=((((IkReal(-1.00000000000000))*(r11)*(x12782)*(x12784)))+(((IkReal(-0.0100000000000000))*(r00)*(sj6)*(x12786)))+(((IkReal(-1.00000000000000))*(py)*(x12802)))+(((IkReal(-0.374290000000000))*(r02)*(x12786)))+(((IkReal(0.374290000000000))*(x12780)*(x12784)))+(((x12793)*(x12808)))+(((x12782)*(x12783)))+(((IkReal(-0.0100000000000000))*(x12779)*(x12780)))+(((x12791)*(x12799)))+(((px)*(sj0)))+(((IkReal(0.0100000000000000))*(x12779)*(x12785)))+(((r00)*(x12792)*(x12798)))+(((IkReal(-1.00000000000000))*(x12791)*(x12803)))+(((IkReal(-1.00000000000000))*(r10)*(x12782)*(x12792))));
evalcond[8]=((IkReal(-0.295420000000000))+(((x12783)*(x12798)))+(((IkReal(-1.00000000000000))*(px)*(x12802)))+(((IkReal(-1.00000000000000))*(r00)*(x12782)*(x12792)))+(((cj5)*(r02)*(x12782)))+(((IkReal(-1.00000000000000))*(r01)*(x12782)*(x12784)))+(((cj0)*(r02)*(x12791)))+(((IkReal(0.0100000000000000))*(x12779)*(x12795)))+(((IkReal(-0.374290000000000))*(x12777)*(x12792)))+(((IkReal(-1.00000000000000))*(r11)*(x12784)*(x12798)))+(((IkReal(0.0100000000000000))*(x12779)*(x12805)))+(((x12777)*(x12808)))+(((IkReal(-1.00000000000000))*(py)*(x12788)))+(((x12797)*(x12808)))+(((r12)*(sj0)*(x12791))));
if( IKabs(evalcond[0]) < 0.0000010000000000  && IKabs(evalcond[1]) < 0.0000010000000000  && IKabs(evalcond[2]) < 0.0000010000000000  && IKabs(evalcond[3]) < 0.0000010000000000  && IKabs(evalcond[4]) < 0.0000010000000000  && IKabs(evalcond[5]) < 0.0000010000000000  && IKabs(evalcond[6]) < 0.0000010000000000  && IKabs(evalcond[7]) < 0.0000010000000000  && IKabs(evalcond[8]) < 0.0000010000000000  )
{
{
IkReal j3array[1], cj3array[1], sj3array[1];
bool j3valid[1]={false};
_nj3 = 1;
IkReal x12809=((IkReal(1.00000000000000))*(cj4));
IkReal x12810=((cj6)*(r21));
IkReal x12811=((r20)*(sj6));
if( IKabs(((((sj5)*(x12811)))+(((sj5)*(x12810)))+(((IkReal(-1.00000000000000))*(cj5)*(r22))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(((((IkReal(-1.00000000000000))*(r22)*(sj5)*(x12809)))+(((r21)*(sj4)*(sj6)))+(((IkReal(-1.00000000000000))*(cj5)*(x12809)*(x12810)))+(((IkReal(-1.00000000000000))*(cj5)*(x12809)*(x12811)))+(((IkReal(-1.00000000000000))*(cj6)*(r20)*(sj4))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(IKsqr(((((sj5)*(x12811)))+(((sj5)*(x12810)))+(((IkReal(-1.00000000000000))*(cj5)*(r22)))))+IKsqr(((((IkReal(-1.00000000000000))*(r22)*(sj5)*(x12809)))+(((r21)*(sj4)*(sj6)))+(((IkReal(-1.00000000000000))*(cj5)*(x12809)*(x12810)))+(((IkReal(-1.00000000000000))*(cj5)*(x12809)*(x12811)))+(((IkReal(-1.00000000000000))*(cj6)*(r20)*(sj4)))))-1) <= IKFAST_SINCOS_THRESH )
    continue;
j3array[0]=IKatan2(((((sj5)*(x12811)))+(((sj5)*(x12810)))+(((IkReal(-1.00000000000000))*(cj5)*(r22)))), ((((IkReal(-1.00000000000000))*(r22)*(sj5)*(x12809)))+(((r21)*(sj4)*(sj6)))+(((IkReal(-1.00000000000000))*(cj5)*(x12809)*(x12810)))+(((IkReal(-1.00000000000000))*(cj5)*(x12809)*(x12811)))+(((IkReal(-1.00000000000000))*(cj6)*(r20)*(sj4)))));
sj3array[0]=IKsin(j3array[0]);
cj3array[0]=IKcos(j3array[0]);
if( j3array[0] > IKPI )
{
    j3array[0]-=IK2PI;
}
else if( j3array[0] < -IKPI )
{    j3array[0]+=IK2PI;
}
j3valid[0] = true;
for(int ij3 = 0; ij3 < 1; ++ij3)
{
if( !j3valid[ij3] )
{
    continue;
}
_ij3[0] = ij3; _ij3[1] = -1;
for(int iij3 = ij3+1; iij3 < 1; ++iij3)
{
if( j3valid[iij3] && IKabs(cj3array[ij3]-cj3array[iij3]) < IKFAST_SOLUTION_THRESH && IKabs(sj3array[ij3]-sj3array[iij3]) < IKFAST_SOLUTION_THRESH )
{
    j3valid[iij3]=false; _ij3[1] = iij3; break; 
}
}
j3 = j3array[ij3]; cj3 = cj3array[ij3]; sj3 = sj3array[ij3];
{
IkReal evalcond[4];
IkReal x12812=IKcos(j3);
IkReal x12813=IKsin(j3);
IkReal x12814=((IkReal(1.00000000000000))*(cj4));
IkReal x12815=((sj0)*(sj5));
IkReal x12816=((cj0)*(cj5));
IkReal x12817=((cj6)*(r01));
IkReal x12818=((r00)*(sj6));
IkReal x12819=((cj6)*(r11));
IkReal x12820=((cj5)*(sj0));
IkReal x12821=((cj6)*(sj4));
IkReal x12822=((sj4)*(sj6));
IkReal x12823=((cj4)*(cj5));
IkReal x12824=((cj6)*(r21));
IkReal x12825=((r20)*(sj6));
IkReal x12826=((r10)*(sj6));
IkReal x12827=((IkReal(1.00000000000000))*(cj0)*(sj5));
evalcond[0]=((((IkReal(-1.00000000000000))*(cj5)*(r22)))+(((sj5)*(x12825)))+(((IkReal(-1.00000000000000))*(x12813)))+(((sj5)*(x12824))));
evalcond[1]=((((x12823)*(x12825)))+(((x12823)*(x12824)))+(((cj4)*(r22)*(sj5)))+(x12812)+(((r20)*(x12821)))+(((IkReal(-1.00000000000000))*(r21)*(x12822))));
evalcond[2]=((((r12)*(x12820)))+(((r02)*(x12816)))+(((IkReal(-1.00000000000000))*(x12815)*(x12826)))+(((IkReal(-1.00000000000000))*(x12818)*(x12827)))+(x12812)+(((IkReal(-1.00000000000000))*(x12817)*(x12827)))+(((IkReal(-1.00000000000000))*(x12815)*(x12819))));
evalcond[3]=((((IkReal(-1.00000000000000))*(cj0)*(r00)*(x12821)))+(((IkReal(-1.00000000000000))*(x12814)*(x12820)*(x12826)))+(((r11)*(sj0)*(x12822)))+(((IkReal(-1.00000000000000))*(x12814)*(x12816)*(x12818)))+(x12813)+(((IkReal(-1.00000000000000))*(x12814)*(x12816)*(x12817)))+(((IkReal(-1.00000000000000))*(cj0)*(r02)*(sj5)*(x12814)))+(((cj0)*(r01)*(x12822)))+(((IkReal(-1.00000000000000))*(x12814)*(x12819)*(x12820)))+(((IkReal(-1.00000000000000))*(r12)*(x12814)*(x12815)))+(((IkReal(-1.00000000000000))*(r10)*(sj0)*(x12821))));
if( IKabs(evalcond[0]) > 0.000001  || IKabs(evalcond[1]) > 0.000001  || IKabs(evalcond[2]) > 0.000001  || IKabs(evalcond[3]) > 0.000001  )
{
continue;
}
}

{
std::vector<IkSingleDOFSolutionBase<IkReal> > vinfos(7);
vinfos[0].jointtype = 1;
vinfos[0].foffset = j0;
vinfos[0].indices[0] = _ij0[0];
vinfos[0].indices[1] = _ij0[1];
vinfos[0].maxsolutions = _nj0;
vinfos[1].jointtype = 1;
vinfos[1].foffset = j1;
vinfos[1].indices[0] = _ij1[0];
vinfos[1].indices[1] = _ij1[1];
vinfos[1].maxsolutions = _nj1;
vinfos[2].jointtype = 1;
vinfos[2].foffset = j2;
vinfos[2].indices[0] = _ij2[0];
vinfos[2].indices[1] = _ij2[1];
vinfos[2].maxsolutions = _nj2;
vinfos[3].jointtype = 1;
vinfos[3].foffset = j3;
vinfos[3].indices[0] = _ij3[0];
vinfos[3].indices[1] = _ij3[1];
vinfos[3].maxsolutions = _nj3;
vinfos[4].jointtype = 1;
vinfos[4].foffset = j4;
vinfos[4].indices[0] = _ij4[0];
vinfos[4].indices[1] = _ij4[1];
vinfos[4].maxsolutions = _nj4;
vinfos[5].jointtype = 1;
vinfos[5].foffset = j5;
vinfos[5].indices[0] = _ij5[0];
vinfos[5].indices[1] = _ij5[1];
vinfos[5].maxsolutions = _nj5;
vinfos[6].jointtype = 1;
vinfos[6].foffset = j6;
vinfos[6].indices[0] = _ij6[0];
vinfos[6].indices[1] = _ij6[1];
vinfos[6].maxsolutions = _nj6;
std::vector<int> vfree(0);
solutions.AddSolution(vinfos,vfree);
}
}
}

} else
{
IkReal x12828=((IkReal(1.00000000000000))*(cj0));
IkReal x12829=((cj4)*(sj6));
IkReal x12830=((sj0)*(sj4));
IkReal x12831=((cj5)*(sj6));
IkReal x12832=((sj4)*(sj5));
IkReal x12833=((r12)*(sj5));
IkReal x12834=((IkReal(0.374290000000000))*(cj5));
IkReal x12835=((r02)*(sj0));
IkReal x12836=((r20)*(sj4));
IkReal x12837=((IkReal(1.00000000000000))*(sj0));
IkReal x12838=((IkReal(1.00000000000000))*(cj5));
IkReal x12839=((cj0)*(r10));
IkReal x12840=((cj4)*(cj6));
IkReal x12841=((r00)*(sj0));
IkReal x12842=((cj6)*(r21));
IkReal x12843=((IkReal(0.374290000000000))*(sj5));
IkReal x12844=((cj0)*(r00));
IkReal x12845=((IkReal(0.0100000000000000))*(sj5));
IkReal x12846=((cj0)*(r02));
IkReal x12847=((cj5)*(sj4));
IkReal x12848=((cj6)*(r01));
IkReal x12849=((cj6)*(r11));
IkReal x12850=((r01)*(sj0));
IkReal x12851=((r10)*(sj0));
IkReal x12852=((IkReal(0.0100000000000000))*(cj5)*(cj6));
IkReal x12853=((sj6)*(x12843));
IkReal x12854=((cj0)*(cj6)*(x12843));
evalcond[0]=((IkReal(-3.14159265358979))+(IKfmod(((IkReal(1.57079632679490))+(j2)), IkReal(6.28318530717959))));
evalcond[1]=((((IkReal(-1.00000000000000))*(r22)*(x12838)))+(((r20)*(sj5)*(sj6)))+(((sj5)*(x12842))));
evalcond[2]=((IkReal(1.00000000000000))+(((IkReal(-1.00000000000000))*(r20)*(x12840)))+(((r21)*(x12829)))+(((x12842)*(x12847)))+(((r22)*(x12832)))+(((x12831)*(x12836))));
evalcond[3]=((((IkReal(-1.00000000000000))*(r22)*(x12845)))+(((IkReal(-1.00000000000000))*(r22)*(x12834)))+(((IkReal(-0.0100000000000000))*(cj5)*(x12842)))+(((IkReal(-0.0100000000000000))*(r20)*(x12831)))+(pz)+(((r20)*(x12853)))+(((x12842)*(x12843))));
evalcond[4]=((((cj5)*(r21)*(x12840)))+(((IkReal(-1.00000000000000))*(r21)*(sj4)*(sj6)))+(((cj5)*(r20)*(x12829)))+(((cj6)*(x12836)))+(((cj4)*(r22)*(sj5))));
evalcond[5]=((((IkReal(-1.00000000000000))*(r12)*(x12828)*(x12832)))+(((IkReal(-1.00000000000000))*(x12828)*(x12847)*(x12849)))+(((r02)*(sj5)*(x12830)))+(((x12829)*(x12850)))+(((x12839)*(x12840)))+(((cj5)*(x12830)*(x12848)))+(((IkReal(-1.00000000000000))*(r00)*(x12837)*(x12840)))+(((r00)*(x12830)*(x12831)))+(((IkReal(-1.00000000000000))*(r11)*(x12828)*(x12829)))+(((IkReal(-1.00000000000000))*(r10)*(sj4)*(x12828)*(x12831))));
evalcond[6]=((((IkReal(-1.00000000000000))*(x12830)*(x12833)))+(((IkReal(-1.00000000000000))*(x12830)*(x12838)*(x12849)))+(((IkReal(-1.00000000000000))*(r02)*(x12828)*(x12832)))+(((x12840)*(x12851)))+(((IkReal(-1.00000000000000))*(r10)*(x12830)*(x12831)))+(((IkReal(-1.00000000000000))*(x12828)*(x12847)*(x12848)))+(((IkReal(-1.00000000000000))*(r00)*(sj4)*(x12828)*(x12831)))+(((IkReal(-1.00000000000000))*(r11)*(x12829)*(x12837)))+(((IkReal(-1.00000000000000))*(r01)*(x12828)*(x12829)))+(((x12840)*(x12844))));
evalcond[7]=((IkReal(0.0690000000000000))+(((IkReal(0.0100000000000000))*(x12831)*(x12839)))+(((cj0)*(r12)*(x12834)))+(((IkReal(-1.00000000000000))*(x12835)*(x12845)))+(((IkReal(-0.0100000000000000))*(cj5)*(sj0)*(x12848)))+(((x12841)*(x12853)))+(((IkReal(-1.00000000000000))*(cj0)*(x12843)*(x12849)))+(((sj0)*(x12843)*(x12848)))+(((IkReal(-1.00000000000000))*(x12839)*(x12853)))+(((IkReal(-1.00000000000000))*(py)*(x12828)))+(((IkReal(-0.0100000000000000))*(x12831)*(x12841)))+(((IkReal(0.0100000000000000))*(cj0)*(x12833)))+(((px)*(sj0)))+(((IkReal(0.0100000000000000))*(cj0)*(cj5)*(x12849)))+(((IkReal(-1.00000000000000))*(x12834)*(x12835))));
evalcond[8]=((IkReal(-0.295420000000000))+(((x12845)*(x12846)))+(((r12)*(sj0)*(x12834)))+(((IkReal(-1.00000000000000))*(x12851)*(x12853)))+(((IkReal(-1.00000000000000))*(sj0)*(x12843)*(x12849)))+(((IkReal(0.0100000000000000))*(x12831)*(x12851)))+(((IkReal(0.0100000000000000))*(cj0)*(cj5)*(x12848)))+(((IkReal(0.0100000000000000))*(sj0)*(x12833)))+(((IkReal(-1.00000000000000))*(py)*(x12837)))+(((x12834)*(x12846)))+(((IkReal(-1.00000000000000))*(x12844)*(x12853)))+(((IkReal(0.0100000000000000))*(cj5)*(sj0)*(x12849)))+(((IkReal(-1.00000000000000))*(cj0)*(x12843)*(x12848)))+(((IkReal(0.0100000000000000))*(x12831)*(x12844)))+(((IkReal(-1.00000000000000))*(px)*(x12828))));
if( IKabs(evalcond[0]) < 0.0000010000000000  && IKabs(evalcond[1]) < 0.0000010000000000  && IKabs(evalcond[2]) < 0.0000010000000000  && IKabs(evalcond[3]) < 0.0000010000000000  && IKabs(evalcond[4]) < 0.0000010000000000  && IKabs(evalcond[5]) < 0.0000010000000000  && IKabs(evalcond[6]) < 0.0000010000000000  && IKabs(evalcond[7]) < 0.0000010000000000  && IKabs(evalcond[8]) < 0.0000010000000000  )
{
{
IkReal j3array[1], cj3array[1], sj3array[1];
bool j3valid[1]={false};
_nj3 = 1;
IkReal x12855=((sj0)*(sj5));
IkReal x12856=((r00)*(sj6));
IkReal x12857=((IkReal(1.00000000000000))*(cj5));
IkReal x12858=((cj6)*(r11));
IkReal x12859=((cj6)*(r01));
IkReal x12860=((r10)*(sj6));
IkReal x12861=((cj0)*(sj5));
if( IKabs(((((IkReal(-1.00000000000000))*(x12860)*(x12861)))+(((x12855)*(x12856)))+(((IkReal(-1.00000000000000))*(x12858)*(x12861)))+(((cj0)*(cj5)*(r12)))+(((IkReal(-1.00000000000000))*(r02)*(sj0)*(x12857)))+(((x12855)*(x12859))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(((((IkReal(-1.00000000000000))*(cj0)*(r02)*(x12857)))+(((x12856)*(x12861)))+(((IkReal(-1.00000000000000))*(r12)*(sj0)*(x12857)))+(((x12855)*(x12860)))+(((x12859)*(x12861)))+(((x12855)*(x12858))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(IKsqr(((((IkReal(-1.00000000000000))*(x12860)*(x12861)))+(((x12855)*(x12856)))+(((IkReal(-1.00000000000000))*(x12858)*(x12861)))+(((cj0)*(cj5)*(r12)))+(((IkReal(-1.00000000000000))*(r02)*(sj0)*(x12857)))+(((x12855)*(x12859)))))+IKsqr(((((IkReal(-1.00000000000000))*(cj0)*(r02)*(x12857)))+(((x12856)*(x12861)))+(((IkReal(-1.00000000000000))*(r12)*(sj0)*(x12857)))+(((x12855)*(x12860)))+(((x12859)*(x12861)))+(((x12855)*(x12858)))))-1) <= IKFAST_SINCOS_THRESH )
    continue;
j3array[0]=IKatan2(((((IkReal(-1.00000000000000))*(x12860)*(x12861)))+(((x12855)*(x12856)))+(((IkReal(-1.00000000000000))*(x12858)*(x12861)))+(((cj0)*(cj5)*(r12)))+(((IkReal(-1.00000000000000))*(r02)*(sj0)*(x12857)))+(((x12855)*(x12859)))), ((((IkReal(-1.00000000000000))*(cj0)*(r02)*(x12857)))+(((x12856)*(x12861)))+(((IkReal(-1.00000000000000))*(r12)*(sj0)*(x12857)))+(((x12855)*(x12860)))+(((x12859)*(x12861)))+(((x12855)*(x12858)))));
sj3array[0]=IKsin(j3array[0]);
cj3array[0]=IKcos(j3array[0]);
if( j3array[0] > IKPI )
{
    j3array[0]-=IK2PI;
}
else if( j3array[0] < -IKPI )
{    j3array[0]+=IK2PI;
}
j3valid[0] = true;
for(int ij3 = 0; ij3 < 1; ++ij3)
{
if( !j3valid[ij3] )
{
    continue;
}
_ij3[0] = ij3; _ij3[1] = -1;
for(int iij3 = ij3+1; iij3 < 1; ++iij3)
{
if( j3valid[iij3] && IKabs(cj3array[ij3]-cj3array[iij3]) < IKFAST_SOLUTION_THRESH && IKabs(sj3array[ij3]-sj3array[iij3]) < IKFAST_SOLUTION_THRESH )
{
    j3valid[iij3]=false; _ij3[1] = iij3; break; 
}
}
j3 = j3array[ij3]; cj3 = cj3array[ij3]; sj3 = sj3array[ij3];
{
IkReal evalcond[4];
IkReal x12862=IKcos(j3);
IkReal x12863=IKsin(j3);
IkReal x12864=((sj0)*(sj5));
IkReal x12865=((r00)*(sj6));
IkReal x12866=((cj6)*(sj0));
IkReal x12867=((IkReal(1.00000000000000))*(cj4));
IkReal x12868=((r00)*(sj4));
IkReal x12869=((cj0)*(cj5));
IkReal x12870=((cj5)*(sj0));
IkReal x12871=((cj6)*(r11));
IkReal x12872=((r10)*(sj6));
IkReal x12873=((cj0)*(sj5));
IkReal x12874=((r10)*(sj4));
IkReal x12875=((cj4)*(cj5)*(r01));
IkReal x12876=((IkReal(1.00000000000000))*(cj0)*(cj6));
IkReal x12877=((cj0)*(sj4)*(sj6));
IkReal x12878=((sj0)*(sj4)*(sj6));
evalcond[0]=((((cj6)*(r01)*(x12864)))+(((IkReal(-1.00000000000000))*(x12871)*(x12873)))+(((IkReal(-1.00000000000000))*(x12863)))+(((IkReal(-1.00000000000000))*(x12872)*(x12873)))+(((x12864)*(x12865)))+(((IkReal(-1.00000000000000))*(r02)*(x12870)))+(((r12)*(x12869))));
evalcond[1]=((((r02)*(x12869)))+(((IkReal(-1.00000000000000))*(cj6)*(r01)*(x12873)))+(((IkReal(-1.00000000000000))*(x12864)*(x12871)))+(((IkReal(-1.00000000000000))*(x12865)*(x12873)))+(((IkReal(-1.00000000000000))*(x12864)*(x12872)))+(x12862)+(((r12)*(x12870))));
evalcond[2]=((((IkReal(-1.00000000000000))*(r12)*(x12867)*(x12873)))+(((cj4)*(r02)*(x12864)))+(((cj4)*(x12865)*(x12870)))+(((IkReal(-1.00000000000000))*(r01)*(x12878)))+(((IkReal(-1.00000000000000))*(x12867)*(x12869)*(x12872)))+(((IkReal(-1.00000000000000))*(x12874)*(x12876)))+(((r11)*(x12877)))+(((x12866)*(x12875)))+(((IkReal(-1.00000000000000))*(x12867)*(x12869)*(x12871)))+(((x12866)*(x12868)))+(x12862));
evalcond[3]=((((r01)*(x12877)))+(((r11)*(x12878)))+(((IkReal(-1.00000000000000))*(r02)*(x12867)*(x12873)))+(((IkReal(-1.00000000000000))*(x12866)*(x12874)))+(((IkReal(-1.00000000000000))*(x12868)*(x12876)))+(((IkReal(-1.00000000000000))*(cj6)*(r01)*(x12867)*(x12869)))+(((IkReal(-1.00000000000000))*(r12)*(x12864)*(x12867)))+(((IkReal(-1.00000000000000))*(cj5)*(r11)*(x12866)*(x12867)))+(((IkReal(-1.00000000000000))*(x12867)*(x12870)*(x12872)))+(((IkReal(-1.00000000000000))*(x12865)*(x12867)*(x12869)))+(x12863));
if( IKabs(evalcond[0]) > 0.000001  || IKabs(evalcond[1]) > 0.000001  || IKabs(evalcond[2]) > 0.000001  || IKabs(evalcond[3]) > 0.000001  )
{
continue;
}
}

{
std::vector<IkSingleDOFSolutionBase<IkReal> > vinfos(7);
vinfos[0].jointtype = 1;
vinfos[0].foffset = j0;
vinfos[0].indices[0] = _ij0[0];
vinfos[0].indices[1] = _ij0[1];
vinfos[0].maxsolutions = _nj0;
vinfos[1].jointtype = 1;
vinfos[1].foffset = j1;
vinfos[1].indices[0] = _ij1[0];
vinfos[1].indices[1] = _ij1[1];
vinfos[1].maxsolutions = _nj1;
vinfos[2].jointtype = 1;
vinfos[2].foffset = j2;
vinfos[2].indices[0] = _ij2[0];
vinfos[2].indices[1] = _ij2[1];
vinfos[2].maxsolutions = _nj2;
vinfos[3].jointtype = 1;
vinfos[3].foffset = j3;
vinfos[3].indices[0] = _ij3[0];
vinfos[3].indices[1] = _ij3[1];
vinfos[3].maxsolutions = _nj3;
vinfos[4].jointtype = 1;
vinfos[4].foffset = j4;
vinfos[4].indices[0] = _ij4[0];
vinfos[4].indices[1] = _ij4[1];
vinfos[4].maxsolutions = _nj4;
vinfos[5].jointtype = 1;
vinfos[5].foffset = j5;
vinfos[5].indices[0] = _ij5[0];
vinfos[5].indices[1] = _ij5[1];
vinfos[5].maxsolutions = _nj5;
vinfos[6].jointtype = 1;
vinfos[6].foffset = j6;
vinfos[6].indices[0] = _ij6[0];
vinfos[6].indices[1] = _ij6[1];
vinfos[6].maxsolutions = _nj6;
std::vector<int> vfree(0);
solutions.AddSolution(vinfos,vfree);
}
}
}

} else
{
IkReal x12879=((IkReal(1.00000000000000))*(cj0));
IkReal x12880=((cj4)*(sj6));
IkReal x12881=((sj0)*(sj4));
IkReal x12882=((cj5)*(sj6));
IkReal x12883=((sj4)*(sj5));
IkReal x12884=((r12)*(sj5));
IkReal x12885=((IkReal(0.374290000000000))*(cj5));
IkReal x12886=((r02)*(sj0));
IkReal x12887=((r20)*(sj4));
IkReal x12888=((IkReal(1.00000000000000))*(sj0));
IkReal x12889=((IkReal(1.00000000000000))*(cj5));
IkReal x12890=((cj0)*(r10));
IkReal x12891=((cj4)*(cj6));
IkReal x12892=((r00)*(sj0));
IkReal x12893=((cj6)*(r21));
IkReal x12894=((IkReal(0.374290000000000))*(sj5));
IkReal x12895=((cj0)*(r00));
IkReal x12896=((IkReal(0.0100000000000000))*(sj5));
IkReal x12897=((cj0)*(r02));
IkReal x12898=((cj5)*(sj4));
IkReal x12899=((cj6)*(r01));
IkReal x12900=((cj6)*(r11));
IkReal x12901=((r01)*(sj0));
IkReal x12902=((r10)*(sj0));
IkReal x12903=((IkReal(0.0100000000000000))*(cj5)*(cj6));
IkReal x12904=((sj6)*(x12894));
IkReal x12905=((cj0)*(cj6)*(x12894));
evalcond[0]=((IkReal(-3.14159265358979))+(IKfmod(((IkReal(4.71238898038469))+(j2)), IkReal(6.28318530717959))));
evalcond[1]=((((sj5)*(x12893)))+(((IkReal(-1.00000000000000))*(r22)*(x12889)))+(((r20)*(sj5)*(sj6))));
evalcond[2]=((IkReal(-1.00000000000000))+(((IkReal(-1.00000000000000))*(r20)*(x12891)))+(((x12882)*(x12887)))+(((x12893)*(x12898)))+(((r21)*(x12880)))+(((r22)*(x12883))));
evalcond[3]=((((IkReal(-1.00000000000000))*(r22)*(x12896)))+(((IkReal(-0.0100000000000000))*(r20)*(x12882)))+(((x12893)*(x12894)))+(pz)+(((IkReal(-1.00000000000000))*(r22)*(x12885)))+(((IkReal(-0.0100000000000000))*(cj5)*(x12893)))+(((r20)*(x12904))));
evalcond[4]=((((IkReal(-1.00000000000000))*(r21)*(sj4)*(sj6)))+(((cj5)*(r21)*(x12891)))+(((cj4)*(r22)*(sj5)))+(((cj6)*(x12887)))+(((cj5)*(r20)*(x12880))));
evalcond[5]=((((IkReal(-1.00000000000000))*(x12879)*(x12898)*(x12900)))+(((IkReal(-1.00000000000000))*(r00)*(x12888)*(x12891)))+(((IkReal(-1.00000000000000))*(r12)*(x12879)*(x12883)))+(((IkReal(-1.00000000000000))*(r10)*(sj4)*(x12879)*(x12882)))+(((r00)*(x12881)*(x12882)))+(((r02)*(sj5)*(x12881)))+(((cj5)*(x12881)*(x12899)))+(((x12890)*(x12891)))+(((IkReal(-1.00000000000000))*(r11)*(x12879)*(x12880)))+(((x12880)*(x12901))));
evalcond[6]=((((IkReal(-1.00000000000000))*(x12879)*(x12898)*(x12899)))+(((IkReal(-1.00000000000000))*(x12881)*(x12884)))+(((IkReal(-1.00000000000000))*(x12881)*(x12889)*(x12900)))+(((x12891)*(x12902)))+(((IkReal(-1.00000000000000))*(r11)*(x12880)*(x12888)))+(((IkReal(-1.00000000000000))*(r02)*(x12879)*(x12883)))+(((IkReal(-1.00000000000000))*(r01)*(x12879)*(x12880)))+(((x12891)*(x12895)))+(((IkReal(-1.00000000000000))*(r00)*(sj4)*(x12879)*(x12882)))+(((IkReal(-1.00000000000000))*(r10)*(x12881)*(x12882))));
evalcond[7]=((IkReal(-0.0690000000000000))+(((cj0)*(r12)*(x12885)))+(((IkReal(-0.0100000000000000))*(cj5)*(sj0)*(x12899)))+(((IkReal(-1.00000000000000))*(py)*(x12879)))+(((IkReal(-1.00000000000000))*(x12890)*(x12904)))+(((sj0)*(x12894)*(x12899)))+(((IkReal(0.0100000000000000))*(cj0)*(cj5)*(x12900)))+(((IkReal(-0.0100000000000000))*(x12882)*(x12892)))+(((IkReal(0.0100000000000000))*(cj0)*(x12884)))+(((x12892)*(x12904)))+(((IkReal(-1.00000000000000))*(cj0)*(x12894)*(x12900)))+(((IkReal(-1.00000000000000))*(x12886)*(x12896)))+(((px)*(sj0)))+(((IkReal(0.0100000000000000))*(x12882)*(x12890)))+(((IkReal(-1.00000000000000))*(x12885)*(x12886))));
evalcond[8]=((IkReal(-0.295420000000000))+(((IkReal(0.0100000000000000))*(cj5)*(sj0)*(x12900)))+(((IkReal(0.0100000000000000))*(x12882)*(x12902)))+(((x12896)*(x12897)))+(((IkReal(-1.00000000000000))*(x12902)*(x12904)))+(((x12885)*(x12897)))+(((IkReal(-1.00000000000000))*(x12895)*(x12904)))+(((IkReal(0.0100000000000000))*(cj0)*(cj5)*(x12899)))+(((IkReal(-1.00000000000000))*(cj0)*(x12894)*(x12899)))+(((IkReal(0.0100000000000000))*(sj0)*(x12884)))+(((IkReal(-1.00000000000000))*(py)*(x12888)))+(((r12)*(sj0)*(x12885)))+(((IkReal(-1.00000000000000))*(px)*(x12879)))+(((IkReal(-1.00000000000000))*(sj0)*(x12894)*(x12900)))+(((IkReal(0.0100000000000000))*(x12882)*(x12895))));
if( IKabs(evalcond[0]) < 0.0000010000000000  && IKabs(evalcond[1]) < 0.0000010000000000  && IKabs(evalcond[2]) < 0.0000010000000000  && IKabs(evalcond[3]) < 0.0000010000000000  && IKabs(evalcond[4]) < 0.0000010000000000  && IKabs(evalcond[5]) < 0.0000010000000000  && IKabs(evalcond[6]) < 0.0000010000000000  && IKabs(evalcond[7]) < 0.0000010000000000  && IKabs(evalcond[8]) < 0.0000010000000000  )
{
{
IkReal j3array[1], cj3array[1], sj3array[1];
bool j3valid[1]={false};
_nj3 = 1;
IkReal x12906=((IkReal(1.00000000000000))*(cj5));
IkReal x12907=((r10)*(sj5)*(sj6));
IkReal x12908=((cj6)*(sj0)*(sj5));
IkReal x12909=((r00)*(sj5)*(sj6));
IkReal x12910=((cj0)*(cj6)*(sj5));
if( IKabs(((((IkReal(-1.00000000000000))*(sj0)*(x12909)))+(((IkReal(-1.00000000000000))*(r01)*(x12908)))+(((cj0)*(x12907)))+(((IkReal(-1.00000000000000))*(cj0)*(r12)*(x12906)))+(((cj5)*(r02)*(sj0)))+(((r11)*(x12910))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(((((IkReal(-1.00000000000000))*(r12)*(sj0)*(x12906)))+(((r11)*(x12908)))+(((r01)*(x12910)))+(((sj0)*(x12907)))+(((IkReal(-1.00000000000000))*(cj0)*(r02)*(x12906)))+(((cj0)*(x12909))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(IKsqr(((((IkReal(-1.00000000000000))*(sj0)*(x12909)))+(((IkReal(-1.00000000000000))*(r01)*(x12908)))+(((cj0)*(x12907)))+(((IkReal(-1.00000000000000))*(cj0)*(r12)*(x12906)))+(((cj5)*(r02)*(sj0)))+(((r11)*(x12910)))))+IKsqr(((((IkReal(-1.00000000000000))*(r12)*(sj0)*(x12906)))+(((r11)*(x12908)))+(((r01)*(x12910)))+(((sj0)*(x12907)))+(((IkReal(-1.00000000000000))*(cj0)*(r02)*(x12906)))+(((cj0)*(x12909)))))-1) <= IKFAST_SINCOS_THRESH )
    continue;
j3array[0]=IKatan2(((((IkReal(-1.00000000000000))*(sj0)*(x12909)))+(((IkReal(-1.00000000000000))*(r01)*(x12908)))+(((cj0)*(x12907)))+(((IkReal(-1.00000000000000))*(cj0)*(r12)*(x12906)))+(((cj5)*(r02)*(sj0)))+(((r11)*(x12910)))), ((((IkReal(-1.00000000000000))*(r12)*(sj0)*(x12906)))+(((r11)*(x12908)))+(((r01)*(x12910)))+(((sj0)*(x12907)))+(((IkReal(-1.00000000000000))*(cj0)*(r02)*(x12906)))+(((cj0)*(x12909)))));
sj3array[0]=IKsin(j3array[0]);
cj3array[0]=IKcos(j3array[0]);
if( j3array[0] > IKPI )
{
    j3array[0]-=IK2PI;
}
else if( j3array[0] < -IKPI )
{    j3array[0]+=IK2PI;
}
j3valid[0] = true;
for(int ij3 = 0; ij3 < 1; ++ij3)
{
if( !j3valid[ij3] )
{
    continue;
}
_ij3[0] = ij3; _ij3[1] = -1;
for(int iij3 = ij3+1; iij3 < 1; ++iij3)
{
if( j3valid[iij3] && IKabs(cj3array[ij3]-cj3array[iij3]) < IKFAST_SOLUTION_THRESH && IKabs(sj3array[ij3]-sj3array[iij3]) < IKFAST_SOLUTION_THRESH )
{
    j3valid[iij3]=false; _ij3[1] = iij3; break; 
}
}
j3 = j3array[ij3]; cj3 = cj3array[ij3]; sj3 = sj3array[ij3];
{
IkReal evalcond[4];
IkReal x12911=IKcos(j3);
IkReal x12912=IKsin(j3);
IkReal x12913=((sj0)*(sj5));
IkReal x12914=((r00)*(sj6));
IkReal x12915=((IkReal(1.00000000000000))*(cj4));
IkReal x12916=((cj6)*(sj0));
IkReal x12917=((r00)*(sj4));
IkReal x12918=((cj0)*(cj5));
IkReal x12919=((cj6)*(r01));
IkReal x12920=((cj5)*(sj0));
IkReal x12921=((cj0)*(sj5));
IkReal x12922=((cj6)*(r11));
IkReal x12923=((r10)*(sj6));
IkReal x12924=((r10)*(sj4));
IkReal x12925=((cj0)*(sj4)*(sj6));
IkReal x12926=((sj0)*(sj4)*(sj6));
IkReal x12927=((IkReal(1.00000000000000))*(cj0)*(cj6));
evalcond[0]=((((IkReal(-1.00000000000000))*(x12921)*(x12922)))+(((x12913)*(x12919)))+(((IkReal(-1.00000000000000))*(x12921)*(x12923)))+(x12912)+(((r12)*(x12918)))+(((IkReal(-1.00000000000000))*(r02)*(x12920)))+(((x12913)*(x12914))));
evalcond[1]=((((r12)*(x12920)))+(((IkReal(-1.00000000000000))*(x12913)*(x12922)))+(((IkReal(-1.00000000000000))*(x12913)*(x12923)))+(((IkReal(-1.00000000000000))*(x12919)*(x12921)))+(x12911)+(((IkReal(-1.00000000000000))*(x12914)*(x12921)))+(((r02)*(x12918))));
evalcond[2]=((((IkReal(-1.00000000000000))*(r01)*(x12926)))+(((cj4)*(x12914)*(x12920)))+(((IkReal(-1.00000000000000))*(x12924)*(x12927)))+(((IkReal(-1.00000000000000))*(x12911)))+(((r11)*(x12925)))+(((cj4)*(r02)*(x12913)))+(((IkReal(-1.00000000000000))*(x12915)*(x12918)*(x12922)))+(((x12916)*(x12917)))+(((IkReal(-1.00000000000000))*(r12)*(x12915)*(x12921)))+(((cj4)*(cj5)*(r01)*(x12916)))+(((IkReal(-1.00000000000000))*(x12915)*(x12918)*(x12923))));
evalcond[3]=((((IkReal(-1.00000000000000))*(cj5)*(r11)*(x12915)*(x12916)))+(((IkReal(-1.00000000000000))*(x12914)*(x12915)*(x12918)))+(((r11)*(x12926)))+(((IkReal(-1.00000000000000))*(x12915)*(x12920)*(x12923)))+(((IkReal(-1.00000000000000))*(x12917)*(x12927)))+(((IkReal(-1.00000000000000))*(x12916)*(x12924)))+(x12912)+(((IkReal(-1.00000000000000))*(r02)*(x12915)*(x12921)))+(((r01)*(x12925)))+(((IkReal(-1.00000000000000))*(x12915)*(x12918)*(x12919)))+(((IkReal(-1.00000000000000))*(r12)*(x12913)*(x12915))));
if( IKabs(evalcond[0]) > 0.000001  || IKabs(evalcond[1]) > 0.000001  || IKabs(evalcond[2]) > 0.000001  || IKabs(evalcond[3]) > 0.000001  )
{
continue;
}
}

{
std::vector<IkSingleDOFSolutionBase<IkReal> > vinfos(7);
vinfos[0].jointtype = 1;
vinfos[0].foffset = j0;
vinfos[0].indices[0] = _ij0[0];
vinfos[0].indices[1] = _ij0[1];
vinfos[0].maxsolutions = _nj0;
vinfos[1].jointtype = 1;
vinfos[1].foffset = j1;
vinfos[1].indices[0] = _ij1[0];
vinfos[1].indices[1] = _ij1[1];
vinfos[1].maxsolutions = _nj1;
vinfos[2].jointtype = 1;
vinfos[2].foffset = j2;
vinfos[2].indices[0] = _ij2[0];
vinfos[2].indices[1] = _ij2[1];
vinfos[2].maxsolutions = _nj2;
vinfos[3].jointtype = 1;
vinfos[3].foffset = j3;
vinfos[3].indices[0] = _ij3[0];
vinfos[3].indices[1] = _ij3[1];
vinfos[3].maxsolutions = _nj3;
vinfos[4].jointtype = 1;
vinfos[4].foffset = j4;
vinfos[4].indices[0] = _ij4[0];
vinfos[4].indices[1] = _ij4[1];
vinfos[4].maxsolutions = _nj4;
vinfos[5].jointtype = 1;
vinfos[5].foffset = j5;
vinfos[5].indices[0] = _ij5[0];
vinfos[5].indices[1] = _ij5[1];
vinfos[5].maxsolutions = _nj5;
vinfos[6].jointtype = 1;
vinfos[6].foffset = j6;
vinfos[6].indices[0] = _ij6[0];
vinfos[6].indices[1] = _ij6[1];
vinfos[6].maxsolutions = _nj6;
std::vector<int> vfree(0);
solutions.AddSolution(vinfos,vfree);
}
}
}

} else
{
if( 1 )
{
continue;

} else
{
}
}
}
}
}
}

} else
{
{
IkReal j3array[1], cj3array[1], sj3array[1];
bool j3valid[1]={false};
_nj3 = 1;
IkReal x12928=((sj0)*(sj5));
IkReal x12929=((r00)*(sj6));
IkReal x12930=((IkReal(1.00000000000000))*(cj5));
IkReal x12931=((cj6)*(r11));
IkReal x12932=((cj6)*(r01));
IkReal x12933=((cj0)*(sj5));
IkReal x12934=((r10)*(sj6));
if( IKabs(((((IKabs(sj2) != 0)?((IkReal)1/(sj2)):(IkReal)1.0e30))*(((((IkReal(-1.00000000000000))*(x12931)*(x12933)))+(((cj0)*(cj5)*(r12)))+(((IkReal(-1.00000000000000))*(r02)*(sj0)*(x12930)))+(((x12928)*(x12929)))+(((x12928)*(x12932)))+(((IkReal(-1.00000000000000))*(x12933)*(x12934))))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(((((IkReal(-1.00000000000000))*(r12)*(sj0)*(x12930)))+(((x12928)*(x12934)))+(((x12929)*(x12933)))+(((IkReal(-1.00000000000000))*(cj0)*(r02)*(x12930)))+(((x12928)*(x12931)))+(((x12932)*(x12933))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(IKsqr(((((IKabs(sj2) != 0)?((IkReal)1/(sj2)):(IkReal)1.0e30))*(((((IkReal(-1.00000000000000))*(x12931)*(x12933)))+(((cj0)*(cj5)*(r12)))+(((IkReal(-1.00000000000000))*(r02)*(sj0)*(x12930)))+(((x12928)*(x12929)))+(((x12928)*(x12932)))+(((IkReal(-1.00000000000000))*(x12933)*(x12934)))))))+IKsqr(((((IkReal(-1.00000000000000))*(r12)*(sj0)*(x12930)))+(((x12928)*(x12934)))+(((x12929)*(x12933)))+(((IkReal(-1.00000000000000))*(cj0)*(r02)*(x12930)))+(((x12928)*(x12931)))+(((x12932)*(x12933)))))-1) <= IKFAST_SINCOS_THRESH )
    continue;
j3array[0]=IKatan2(((((IKabs(sj2) != 0)?((IkReal)1/(sj2)):(IkReal)1.0e30))*(((((IkReal(-1.00000000000000))*(x12931)*(x12933)))+(((cj0)*(cj5)*(r12)))+(((IkReal(-1.00000000000000))*(r02)*(sj0)*(x12930)))+(((x12928)*(x12929)))+(((x12928)*(x12932)))+(((IkReal(-1.00000000000000))*(x12933)*(x12934)))))), ((((IkReal(-1.00000000000000))*(r12)*(sj0)*(x12930)))+(((x12928)*(x12934)))+(((x12929)*(x12933)))+(((IkReal(-1.00000000000000))*(cj0)*(r02)*(x12930)))+(((x12928)*(x12931)))+(((x12932)*(x12933)))));
sj3array[0]=IKsin(j3array[0]);
cj3array[0]=IKcos(j3array[0]);
if( j3array[0] > IKPI )
{
    j3array[0]-=IK2PI;
}
else if( j3array[0] < -IKPI )
{    j3array[0]+=IK2PI;
}
j3valid[0] = true;
for(int ij3 = 0; ij3 < 1; ++ij3)
{
if( !j3valid[ij3] )
{
    continue;
}
_ij3[0] = ij3; _ij3[1] = -1;
for(int iij3 = ij3+1; iij3 < 1; ++iij3)
{
if( j3valid[iij3] && IKabs(cj3array[ij3]-cj3array[iij3]) < IKFAST_SOLUTION_THRESH && IKabs(sj3array[ij3]-sj3array[iij3]) < IKFAST_SOLUTION_THRESH )
{
    j3valid[iij3]=false; _ij3[1] = iij3; break; 
}
}
j3 = j3array[ij3]; cj3 = cj3array[ij3]; sj3 = sj3array[ij3];
{
IkReal evalcond[6];
IkReal x12935=IKsin(j3);
IkReal x12936=IKcos(j3);
IkReal x12937=((sj0)*(sj5));
IkReal x12938=((r00)*(sj6));
IkReal x12939=((IkReal(1.00000000000000))*(cj4));
IkReal x12940=((cj6)*(r01));
IkReal x12941=((cj0)*(cj5));
IkReal x12942=((cj5)*(sj0));
IkReal x12943=((cj6)*(r11));
IkReal x12944=((cj6)*(sj4));
IkReal x12945=((cj0)*(sj5));
IkReal x12946=((cj4)*(cj5));
IkReal x12947=((cj6)*(r21));
IkReal x12948=((r20)*(sj6));
IkReal x12949=((r10)*(sj6));
IkReal x12950=((IkReal(1.00000000000000))*(cj0));
IkReal x12951=((cj0)*(sj4)*(sj6));
IkReal x12952=((sj0)*(sj4)*(sj6));
evalcond[0]=((((sj5)*(x12947)))+(((sj5)*(x12948)))+(((IkReal(-1.00000000000000))*(cj5)*(r22)))+(((cj2)*(x12935))));
evalcond[1]=((((x12946)*(x12947)))+(((IkReal(-1.00000000000000))*(r21)*(sj4)*(sj6)))+(((x12946)*(x12948)))+(((cj4)*(r22)*(sj5)))+(((r20)*(x12944)))+(((IkReal(-1.00000000000000))*(cj2)*(x12936))));
evalcond[2]=((((r12)*(x12941)))+(((IkReal(-1.00000000000000))*(r02)*(x12942)))+(((x12937)*(x12940)))+(((x12937)*(x12938)))+(((IkReal(-1.00000000000000))*(x12943)*(x12945)))+(((IkReal(-1.00000000000000))*(x12945)*(x12949)))+(((IkReal(-1.00000000000000))*(sj2)*(x12935))));
evalcond[3]=((((IkReal(-1.00000000000000))*(x12937)*(x12943)))+(x12936)+(((r12)*(x12942)))+(((IkReal(-1.00000000000000))*(x12937)*(x12949)))+(((IkReal(-1.00000000000000))*(x12938)*(x12945)))+(((IkReal(-1.00000000000000))*(x12940)*(x12945)))+(((r02)*(x12941))));
evalcond[4]=((((sj2)*(x12936)))+(((cj4)*(r02)*(x12937)))+(((cj4)*(x12940)*(x12942)))+(((r11)*(x12951)))+(((IkReal(-1.00000000000000))*(x12939)*(x12941)*(x12949)))+(((IkReal(-1.00000000000000))*(r12)*(x12939)*(x12945)))+(((IkReal(-1.00000000000000))*(r10)*(x12944)*(x12950)))+(((cj4)*(x12938)*(x12942)))+(((IkReal(-1.00000000000000))*(r01)*(x12952)))+(((r00)*(sj0)*(x12944)))+(((IkReal(-1.00000000000000))*(x12939)*(x12941)*(x12943))));
evalcond[5]=((((IkReal(-1.00000000000000))*(r00)*(x12944)*(x12950)))+(((r11)*(x12952)))+(((IkReal(-1.00000000000000))*(r10)*(sj0)*(x12944)))+(((IkReal(-1.00000000000000))*(x12939)*(x12942)*(x12943)))+(((IkReal(-1.00000000000000))*(x12938)*(x12939)*(x12941)))+(x12935)+(((IkReal(-1.00000000000000))*(x12939)*(x12942)*(x12949)))+(((IkReal(-1.00000000000000))*(x12939)*(x12940)*(x12941)))+(((IkReal(-1.00000000000000))*(r12)*(x12937)*(x12939)))+(((IkReal(-1.00000000000000))*(r02)*(x12939)*(x12945)))+(((r01)*(x12951))));
if( IKabs(evalcond[0]) > 0.000001  || IKabs(evalcond[1]) > 0.000001  || IKabs(evalcond[2]) > 0.000001  || IKabs(evalcond[3]) > 0.000001  || IKabs(evalcond[4]) > 0.000001  || IKabs(evalcond[5]) > 0.000001  )
{
continue;
}
}

{
std::vector<IkSingleDOFSolutionBase<IkReal> > vinfos(7);
vinfos[0].jointtype = 1;
vinfos[0].foffset = j0;
vinfos[0].indices[0] = _ij0[0];
vinfos[0].indices[1] = _ij0[1];
vinfos[0].maxsolutions = _nj0;
vinfos[1].jointtype = 1;
vinfos[1].foffset = j1;
vinfos[1].indices[0] = _ij1[0];
vinfos[1].indices[1] = _ij1[1];
vinfos[1].maxsolutions = _nj1;
vinfos[2].jointtype = 1;
vinfos[2].foffset = j2;
vinfos[2].indices[0] = _ij2[0];
vinfos[2].indices[1] = _ij2[1];
vinfos[2].maxsolutions = _nj2;
vinfos[3].jointtype = 1;
vinfos[3].foffset = j3;
vinfos[3].indices[0] = _ij3[0];
vinfos[3].indices[1] = _ij3[1];
vinfos[3].maxsolutions = _nj3;
vinfos[4].jointtype = 1;
vinfos[4].foffset = j4;
vinfos[4].indices[0] = _ij4[0];
vinfos[4].indices[1] = _ij4[1];
vinfos[4].maxsolutions = _nj4;
vinfos[5].jointtype = 1;
vinfos[5].foffset = j5;
vinfos[5].indices[0] = _ij5[0];
vinfos[5].indices[1] = _ij5[1];
vinfos[5].maxsolutions = _nj5;
vinfos[6].jointtype = 1;
vinfos[6].foffset = j6;
vinfos[6].indices[0] = _ij6[0];
vinfos[6].indices[1] = _ij6[1];
vinfos[6].maxsolutions = _nj6;
std::vector<int> vfree(0);
solutions.AddSolution(vinfos,vfree);
}
}
}

}

}

} else
{
{
IkReal j3array[1], cj3array[1], sj3array[1];
bool j3valid[1]={false};
_nj3 = 1;
IkReal x12953=((cj6)*(sj5));
IkReal x12954=((IkReal(1.00000000000000))*(cj5));
IkReal x12955=((sj5)*(sj6));
if( IKabs(((((IKabs(cj2) != 0)?((IkReal)1/(cj2)):(IkReal)1.0e30))*(((((IkReal(-1.00000000000000))*(r21)*(x12953)))+(((IkReal(-1.00000000000000))*(r20)*(x12955)))+(((cj5)*(r22))))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(((((r11)*(sj0)*(x12953)))+(((IkReal(-1.00000000000000))*(cj0)*(r02)*(x12954)))+(((cj0)*(r01)*(x12953)))+(((r10)*(sj0)*(x12955)))+(((IkReal(-1.00000000000000))*(r12)*(sj0)*(x12954)))+(((cj0)*(r00)*(x12955))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(IKsqr(((((IKabs(cj2) != 0)?((IkReal)1/(cj2)):(IkReal)1.0e30))*(((((IkReal(-1.00000000000000))*(r21)*(x12953)))+(((IkReal(-1.00000000000000))*(r20)*(x12955)))+(((cj5)*(r22)))))))+IKsqr(((((r11)*(sj0)*(x12953)))+(((IkReal(-1.00000000000000))*(cj0)*(r02)*(x12954)))+(((cj0)*(r01)*(x12953)))+(((r10)*(sj0)*(x12955)))+(((IkReal(-1.00000000000000))*(r12)*(sj0)*(x12954)))+(((cj0)*(r00)*(x12955)))))-1) <= IKFAST_SINCOS_THRESH )
    continue;
j3array[0]=IKatan2(((((IKabs(cj2) != 0)?((IkReal)1/(cj2)):(IkReal)1.0e30))*(((((IkReal(-1.00000000000000))*(r21)*(x12953)))+(((IkReal(-1.00000000000000))*(r20)*(x12955)))+(((cj5)*(r22)))))), ((((r11)*(sj0)*(x12953)))+(((IkReal(-1.00000000000000))*(cj0)*(r02)*(x12954)))+(((cj0)*(r01)*(x12953)))+(((r10)*(sj0)*(x12955)))+(((IkReal(-1.00000000000000))*(r12)*(sj0)*(x12954)))+(((cj0)*(r00)*(x12955)))));
sj3array[0]=IKsin(j3array[0]);
cj3array[0]=IKcos(j3array[0]);
if( j3array[0] > IKPI )
{
    j3array[0]-=IK2PI;
}
else if( j3array[0] < -IKPI )
{    j3array[0]+=IK2PI;
}
j3valid[0] = true;
for(int ij3 = 0; ij3 < 1; ++ij3)
{
if( !j3valid[ij3] )
{
    continue;
}
_ij3[0] = ij3; _ij3[1] = -1;
for(int iij3 = ij3+1; iij3 < 1; ++iij3)
{
if( j3valid[iij3] && IKabs(cj3array[ij3]-cj3array[iij3]) < IKFAST_SOLUTION_THRESH && IKabs(sj3array[ij3]-sj3array[iij3]) < IKFAST_SOLUTION_THRESH )
{
    j3valid[iij3]=false; _ij3[1] = iij3; break; 
}
}
j3 = j3array[ij3]; cj3 = cj3array[ij3]; sj3 = sj3array[ij3];
{
IkReal evalcond[6];
IkReal x12956=IKsin(j3);
IkReal x12957=IKcos(j3);
IkReal x12958=((sj0)*(sj5));
IkReal x12959=((r00)*(sj6));
IkReal x12960=((IkReal(1.00000000000000))*(cj4));
IkReal x12961=((cj6)*(r01));
IkReal x12962=((cj0)*(cj5));
IkReal x12963=((cj5)*(sj0));
IkReal x12964=((cj6)*(r11));
IkReal x12965=((cj6)*(sj4));
IkReal x12966=((cj0)*(sj5));
IkReal x12967=((cj4)*(cj5));
IkReal x12968=((cj6)*(r21));
IkReal x12969=((r20)*(sj6));
IkReal x12970=((r10)*(sj6));
IkReal x12971=((IkReal(1.00000000000000))*(cj0));
IkReal x12972=((cj0)*(sj4)*(sj6));
IkReal x12973=((sj0)*(sj4)*(sj6));
evalcond[0]=((((cj2)*(x12956)))+(((sj5)*(x12968)))+(((IkReal(-1.00000000000000))*(cj5)*(r22)))+(((sj5)*(x12969))));
evalcond[1]=((((IkReal(-1.00000000000000))*(cj2)*(x12957)))+(((IkReal(-1.00000000000000))*(r21)*(sj4)*(sj6)))+(((x12967)*(x12968)))+(((cj4)*(r22)*(sj5)))+(((x12967)*(x12969)))+(((r20)*(x12965))));
evalcond[2]=((((IkReal(-1.00000000000000))*(sj2)*(x12956)))+(((IkReal(-1.00000000000000))*(x12966)*(x12970)))+(((IkReal(-1.00000000000000))*(x12964)*(x12966)))+(((x12958)*(x12959)))+(((x12958)*(x12961)))+(((IkReal(-1.00000000000000))*(r02)*(x12963)))+(((r12)*(x12962))));
evalcond[3]=((((IkReal(-1.00000000000000))*(x12958)*(x12964)))+(((r12)*(x12963)))+(((IkReal(-1.00000000000000))*(x12961)*(x12966)))+(((r02)*(x12962)))+(((IkReal(-1.00000000000000))*(x12958)*(x12970)))+(((IkReal(-1.00000000000000))*(x12959)*(x12966)))+(x12957));
evalcond[4]=((((IkReal(-1.00000000000000))*(x12960)*(x12962)*(x12970)))+(((cj4)*(r02)*(x12958)))+(((IkReal(-1.00000000000000))*(r10)*(x12965)*(x12971)))+(((IkReal(-1.00000000000000))*(x12960)*(x12962)*(x12964)))+(((r00)*(sj0)*(x12965)))+(((cj4)*(x12959)*(x12963)))+(((cj4)*(x12961)*(x12963)))+(((IkReal(-1.00000000000000))*(r12)*(x12960)*(x12966)))+(((IkReal(-1.00000000000000))*(r01)*(x12973)))+(((sj2)*(x12957)))+(((r11)*(x12972))));
evalcond[5]=((((r11)*(x12973)))+(((r01)*(x12972)))+(((IkReal(-1.00000000000000))*(x12960)*(x12961)*(x12962)))+(((IkReal(-1.00000000000000))*(x12960)*(x12963)*(x12964)))+(((IkReal(-1.00000000000000))*(r12)*(x12958)*(x12960)))+(((IkReal(-1.00000000000000))*(r00)*(x12965)*(x12971)))+(((IkReal(-1.00000000000000))*(r10)*(sj0)*(x12965)))+(((IkReal(-1.00000000000000))*(x12959)*(x12960)*(x12962)))+(((IkReal(-1.00000000000000))*(x12960)*(x12963)*(x12970)))+(x12956)+(((IkReal(-1.00000000000000))*(r02)*(x12960)*(x12966))));
if( IKabs(evalcond[0]) > 0.000001  || IKabs(evalcond[1]) > 0.000001  || IKabs(evalcond[2]) > 0.000001  || IKabs(evalcond[3]) > 0.000001  || IKabs(evalcond[4]) > 0.000001  || IKabs(evalcond[5]) > 0.000001  )
{
continue;
}
}

{
std::vector<IkSingleDOFSolutionBase<IkReal> > vinfos(7);
vinfos[0].jointtype = 1;
vinfos[0].foffset = j0;
vinfos[0].indices[0] = _ij0[0];
vinfos[0].indices[1] = _ij0[1];
vinfos[0].maxsolutions = _nj0;
vinfos[1].jointtype = 1;
vinfos[1].foffset = j1;
vinfos[1].indices[0] = _ij1[0];
vinfos[1].indices[1] = _ij1[1];
vinfos[1].maxsolutions = _nj1;
vinfos[2].jointtype = 1;
vinfos[2].foffset = j2;
vinfos[2].indices[0] = _ij2[0];
vinfos[2].indices[1] = _ij2[1];
vinfos[2].maxsolutions = _nj2;
vinfos[3].jointtype = 1;
vinfos[3].foffset = j3;
vinfos[3].indices[0] = _ij3[0];
vinfos[3].indices[1] = _ij3[1];
vinfos[3].maxsolutions = _nj3;
vinfos[4].jointtype = 1;
vinfos[4].foffset = j4;
vinfos[4].indices[0] = _ij4[0];
vinfos[4].indices[1] = _ij4[1];
vinfos[4].maxsolutions = _nj4;
vinfos[5].jointtype = 1;
vinfos[5].foffset = j5;
vinfos[5].indices[0] = _ij5[0];
vinfos[5].indices[1] = _ij5[1];
vinfos[5].maxsolutions = _nj5;
vinfos[6].jointtype = 1;
vinfos[6].foffset = j6;
vinfos[6].indices[0] = _ij6[0];
vinfos[6].indices[1] = _ij6[1];
vinfos[6].maxsolutions = _nj6;
std::vector<int> vfree(0);
solutions.AddSolution(vinfos,vfree);
}
}
}

}

}

} else
{
{
IkReal j3array[1], cj3array[1], sj3array[1];
bool j3valid[1]={false};
_nj3 = 1;
IkReal x12974=((IkReal(1.00000000000000))*(r21));
IkReal x12975=((cj4)*(cj5));
IkReal x12976=((r20)*(sj6));
if( IKabs(((gconst10)*(((((IkReal(-1.00000000000000))*(sj5)*(x12976)))+(((IkReal(-1.00000000000000))*(cj6)*(sj5)*(x12974)))+(((cj5)*(r22))))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(((gconst10)*(((((cj6)*(r20)*(sj4)))+(((cj4)*(r22)*(sj5)))+(((IkReal(-1.00000000000000))*(sj4)*(sj6)*(x12974)))+(((cj6)*(r21)*(x12975)))+(((x12975)*(x12976))))))) < IKFAST_ATAN2_MAGTHRESH )
    continue;
j3array[0]=IKatan2(((gconst10)*(((((IkReal(-1.00000000000000))*(sj5)*(x12976)))+(((IkReal(-1.00000000000000))*(cj6)*(sj5)*(x12974)))+(((cj5)*(r22)))))), ((gconst10)*(((((cj6)*(r20)*(sj4)))+(((cj4)*(r22)*(sj5)))+(((IkReal(-1.00000000000000))*(sj4)*(sj6)*(x12974)))+(((cj6)*(r21)*(x12975)))+(((x12975)*(x12976)))))));
sj3array[0]=IKsin(j3array[0]);
cj3array[0]=IKcos(j3array[0]);
if( j3array[0] > IKPI )
{
    j3array[0]-=IK2PI;
}
else if( j3array[0] < -IKPI )
{    j3array[0]+=IK2PI;
}
j3valid[0] = true;
for(int ij3 = 0; ij3 < 1; ++ij3)
{
if( !j3valid[ij3] )
{
    continue;
}
_ij3[0] = ij3; _ij3[1] = -1;
for(int iij3 = ij3+1; iij3 < 1; ++iij3)
{
if( j3valid[iij3] && IKabs(cj3array[ij3]-cj3array[iij3]) < IKFAST_SOLUTION_THRESH && IKabs(sj3array[ij3]-sj3array[iij3]) < IKFAST_SOLUTION_THRESH )
{
    j3valid[iij3]=false; _ij3[1] = iij3; break; 
}
}
j3 = j3array[ij3]; cj3 = cj3array[ij3]; sj3 = sj3array[ij3];
{
IkReal evalcond[6];
IkReal x12977=IKsin(j3);
IkReal x12978=IKcos(j3);
IkReal x12979=((sj0)*(sj5));
IkReal x12980=((r00)*(sj6));
IkReal x12981=((IkReal(1.00000000000000))*(cj4));
IkReal x12982=((cj6)*(r01));
IkReal x12983=((cj0)*(cj5));
IkReal x12984=((cj5)*(sj0));
IkReal x12985=((cj6)*(r11));
IkReal x12986=((cj6)*(sj4));
IkReal x12987=((cj0)*(sj5));
IkReal x12988=((cj4)*(cj5));
IkReal x12989=((cj6)*(r21));
IkReal x12990=((r20)*(sj6));
IkReal x12991=((r10)*(sj6));
IkReal x12992=((IkReal(1.00000000000000))*(cj0));
IkReal x12993=((cj0)*(sj4)*(sj6));
IkReal x12994=((sj0)*(sj4)*(sj6));
evalcond[0]=((((sj5)*(x12990)))+(((IkReal(-1.00000000000000))*(cj5)*(r22)))+(((sj5)*(x12989)))+(((cj2)*(x12977))));
evalcond[1]=((((IkReal(-1.00000000000000))*(r21)*(sj4)*(sj6)))+(((IkReal(-1.00000000000000))*(cj2)*(x12978)))+(((x12988)*(x12989)))+(((cj4)*(r22)*(sj5)))+(((x12988)*(x12990)))+(((r20)*(x12986))));
evalcond[2]=((((r12)*(x12983)))+(((x12979)*(x12982)))+(((IkReal(-1.00000000000000))*(x12987)*(x12991)))+(((x12979)*(x12980)))+(((IkReal(-1.00000000000000))*(sj2)*(x12977)))+(((IkReal(-1.00000000000000))*(r02)*(x12984)))+(((IkReal(-1.00000000000000))*(x12985)*(x12987))));
evalcond[3]=((((r02)*(x12983)))+(((IkReal(-1.00000000000000))*(x12982)*(x12987)))+(x12978)+(((IkReal(-1.00000000000000))*(x12979)*(x12991)))+(((IkReal(-1.00000000000000))*(x12979)*(x12985)))+(((IkReal(-1.00000000000000))*(x12980)*(x12987)))+(((r12)*(x12984))));
evalcond[4]=((((IkReal(-1.00000000000000))*(x12981)*(x12983)*(x12985)))+(((IkReal(-1.00000000000000))*(r12)*(x12981)*(x12987)))+(((sj2)*(x12978)))+(((cj4)*(x12980)*(x12984)))+(((cj4)*(r02)*(x12979)))+(((IkReal(-1.00000000000000))*(r10)*(x12986)*(x12992)))+(((IkReal(-1.00000000000000))*(x12981)*(x12983)*(x12991)))+(((cj4)*(x12982)*(x12984)))+(((IkReal(-1.00000000000000))*(r01)*(x12994)))+(((r11)*(x12993)))+(((r00)*(sj0)*(x12986))));
evalcond[5]=((((IkReal(-1.00000000000000))*(x12980)*(x12981)*(x12983)))+(((r01)*(x12993)))+(((r11)*(x12994)))+(((IkReal(-1.00000000000000))*(r10)*(sj0)*(x12986)))+(((IkReal(-1.00000000000000))*(x12981)*(x12984)*(x12985)))+(x12977)+(((IkReal(-1.00000000000000))*(r02)*(x12981)*(x12987)))+(((IkReal(-1.00000000000000))*(x12981)*(x12984)*(x12991)))+(((IkReal(-1.00000000000000))*(x12981)*(x12982)*(x12983)))+(((IkReal(-1.00000000000000))*(r00)*(x12986)*(x12992)))+(((IkReal(-1.00000000000000))*(r12)*(x12979)*(x12981))));
if( IKabs(evalcond[0]) > 0.000001  || IKabs(evalcond[1]) > 0.000001  || IKabs(evalcond[2]) > 0.000001  || IKabs(evalcond[3]) > 0.000001  || IKabs(evalcond[4]) > 0.000001  || IKabs(evalcond[5]) > 0.000001  )
{
continue;
}
}

{
std::vector<IkSingleDOFSolutionBase<IkReal> > vinfos(7);
vinfos[0].jointtype = 1;
vinfos[0].foffset = j0;
vinfos[0].indices[0] = _ij0[0];
vinfos[0].indices[1] = _ij0[1];
vinfos[0].maxsolutions = _nj0;
vinfos[1].jointtype = 1;
vinfos[1].foffset = j1;
vinfos[1].indices[0] = _ij1[0];
vinfos[1].indices[1] = _ij1[1];
vinfos[1].maxsolutions = _nj1;
vinfos[2].jointtype = 1;
vinfos[2].foffset = j2;
vinfos[2].indices[0] = _ij2[0];
vinfos[2].indices[1] = _ij2[1];
vinfos[2].maxsolutions = _nj2;
vinfos[3].jointtype = 1;
vinfos[3].foffset = j3;
vinfos[3].indices[0] = _ij3[0];
vinfos[3].indices[1] = _ij3[1];
vinfos[3].maxsolutions = _nj3;
vinfos[4].jointtype = 1;
vinfos[4].foffset = j4;
vinfos[4].indices[0] = _ij4[0];
vinfos[4].indices[1] = _ij4[1];
vinfos[4].maxsolutions = _nj4;
vinfos[5].jointtype = 1;
vinfos[5].foffset = j5;
vinfos[5].indices[0] = _ij5[0];
vinfos[5].indices[1] = _ij5[1];
vinfos[5].maxsolutions = _nj5;
vinfos[6].jointtype = 1;
vinfos[6].foffset = j6;
vinfos[6].indices[0] = _ij6[0];
vinfos[6].indices[1] = _ij6[1];
vinfos[6].maxsolutions = _nj6;
std::vector<int> vfree(0);
solutions.AddSolution(vinfos,vfree);
}
}
}

}

}

} else
{
IkReal x12995=((IkReal(1.00000000000000))*(cj0));
IkReal x12996=((cj4)*(sj6));
IkReal x12997=((sj0)*(sj4));
IkReal x12998=((cj5)*(sj6));
IkReal x12999=((sj4)*(sj5));
IkReal x13000=((r12)*(sj5));
IkReal x13001=((IkReal(0.374290000000000))*(cj5));
IkReal x13002=((r02)*(sj0));
IkReal x13003=((IkReal(1.00000000000000))*(sj0));
IkReal x13004=((cj0)*(r10));
IkReal x13005=((cj4)*(cj6));
IkReal x13006=((r00)*(sj0));
IkReal x13007=((cj6)*(r21));
IkReal x13008=((IkReal(0.374290000000000))*(sj5));
IkReal x13009=((IkReal(0.0100000000000000))*(sj5));
IkReal x13010=((cj0)*(r02));
IkReal x13011=((cj5)*(sj4));
IkReal x13012=((cj6)*(r01));
IkReal x13013=((cj0)*(r00));
IkReal x13014=((cj6)*(r11));
IkReal x13015=((r01)*(sj0));
IkReal x13016=((r10)*(sj0));
IkReal x13017=((IkReal(0.0100000000000000))*(cj5)*(cj6));
IkReal x13018=((sj6)*(x13008));
IkReal x13019=((cj0)*(cj6)*(x13008));
evalcond[0]=((IkReal(-3.14159265358979))+(IKfmod(((IkReal(1.57079632679490))+(j2)), IkReal(6.28318530717959))));
evalcond[1]=((((x13007)*(x13011)))+(((r21)*(x12996)))+(((r20)*(sj4)*(x12998)))+(((IkReal(-1.00000000000000))*(cj1)))+(((r22)*(x12999)))+(((IkReal(-1.00000000000000))*(r20)*(x13005))));
evalcond[2]=((((IkReal(-0.0100000000000000))*(cj5)*(x13007)))+(((x13007)*(x13008)))+(((r20)*(x13018)))+(((IkReal(0.364420000000000))*(sj1)))+(((IkReal(-1.00000000000000))*(r22)*(x13009)))+(((IkReal(-1.00000000000000))*(r22)*(x13001)))+(((IkReal(-0.0100000000000000))*(r20)*(x12998)))+(pz));
evalcond[3]=((((r00)*(x12997)*(x12998)))+(((r02)*(sj5)*(x12997)))+(((IkReal(-1.00000000000000))*(r10)*(sj4)*(x12995)*(x12998)))+(((IkReal(-1.00000000000000))*(r11)*(x12995)*(x12996)))+(((x12996)*(x13015)))+(((x13004)*(x13005)))+(((IkReal(-1.00000000000000))*(r12)*(x12995)*(x12999)))+(((IkReal(-1.00000000000000))*(x12995)*(x13011)*(x13014)))+(((IkReal(-1.00000000000000))*(r00)*(x13003)*(x13005)))+(((cj5)*(x12997)*(x13012))));
evalcond[4]=((((IkReal(-1.00000000000000))*(r02)*(x12995)*(x12999)))+(((IkReal(-1.00000000000000))*(x12997)*(x13000)))+(((IkReal(-1.00000000000000))*(r01)*(x12995)*(x12996)))+(sj1)+(((IkReal(-1.00000000000000))*(r11)*(x12996)*(x13003)))+(((x13005)*(x13016)))+(((x13005)*(x13013)))+(((IkReal(-1.00000000000000))*(r10)*(x12997)*(x12998)))+(((IkReal(-1.00000000000000))*(x12995)*(x13011)*(x13012)))+(((IkReal(-1.00000000000000))*(cj5)*(x12997)*(x13014)))+(((IkReal(-1.00000000000000))*(r00)*(sj4)*(x12995)*(x12998))));
evalcond[5]=((IkReal(0.0690000000000000))+(((IkReal(0.0100000000000000))*(cj0)*(cj5)*(x13014)))+(((IkReal(-1.00000000000000))*(py)*(x12995)))+(((IkReal(-0.0100000000000000))*(cj5)*(sj0)*(x13012)))+(((IkReal(-0.0100000000000000))*(x12998)*(x13006)))+(((IkReal(-1.00000000000000))*(x13002)*(x13009)))+(((IkReal(-1.00000000000000))*(cj0)*(x13008)*(x13014)))+(((IkReal(-1.00000000000000))*(x13001)*(x13002)))+(((cj0)*(r12)*(x13001)))+(((IkReal(-1.00000000000000))*(x13004)*(x13018)))+(((IkReal(0.0100000000000000))*(x12998)*(x13004)))+(((x13006)*(x13018)))+(((sj0)*(x13008)*(x13012)))+(((IkReal(0.0100000000000000))*(cj0)*(x13000)))+(((px)*(sj0))));
evalcond[6]=((IkReal(0.0690000000000000))+(((IkReal(-1.00000000000000))*(cj0)*(x13008)*(x13012)))+(((IkReal(-1.00000000000000))*(py)*(x13003)))+(((IkReal(0.0100000000000000))*(x12998)*(x13016)))+(((IkReal(0.0100000000000000))*(x12998)*(x13013)))+(((IkReal(-1.00000000000000))*(x13013)*(x13018)))+(((IkReal(0.0100000000000000))*(cj0)*(cj5)*(x13012)))+(((IkReal(-1.00000000000000))*(x13016)*(x13018)))+(((r12)*(sj0)*(x13001)))+(((x13001)*(x13010)))+(((IkReal(-1.00000000000000))*(px)*(x12995)))+(((IkReal(0.0100000000000000))*(sj0)*(x13000)))+(((x13009)*(x13010)))+(((IkReal(0.364420000000000))*(cj1)))+(((IkReal(-1.00000000000000))*(sj0)*(x13008)*(x13014)))+(((IkReal(0.0100000000000000))*(cj5)*(sj0)*(x13014))));
if( IKabs(evalcond[0]) < 0.0000010000000000  && IKabs(evalcond[1]) < 0.0000010000000000  && IKabs(evalcond[2]) < 0.0000010000000000  && IKabs(evalcond[3]) < 0.0000010000000000  && IKabs(evalcond[4]) < 0.0000010000000000  && IKabs(evalcond[5]) < 0.0000010000000000  && IKabs(evalcond[6]) < 0.0000010000000000  )
{
{
IkReal dummyeval[1];
IkReal gconst11;
gconst11=IKsign(sj1);
dummyeval[0]=sj1;
if( IKabs(dummyeval[0]) < 0.0000010000000000  )
{
{
IkReal dummyeval[1];
dummyeval[0]=sj1;
if( IKabs(dummyeval[0]) < 0.0000010000000000  )
{
{
IkReal dummyeval[1];
dummyeval[0]=cj1;
if( IKabs(dummyeval[0]) < 0.0000010000000000  )
{
{
IkReal evalcond[9];
IkReal x13020=((IkReal(1.00000000000000))*(cj0));
IkReal x13021=((cj4)*(sj6));
IkReal x13022=((sj0)*(sj6));
IkReal x13023=((cj5)*(sj4));
IkReal x13024=((IkReal(0.374290000000000))*(sj5));
IkReal x13025=((sj4)*(sj5));
IkReal x13026=((cj0)*(cj6));
IkReal x13027=((IkReal(0.0100000000000000))*(cj5));
IkReal x13028=((cj4)*(sj5));
IkReal x13029=((cj5)*(sj0));
IkReal x13030=((IkReal(0.374290000000000))*(r02));
IkReal x13031=((r20)*(sj6));
IkReal x13032=((cj6)*(r21));
IkReal x13033=((IkReal(1.00000000000000))*(sj0));
IkReal x13034=((cj0)*(sj6));
IkReal x13035=((cj4)*(cj6));
IkReal x13036=((IkReal(0.374290000000000))*(r12));
IkReal x13037=((cj0)*(cj5));
IkReal x13038=((cj6)*(sj5));
IkReal x13039=((cj6)*(r01));
IkReal x13040=((r00)*(sj6));
IkReal x13041=((IkReal(0.0100000000000000))*(sj5));
IkReal x13042=((cj6)*(r11));
IkReal x13043=((IkReal(1.00000000000000))*(r10));
IkReal x13044=((r02)*(sj0));
IkReal x13045=((cj6)*(sj4));
IkReal x13046=((r12)*(x13033));
evalcond[0]=((IkReal(-3.14159265358979))+(IKfmod(((IkReal(1.57079632679490))+(j1)), IkReal(6.28318530717959))));
evalcond[1]=((((r22)*(x13025)))+(((IkReal(-1.00000000000000))*(r20)*(x13035)))+(((x13023)*(x13031)))+(((r21)*(x13021)))+(((x13023)*(x13032))));
evalcond[2]=((IkReal(0.364420000000000))+(((x13024)*(x13031)))+(((IkReal(-0.374290000000000))*(cj5)*(r22)))+(((IkReal(-1.00000000000000))*(x13027)*(x13031)))+(pz)+(((IkReal(-1.00000000000000))*(x13027)*(x13032)))+(((x13024)*(x13032)))+(((IkReal(-1.00000000000000))*(r22)*(x13041))));
evalcond[3]=((((r12)*(x13029)))+(((IkReal(-1.00000000000000))*(sj5)*(x13020)*(x13040)))+(((IkReal(-1.00000000000000))*(r11)*(x13033)*(x13038)))+(((r02)*(x13037)))+(((IkReal(-1.00000000000000))*(r01)*(x13020)*(x13038)))+(((IkReal(-1.00000000000000))*(sj5)*(x13022)*(x13043))));
evalcond[4]=((((x13025)*(x13044)))+(((IkReal(-1.00000000000000))*(r11)*(x13020)*(x13021)))+(((cj4)*(r10)*(x13026)))+(((IkReal(-1.00000000000000))*(r10)*(sj6)*(x13020)*(x13023)))+(((r00)*(x13022)*(x13023)))+(((r01)*(sj0)*(x13021)))+(((IkReal(-1.00000000000000))*(x13020)*(x13023)*(x13042)))+(((IkReal(-1.00000000000000))*(r00)*(x13033)*(x13035)))+(((sj0)*(x13023)*(x13039)))+(((IkReal(-1.00000000000000))*(r12)*(x13020)*(x13025))));
evalcond[5]=((IkReal(1.00000000000000))+(((IkReal(-1.00000000000000))*(x13020)*(x13023)*(x13040)))+(((IkReal(-1.00000000000000))*(x13025)*(x13046)))+(((IkReal(-1.00000000000000))*(r02)*(x13020)*(x13025)))+(((IkReal(-1.00000000000000))*(r01)*(x13020)*(x13021)))+(((cj4)*(r00)*(x13026)))+(((IkReal(-1.00000000000000))*(x13023)*(x13033)*(x13042)))+(((IkReal(-1.00000000000000))*(x13020)*(x13023)*(x13039)))+(((r10)*(sj0)*(x13035)))+(((IkReal(-1.00000000000000))*(x13022)*(x13023)*(x13043)))+(((IkReal(-1.00000000000000))*(r11)*(x13021)*(x13033))));
evalcond[6]=((IkReal(0.0690000000000000))+(((r11)*(x13026)*(x13027)))+(((IkReal(-1.00000000000000))*(x13041)*(x13044)))+(((IkReal(-1.00000000000000))*(r00)*(x13022)*(x13027)))+(((IkReal(-1.00000000000000))*(r11)*(x13024)*(x13026)))+(((r00)*(x13022)*(x13024)))+(((IkReal(-1.00000000000000))*(sj0)*(x13027)*(x13039)))+(((IkReal(-1.00000000000000))*(r10)*(x13024)*(x13034)))+(((IkReal(-1.00000000000000))*(x13029)*(x13030)))+(((IkReal(-1.00000000000000))*(py)*(x13020)))+(((sj0)*(x13024)*(x13039)))+(((cj0)*(r12)*(x13041)))+(((x13036)*(x13037)))+(((r10)*(x13027)*(x13034)))+(((px)*(sj0))));
evalcond[7]=((((IkReal(-1.00000000000000))*(r00)*(x13020)*(x13045)))+(((IkReal(-1.00000000000000))*(cj5)*(r00)*(x13020)*(x13021)))+(((r11)*(sj4)*(x13022)))+(((IkReal(-1.00000000000000))*(cj5)*(r01)*(x13020)*(x13035)))+(((IkReal(-1.00000000000000))*(x13021)*(x13029)*(x13043)))+(((IkReal(-1.00000000000000))*(r10)*(x13033)*(x13045)))+(((r01)*(sj4)*(x13034)))+(((IkReal(-1.00000000000000))*(r11)*(x13029)*(x13035)))+(((IkReal(-1.00000000000000))*(x13028)*(x13046)))+(((IkReal(-1.00000000000000))*(r02)*(x13020)*(x13028))));
evalcond[8]=((IkReal(0.0690000000000000))+(((x13030)*(x13037)))+(((r00)*(x13027)*(x13034)))+(((r10)*(x13022)*(x13027)))+(((IkReal(-1.00000000000000))*(px)*(x13020)))+(((IkReal(-1.00000000000000))*(r00)*(x13024)*(x13034)))+(((IkReal(-1.00000000000000))*(r10)*(x13022)*(x13024)))+(((cj0)*(r02)*(x13041)))+(((x13029)*(x13036)))+(((r12)*(sj0)*(x13041)))+(((sj0)*(x13027)*(x13042)))+(((r01)*(x13026)*(x13027)))+(((IkReal(-1.00000000000000))*(sj0)*(x13024)*(x13042)))+(((IkReal(-1.00000000000000))*(r01)*(x13024)*(x13026)))+(((IkReal(-1.00000000000000))*(py)*(x13033))));
if( IKabs(evalcond[0]) < 0.0000010000000000  && IKabs(evalcond[1]) < 0.0000010000000000  && IKabs(evalcond[2]) < 0.0000010000000000  && IKabs(evalcond[3]) < 0.0000010000000000  && IKabs(evalcond[4]) < 0.0000010000000000  && IKabs(evalcond[5]) < 0.0000010000000000  && IKabs(evalcond[6]) < 0.0000010000000000  && IKabs(evalcond[7]) < 0.0000010000000000  && IKabs(evalcond[8]) < 0.0000010000000000  )
{
{
IkReal j3array[1], cj3array[1], sj3array[1];
bool j3valid[1]={false};
_nj3 = 1;
IkReal x13047=((r20)*(sj6));
IkReal x13048=((cj4)*(cj5));
IkReal x13049=((cj6)*(r21));
if( IKabs(((((x13047)*(x13048)))+(((IkReal(-1.00000000000000))*(r21)*(sj4)*(sj6)))+(((cj6)*(r20)*(sj4)))+(((cj4)*(r22)*(sj5)))+(((x13048)*(x13049))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(((((IkReal(-1.00000000000000))*(cj5)*(r22)))+(((sj5)*(x13047)))+(((sj5)*(x13049))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(IKsqr(((((x13047)*(x13048)))+(((IkReal(-1.00000000000000))*(r21)*(sj4)*(sj6)))+(((cj6)*(r20)*(sj4)))+(((cj4)*(r22)*(sj5)))+(((x13048)*(x13049)))))+IKsqr(((((IkReal(-1.00000000000000))*(cj5)*(r22)))+(((sj5)*(x13047)))+(((sj5)*(x13049)))))-1) <= IKFAST_SINCOS_THRESH )
    continue;
j3array[0]=IKatan2(((((x13047)*(x13048)))+(((IkReal(-1.00000000000000))*(r21)*(sj4)*(sj6)))+(((cj6)*(r20)*(sj4)))+(((cj4)*(r22)*(sj5)))+(((x13048)*(x13049)))), ((((IkReal(-1.00000000000000))*(cj5)*(r22)))+(((sj5)*(x13047)))+(((sj5)*(x13049)))));
sj3array[0]=IKsin(j3array[0]);
cj3array[0]=IKcos(j3array[0]);
if( j3array[0] > IKPI )
{
    j3array[0]-=IK2PI;
}
else if( j3array[0] < -IKPI )
{    j3array[0]+=IK2PI;
}
j3valid[0] = true;
for(int ij3 = 0; ij3 < 1; ++ij3)
{
if( !j3valid[ij3] )
{
    continue;
}
_ij3[0] = ij3; _ij3[1] = -1;
for(int iij3 = ij3+1; iij3 < 1; ++iij3)
{
if( j3valid[iij3] && IKabs(cj3array[ij3]-cj3array[iij3]) < IKFAST_SOLUTION_THRESH && IKabs(sj3array[ij3]-sj3array[iij3]) < IKFAST_SOLUTION_THRESH )
{
    j3valid[iij3]=false; _ij3[1] = iij3; break; 
}
}
j3 = j3array[ij3]; cj3 = cj3array[ij3]; sj3 = sj3array[ij3];
{
IkReal evalcond[4];
IkReal x13050=IKcos(j3);
IkReal x13051=((sj0)*(sj5));
IkReal x13052=((r00)*(sj6));
IkReal x13053=((cj6)*(r01));
IkReal x13054=((cj5)*(sj0));
IkReal x13055=((cj0)*(cj5));
IkReal x13056=((cj6)*(sj4));
IkReal x13057=((sj4)*(sj6));
IkReal x13058=((cj0)*(r11));
IkReal x13059=((cj4)*(cj6));
IkReal x13060=((cj4)*(sj6));
IkReal x13061=((IkReal(1.00000000000000))*(cj0));
IkReal x13062=((cj4)*(sj5));
IkReal x13063=((sj5)*(sj6));
IkReal x13064=((cj6)*(sj5));
IkReal x13065=((IkReal(1.00000000000000))*(IKsin(j3)));
evalcond[0]=((((IkReal(-1.00000000000000))*(x13050)))+(((r21)*(x13064)))+(((IkReal(-1.00000000000000))*(cj5)*(r22)))+(((r20)*(x13063))));
evalcond[1]=((((r22)*(x13062)))+(((IkReal(-1.00000000000000))*(r21)*(x13057)))+(((IkReal(-1.00000000000000))*(x13065)))+(((r20)*(x13056)))+(((cj5)*(r20)*(x13060)))+(((cj5)*(r21)*(x13059))));
evalcond[2]=((((r12)*(x13055)))+(((x13051)*(x13052)))+(((IkReal(-1.00000000000000))*(x13058)*(x13064)))+(((x13051)*(x13053)))+(((IkReal(-1.00000000000000))*(x13065)))+(((IkReal(-1.00000000000000))*(r10)*(x13061)*(x13063)))+(((IkReal(-1.00000000000000))*(r02)*(x13054))));
evalcond[3]=((((IkReal(-1.00000000000000))*(r01)*(sj0)*(x13057)))+(((x13057)*(x13058)))+(((r00)*(sj0)*(x13056)))+(((IkReal(-1.00000000000000))*(r10)*(x13056)*(x13061)))+(((IkReal(-1.00000000000000))*(r12)*(x13061)*(x13062)))+(((cj4)*(r02)*(x13051)))+(((IkReal(-1.00000000000000))*(r11)*(x13055)*(x13059)))+(((IkReal(-1.00000000000000))*(r10)*(x13055)*(x13060)))+(((cj4)*(x13053)*(x13054)))+(x13050)+(((cj4)*(x13052)*(x13054))));
if( IKabs(evalcond[0]) > 0.000001  || IKabs(evalcond[1]) > 0.000001  || IKabs(evalcond[2]) > 0.000001  || IKabs(evalcond[3]) > 0.000001  )
{
continue;
}
}

{
std::vector<IkSingleDOFSolutionBase<IkReal> > vinfos(7);
vinfos[0].jointtype = 1;
vinfos[0].foffset = j0;
vinfos[0].indices[0] = _ij0[0];
vinfos[0].indices[1] = _ij0[1];
vinfos[0].maxsolutions = _nj0;
vinfos[1].jointtype = 1;
vinfos[1].foffset = j1;
vinfos[1].indices[0] = _ij1[0];
vinfos[1].indices[1] = _ij1[1];
vinfos[1].maxsolutions = _nj1;
vinfos[2].jointtype = 1;
vinfos[2].foffset = j2;
vinfos[2].indices[0] = _ij2[0];
vinfos[2].indices[1] = _ij2[1];
vinfos[2].maxsolutions = _nj2;
vinfos[3].jointtype = 1;
vinfos[3].foffset = j3;
vinfos[3].indices[0] = _ij3[0];
vinfos[3].indices[1] = _ij3[1];
vinfos[3].maxsolutions = _nj3;
vinfos[4].jointtype = 1;
vinfos[4].foffset = j4;
vinfos[4].indices[0] = _ij4[0];
vinfos[4].indices[1] = _ij4[1];
vinfos[4].maxsolutions = _nj4;
vinfos[5].jointtype = 1;
vinfos[5].foffset = j5;
vinfos[5].indices[0] = _ij5[0];
vinfos[5].indices[1] = _ij5[1];
vinfos[5].maxsolutions = _nj5;
vinfos[6].jointtype = 1;
vinfos[6].foffset = j6;
vinfos[6].indices[0] = _ij6[0];
vinfos[6].indices[1] = _ij6[1];
vinfos[6].maxsolutions = _nj6;
std::vector<int> vfree(0);
solutions.AddSolution(vinfos,vfree);
}
}
}

} else
{
IkReal x13066=((IkReal(1.00000000000000))*(cj0));
IkReal x13067=((cj4)*(sj6));
IkReal x13068=((sj0)*(sj6));
IkReal x13069=((cj5)*(sj4));
IkReal x13070=((IkReal(0.374290000000000))*(sj5));
IkReal x13071=((sj4)*(sj5));
IkReal x13072=((cj0)*(cj6));
IkReal x13073=((IkReal(0.0100000000000000))*(cj5));
IkReal x13074=((cj4)*(sj5));
IkReal x13075=((cj5)*(sj0));
IkReal x13076=((IkReal(0.374290000000000))*(r02));
IkReal x13077=((r20)*(sj6));
IkReal x13078=((cj6)*(r21));
IkReal x13079=((IkReal(1.00000000000000))*(sj0));
IkReal x13080=((cj0)*(sj6));
IkReal x13081=((cj4)*(cj6));
IkReal x13082=((IkReal(0.374290000000000))*(r12));
IkReal x13083=((cj0)*(cj5));
IkReal x13084=((cj6)*(sj5));
IkReal x13085=((cj6)*(r01));
IkReal x13086=((r00)*(sj6));
IkReal x13087=((IkReal(0.0100000000000000))*(sj5));
IkReal x13088=((cj6)*(r11));
IkReal x13089=((IkReal(1.00000000000000))*(r10));
IkReal x13090=((r02)*(sj0));
IkReal x13091=((cj6)*(sj4));
IkReal x13092=((r12)*(x13079));
evalcond[0]=((IkReal(-3.14159265358979))+(IKfmod(((IkReal(4.71238898038469))+(j1)), IkReal(6.28318530717959))));
evalcond[1]=((((x13069)*(x13078)))+(((r22)*(x13071)))+(((IkReal(-1.00000000000000))*(r20)*(x13081)))+(((x13069)*(x13077)))+(((r21)*(x13067))));
evalcond[2]=((IkReal(-0.364420000000000))+(((IkReal(-1.00000000000000))*(x13073)*(x13077)))+(((IkReal(-0.374290000000000))*(cj5)*(r22)))+(((IkReal(-1.00000000000000))*(r22)*(x13087)))+(((x13070)*(x13078)))+(((IkReal(-1.00000000000000))*(x13073)*(x13078)))+(pz)+(((x13070)*(x13077))));
evalcond[3]=((((r02)*(x13083)))+(((IkReal(-1.00000000000000))*(sj5)*(x13066)*(x13086)))+(((IkReal(-1.00000000000000))*(r11)*(x13079)*(x13084)))+(((r12)*(x13075)))+(((IkReal(-1.00000000000000))*(r01)*(x13066)*(x13084)))+(((IkReal(-1.00000000000000))*(sj5)*(x13068)*(x13089))));
evalcond[4]=((((IkReal(-1.00000000000000))*(x13066)*(x13069)*(x13088)))+(((r01)*(sj0)*(x13067)))+(((IkReal(-1.00000000000000))*(r11)*(x13066)*(x13067)))+(((sj0)*(x13069)*(x13085)))+(((x13071)*(x13090)))+(((IkReal(-1.00000000000000))*(r00)*(x13079)*(x13081)))+(((r00)*(x13068)*(x13069)))+(((IkReal(-1.00000000000000))*(r12)*(x13066)*(x13071)))+(((IkReal(-1.00000000000000))*(r10)*(sj6)*(x13066)*(x13069)))+(((cj4)*(r10)*(x13072))));
evalcond[5]=((IkReal(-1.00000000000000))+(((r10)*(sj0)*(x13081)))+(((IkReal(-1.00000000000000))*(x13071)*(x13092)))+(((IkReal(-1.00000000000000))*(r11)*(x13067)*(x13079)))+(((IkReal(-1.00000000000000))*(x13068)*(x13069)*(x13089)))+(((cj4)*(r00)*(x13072)))+(((IkReal(-1.00000000000000))*(x13069)*(x13079)*(x13088)))+(((IkReal(-1.00000000000000))*(x13066)*(x13069)*(x13085)))+(((IkReal(-1.00000000000000))*(x13066)*(x13069)*(x13086)))+(((IkReal(-1.00000000000000))*(r01)*(x13066)*(x13067)))+(((IkReal(-1.00000000000000))*(r02)*(x13066)*(x13071))));
evalcond[6]=((IkReal(0.0690000000000000))+(((r10)*(x13073)*(x13080)))+(((IkReal(-1.00000000000000))*(py)*(x13066)))+(((IkReal(-1.00000000000000))*(r10)*(x13070)*(x13080)))+(((IkReal(-1.00000000000000))*(sj0)*(x13073)*(x13085)))+(((IkReal(-1.00000000000000))*(x13075)*(x13076)))+(((IkReal(-1.00000000000000))*(r00)*(x13068)*(x13073)))+(((r11)*(x13072)*(x13073)))+(((IkReal(-1.00000000000000))*(x13087)*(x13090)))+(((x13082)*(x13083)))+(((cj0)*(r12)*(x13087)))+(((IkReal(-1.00000000000000))*(r11)*(x13070)*(x13072)))+(((r00)*(x13068)*(x13070)))+(((sj0)*(x13070)*(x13085)))+(((px)*(sj0))));
evalcond[7]=((((IkReal(-1.00000000000000))*(r00)*(x13066)*(x13091)))+(((IkReal(-1.00000000000000))*(r11)*(x13075)*(x13081)))+(((IkReal(-1.00000000000000))*(cj5)*(r01)*(x13066)*(x13081)))+(((r11)*(sj4)*(x13068)))+(((IkReal(-1.00000000000000))*(cj5)*(r00)*(x13066)*(x13067)))+(((IkReal(-1.00000000000000))*(r10)*(x13079)*(x13091)))+(((IkReal(-1.00000000000000))*(r02)*(x13066)*(x13074)))+(((r01)*(sj4)*(x13080)))+(((IkReal(-1.00000000000000))*(x13067)*(x13075)*(x13089)))+(((IkReal(-1.00000000000000))*(x13074)*(x13092))));
evalcond[8]=((IkReal(0.0690000000000000))+(((IkReal(-1.00000000000000))*(px)*(x13066)))+(((r00)*(x13073)*(x13080)))+(((r10)*(x13068)*(x13073)))+(((IkReal(-1.00000000000000))*(r00)*(x13070)*(x13080)))+(((cj0)*(r02)*(x13087)))+(((r01)*(x13072)*(x13073)))+(((x13075)*(x13082)))+(((IkReal(-1.00000000000000))*(sj0)*(x13070)*(x13088)))+(((r12)*(sj0)*(x13087)))+(((IkReal(-1.00000000000000))*(py)*(x13079)))+(((IkReal(-1.00000000000000))*(r01)*(x13070)*(x13072)))+(((x13076)*(x13083)))+(((IkReal(-1.00000000000000))*(r10)*(x13068)*(x13070)))+(((sj0)*(x13073)*(x13088))));
if( IKabs(evalcond[0]) < 0.0000010000000000  && IKabs(evalcond[1]) < 0.0000010000000000  && IKabs(evalcond[2]) < 0.0000010000000000  && IKabs(evalcond[3]) < 0.0000010000000000  && IKabs(evalcond[4]) < 0.0000010000000000  && IKabs(evalcond[5]) < 0.0000010000000000  && IKabs(evalcond[6]) < 0.0000010000000000  && IKabs(evalcond[7]) < 0.0000010000000000  && IKabs(evalcond[8]) < 0.0000010000000000  )
{
{
IkReal j3array[1], cj3array[1], sj3array[1];
bool j3valid[1]={false};
_nj3 = 1;
IkReal x13093=((IkReal(1.00000000000000))*(sj5));
IkReal x13094=((cj6)*(r21));
IkReal x13095=((r20)*(sj6));
IkReal x13096=((IkReal(1.00000000000000))*(cj4)*(cj5));
if( IKabs(((((IkReal(-1.00000000000000))*(x13095)*(x13096)))+(((r21)*(sj4)*(sj6)))+(((IkReal(-1.00000000000000))*(x13094)*(x13096)))+(((IkReal(-1.00000000000000))*(cj4)*(r22)*(x13093)))+(((IkReal(-1.00000000000000))*(cj6)*(r20)*(sj4))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(((((IkReal(-1.00000000000000))*(x13093)*(x13094)))+(((IkReal(-1.00000000000000))*(x13093)*(x13095)))+(((cj5)*(r22))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(IKsqr(((((IkReal(-1.00000000000000))*(x13095)*(x13096)))+(((r21)*(sj4)*(sj6)))+(((IkReal(-1.00000000000000))*(x13094)*(x13096)))+(((IkReal(-1.00000000000000))*(cj4)*(r22)*(x13093)))+(((IkReal(-1.00000000000000))*(cj6)*(r20)*(sj4)))))+IKsqr(((((IkReal(-1.00000000000000))*(x13093)*(x13094)))+(((IkReal(-1.00000000000000))*(x13093)*(x13095)))+(((cj5)*(r22)))))-1) <= IKFAST_SINCOS_THRESH )
    continue;
j3array[0]=IKatan2(((((IkReal(-1.00000000000000))*(x13095)*(x13096)))+(((r21)*(sj4)*(sj6)))+(((IkReal(-1.00000000000000))*(x13094)*(x13096)))+(((IkReal(-1.00000000000000))*(cj4)*(r22)*(x13093)))+(((IkReal(-1.00000000000000))*(cj6)*(r20)*(sj4)))), ((((IkReal(-1.00000000000000))*(x13093)*(x13094)))+(((IkReal(-1.00000000000000))*(x13093)*(x13095)))+(((cj5)*(r22)))));
sj3array[0]=IKsin(j3array[0]);
cj3array[0]=IKcos(j3array[0]);
if( j3array[0] > IKPI )
{
    j3array[0]-=IK2PI;
}
else if( j3array[0] < -IKPI )
{    j3array[0]+=IK2PI;
}
j3valid[0] = true;
for(int ij3 = 0; ij3 < 1; ++ij3)
{
if( !j3valid[ij3] )
{
    continue;
}
_ij3[0] = ij3; _ij3[1] = -1;
for(int iij3 = ij3+1; iij3 < 1; ++iij3)
{
if( j3valid[iij3] && IKabs(cj3array[ij3]-cj3array[iij3]) < IKFAST_SOLUTION_THRESH && IKabs(sj3array[ij3]-sj3array[iij3]) < IKFAST_SOLUTION_THRESH )
{
    j3valid[iij3]=false; _ij3[1] = iij3; break; 
}
}
j3 = j3array[ij3]; cj3 = cj3array[ij3]; sj3 = sj3array[ij3];
{
IkReal evalcond[4];
IkReal x13097=IKsin(j3);
IkReal x13098=IKcos(j3);
IkReal x13099=((sj0)*(sj5));
IkReal x13100=((r00)*(sj6));
IkReal x13101=((cj6)*(r01));
IkReal x13102=((cj5)*(sj0));
IkReal x13103=((cj0)*(cj5));
IkReal x13104=((cj6)*(sj4));
IkReal x13105=((sj4)*(sj6));
IkReal x13106=((cj0)*(r11));
IkReal x13107=((cj4)*(cj6));
IkReal x13108=((cj4)*(sj6));
IkReal x13109=((IkReal(1.00000000000000))*(cj0));
IkReal x13110=((cj4)*(sj5));
IkReal x13111=((sj5)*(sj6));
IkReal x13112=((cj6)*(sj5));
evalcond[0]=((((IkReal(-1.00000000000000))*(cj5)*(r22)))+(((r20)*(x13111)))+(x13098)+(((r21)*(x13112))));
evalcond[1]=((((cj5)*(r21)*(x13107)))+(((IkReal(-1.00000000000000))*(r21)*(x13105)))+(((r22)*(x13110)))+(x13097)+(((cj5)*(r20)*(x13108)))+(((r20)*(x13104))));
evalcond[2]=((((IkReal(-1.00000000000000))*(r02)*(x13102)))+(((IkReal(-1.00000000000000))*(x13106)*(x13112)))+(((x13099)*(x13100)))+(((IkReal(-1.00000000000000))*(r10)*(x13109)*(x13111)))+(((x13099)*(x13101)))+(((IkReal(-1.00000000000000))*(x13097)))+(((r12)*(x13103))));
evalcond[3]=((((IkReal(-1.00000000000000))*(r10)*(x13103)*(x13108)))+(((cj4)*(r02)*(x13099)))+(((IkReal(-1.00000000000000))*(r11)*(x13103)*(x13107)))+(((IkReal(-1.00000000000000))*(r10)*(x13104)*(x13109)))+(((x13105)*(x13106)))+(((r00)*(sj0)*(x13104)))+(((IkReal(-1.00000000000000))*(r01)*(sj0)*(x13105)))+(((IkReal(-1.00000000000000))*(r12)*(x13109)*(x13110)))+(x13098)+(((cj4)*(x13100)*(x13102)))+(((cj4)*(x13101)*(x13102))));
if( IKabs(evalcond[0]) > 0.000001  || IKabs(evalcond[1]) > 0.000001  || IKabs(evalcond[2]) > 0.000001  || IKabs(evalcond[3]) > 0.000001  )
{
continue;
}
}

{
std::vector<IkSingleDOFSolutionBase<IkReal> > vinfos(7);
vinfos[0].jointtype = 1;
vinfos[0].foffset = j0;
vinfos[0].indices[0] = _ij0[0];
vinfos[0].indices[1] = _ij0[1];
vinfos[0].maxsolutions = _nj0;
vinfos[1].jointtype = 1;
vinfos[1].foffset = j1;
vinfos[1].indices[0] = _ij1[0];
vinfos[1].indices[1] = _ij1[1];
vinfos[1].maxsolutions = _nj1;
vinfos[2].jointtype = 1;
vinfos[2].foffset = j2;
vinfos[2].indices[0] = _ij2[0];
vinfos[2].indices[1] = _ij2[1];
vinfos[2].maxsolutions = _nj2;
vinfos[3].jointtype = 1;
vinfos[3].foffset = j3;
vinfos[3].indices[0] = _ij3[0];
vinfos[3].indices[1] = _ij3[1];
vinfos[3].maxsolutions = _nj3;
vinfos[4].jointtype = 1;
vinfos[4].foffset = j4;
vinfos[4].indices[0] = _ij4[0];
vinfos[4].indices[1] = _ij4[1];
vinfos[4].maxsolutions = _nj4;
vinfos[5].jointtype = 1;
vinfos[5].foffset = j5;
vinfos[5].indices[0] = _ij5[0];
vinfos[5].indices[1] = _ij5[1];
vinfos[5].maxsolutions = _nj5;
vinfos[6].jointtype = 1;
vinfos[6].foffset = j6;
vinfos[6].indices[0] = _ij6[0];
vinfos[6].indices[1] = _ij6[1];
vinfos[6].maxsolutions = _nj6;
std::vector<int> vfree(0);
solutions.AddSolution(vinfos,vfree);
}
}
}

} else
{
if( 1 )
{
continue;

} else
{
}
}
}
}

} else
{
{
IkReal j3array[1], cj3array[1], sj3array[1];
bool j3valid[1]={false};
_nj3 = 1;
IkReal x13113=((cj0)*(cj5));
IkReal x13114=((IkReal(1.00000000000000))*(cj0));
IkReal x13115=((cj6)*(r11));
IkReal x13116=((r10)*(sj6));
IkReal x13117=((cj5)*(sj0));
IkReal x13118=((r00)*(sj5)*(sj6));
IkReal x13119=((cj6)*(r01)*(sj5));
IkReal x13120=((IkReal(1.00000000000000))*(sj0)*(sj5));
if( IKabs(((((IkReal(-1.00000000000000))*(sj5)*(x13114)*(x13115)))+(((r12)*(x13113)))+(((IkReal(-1.00000000000000))*(sj5)*(x13114)*(x13116)))+(((sj0)*(x13118)))+(((sj0)*(x13119)))+(((IkReal(-1.00000000000000))*(r02)*(x13117))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(((((IKabs(cj1) != 0)?((IkReal)1/(cj1)):(IkReal)1.0e30))*(((((r02)*(x13113)))+(((IkReal(-1.00000000000000))*(x13114)*(x13119)))+(((r12)*(x13117)))+(((IkReal(-1.00000000000000))*(x13114)*(x13118)))+(((IkReal(-1.00000000000000))*(x13115)*(x13120)))+(((IkReal(-1.00000000000000))*(x13116)*(x13120))))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(IKsqr(((((IkReal(-1.00000000000000))*(sj5)*(x13114)*(x13115)))+(((r12)*(x13113)))+(((IkReal(-1.00000000000000))*(sj5)*(x13114)*(x13116)))+(((sj0)*(x13118)))+(((sj0)*(x13119)))+(((IkReal(-1.00000000000000))*(r02)*(x13117)))))+IKsqr(((((IKabs(cj1) != 0)?((IkReal)1/(cj1)):(IkReal)1.0e30))*(((((r02)*(x13113)))+(((IkReal(-1.00000000000000))*(x13114)*(x13119)))+(((r12)*(x13117)))+(((IkReal(-1.00000000000000))*(x13114)*(x13118)))+(((IkReal(-1.00000000000000))*(x13115)*(x13120)))+(((IkReal(-1.00000000000000))*(x13116)*(x13120)))))))-1) <= IKFAST_SINCOS_THRESH )
    continue;
j3array[0]=IKatan2(((((IkReal(-1.00000000000000))*(sj5)*(x13114)*(x13115)))+(((r12)*(x13113)))+(((IkReal(-1.00000000000000))*(sj5)*(x13114)*(x13116)))+(((sj0)*(x13118)))+(((sj0)*(x13119)))+(((IkReal(-1.00000000000000))*(r02)*(x13117)))), ((((IKabs(cj1) != 0)?((IkReal)1/(cj1)):(IkReal)1.0e30))*(((((r02)*(x13113)))+(((IkReal(-1.00000000000000))*(x13114)*(x13119)))+(((r12)*(x13117)))+(((IkReal(-1.00000000000000))*(x13114)*(x13118)))+(((IkReal(-1.00000000000000))*(x13115)*(x13120)))+(((IkReal(-1.00000000000000))*(x13116)*(x13120)))))));
sj3array[0]=IKsin(j3array[0]);
cj3array[0]=IKcos(j3array[0]);
if( j3array[0] > IKPI )
{
    j3array[0]-=IK2PI;
}
else if( j3array[0] < -IKPI )
{    j3array[0]+=IK2PI;
}
j3valid[0] = true;
for(int ij3 = 0; ij3 < 1; ++ij3)
{
if( !j3valid[ij3] )
{
    continue;
}
_ij3[0] = ij3; _ij3[1] = -1;
for(int iij3 = ij3+1; iij3 < 1; ++iij3)
{
if( j3valid[iij3] && IKabs(cj3array[ij3]-cj3array[iij3]) < IKFAST_SOLUTION_THRESH && IKabs(sj3array[ij3]-sj3array[iij3]) < IKFAST_SOLUTION_THRESH )
{
    j3valid[iij3]=false; _ij3[1] = iij3; break; 
}
}
j3 = j3array[ij3]; cj3 = cj3array[ij3]; sj3 = sj3array[ij3];
{
IkReal evalcond[6];
IkReal x13121=IKsin(j3);
IkReal x13122=IKcos(j3);
IkReal x13123=((sj0)*(sj5));
IkReal x13124=((r00)*(sj6));
IkReal x13125=((cj6)*(r01));
IkReal x13126=((cj4)*(cj5));
IkReal x13127=((IkReal(1.00000000000000))*(cj0));
IkReal x13128=((cj5)*(r12));
IkReal x13129=((IkReal(1.00000000000000))*(sj0));
IkReal x13130=((cj6)*(r11));
IkReal x13131=((cj5)*(r02));
IkReal x13132=((IkReal(1.00000000000000))*(cj1));
IkReal x13133=((cj6)*(sj4));
IkReal x13134=((cj6)*(r21));
IkReal x13135=((r20)*(sj6));
IkReal x13136=((r10)*(sj6));
IkReal x13137=((sj4)*(sj6));
IkReal x13138=((cj4)*(r02));
IkReal x13139=((IkReal(1.00000000000000))*(cj4)*(r12));
IkReal x13140=((IkReal(1.00000000000000))*(x13121));
IkReal x13141=((cj0)*(x13137));
evalcond[0]=((((sj5)*(x13135)))+(((IkReal(-1.00000000000000))*(cj5)*(r22)))+(((IkReal(-1.00000000000000))*(sj1)*(x13122)))+(((sj5)*(x13134))));
evalcond[1]=((((IkReal(-1.00000000000000))*(r21)*(x13137)))+(((cj4)*(r22)*(sj5)))+(((IkReal(-1.00000000000000))*(sj1)*(x13140)))+(((x13126)*(x13134)))+(((x13126)*(x13135)))+(((r20)*(x13133))));
evalcond[2]=((((cj0)*(x13128)))+(((x13123)*(x13125)))+(((IkReal(-1.00000000000000))*(sj5)*(x13127)*(x13130)))+(((IkReal(-1.00000000000000))*(x13140)))+(((IkReal(-1.00000000000000))*(sj5)*(x13127)*(x13136)))+(((IkReal(-1.00000000000000))*(x13129)*(x13131)))+(((x13123)*(x13124))));
evalcond[3]=((((IkReal(-1.00000000000000))*(x13123)*(x13130)))+(((IkReal(-1.00000000000000))*(sj5)*(x13125)*(x13127)))+(((sj0)*(x13128)))+(((IkReal(-1.00000000000000))*(x13123)*(x13136)))+(((cj0)*(x13131)))+(((IkReal(-1.00000000000000))*(sj5)*(x13124)*(x13127)))+(((IkReal(-1.00000000000000))*(x13122)*(x13132))));
evalcond[4]=((((IkReal(-1.00000000000000))*(r10)*(x13127)*(x13133)))+(((r00)*(sj0)*(x13133)))+(((x13123)*(x13138)))+(((IkReal(-1.00000000000000))*(x13126)*(x13127)*(x13136)))+(((r11)*(x13141)))+(((IkReal(-1.00000000000000))*(x13126)*(x13127)*(x13130)))+(((sj0)*(x13125)*(x13126)))+(((sj0)*(x13124)*(x13126)))+(((IkReal(-1.00000000000000))*(r01)*(x13129)*(x13137)))+(((IkReal(-1.00000000000000))*(cj4)*(r12)*(sj5)*(x13127)))+(x13122));
evalcond[5]=((((r11)*(sj0)*(x13137)))+(((IkReal(-1.00000000000000))*(x13121)*(x13132)))+(((r01)*(x13141)))+(((IkReal(-1.00000000000000))*(r10)*(x13129)*(x13133)))+(((IkReal(-1.00000000000000))*(x13126)*(x13129)*(x13136)))+(((IkReal(-1.00000000000000))*(x13125)*(x13126)*(x13127)))+(((IkReal(-1.00000000000000))*(x13124)*(x13126)*(x13127)))+(((IkReal(-1.00000000000000))*(x13126)*(x13129)*(x13130)))+(((IkReal(-1.00000000000000))*(sj5)*(x13127)*(x13138)))+(((IkReal(-1.00000000000000))*(x13123)*(x13139)))+(((IkReal(-1.00000000000000))*(r00)*(x13127)*(x13133))));
if( IKabs(evalcond[0]) > 0.000001  || IKabs(evalcond[1]) > 0.000001  || IKabs(evalcond[2]) > 0.000001  || IKabs(evalcond[3]) > 0.000001  || IKabs(evalcond[4]) > 0.000001  || IKabs(evalcond[5]) > 0.000001  )
{
continue;
}
}

{
std::vector<IkSingleDOFSolutionBase<IkReal> > vinfos(7);
vinfos[0].jointtype = 1;
vinfos[0].foffset = j0;
vinfos[0].indices[0] = _ij0[0];
vinfos[0].indices[1] = _ij0[1];
vinfos[0].maxsolutions = _nj0;
vinfos[1].jointtype = 1;
vinfos[1].foffset = j1;
vinfos[1].indices[0] = _ij1[0];
vinfos[1].indices[1] = _ij1[1];
vinfos[1].maxsolutions = _nj1;
vinfos[2].jointtype = 1;
vinfos[2].foffset = j2;
vinfos[2].indices[0] = _ij2[0];
vinfos[2].indices[1] = _ij2[1];
vinfos[2].maxsolutions = _nj2;
vinfos[3].jointtype = 1;
vinfos[3].foffset = j3;
vinfos[3].indices[0] = _ij3[0];
vinfos[3].indices[1] = _ij3[1];
vinfos[3].maxsolutions = _nj3;
vinfos[4].jointtype = 1;
vinfos[4].foffset = j4;
vinfos[4].indices[0] = _ij4[0];
vinfos[4].indices[1] = _ij4[1];
vinfos[4].maxsolutions = _nj4;
vinfos[5].jointtype = 1;
vinfos[5].foffset = j5;
vinfos[5].indices[0] = _ij5[0];
vinfos[5].indices[1] = _ij5[1];
vinfos[5].maxsolutions = _nj5;
vinfos[6].jointtype = 1;
vinfos[6].foffset = j6;
vinfos[6].indices[0] = _ij6[0];
vinfos[6].indices[1] = _ij6[1];
vinfos[6].maxsolutions = _nj6;
std::vector<int> vfree(0);
solutions.AddSolution(vinfos,vfree);
}
}
}

}

}

} else
{
{
IkReal j3array[1], cj3array[1], sj3array[1];
bool j3valid[1]={false};
_nj3 = 1;
IkReal x13142=((sj5)*(sj6));
IkReal x13143=((cj6)*(sj5));
IkReal x13144=((IkReal(1.00000000000000))*(cj0));
IkReal x13145=((IkReal(1.00000000000000))*(cj5));
if( IKabs(((((IkReal(-1.00000000000000))*(r11)*(x13143)*(x13144)))+(((r01)*(sj0)*(x13143)))+(((r00)*(sj0)*(x13142)))+(((IkReal(-1.00000000000000))*(r02)*(sj0)*(x13145)))+(((cj0)*(cj5)*(r12)))+(((IkReal(-1.00000000000000))*(r10)*(x13142)*(x13144))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(((((IKabs(sj1) != 0)?((IkReal)1/(sj1)):(IkReal)1.0e30))*(((((IkReal(-1.00000000000000))*(r22)*(x13145)))+(((r21)*(x13143)))+(((r20)*(x13142))))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(IKsqr(((((IkReal(-1.00000000000000))*(r11)*(x13143)*(x13144)))+(((r01)*(sj0)*(x13143)))+(((r00)*(sj0)*(x13142)))+(((IkReal(-1.00000000000000))*(r02)*(sj0)*(x13145)))+(((cj0)*(cj5)*(r12)))+(((IkReal(-1.00000000000000))*(r10)*(x13142)*(x13144)))))+IKsqr(((((IKabs(sj1) != 0)?((IkReal)1/(sj1)):(IkReal)1.0e30))*(((((IkReal(-1.00000000000000))*(r22)*(x13145)))+(((r21)*(x13143)))+(((r20)*(x13142)))))))-1) <= IKFAST_SINCOS_THRESH )
    continue;
j3array[0]=IKatan2(((((IkReal(-1.00000000000000))*(r11)*(x13143)*(x13144)))+(((r01)*(sj0)*(x13143)))+(((r00)*(sj0)*(x13142)))+(((IkReal(-1.00000000000000))*(r02)*(sj0)*(x13145)))+(((cj0)*(cj5)*(r12)))+(((IkReal(-1.00000000000000))*(r10)*(x13142)*(x13144)))), ((((IKabs(sj1) != 0)?((IkReal)1/(sj1)):(IkReal)1.0e30))*(((((IkReal(-1.00000000000000))*(r22)*(x13145)))+(((r21)*(x13143)))+(((r20)*(x13142)))))));
sj3array[0]=IKsin(j3array[0]);
cj3array[0]=IKcos(j3array[0]);
if( j3array[0] > IKPI )
{
    j3array[0]-=IK2PI;
}
else if( j3array[0] < -IKPI )
{    j3array[0]+=IK2PI;
}
j3valid[0] = true;
for(int ij3 = 0; ij3 < 1; ++ij3)
{
if( !j3valid[ij3] )
{
    continue;
}
_ij3[0] = ij3; _ij3[1] = -1;
for(int iij3 = ij3+1; iij3 < 1; ++iij3)
{
if( j3valid[iij3] && IKabs(cj3array[ij3]-cj3array[iij3]) < IKFAST_SOLUTION_THRESH && IKabs(sj3array[ij3]-sj3array[iij3]) < IKFAST_SOLUTION_THRESH )
{
    j3valid[iij3]=false; _ij3[1] = iij3; break; 
}
}
j3 = j3array[ij3]; cj3 = cj3array[ij3]; sj3 = sj3array[ij3];
{
IkReal evalcond[6];
IkReal x13146=IKsin(j3);
IkReal x13147=IKcos(j3);
IkReal x13148=((sj0)*(sj5));
IkReal x13149=((r00)*(sj6));
IkReal x13150=((cj6)*(r01));
IkReal x13151=((cj4)*(cj5));
IkReal x13152=((IkReal(1.00000000000000))*(cj0));
IkReal x13153=((cj5)*(r12));
IkReal x13154=((IkReal(1.00000000000000))*(sj0));
IkReal x13155=((cj6)*(r11));
IkReal x13156=((cj5)*(r02));
IkReal x13157=((IkReal(1.00000000000000))*(cj1));
IkReal x13158=((cj6)*(sj4));
IkReal x13159=((cj6)*(r21));
IkReal x13160=((r20)*(sj6));
IkReal x13161=((r10)*(sj6));
IkReal x13162=((sj4)*(sj6));
IkReal x13163=((cj4)*(r02));
IkReal x13164=((IkReal(1.00000000000000))*(cj4)*(r12));
IkReal x13165=((IkReal(1.00000000000000))*(x13146));
IkReal x13166=((cj0)*(x13162));
evalcond[0]=((((sj5)*(x13159)))+(((IkReal(-1.00000000000000))*(cj5)*(r22)))+(((IkReal(-1.00000000000000))*(sj1)*(x13147)))+(((sj5)*(x13160))));
evalcond[1]=((((x13151)*(x13159)))+(((r20)*(x13158)))+(((cj4)*(r22)*(sj5)))+(((x13151)*(x13160)))+(((IkReal(-1.00000000000000))*(sj1)*(x13165)))+(((IkReal(-1.00000000000000))*(r21)*(x13162))));
evalcond[2]=((((IkReal(-1.00000000000000))*(x13165)))+(((IkReal(-1.00000000000000))*(sj5)*(x13152)*(x13161)))+(((cj0)*(x13153)))+(((x13148)*(x13150)))+(((x13148)*(x13149)))+(((IkReal(-1.00000000000000))*(sj5)*(x13152)*(x13155)))+(((IkReal(-1.00000000000000))*(x13154)*(x13156))));
evalcond[3]=((((sj0)*(x13153)))+(((IkReal(-1.00000000000000))*(x13147)*(x13157)))+(((IkReal(-1.00000000000000))*(sj5)*(x13150)*(x13152)))+(((IkReal(-1.00000000000000))*(sj5)*(x13149)*(x13152)))+(((cj0)*(x13156)))+(((IkReal(-1.00000000000000))*(x13148)*(x13161)))+(((IkReal(-1.00000000000000))*(x13148)*(x13155))));
evalcond[4]=((((r11)*(x13166)))+(((x13148)*(x13163)))+(((r00)*(sj0)*(x13158)))+(((sj0)*(x13149)*(x13151)))+(x13147)+(((IkReal(-1.00000000000000))*(x13151)*(x13152)*(x13155)))+(((IkReal(-1.00000000000000))*(r01)*(x13154)*(x13162)))+(((IkReal(-1.00000000000000))*(x13151)*(x13152)*(x13161)))+(((IkReal(-1.00000000000000))*(r10)*(x13152)*(x13158)))+(((sj0)*(x13150)*(x13151)))+(((IkReal(-1.00000000000000))*(cj4)*(r12)*(sj5)*(x13152))));
evalcond[5]=((((r01)*(x13166)))+(((IkReal(-1.00000000000000))*(x13149)*(x13151)*(x13152)))+(((IkReal(-1.00000000000000))*(sj5)*(x13152)*(x13163)))+(((IkReal(-1.00000000000000))*(r00)*(x13152)*(x13158)))+(((IkReal(-1.00000000000000))*(x13150)*(x13151)*(x13152)))+(((IkReal(-1.00000000000000))*(r10)*(x13154)*(x13158)))+(((IkReal(-1.00000000000000))*(x13151)*(x13154)*(x13155)))+(((IkReal(-1.00000000000000))*(x13146)*(x13157)))+(((r11)*(sj0)*(x13162)))+(((IkReal(-1.00000000000000))*(x13148)*(x13164)))+(((IkReal(-1.00000000000000))*(x13151)*(x13154)*(x13161))));
if( IKabs(evalcond[0]) > 0.000001  || IKabs(evalcond[1]) > 0.000001  || IKabs(evalcond[2]) > 0.000001  || IKabs(evalcond[3]) > 0.000001  || IKabs(evalcond[4]) > 0.000001  || IKabs(evalcond[5]) > 0.000001  )
{
continue;
}
}

{
std::vector<IkSingleDOFSolutionBase<IkReal> > vinfos(7);
vinfos[0].jointtype = 1;
vinfos[0].foffset = j0;
vinfos[0].indices[0] = _ij0[0];
vinfos[0].indices[1] = _ij0[1];
vinfos[0].maxsolutions = _nj0;
vinfos[1].jointtype = 1;
vinfos[1].foffset = j1;
vinfos[1].indices[0] = _ij1[0];
vinfos[1].indices[1] = _ij1[1];
vinfos[1].maxsolutions = _nj1;
vinfos[2].jointtype = 1;
vinfos[2].foffset = j2;
vinfos[2].indices[0] = _ij2[0];
vinfos[2].indices[1] = _ij2[1];
vinfos[2].maxsolutions = _nj2;
vinfos[3].jointtype = 1;
vinfos[3].foffset = j3;
vinfos[3].indices[0] = _ij3[0];
vinfos[3].indices[1] = _ij3[1];
vinfos[3].maxsolutions = _nj3;
vinfos[4].jointtype = 1;
vinfos[4].foffset = j4;
vinfos[4].indices[0] = _ij4[0];
vinfos[4].indices[1] = _ij4[1];
vinfos[4].maxsolutions = _nj4;
vinfos[5].jointtype = 1;
vinfos[5].foffset = j5;
vinfos[5].indices[0] = _ij5[0];
vinfos[5].indices[1] = _ij5[1];
vinfos[5].maxsolutions = _nj5;
vinfos[6].jointtype = 1;
vinfos[6].foffset = j6;
vinfos[6].indices[0] = _ij6[0];
vinfos[6].indices[1] = _ij6[1];
vinfos[6].maxsolutions = _nj6;
std::vector<int> vfree(0);
solutions.AddSolution(vinfos,vfree);
}
}
}

}

}

} else
{
{
IkReal j3array[1], cj3array[1], sj3array[1];
bool j3valid[1]={false};
_nj3 = 1;
IkReal x13167=((r20)*(sj6));
IkReal x13168=((cj4)*(cj5));
IkReal x13169=((cj6)*(r21));
if( IKabs(((gconst11)*(((((IkReal(-1.00000000000000))*(r21)*(sj4)*(sj6)))+(((cj6)*(r20)*(sj4)))+(((cj4)*(r22)*(sj5)))+(((x13167)*(x13168)))+(((x13168)*(x13169))))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(((gconst11)*(((((sj5)*(x13167)))+(((IkReal(-1.00000000000000))*(cj5)*(r22)))+(((sj5)*(x13169))))))) < IKFAST_ATAN2_MAGTHRESH )
    continue;
j3array[0]=IKatan2(((gconst11)*(((((IkReal(-1.00000000000000))*(r21)*(sj4)*(sj6)))+(((cj6)*(r20)*(sj4)))+(((cj4)*(r22)*(sj5)))+(((x13167)*(x13168)))+(((x13168)*(x13169)))))), ((gconst11)*(((((sj5)*(x13167)))+(((IkReal(-1.00000000000000))*(cj5)*(r22)))+(((sj5)*(x13169)))))));
sj3array[0]=IKsin(j3array[0]);
cj3array[0]=IKcos(j3array[0]);
if( j3array[0] > IKPI )
{
    j3array[0]-=IK2PI;
}
else if( j3array[0] < -IKPI )
{    j3array[0]+=IK2PI;
}
j3valid[0] = true;
for(int ij3 = 0; ij3 < 1; ++ij3)
{
if( !j3valid[ij3] )
{
    continue;
}
_ij3[0] = ij3; _ij3[1] = -1;
for(int iij3 = ij3+1; iij3 < 1; ++iij3)
{
if( j3valid[iij3] && IKabs(cj3array[ij3]-cj3array[iij3]) < IKFAST_SOLUTION_THRESH && IKabs(sj3array[ij3]-sj3array[iij3]) < IKFAST_SOLUTION_THRESH )
{
    j3valid[iij3]=false; _ij3[1] = iij3; break; 
}
}
j3 = j3array[ij3]; cj3 = cj3array[ij3]; sj3 = sj3array[ij3];
{
IkReal evalcond[6];
IkReal x13170=IKsin(j3);
IkReal x13171=IKcos(j3);
IkReal x13172=((sj0)*(sj5));
IkReal x13173=((r00)*(sj6));
IkReal x13174=((cj6)*(r01));
IkReal x13175=((cj4)*(cj5));
IkReal x13176=((IkReal(1.00000000000000))*(cj0));
IkReal x13177=((cj5)*(r12));
IkReal x13178=((IkReal(1.00000000000000))*(sj0));
IkReal x13179=((cj6)*(r11));
IkReal x13180=((cj5)*(r02));
IkReal x13181=((IkReal(1.00000000000000))*(cj1));
IkReal x13182=((cj6)*(sj4));
IkReal x13183=((cj6)*(r21));
IkReal x13184=((r20)*(sj6));
IkReal x13185=((r10)*(sj6));
IkReal x13186=((sj4)*(sj6));
IkReal x13187=((cj4)*(r02));
IkReal x13188=((IkReal(1.00000000000000))*(cj4)*(r12));
IkReal x13189=((IkReal(1.00000000000000))*(x13170));
IkReal x13190=((cj0)*(x13186));
evalcond[0]=((((IkReal(-1.00000000000000))*(sj1)*(x13171)))+(((IkReal(-1.00000000000000))*(cj5)*(r22)))+(((sj5)*(x13184)))+(((sj5)*(x13183))));
evalcond[1]=((((IkReal(-1.00000000000000))*(r21)*(x13186)))+(((cj4)*(r22)*(sj5)))+(((x13175)*(x13184)))+(((x13175)*(x13183)))+(((r20)*(x13182)))+(((IkReal(-1.00000000000000))*(sj1)*(x13189))));
evalcond[2]=((((IkReal(-1.00000000000000))*(x13178)*(x13180)))+(((x13172)*(x13173)))+(((IkReal(-1.00000000000000))*(x13189)))+(((cj0)*(x13177)))+(((IkReal(-1.00000000000000))*(sj5)*(x13176)*(x13185)))+(((IkReal(-1.00000000000000))*(sj5)*(x13176)*(x13179)))+(((x13172)*(x13174))));
evalcond[3]=((((IkReal(-1.00000000000000))*(x13171)*(x13181)))+(((IkReal(-1.00000000000000))*(sj5)*(x13174)*(x13176)))+(((IkReal(-1.00000000000000))*(x13172)*(x13179)))+(((IkReal(-1.00000000000000))*(x13172)*(x13185)))+(((IkReal(-1.00000000000000))*(sj5)*(x13173)*(x13176)))+(((sj0)*(x13177)))+(((cj0)*(x13180))));
evalcond[4]=((x13171)+(((r00)*(sj0)*(x13182)))+(((IkReal(-1.00000000000000))*(x13175)*(x13176)*(x13185)))+(((IkReal(-1.00000000000000))*(r10)*(x13176)*(x13182)))+(((IkReal(-1.00000000000000))*(r01)*(x13178)*(x13186)))+(((IkReal(-1.00000000000000))*(x13175)*(x13176)*(x13179)))+(((x13172)*(x13187)))+(((IkReal(-1.00000000000000))*(cj4)*(r12)*(sj5)*(x13176)))+(((r11)*(x13190)))+(((sj0)*(x13173)*(x13175)))+(((sj0)*(x13174)*(x13175))));
evalcond[5]=((((IkReal(-1.00000000000000))*(x13175)*(x13178)*(x13179)))+(((IkReal(-1.00000000000000))*(x13173)*(x13175)*(x13176)))+(((IkReal(-1.00000000000000))*(x13172)*(x13188)))+(((IkReal(-1.00000000000000))*(r00)*(x13176)*(x13182)))+(((IkReal(-1.00000000000000))*(x13174)*(x13175)*(x13176)))+(((r01)*(x13190)))+(((IkReal(-1.00000000000000))*(x13170)*(x13181)))+(((IkReal(-1.00000000000000))*(x13175)*(x13178)*(x13185)))+(((IkReal(-1.00000000000000))*(r10)*(x13178)*(x13182)))+(((r11)*(sj0)*(x13186)))+(((IkReal(-1.00000000000000))*(sj5)*(x13176)*(x13187))));
if( IKabs(evalcond[0]) > 0.000001  || IKabs(evalcond[1]) > 0.000001  || IKabs(evalcond[2]) > 0.000001  || IKabs(evalcond[3]) > 0.000001  || IKabs(evalcond[4]) > 0.000001  || IKabs(evalcond[5]) > 0.000001  )
{
continue;
}
}

{
std::vector<IkSingleDOFSolutionBase<IkReal> > vinfos(7);
vinfos[0].jointtype = 1;
vinfos[0].foffset = j0;
vinfos[0].indices[0] = _ij0[0];
vinfos[0].indices[1] = _ij0[1];
vinfos[0].maxsolutions = _nj0;
vinfos[1].jointtype = 1;
vinfos[1].foffset = j1;
vinfos[1].indices[0] = _ij1[0];
vinfos[1].indices[1] = _ij1[1];
vinfos[1].maxsolutions = _nj1;
vinfos[2].jointtype = 1;
vinfos[2].foffset = j2;
vinfos[2].indices[0] = _ij2[0];
vinfos[2].indices[1] = _ij2[1];
vinfos[2].maxsolutions = _nj2;
vinfos[3].jointtype = 1;
vinfos[3].foffset = j3;
vinfos[3].indices[0] = _ij3[0];
vinfos[3].indices[1] = _ij3[1];
vinfos[3].maxsolutions = _nj3;
vinfos[4].jointtype = 1;
vinfos[4].foffset = j4;
vinfos[4].indices[0] = _ij4[0];
vinfos[4].indices[1] = _ij4[1];
vinfos[4].maxsolutions = _nj4;
vinfos[5].jointtype = 1;
vinfos[5].foffset = j5;
vinfos[5].indices[0] = _ij5[0];
vinfos[5].indices[1] = _ij5[1];
vinfos[5].maxsolutions = _nj5;
vinfos[6].jointtype = 1;
vinfos[6].foffset = j6;
vinfos[6].indices[0] = _ij6[0];
vinfos[6].indices[1] = _ij6[1];
vinfos[6].maxsolutions = _nj6;
std::vector<int> vfree(0);
solutions.AddSolution(vinfos,vfree);
}
}
}

}

}

} else
{
IkReal x13191=((IkReal(1.00000000000000))*(cj0));
IkReal x13192=((cj4)*(sj6));
IkReal x13193=((sj0)*(sj4));
IkReal x13194=((cj5)*(sj6));
IkReal x13195=((sj4)*(sj5));
IkReal x13196=((r12)*(sj5));
IkReal x13197=((IkReal(0.374290000000000))*(cj5));
IkReal x13198=((r02)*(sj0));
IkReal x13199=((IkReal(1.00000000000000))*(sj0));
IkReal x13200=((cj0)*(r10));
IkReal x13201=((cj4)*(cj6));
IkReal x13202=((r00)*(sj0));
IkReal x13203=((cj6)*(r21));
IkReal x13204=((IkReal(0.374290000000000))*(sj5));
IkReal x13205=((cj0)*(r00));
IkReal x13206=((IkReal(0.0100000000000000))*(sj5));
IkReal x13207=((cj0)*(r02));
IkReal x13208=((cj5)*(sj4));
IkReal x13209=((cj6)*(r01));
IkReal x13210=((cj6)*(r11));
IkReal x13211=((r01)*(sj0));
IkReal x13212=((r10)*(sj0));
IkReal x13213=((IkReal(0.0100000000000000))*(cj5)*(cj6));
IkReal x13214=((sj6)*(x13204));
IkReal x13215=((cj0)*(cj6)*(x13204));
evalcond[0]=((IkReal(-3.14159265358979))+(IKfmod(((IkReal(4.71238898038469))+(j2)), IkReal(6.28318530717959))));
evalcond[1]=((((r21)*(x13192)))+(((r22)*(x13195)))+(((IkReal(-1.00000000000000))*(r20)*(x13201)))+(((x13203)*(x13208)))+(cj1)+(((r20)*(sj4)*(x13194))));
evalcond[2]=((((IkReal(-1.00000000000000))*(r22)*(x13197)))+(((IkReal(0.364420000000000))*(sj1)))+(((IkReal(-1.00000000000000))*(r22)*(x13206)))+(((r20)*(x13214)))+(((IkReal(-0.0100000000000000))*(cj5)*(x13203)))+(pz)+(((x13203)*(x13204)))+(((IkReal(-0.0100000000000000))*(r20)*(x13194))));
evalcond[3]=((((IkReal(-1.00000000000000))*(r10)*(sj4)*(x13191)*(x13194)))+(((IkReal(-1.00000000000000))*(r12)*(x13191)*(x13195)))+(((IkReal(-1.00000000000000))*(r00)*(x13199)*(x13201)))+(((IkReal(-1.00000000000000))*(x13191)*(x13208)*(x13210)))+(((r00)*(x13193)*(x13194)))+(((x13192)*(x13211)))+(((r02)*(sj5)*(x13193)))+(((IkReal(-1.00000000000000))*(r11)*(x13191)*(x13192)))+(((cj5)*(x13193)*(x13209)))+(((x13200)*(x13201))));
evalcond[4]=((((IkReal(-1.00000000000000))*(r10)*(x13193)*(x13194)))+(((IkReal(-1.00000000000000))*(cj5)*(x13193)*(x13210)))+(((IkReal(-1.00000000000000))*(r01)*(x13191)*(x13192)))+(((x13201)*(x13212)))+(((IkReal(-1.00000000000000))*(r11)*(x13192)*(x13199)))+(((IkReal(-1.00000000000000))*(sj1)))+(((IkReal(-1.00000000000000))*(r02)*(x13191)*(x13195)))+(((IkReal(-1.00000000000000))*(x13191)*(x13208)*(x13209)))+(((IkReal(-1.00000000000000))*(r00)*(sj4)*(x13191)*(x13194)))+(((x13201)*(x13205)))+(((IkReal(-1.00000000000000))*(x13193)*(x13196))));
evalcond[5]=((IkReal(-0.0690000000000000))+(((sj0)*(x13204)*(x13209)))+(((x13202)*(x13214)))+(((IkReal(-0.0100000000000000))*(x13194)*(x13202)))+(((IkReal(-1.00000000000000))*(cj0)*(x13204)*(x13210)))+(((IkReal(-1.00000000000000))*(py)*(x13191)))+(((cj0)*(r12)*(x13197)))+(((IkReal(-1.00000000000000))*(x13200)*(x13214)))+(((IkReal(0.0100000000000000))*(cj0)*(x13196)))+(((IkReal(-1.00000000000000))*(x13197)*(x13198)))+(((IkReal(0.0100000000000000))*(x13194)*(x13200)))+(((IkReal(-0.0100000000000000))*(cj5)*(sj0)*(x13209)))+(((IkReal(-1.00000000000000))*(x13198)*(x13206)))+(((px)*(sj0)))+(((IkReal(0.0100000000000000))*(cj0)*(cj5)*(x13210))));
evalcond[6]=((IkReal(0.0690000000000000))+(((IkReal(-1.00000000000000))*(py)*(x13199)))+(((IkReal(0.0100000000000000))*(cj5)*(sj0)*(x13210)))+(((IkReal(-1.00000000000000))*(x13205)*(x13214)))+(((IkReal(-1.00000000000000))*(sj0)*(x13204)*(x13210)))+(((IkReal(0.0100000000000000))*(x13194)*(x13205)))+(((IkReal(0.0100000000000000))*(sj0)*(x13196)))+(((x13206)*(x13207)))+(((r12)*(sj0)*(x13197)))+(((IkReal(0.0100000000000000))*(cj0)*(cj5)*(x13209)))+(((IkReal(-1.00000000000000))*(x13212)*(x13214)))+(((x13197)*(x13207)))+(((IkReal(0.0100000000000000))*(x13194)*(x13212)))+(((IkReal(-1.00000000000000))*(cj0)*(x13204)*(x13209)))+(((IkReal(0.364420000000000))*(cj1)))+(((IkReal(-1.00000000000000))*(px)*(x13191))));
if( IKabs(evalcond[0]) < 0.0000010000000000  && IKabs(evalcond[1]) < 0.0000010000000000  && IKabs(evalcond[2]) < 0.0000010000000000  && IKabs(evalcond[3]) < 0.0000010000000000  && IKabs(evalcond[4]) < 0.0000010000000000  && IKabs(evalcond[5]) < 0.0000010000000000  && IKabs(evalcond[6]) < 0.0000010000000000  )
{
{
IkReal dummyeval[1];
IkReal gconst12;
gconst12=IKsign(sj1);
dummyeval[0]=sj1;
if( IKabs(dummyeval[0]) < 0.0000010000000000  )
{
{
IkReal dummyeval[1];
dummyeval[0]=sj1;
if( IKabs(dummyeval[0]) < 0.0000010000000000  )
{
{
IkReal dummyeval[1];
dummyeval[0]=cj1;
if( IKabs(dummyeval[0]) < 0.0000010000000000  )
{
{
IkReal evalcond[9];
IkReal x13216=((IkReal(1.00000000000000))*(cj0));
IkReal x13217=((cj4)*(sj6));
IkReal x13218=((sj0)*(sj6));
IkReal x13219=((cj5)*(sj4));
IkReal x13220=((IkReal(0.374290000000000))*(sj5));
IkReal x13221=((sj4)*(sj5));
IkReal x13222=((cj0)*(cj6));
IkReal x13223=((IkReal(0.0100000000000000))*(cj5));
IkReal x13224=((cj4)*(sj5));
IkReal x13225=((cj5)*(sj0));
IkReal x13226=((IkReal(0.374290000000000))*(r02));
IkReal x13227=((r20)*(sj6));
IkReal x13228=((cj6)*(r21));
IkReal x13229=((IkReal(1.00000000000000))*(sj0));
IkReal x13230=((cj0)*(sj6));
IkReal x13231=((cj4)*(cj6));
IkReal x13232=((IkReal(0.374290000000000))*(r12));
IkReal x13233=((cj0)*(cj5));
IkReal x13234=((cj6)*(sj5));
IkReal x13235=((cj6)*(r01));
IkReal x13236=((r00)*(sj6));
IkReal x13237=((IkReal(0.0100000000000000))*(sj5));
IkReal x13238=((cj6)*(r11));
IkReal x13239=((IkReal(1.00000000000000))*(r10));
IkReal x13240=((r02)*(sj0));
IkReal x13241=((cj6)*(sj4));
IkReal x13242=((r12)*(x13229));
evalcond[0]=((IkReal(-3.14159265358979))+(IKfmod(((IkReal(1.57079632679490))+(j1)), IkReal(6.28318530717959))));
evalcond[1]=((((IkReal(-1.00000000000000))*(r20)*(x13231)))+(((r22)*(x13221)))+(((x13219)*(x13227)))+(((x13219)*(x13228)))+(((r21)*(x13217))));
evalcond[2]=((IkReal(0.364420000000000))+(((x13220)*(x13227)))+(((IkReal(-0.374290000000000))*(cj5)*(r22)))+(((IkReal(-1.00000000000000))*(x13223)*(x13227)))+(pz)+(((x13220)*(x13228)))+(((IkReal(-1.00000000000000))*(r22)*(x13237)))+(((IkReal(-1.00000000000000))*(x13223)*(x13228))));
evalcond[3]=((((IkReal(-1.00000000000000))*(sj5)*(x13216)*(x13236)))+(((IkReal(-1.00000000000000))*(r01)*(x13216)*(x13234)))+(((IkReal(-1.00000000000000))*(r11)*(x13229)*(x13234)))+(((r12)*(x13225)))+(((IkReal(-1.00000000000000))*(sj5)*(x13218)*(x13239)))+(((r02)*(x13233))));
evalcond[4]=((((cj4)*(r10)*(x13222)))+(((IkReal(-1.00000000000000))*(r12)*(x13216)*(x13221)))+(((IkReal(-1.00000000000000))*(r10)*(sj6)*(x13216)*(x13219)))+(((sj0)*(x13219)*(x13235)))+(((r00)*(x13218)*(x13219)))+(((IkReal(-1.00000000000000))*(r11)*(x13216)*(x13217)))+(((x13221)*(x13240)))+(((IkReal(-1.00000000000000))*(r00)*(x13229)*(x13231)))+(((r01)*(sj0)*(x13217)))+(((IkReal(-1.00000000000000))*(x13216)*(x13219)*(x13238))));
evalcond[5]=((IkReal(-1.00000000000000))+(((IkReal(-1.00000000000000))*(x13219)*(x13229)*(x13238)))+(((cj4)*(r00)*(x13222)))+(((IkReal(-1.00000000000000))*(x13216)*(x13219)*(x13235)))+(((IkReal(-1.00000000000000))*(r11)*(x13217)*(x13229)))+(((r10)*(sj0)*(x13231)))+(((IkReal(-1.00000000000000))*(x13216)*(x13219)*(x13236)))+(((IkReal(-1.00000000000000))*(x13218)*(x13219)*(x13239)))+(((IkReal(-1.00000000000000))*(r01)*(x13216)*(x13217)))+(((IkReal(-1.00000000000000))*(x13221)*(x13242)))+(((IkReal(-1.00000000000000))*(r02)*(x13216)*(x13221))));
evalcond[6]=((IkReal(-0.0690000000000000))+(((IkReal(-1.00000000000000))*(r10)*(x13220)*(x13230)))+(((IkReal(-1.00000000000000))*(r00)*(x13218)*(x13223)))+(((r00)*(x13218)*(x13220)))+(((x13232)*(x13233)))+(((sj0)*(x13220)*(x13235)))+(((IkReal(-1.00000000000000))*(py)*(x13216)))+(((r10)*(x13223)*(x13230)))+(((IkReal(-1.00000000000000))*(r11)*(x13220)*(x13222)))+(((r11)*(x13222)*(x13223)))+(((IkReal(-1.00000000000000))*(sj0)*(x13223)*(x13235)))+(((cj0)*(r12)*(x13237)))+(((IkReal(-1.00000000000000))*(x13225)*(x13226)))+(((IkReal(-1.00000000000000))*(x13237)*(x13240)))+(((px)*(sj0))));
evalcond[7]=((((IkReal(-1.00000000000000))*(r00)*(x13216)*(x13241)))+(((IkReal(-1.00000000000000))*(r10)*(x13229)*(x13241)))+(((IkReal(-1.00000000000000))*(x13224)*(x13242)))+(((IkReal(-1.00000000000000))*(cj5)*(r00)*(x13216)*(x13217)))+(((IkReal(-1.00000000000000))*(cj5)*(r01)*(x13216)*(x13231)))+(((IkReal(-1.00000000000000))*(r11)*(x13225)*(x13231)))+(((r11)*(sj4)*(x13218)))+(((IkReal(-1.00000000000000))*(x13217)*(x13225)*(x13239)))+(((IkReal(-1.00000000000000))*(r02)*(x13216)*(x13224)))+(((r01)*(sj4)*(x13230))));
evalcond[8]=((IkReal(0.0690000000000000))+(((IkReal(-1.00000000000000))*(sj0)*(x13220)*(x13238)))+(((IkReal(-1.00000000000000))*(r01)*(x13220)*(x13222)))+(((sj0)*(x13223)*(x13238)))+(((r12)*(sj0)*(x13237)))+(((r10)*(x13218)*(x13223)))+(((IkReal(-1.00000000000000))*(py)*(x13229)))+(((cj0)*(r02)*(x13237)))+(((x13225)*(x13232)))+(((IkReal(-1.00000000000000))*(px)*(x13216)))+(((r01)*(x13222)*(x13223)))+(((IkReal(-1.00000000000000))*(r10)*(x13218)*(x13220)))+(((r00)*(x13223)*(x13230)))+(((x13226)*(x13233)))+(((IkReal(-1.00000000000000))*(r00)*(x13220)*(x13230))));
if( IKabs(evalcond[0]) < 0.0000010000000000  && IKabs(evalcond[1]) < 0.0000010000000000  && IKabs(evalcond[2]) < 0.0000010000000000  && IKabs(evalcond[3]) < 0.0000010000000000  && IKabs(evalcond[4]) < 0.0000010000000000  && IKabs(evalcond[5]) < 0.0000010000000000  && IKabs(evalcond[6]) < 0.0000010000000000  && IKabs(evalcond[7]) < 0.0000010000000000  && IKabs(evalcond[8]) < 0.0000010000000000  )
{
{
IkReal j3array[1], cj3array[1], sj3array[1];
bool j3valid[1]={false};
_nj3 = 1;
IkReal x13243=((r20)*(sj6));
IkReal x13244=((cj4)*(cj5));
IkReal x13245=((cj6)*(r21));
if( IKabs(((((IkReal(-1.00000000000000))*(r21)*(sj4)*(sj6)))+(((x13244)*(x13245)))+(((cj6)*(r20)*(sj4)))+(((cj4)*(r22)*(sj5)))+(((x13243)*(x13244))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(((((sj5)*(x13243)))+(((IkReal(-1.00000000000000))*(cj5)*(r22)))+(((sj5)*(x13245))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(IKsqr(((((IkReal(-1.00000000000000))*(r21)*(sj4)*(sj6)))+(((x13244)*(x13245)))+(((cj6)*(r20)*(sj4)))+(((cj4)*(r22)*(sj5)))+(((x13243)*(x13244)))))+IKsqr(((((sj5)*(x13243)))+(((IkReal(-1.00000000000000))*(cj5)*(r22)))+(((sj5)*(x13245)))))-1) <= IKFAST_SINCOS_THRESH )
    continue;
j3array[0]=IKatan2(((((IkReal(-1.00000000000000))*(r21)*(sj4)*(sj6)))+(((x13244)*(x13245)))+(((cj6)*(r20)*(sj4)))+(((cj4)*(r22)*(sj5)))+(((x13243)*(x13244)))), ((((sj5)*(x13243)))+(((IkReal(-1.00000000000000))*(cj5)*(r22)))+(((sj5)*(x13245)))));
sj3array[0]=IKsin(j3array[0]);
cj3array[0]=IKcos(j3array[0]);
if( j3array[0] > IKPI )
{
    j3array[0]-=IK2PI;
}
else if( j3array[0] < -IKPI )
{    j3array[0]+=IK2PI;
}
j3valid[0] = true;
for(int ij3 = 0; ij3 < 1; ++ij3)
{
if( !j3valid[ij3] )
{
    continue;
}
_ij3[0] = ij3; _ij3[1] = -1;
for(int iij3 = ij3+1; iij3 < 1; ++iij3)
{
if( j3valid[iij3] && IKabs(cj3array[ij3]-cj3array[iij3]) < IKFAST_SOLUTION_THRESH && IKabs(sj3array[ij3]-sj3array[iij3]) < IKFAST_SOLUTION_THRESH )
{
    j3valid[iij3]=false; _ij3[1] = iij3; break; 
}
}
j3 = j3array[ij3]; cj3 = cj3array[ij3]; sj3 = sj3array[ij3];
{
IkReal evalcond[4];
IkReal x13246=IKsin(j3);
IkReal x13247=((sj0)*(sj5));
IkReal x13248=((r00)*(sj6));
IkReal x13249=((cj6)*(r01));
IkReal x13250=((cj5)*(sj0));
IkReal x13251=((cj0)*(cj5));
IkReal x13252=((cj6)*(sj4));
IkReal x13253=((sj4)*(sj6));
IkReal x13254=((cj0)*(r11));
IkReal x13255=((cj4)*(cj6));
IkReal x13256=((cj4)*(sj6));
IkReal x13257=((IkReal(1.00000000000000))*(cj0));
IkReal x13258=((cj4)*(sj5));
IkReal x13259=((sj5)*(sj6));
IkReal x13260=((cj6)*(sj5));
IkReal x13261=((IkReal(1.00000000000000))*(IKcos(j3)));
evalcond[0]=((((r21)*(x13260)))+(((IkReal(-1.00000000000000))*(x13261)))+(((r20)*(x13259)))+(((IkReal(-1.00000000000000))*(cj5)*(r22))));
evalcond[1]=((((IkReal(-1.00000000000000))*(r21)*(x13253)))+(((r20)*(x13252)))+(((cj5)*(r20)*(x13256)))+(((IkReal(-1.00000000000000))*(x13246)))+(((r22)*(x13258)))+(((cj5)*(r21)*(x13255))));
evalcond[2]=((((IkReal(-1.00000000000000))*(r02)*(x13250)))+(x13246)+(((x13247)*(x13249)))+(((IkReal(-1.00000000000000))*(r10)*(x13257)*(x13259)))+(((IkReal(-1.00000000000000))*(x13254)*(x13260)))+(((r12)*(x13251)))+(((x13247)*(x13248))));
evalcond[3]=((((cj4)*(x13249)*(x13250)))+(((cj4)*(x13248)*(x13250)))+(((IkReal(-1.00000000000000))*(r11)*(x13251)*(x13255)))+(((IkReal(-1.00000000000000))*(r10)*(x13251)*(x13256)))+(((IkReal(-1.00000000000000))*(x13261)))+(((r00)*(sj0)*(x13252)))+(((IkReal(-1.00000000000000))*(r10)*(x13252)*(x13257)))+(((IkReal(-1.00000000000000))*(r12)*(x13257)*(x13258)))+(((IkReal(-1.00000000000000))*(r01)*(sj0)*(x13253)))+(((cj4)*(r02)*(x13247)))+(((x13253)*(x13254))));
if( IKabs(evalcond[0]) > 0.000001  || IKabs(evalcond[1]) > 0.000001  || IKabs(evalcond[2]) > 0.000001  || IKabs(evalcond[3]) > 0.000001  )
{
continue;
}
}

{
std::vector<IkSingleDOFSolutionBase<IkReal> > vinfos(7);
vinfos[0].jointtype = 1;
vinfos[0].foffset = j0;
vinfos[0].indices[0] = _ij0[0];
vinfos[0].indices[1] = _ij0[1];
vinfos[0].maxsolutions = _nj0;
vinfos[1].jointtype = 1;
vinfos[1].foffset = j1;
vinfos[1].indices[0] = _ij1[0];
vinfos[1].indices[1] = _ij1[1];
vinfos[1].maxsolutions = _nj1;
vinfos[2].jointtype = 1;
vinfos[2].foffset = j2;
vinfos[2].indices[0] = _ij2[0];
vinfos[2].indices[1] = _ij2[1];
vinfos[2].maxsolutions = _nj2;
vinfos[3].jointtype = 1;
vinfos[3].foffset = j3;
vinfos[3].indices[0] = _ij3[0];
vinfos[3].indices[1] = _ij3[1];
vinfos[3].maxsolutions = _nj3;
vinfos[4].jointtype = 1;
vinfos[4].foffset = j4;
vinfos[4].indices[0] = _ij4[0];
vinfos[4].indices[1] = _ij4[1];
vinfos[4].maxsolutions = _nj4;
vinfos[5].jointtype = 1;
vinfos[5].foffset = j5;
vinfos[5].indices[0] = _ij5[0];
vinfos[5].indices[1] = _ij5[1];
vinfos[5].maxsolutions = _nj5;
vinfos[6].jointtype = 1;
vinfos[6].foffset = j6;
vinfos[6].indices[0] = _ij6[0];
vinfos[6].indices[1] = _ij6[1];
vinfos[6].maxsolutions = _nj6;
std::vector<int> vfree(0);
solutions.AddSolution(vinfos,vfree);
}
}
}

} else
{
IkReal x13262=((IkReal(1.00000000000000))*(cj0));
IkReal x13263=((cj4)*(sj6));
IkReal x13264=((sj0)*(sj6));
IkReal x13265=((cj5)*(sj4));
IkReal x13266=((IkReal(0.374290000000000))*(sj5));
IkReal x13267=((sj4)*(sj5));
IkReal x13268=((cj0)*(cj6));
IkReal x13269=((IkReal(0.0100000000000000))*(cj5));
IkReal x13270=((cj4)*(sj5));
IkReal x13271=((cj5)*(sj0));
IkReal x13272=((IkReal(0.374290000000000))*(r02));
IkReal x13273=((r20)*(sj6));
IkReal x13274=((cj6)*(r21));
IkReal x13275=((IkReal(1.00000000000000))*(sj0));
IkReal x13276=((cj0)*(sj6));
IkReal x13277=((cj4)*(cj6));
IkReal x13278=((IkReal(0.374290000000000))*(r12));
IkReal x13279=((cj0)*(cj5));
IkReal x13280=((cj6)*(sj5));
IkReal x13281=((cj6)*(r01));
IkReal x13282=((r00)*(sj6));
IkReal x13283=((IkReal(0.0100000000000000))*(sj5));
IkReal x13284=((cj6)*(r11));
IkReal x13285=((IkReal(1.00000000000000))*(r10));
IkReal x13286=((r02)*(sj0));
IkReal x13287=((cj6)*(sj4));
IkReal x13288=((r12)*(x13275));
evalcond[0]=((IkReal(-3.14159265358979))+(IKfmod(((IkReal(4.71238898038469))+(j1)), IkReal(6.28318530717959))));
evalcond[1]=((((x13265)*(x13273)))+(((IkReal(-1.00000000000000))*(r20)*(x13277)))+(((r21)*(x13263)))+(((x13265)*(x13274)))+(((r22)*(x13267))));
evalcond[2]=((IkReal(-0.364420000000000))+(((IkReal(-1.00000000000000))*(x13269)*(x13274)))+(((x13266)*(x13274)))+(((IkReal(-0.374290000000000))*(cj5)*(r22)))+(pz)+(((IkReal(-1.00000000000000))*(x13269)*(x13273)))+(((IkReal(-1.00000000000000))*(r22)*(x13283)))+(((x13266)*(x13273))));
evalcond[3]=((((IkReal(-1.00000000000000))*(sj5)*(x13262)*(x13282)))+(((r02)*(x13279)))+(((r12)*(x13271)))+(((IkReal(-1.00000000000000))*(r11)*(x13275)*(x13280)))+(((IkReal(-1.00000000000000))*(r01)*(x13262)*(x13280)))+(((IkReal(-1.00000000000000))*(sj5)*(x13264)*(x13285))));
evalcond[4]=((((r01)*(sj0)*(x13263)))+(((IkReal(-1.00000000000000))*(r00)*(x13275)*(x13277)))+(((cj4)*(r10)*(x13268)))+(((sj0)*(x13265)*(x13281)))+(((IkReal(-1.00000000000000))*(r11)*(x13262)*(x13263)))+(((IkReal(-1.00000000000000))*(x13262)*(x13265)*(x13284)))+(((IkReal(-1.00000000000000))*(r10)*(sj6)*(x13262)*(x13265)))+(((IkReal(-1.00000000000000))*(r12)*(x13262)*(x13267)))+(((r00)*(x13264)*(x13265)))+(((x13267)*(x13286))));
evalcond[5]=((IkReal(1.00000000000000))+(((IkReal(-1.00000000000000))*(r02)*(x13262)*(x13267)))+(((IkReal(-1.00000000000000))*(x13267)*(x13288)))+(((IkReal(-1.00000000000000))*(x13262)*(x13265)*(x13281)))+(((r10)*(sj0)*(x13277)))+(((IkReal(-1.00000000000000))*(x13264)*(x13265)*(x13285)))+(((cj4)*(r00)*(x13268)))+(((IkReal(-1.00000000000000))*(r11)*(x13263)*(x13275)))+(((IkReal(-1.00000000000000))*(x13265)*(x13275)*(x13284)))+(((IkReal(-1.00000000000000))*(r01)*(x13262)*(x13263)))+(((IkReal(-1.00000000000000))*(x13262)*(x13265)*(x13282))));
evalcond[6]=((IkReal(-0.0690000000000000))+(((sj0)*(x13266)*(x13281)))+(((IkReal(-1.00000000000000))*(r10)*(x13266)*(x13276)))+(((IkReal(-1.00000000000000))*(sj0)*(x13269)*(x13281)))+(((IkReal(-1.00000000000000))*(x13283)*(x13286)))+(((r11)*(x13268)*(x13269)))+(((cj0)*(r12)*(x13283)))+(((IkReal(-1.00000000000000))*(r11)*(x13266)*(x13268)))+(((r10)*(x13269)*(x13276)))+(((IkReal(-1.00000000000000))*(r00)*(x13264)*(x13269)))+(((IkReal(-1.00000000000000))*(py)*(x13262)))+(((r00)*(x13264)*(x13266)))+(((px)*(sj0)))+(((IkReal(-1.00000000000000))*(x13271)*(x13272)))+(((x13278)*(x13279))));
evalcond[7]=((((r11)*(sj4)*(x13264)))+(((IkReal(-1.00000000000000))*(x13263)*(x13271)*(x13285)))+(((IkReal(-1.00000000000000))*(r02)*(x13262)*(x13270)))+(((IkReal(-1.00000000000000))*(x13270)*(x13288)))+(((IkReal(-1.00000000000000))*(r10)*(x13275)*(x13287)))+(((r01)*(sj4)*(x13276)))+(((IkReal(-1.00000000000000))*(r00)*(x13262)*(x13287)))+(((IkReal(-1.00000000000000))*(cj5)*(r01)*(x13262)*(x13277)))+(((IkReal(-1.00000000000000))*(cj5)*(r00)*(x13262)*(x13263)))+(((IkReal(-1.00000000000000))*(r11)*(x13271)*(x13277))));
evalcond[8]=((IkReal(0.0690000000000000))+(((r12)*(sj0)*(x13283)))+(((r00)*(x13269)*(x13276)))+(((sj0)*(x13269)*(x13284)))+(((IkReal(-1.00000000000000))*(sj0)*(x13266)*(x13284)))+(((x13271)*(x13278)))+(((r01)*(x13268)*(x13269)))+(((IkReal(-1.00000000000000))*(r00)*(x13266)*(x13276)))+(((x13272)*(x13279)))+(((cj0)*(r02)*(x13283)))+(((r10)*(x13264)*(x13269)))+(((IkReal(-1.00000000000000))*(py)*(x13275)))+(((IkReal(-1.00000000000000))*(r01)*(x13266)*(x13268)))+(((IkReal(-1.00000000000000))*(r10)*(x13264)*(x13266)))+(((IkReal(-1.00000000000000))*(px)*(x13262))));
if( IKabs(evalcond[0]) < 0.0000010000000000  && IKabs(evalcond[1]) < 0.0000010000000000  && IKabs(evalcond[2]) < 0.0000010000000000  && IKabs(evalcond[3]) < 0.0000010000000000  && IKabs(evalcond[4]) < 0.0000010000000000  && IKabs(evalcond[5]) < 0.0000010000000000  && IKabs(evalcond[6]) < 0.0000010000000000  && IKabs(evalcond[7]) < 0.0000010000000000  && IKabs(evalcond[8]) < 0.0000010000000000  )
{
{
IkReal j3array[1], cj3array[1], sj3array[1];
bool j3valid[1]={false};
_nj3 = 1;
IkReal x13289=((IkReal(1.00000000000000))*(sj5));
IkReal x13290=((cj6)*(r21));
IkReal x13291=((r20)*(sj6));
IkReal x13292=((IkReal(1.00000000000000))*(cj4)*(cj5));
if( IKabs(((((IkReal(-1.00000000000000))*(x13290)*(x13292)))+(((IkReal(-1.00000000000000))*(x13291)*(x13292)))+(((r21)*(sj4)*(sj6)))+(((IkReal(-1.00000000000000))*(cj4)*(r22)*(x13289)))+(((IkReal(-1.00000000000000))*(cj6)*(r20)*(sj4))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(((((IkReal(-1.00000000000000))*(x13289)*(x13291)))+(((IkReal(-1.00000000000000))*(x13289)*(x13290)))+(((cj5)*(r22))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(IKsqr(((((IkReal(-1.00000000000000))*(x13290)*(x13292)))+(((IkReal(-1.00000000000000))*(x13291)*(x13292)))+(((r21)*(sj4)*(sj6)))+(((IkReal(-1.00000000000000))*(cj4)*(r22)*(x13289)))+(((IkReal(-1.00000000000000))*(cj6)*(r20)*(sj4)))))+IKsqr(((((IkReal(-1.00000000000000))*(x13289)*(x13291)))+(((IkReal(-1.00000000000000))*(x13289)*(x13290)))+(((cj5)*(r22)))))-1) <= IKFAST_SINCOS_THRESH )
    continue;
j3array[0]=IKatan2(((((IkReal(-1.00000000000000))*(x13290)*(x13292)))+(((IkReal(-1.00000000000000))*(x13291)*(x13292)))+(((r21)*(sj4)*(sj6)))+(((IkReal(-1.00000000000000))*(cj4)*(r22)*(x13289)))+(((IkReal(-1.00000000000000))*(cj6)*(r20)*(sj4)))), ((((IkReal(-1.00000000000000))*(x13289)*(x13291)))+(((IkReal(-1.00000000000000))*(x13289)*(x13290)))+(((cj5)*(r22)))));
sj3array[0]=IKsin(j3array[0]);
cj3array[0]=IKcos(j3array[0]);
if( j3array[0] > IKPI )
{
    j3array[0]-=IK2PI;
}
else if( j3array[0] < -IKPI )
{    j3array[0]+=IK2PI;
}
j3valid[0] = true;
for(int ij3 = 0; ij3 < 1; ++ij3)
{
if( !j3valid[ij3] )
{
    continue;
}
_ij3[0] = ij3; _ij3[1] = -1;
for(int iij3 = ij3+1; iij3 < 1; ++iij3)
{
if( j3valid[iij3] && IKabs(cj3array[ij3]-cj3array[iij3]) < IKFAST_SOLUTION_THRESH && IKabs(sj3array[ij3]-sj3array[iij3]) < IKFAST_SOLUTION_THRESH )
{
    j3valid[iij3]=false; _ij3[1] = iij3; break; 
}
}
j3 = j3array[ij3]; cj3 = cj3array[ij3]; sj3 = sj3array[ij3];
{
IkReal evalcond[4];
IkReal x13293=IKsin(j3);
IkReal x13294=IKcos(j3);
IkReal x13295=((sj0)*(sj5));
IkReal x13296=((r00)*(sj6));
IkReal x13297=((cj6)*(r01));
IkReal x13298=((cj0)*(cj5));
IkReal x13299=((IkReal(1.00000000000000))*(cj5));
IkReal x13300=((cj4)*(cj5));
IkReal x13301=((cj6)*(sj4));
IkReal x13302=((sj4)*(sj6));
IkReal x13303=((cj0)*(r11));
IkReal x13304=((IkReal(1.00000000000000))*(cj4));
IkReal x13305=((cj6)*(r21));
IkReal x13306=((r20)*(sj6));
IkReal x13307=((cj0)*(sj5));
IkReal x13308=((r10)*(sj6));
evalcond[0]=((((IkReal(-1.00000000000000))*(r22)*(x13299)))+(((sj5)*(x13306)))+(((sj5)*(x13305)))+(x13294));
evalcond[1]=((((r20)*(x13301)))+(((x13300)*(x13305)))+(((x13300)*(x13306)))+(((cj4)*(r22)*(sj5)))+(x13293)+(((IkReal(-1.00000000000000))*(r21)*(x13302))));
evalcond[2]=((((IkReal(-1.00000000000000))*(r02)*(sj0)*(x13299)))+(((x13295)*(x13296)))+(((r12)*(x13298)))+(((x13295)*(x13297)))+(((IkReal(-1.00000000000000))*(cj6)*(sj5)*(x13303)))+(((IkReal(-1.00000000000000))*(x13307)*(x13308)))+(x13293));
evalcond[3]=((((IkReal(-1.00000000000000))*(x13298)*(x13304)*(x13308)))+(((sj0)*(x13296)*(x13300)))+(((IkReal(-1.00000000000000))*(r01)*(sj0)*(x13302)))+(((IkReal(-1.00000000000000))*(cj0)*(r10)*(x13301)))+(((sj0)*(x13297)*(x13300)))+(((cj4)*(r02)*(x13295)))+(((x13302)*(x13303)))+(((IkReal(-1.00000000000000))*(r12)*(x13304)*(x13307)))+(((IkReal(-1.00000000000000))*(cj6)*(r11)*(x13298)*(x13304)))+(((IkReal(-1.00000000000000))*(x13294)))+(((r00)*(sj0)*(x13301))));
if( IKabs(evalcond[0]) > 0.000001  || IKabs(evalcond[1]) > 0.000001  || IKabs(evalcond[2]) > 0.000001  || IKabs(evalcond[3]) > 0.000001  )
{
continue;
}
}

{
std::vector<IkSingleDOFSolutionBase<IkReal> > vinfos(7);
vinfos[0].jointtype = 1;
vinfos[0].foffset = j0;
vinfos[0].indices[0] = _ij0[0];
vinfos[0].indices[1] = _ij0[1];
vinfos[0].maxsolutions = _nj0;
vinfos[1].jointtype = 1;
vinfos[1].foffset = j1;
vinfos[1].indices[0] = _ij1[0];
vinfos[1].indices[1] = _ij1[1];
vinfos[1].maxsolutions = _nj1;
vinfos[2].jointtype = 1;
vinfos[2].foffset = j2;
vinfos[2].indices[0] = _ij2[0];
vinfos[2].indices[1] = _ij2[1];
vinfos[2].maxsolutions = _nj2;
vinfos[3].jointtype = 1;
vinfos[3].foffset = j3;
vinfos[3].indices[0] = _ij3[0];
vinfos[3].indices[1] = _ij3[1];
vinfos[3].maxsolutions = _nj3;
vinfos[4].jointtype = 1;
vinfos[4].foffset = j4;
vinfos[4].indices[0] = _ij4[0];
vinfos[4].indices[1] = _ij4[1];
vinfos[4].maxsolutions = _nj4;
vinfos[5].jointtype = 1;
vinfos[5].foffset = j5;
vinfos[5].indices[0] = _ij5[0];
vinfos[5].indices[1] = _ij5[1];
vinfos[5].maxsolutions = _nj5;
vinfos[6].jointtype = 1;
vinfos[6].foffset = j6;
vinfos[6].indices[0] = _ij6[0];
vinfos[6].indices[1] = _ij6[1];
vinfos[6].maxsolutions = _nj6;
std::vector<int> vfree(0);
solutions.AddSolution(vinfos,vfree);
}
}
}

} else
{
if( 1 )
{
continue;

} else
{
}
}
}
}

} else
{
{
IkReal j3array[1], cj3array[1], sj3array[1];
bool j3valid[1]={false};
_nj3 = 1;
IkReal x13309=((cj5)*(r02));
IkReal x13310=((cj0)*(sj5));
IkReal x13311=((r10)*(sj6));
IkReal x13312=((IkReal(1.00000000000000))*(cj6));
IkReal x13313=((sj0)*(sj5));
IkReal x13314=((cj5)*(r12));
IkReal x13315=((IkReal(1.00000000000000))*(r00)*(sj6));
if( IKabs(((((sj0)*(x13309)))+(((x13310)*(x13311)))+(((IkReal(-1.00000000000000))*(r01)*(x13312)*(x13313)))+(((cj6)*(r11)*(x13310)))+(((IkReal(-1.00000000000000))*(x13313)*(x13315)))+(((IkReal(-1.00000000000000))*(cj0)*(x13314))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(((((IKabs(cj1) != 0)?((IkReal)1/(cj1)):(IkReal)1.0e30))*(((((IkReal(-1.00000000000000))*(r01)*(x13310)*(x13312)))+(((sj0)*(x13314)))+(((IkReal(-1.00000000000000))*(r11)*(x13312)*(x13313)))+(((IkReal(-1.00000000000000))*(x13310)*(x13315)))+(((IkReal(-1.00000000000000))*(x13311)*(x13313)))+(((cj0)*(x13309))))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(IKsqr(((((sj0)*(x13309)))+(((x13310)*(x13311)))+(((IkReal(-1.00000000000000))*(r01)*(x13312)*(x13313)))+(((cj6)*(r11)*(x13310)))+(((IkReal(-1.00000000000000))*(x13313)*(x13315)))+(((IkReal(-1.00000000000000))*(cj0)*(x13314)))))+IKsqr(((((IKabs(cj1) != 0)?((IkReal)1/(cj1)):(IkReal)1.0e30))*(((((IkReal(-1.00000000000000))*(r01)*(x13310)*(x13312)))+(((sj0)*(x13314)))+(((IkReal(-1.00000000000000))*(r11)*(x13312)*(x13313)))+(((IkReal(-1.00000000000000))*(x13310)*(x13315)))+(((IkReal(-1.00000000000000))*(x13311)*(x13313)))+(((cj0)*(x13309)))))))-1) <= IKFAST_SINCOS_THRESH )
    continue;
j3array[0]=IKatan2(((((sj0)*(x13309)))+(((x13310)*(x13311)))+(((IkReal(-1.00000000000000))*(r01)*(x13312)*(x13313)))+(((cj6)*(r11)*(x13310)))+(((IkReal(-1.00000000000000))*(x13313)*(x13315)))+(((IkReal(-1.00000000000000))*(cj0)*(x13314)))), ((((IKabs(cj1) != 0)?((IkReal)1/(cj1)):(IkReal)1.0e30))*(((((IkReal(-1.00000000000000))*(r01)*(x13310)*(x13312)))+(((sj0)*(x13314)))+(((IkReal(-1.00000000000000))*(r11)*(x13312)*(x13313)))+(((IkReal(-1.00000000000000))*(x13310)*(x13315)))+(((IkReal(-1.00000000000000))*(x13311)*(x13313)))+(((cj0)*(x13309)))))));
sj3array[0]=IKsin(j3array[0]);
cj3array[0]=IKcos(j3array[0]);
if( j3array[0] > IKPI )
{
    j3array[0]-=IK2PI;
}
else if( j3array[0] < -IKPI )
{    j3array[0]+=IK2PI;
}
j3valid[0] = true;
for(int ij3 = 0; ij3 < 1; ++ij3)
{
if( !j3valid[ij3] )
{
    continue;
}
_ij3[0] = ij3; _ij3[1] = -1;
for(int iij3 = ij3+1; iij3 < 1; ++iij3)
{
if( j3valid[iij3] && IKabs(cj3array[ij3]-cj3array[iij3]) < IKFAST_SOLUTION_THRESH && IKabs(sj3array[ij3]-sj3array[iij3]) < IKFAST_SOLUTION_THRESH )
{
    j3valid[iij3]=false; _ij3[1] = iij3; break; 
}
}
j3 = j3array[ij3]; cj3 = cj3array[ij3]; sj3 = sj3array[ij3];
{
IkReal evalcond[6];
IkReal x13316=IKsin(j3);
IkReal x13317=IKcos(j3);
IkReal x13318=((sj0)*(sj5));
IkReal x13319=((r00)*(sj6));
IkReal x13320=((IkReal(1.00000000000000))*(cj4));
IkReal x13321=((cj6)*(r01));
IkReal x13322=((cj0)*(cj5));
IkReal x13323=((cj5)*(sj0));
IkReal x13324=((cj6)*(r11));
IkReal x13325=((cj0)*(sj5));
IkReal x13326=((IkReal(1.00000000000000))*(cj1));
IkReal x13327=((cj6)*(sj4));
IkReal x13328=((IkReal(1.00000000000000))*(sj1));
IkReal x13329=((cj4)*(cj5));
IkReal x13330=((cj6)*(r21));
IkReal x13331=((r20)*(sj6));
IkReal x13332=((r10)*(sj6));
IkReal x13333=((IkReal(1.00000000000000))*(cj0));
IkReal x13334=((cj0)*(sj4)*(sj6));
IkReal x13335=((sj0)*(sj4)*(sj6));
evalcond[0]=((((IkReal(-1.00000000000000))*(x13317)*(x13328)))+(((sj5)*(x13331)))+(((IkReal(-1.00000000000000))*(cj5)*(r22)))+(((sj5)*(x13330))));
evalcond[1]=((((IkReal(-1.00000000000000))*(r21)*(sj4)*(sj6)))+(((IkReal(-1.00000000000000))*(x13316)*(x13328)))+(((x13329)*(x13331)))+(((cj4)*(r22)*(sj5)))+(((x13329)*(x13330)))+(((r20)*(x13327))));
evalcond[2]=((((IkReal(-1.00000000000000))*(r02)*(x13323)))+(((IkReal(-1.00000000000000))*(x13324)*(x13325)))+(((r12)*(x13322)))+(((x13318)*(x13321)))+(((x13318)*(x13319)))+(x13316)+(((IkReal(-1.00000000000000))*(x13325)*(x13332))));
evalcond[3]=((((r12)*(x13323)))+(((IkReal(-1.00000000000000))*(x13321)*(x13325)))+(((IkReal(-1.00000000000000))*(x13317)*(x13326)))+(((IkReal(-1.00000000000000))*(x13319)*(x13325)))+(((r02)*(x13322)))+(((IkReal(-1.00000000000000))*(x13318)*(x13324)))+(((IkReal(-1.00000000000000))*(x13318)*(x13332))));
evalcond[4]=((((IkReal(-1.00000000000000))*(x13320)*(x13322)*(x13332)))+(((cj4)*(x13321)*(x13323)))+(((cj4)*(x13319)*(x13323)))+(((r11)*(x13334)))+(((IkReal(-1.00000000000000))*(x13317)))+(((IkReal(-1.00000000000000))*(r01)*(x13335)))+(((IkReal(-1.00000000000000))*(x13320)*(x13322)*(x13324)))+(((IkReal(-1.00000000000000))*(r12)*(x13320)*(x13325)))+(((r00)*(sj0)*(x13327)))+(((cj4)*(r02)*(x13318)))+(((IkReal(-1.00000000000000))*(r10)*(x13327)*(x13333))));
evalcond[5]=((((IkReal(-1.00000000000000))*(x13320)*(x13323)*(x13332)))+(((IkReal(-1.00000000000000))*(r12)*(x13318)*(x13320)))+(((IkReal(-1.00000000000000))*(x13316)*(x13326)))+(((IkReal(-1.00000000000000))*(r00)*(x13327)*(x13333)))+(((r11)*(x13335)))+(((IkReal(-1.00000000000000))*(r02)*(x13320)*(x13325)))+(((IkReal(-1.00000000000000))*(x13320)*(x13321)*(x13322)))+(((IkReal(-1.00000000000000))*(r10)*(sj0)*(x13327)))+(((IkReal(-1.00000000000000))*(x13320)*(x13323)*(x13324)))+(((IkReal(-1.00000000000000))*(x13319)*(x13320)*(x13322)))+(((r01)*(x13334))));
if( IKabs(evalcond[0]) > 0.000001  || IKabs(evalcond[1]) > 0.000001  || IKabs(evalcond[2]) > 0.000001  || IKabs(evalcond[3]) > 0.000001  || IKabs(evalcond[4]) > 0.000001  || IKabs(evalcond[5]) > 0.000001  )
{
continue;
}
}

{
std::vector<IkSingleDOFSolutionBase<IkReal> > vinfos(7);
vinfos[0].jointtype = 1;
vinfos[0].foffset = j0;
vinfos[0].indices[0] = _ij0[0];
vinfos[0].indices[1] = _ij0[1];
vinfos[0].maxsolutions = _nj0;
vinfos[1].jointtype = 1;
vinfos[1].foffset = j1;
vinfos[1].indices[0] = _ij1[0];
vinfos[1].indices[1] = _ij1[1];
vinfos[1].maxsolutions = _nj1;
vinfos[2].jointtype = 1;
vinfos[2].foffset = j2;
vinfos[2].indices[0] = _ij2[0];
vinfos[2].indices[1] = _ij2[1];
vinfos[2].maxsolutions = _nj2;
vinfos[3].jointtype = 1;
vinfos[3].foffset = j3;
vinfos[3].indices[0] = _ij3[0];
vinfos[3].indices[1] = _ij3[1];
vinfos[3].maxsolutions = _nj3;
vinfos[4].jointtype = 1;
vinfos[4].foffset = j4;
vinfos[4].indices[0] = _ij4[0];
vinfos[4].indices[1] = _ij4[1];
vinfos[4].maxsolutions = _nj4;
vinfos[5].jointtype = 1;
vinfos[5].foffset = j5;
vinfos[5].indices[0] = _ij5[0];
vinfos[5].indices[1] = _ij5[1];
vinfos[5].maxsolutions = _nj5;
vinfos[6].jointtype = 1;
vinfos[6].foffset = j6;
vinfos[6].indices[0] = _ij6[0];
vinfos[6].indices[1] = _ij6[1];
vinfos[6].maxsolutions = _nj6;
std::vector<int> vfree(0);
solutions.AddSolution(vinfos,vfree);
}
}
}

}

}

} else
{
{
IkReal j3array[1], cj3array[1], sj3array[1];
bool j3valid[1]={false};
_nj3 = 1;
IkReal x13336=((sj5)*(sj6));
IkReal x13337=((IkReal(1.00000000000000))*(sj0));
IkReal x13338=((cj6)*(sj5));
IkReal x13339=((IkReal(1.00000000000000))*(cj5));
if( IKabs(((((cj0)*(r10)*(x13336)))+(((cj0)*(r11)*(x13338)))+(((cj5)*(r02)*(sj0)))+(((IkReal(-1.00000000000000))*(cj0)*(r12)*(x13339)))+(((IkReal(-1.00000000000000))*(r00)*(x13336)*(x13337)))+(((IkReal(-1.00000000000000))*(r01)*(x13337)*(x13338))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(((((IKabs(sj1) != 0)?((IkReal)1/(sj1)):(IkReal)1.0e30))*(((((IkReal(-1.00000000000000))*(r22)*(x13339)))+(((r20)*(x13336)))+(((r21)*(x13338))))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(IKsqr(((((cj0)*(r10)*(x13336)))+(((cj0)*(r11)*(x13338)))+(((cj5)*(r02)*(sj0)))+(((IkReal(-1.00000000000000))*(cj0)*(r12)*(x13339)))+(((IkReal(-1.00000000000000))*(r00)*(x13336)*(x13337)))+(((IkReal(-1.00000000000000))*(r01)*(x13337)*(x13338)))))+IKsqr(((((IKabs(sj1) != 0)?((IkReal)1/(sj1)):(IkReal)1.0e30))*(((((IkReal(-1.00000000000000))*(r22)*(x13339)))+(((r20)*(x13336)))+(((r21)*(x13338)))))))-1) <= IKFAST_SINCOS_THRESH )
    continue;
j3array[0]=IKatan2(((((cj0)*(r10)*(x13336)))+(((cj0)*(r11)*(x13338)))+(((cj5)*(r02)*(sj0)))+(((IkReal(-1.00000000000000))*(cj0)*(r12)*(x13339)))+(((IkReal(-1.00000000000000))*(r00)*(x13336)*(x13337)))+(((IkReal(-1.00000000000000))*(r01)*(x13337)*(x13338)))), ((((IKabs(sj1) != 0)?((IkReal)1/(sj1)):(IkReal)1.0e30))*(((((IkReal(-1.00000000000000))*(r22)*(x13339)))+(((r20)*(x13336)))+(((r21)*(x13338)))))));
sj3array[0]=IKsin(j3array[0]);
cj3array[0]=IKcos(j3array[0]);
if( j3array[0] > IKPI )
{
    j3array[0]-=IK2PI;
}
else if( j3array[0] < -IKPI )
{    j3array[0]+=IK2PI;
}
j3valid[0] = true;
for(int ij3 = 0; ij3 < 1; ++ij3)
{
if( !j3valid[ij3] )
{
    continue;
}
_ij3[0] = ij3; _ij3[1] = -1;
for(int iij3 = ij3+1; iij3 < 1; ++iij3)
{
if( j3valid[iij3] && IKabs(cj3array[ij3]-cj3array[iij3]) < IKFAST_SOLUTION_THRESH && IKabs(sj3array[ij3]-sj3array[iij3]) < IKFAST_SOLUTION_THRESH )
{
    j3valid[iij3]=false; _ij3[1] = iij3; break; 
}
}
j3 = j3array[ij3]; cj3 = cj3array[ij3]; sj3 = sj3array[ij3];
{
IkReal evalcond[6];
IkReal x13340=IKsin(j3);
IkReal x13341=IKcos(j3);
IkReal x13342=((sj0)*(sj5));
IkReal x13343=((r00)*(sj6));
IkReal x13344=((IkReal(1.00000000000000))*(cj4));
IkReal x13345=((cj6)*(r01));
IkReal x13346=((cj0)*(cj5));
IkReal x13347=((cj5)*(sj0));
IkReal x13348=((cj6)*(r11));
IkReal x13349=((cj0)*(sj5));
IkReal x13350=((IkReal(1.00000000000000))*(cj1));
IkReal x13351=((cj6)*(sj4));
IkReal x13352=((IkReal(1.00000000000000))*(sj1));
IkReal x13353=((cj4)*(cj5));
IkReal x13354=((cj6)*(r21));
IkReal x13355=((r20)*(sj6));
IkReal x13356=((r10)*(sj6));
IkReal x13357=((IkReal(1.00000000000000))*(cj0));
IkReal x13358=((cj0)*(sj4)*(sj6));
IkReal x13359=((sj0)*(sj4)*(sj6));
evalcond[0]=((((IkReal(-1.00000000000000))*(x13341)*(x13352)))+(((sj5)*(x13355)))+(((IkReal(-1.00000000000000))*(cj5)*(r22)))+(((sj5)*(x13354))));
evalcond[1]=((((IkReal(-1.00000000000000))*(r21)*(sj4)*(sj6)))+(((x13353)*(x13354)))+(((cj4)*(r22)*(sj5)))+(((x13353)*(x13355)))+(((IkReal(-1.00000000000000))*(x13340)*(x13352)))+(((r20)*(x13351))));
evalcond[2]=((((IkReal(-1.00000000000000))*(x13349)*(x13356)))+(((r12)*(x13346)))+(((IkReal(-1.00000000000000))*(x13348)*(x13349)))+(((x13342)*(x13345)))+(x13340)+(((x13342)*(x13343)))+(((IkReal(-1.00000000000000))*(r02)*(x13347))));
evalcond[3]=((((IkReal(-1.00000000000000))*(x13341)*(x13350)))+(((IkReal(-1.00000000000000))*(x13342)*(x13348)))+(((IkReal(-1.00000000000000))*(x13342)*(x13356)))+(((IkReal(-1.00000000000000))*(x13343)*(x13349)))+(((r12)*(x13347)))+(((r02)*(x13346)))+(((IkReal(-1.00000000000000))*(x13345)*(x13349))));
evalcond[4]=((((IkReal(-1.00000000000000))*(x13344)*(x13346)*(x13348)))+(((IkReal(-1.00000000000000))*(x13341)))+(((IkReal(-1.00000000000000))*(r10)*(x13351)*(x13357)))+(((IkReal(-1.00000000000000))*(x13344)*(x13346)*(x13356)))+(((cj4)*(x13345)*(x13347)))+(((cj4)*(x13343)*(x13347)))+(((r11)*(x13358)))+(((IkReal(-1.00000000000000))*(r01)*(x13359)))+(((cj4)*(r02)*(x13342)))+(((IkReal(-1.00000000000000))*(r12)*(x13344)*(x13349)))+(((r00)*(sj0)*(x13351))));
evalcond[5]=((((IkReal(-1.00000000000000))*(r10)*(sj0)*(x13351)))+(((IkReal(-1.00000000000000))*(x13340)*(x13350)))+(((IkReal(-1.00000000000000))*(r12)*(x13342)*(x13344)))+(((IkReal(-1.00000000000000))*(x13344)*(x13345)*(x13346)))+(((IkReal(-1.00000000000000))*(x13344)*(x13347)*(x13348)))+(((IkReal(-1.00000000000000))*(r02)*(x13344)*(x13349)))+(((r01)*(x13358)))+(((r11)*(x13359)))+(((IkReal(-1.00000000000000))*(r00)*(x13351)*(x13357)))+(((IkReal(-1.00000000000000))*(x13344)*(x13347)*(x13356)))+(((IkReal(-1.00000000000000))*(x13343)*(x13344)*(x13346))));
if( IKabs(evalcond[0]) > 0.000001  || IKabs(evalcond[1]) > 0.000001  || IKabs(evalcond[2]) > 0.000001  || IKabs(evalcond[3]) > 0.000001  || IKabs(evalcond[4]) > 0.000001  || IKabs(evalcond[5]) > 0.000001  )
{
continue;
}
}

{
std::vector<IkSingleDOFSolutionBase<IkReal> > vinfos(7);
vinfos[0].jointtype = 1;
vinfos[0].foffset = j0;
vinfos[0].indices[0] = _ij0[0];
vinfos[0].indices[1] = _ij0[1];
vinfos[0].maxsolutions = _nj0;
vinfos[1].jointtype = 1;
vinfos[1].foffset = j1;
vinfos[1].indices[0] = _ij1[0];
vinfos[1].indices[1] = _ij1[1];
vinfos[1].maxsolutions = _nj1;
vinfos[2].jointtype = 1;
vinfos[2].foffset = j2;
vinfos[2].indices[0] = _ij2[0];
vinfos[2].indices[1] = _ij2[1];
vinfos[2].maxsolutions = _nj2;
vinfos[3].jointtype = 1;
vinfos[3].foffset = j3;
vinfos[3].indices[0] = _ij3[0];
vinfos[3].indices[1] = _ij3[1];
vinfos[3].maxsolutions = _nj3;
vinfos[4].jointtype = 1;
vinfos[4].foffset = j4;
vinfos[4].indices[0] = _ij4[0];
vinfos[4].indices[1] = _ij4[1];
vinfos[4].maxsolutions = _nj4;
vinfos[5].jointtype = 1;
vinfos[5].foffset = j5;
vinfos[5].indices[0] = _ij5[0];
vinfos[5].indices[1] = _ij5[1];
vinfos[5].maxsolutions = _nj5;
vinfos[6].jointtype = 1;
vinfos[6].foffset = j6;
vinfos[6].indices[0] = _ij6[0];
vinfos[6].indices[1] = _ij6[1];
vinfos[6].maxsolutions = _nj6;
std::vector<int> vfree(0);
solutions.AddSolution(vinfos,vfree);
}
}
}

}

}

} else
{
{
IkReal j3array[1], cj3array[1], sj3array[1];
bool j3valid[1]={false};
_nj3 = 1;
IkReal x13360=((r20)*(sj6));
IkReal x13361=((cj4)*(cj5));
IkReal x13362=((cj6)*(r21));
if( IKabs(((gconst12)*(((((IkReal(-1.00000000000000))*(r21)*(sj4)*(sj6)))+(((x13360)*(x13361)))+(((x13361)*(x13362)))+(((cj6)*(r20)*(sj4)))+(((cj4)*(r22)*(sj5))))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(((gconst12)*(((((sj5)*(x13360)))+(((IkReal(-1.00000000000000))*(cj5)*(r22)))+(((sj5)*(x13362))))))) < IKFAST_ATAN2_MAGTHRESH )
    continue;
j3array[0]=IKatan2(((gconst12)*(((((IkReal(-1.00000000000000))*(r21)*(sj4)*(sj6)))+(((x13360)*(x13361)))+(((x13361)*(x13362)))+(((cj6)*(r20)*(sj4)))+(((cj4)*(r22)*(sj5)))))), ((gconst12)*(((((sj5)*(x13360)))+(((IkReal(-1.00000000000000))*(cj5)*(r22)))+(((sj5)*(x13362)))))));
sj3array[0]=IKsin(j3array[0]);
cj3array[0]=IKcos(j3array[0]);
if( j3array[0] > IKPI )
{
    j3array[0]-=IK2PI;
}
else if( j3array[0] < -IKPI )
{    j3array[0]+=IK2PI;
}
j3valid[0] = true;
for(int ij3 = 0; ij3 < 1; ++ij3)
{
if( !j3valid[ij3] )
{
    continue;
}
_ij3[0] = ij3; _ij3[1] = -1;
for(int iij3 = ij3+1; iij3 < 1; ++iij3)
{
if( j3valid[iij3] && IKabs(cj3array[ij3]-cj3array[iij3]) < IKFAST_SOLUTION_THRESH && IKabs(sj3array[ij3]-sj3array[iij3]) < IKFAST_SOLUTION_THRESH )
{
    j3valid[iij3]=false; _ij3[1] = iij3; break; 
}
}
j3 = j3array[ij3]; cj3 = cj3array[ij3]; sj3 = sj3array[ij3];
{
IkReal evalcond[6];
IkReal x13363=IKsin(j3);
IkReal x13364=IKcos(j3);
IkReal x13365=((sj0)*(sj5));
IkReal x13366=((r00)*(sj6));
IkReal x13367=((IkReal(1.00000000000000))*(cj4));
IkReal x13368=((cj6)*(r01));
IkReal x13369=((cj0)*(cj5));
IkReal x13370=((cj5)*(sj0));
IkReal x13371=((cj6)*(r11));
IkReal x13372=((cj0)*(sj5));
IkReal x13373=((IkReal(1.00000000000000))*(cj1));
IkReal x13374=((cj6)*(sj4));
IkReal x13375=((IkReal(1.00000000000000))*(sj1));
IkReal x13376=((cj4)*(cj5));
IkReal x13377=((cj6)*(r21));
IkReal x13378=((r20)*(sj6));
IkReal x13379=((r10)*(sj6));
IkReal x13380=((IkReal(1.00000000000000))*(cj0));
IkReal x13381=((cj0)*(sj4)*(sj6));
IkReal x13382=((sj0)*(sj4)*(sj6));
evalcond[0]=((((IkReal(-1.00000000000000))*(x13364)*(x13375)))+(((sj5)*(x13378)))+(((IkReal(-1.00000000000000))*(cj5)*(r22)))+(((sj5)*(x13377))));
evalcond[1]=((((IkReal(-1.00000000000000))*(r21)*(sj4)*(sj6)))+(((cj4)*(r22)*(sj5)))+(((x13376)*(x13378)))+(((r20)*(x13374)))+(((x13376)*(x13377)))+(((IkReal(-1.00000000000000))*(x13363)*(x13375))));
evalcond[2]=((((IkReal(-1.00000000000000))*(x13371)*(x13372)))+(((IkReal(-1.00000000000000))*(r02)*(x13370)))+(((r12)*(x13369)))+(((x13365)*(x13368)))+(((IkReal(-1.00000000000000))*(x13372)*(x13379)))+(x13363)+(((x13365)*(x13366))));
evalcond[3]=((((IkReal(-1.00000000000000))*(x13365)*(x13379)))+(((r02)*(x13369)))+(((IkReal(-1.00000000000000))*(x13365)*(x13371)))+(((IkReal(-1.00000000000000))*(x13366)*(x13372)))+(((r12)*(x13370)))+(((IkReal(-1.00000000000000))*(x13368)*(x13372)))+(((IkReal(-1.00000000000000))*(x13364)*(x13373))));
evalcond[4]=((((IkReal(-1.00000000000000))*(r01)*(x13382)))+(((cj4)*(x13368)*(x13370)))+(((cj4)*(x13366)*(x13370)))+(((IkReal(-1.00000000000000))*(r12)*(x13367)*(x13372)))+(((IkReal(-1.00000000000000))*(x13367)*(x13369)*(x13379)))+(((cj4)*(r02)*(x13365)))+(((r11)*(x13381)))+(((IkReal(-1.00000000000000))*(x13364)))+(((IkReal(-1.00000000000000))*(r10)*(x13374)*(x13380)))+(((r00)*(sj0)*(x13374)))+(((IkReal(-1.00000000000000))*(x13367)*(x13369)*(x13371))));
evalcond[5]=((((IkReal(-1.00000000000000))*(r12)*(x13365)*(x13367)))+(((IkReal(-1.00000000000000))*(r00)*(x13374)*(x13380)))+(((IkReal(-1.00000000000000))*(x13367)*(x13370)*(x13379)))+(((IkReal(-1.00000000000000))*(x13366)*(x13367)*(x13369)))+(((IkReal(-1.00000000000000))*(r02)*(x13367)*(x13372)))+(((r11)*(x13382)))+(((IkReal(-1.00000000000000))*(r10)*(sj0)*(x13374)))+(((IkReal(-1.00000000000000))*(x13367)*(x13370)*(x13371)))+(((IkReal(-1.00000000000000))*(x13367)*(x13368)*(x13369)))+(((IkReal(-1.00000000000000))*(x13363)*(x13373)))+(((r01)*(x13381))));
if( IKabs(evalcond[0]) > 0.000001  || IKabs(evalcond[1]) > 0.000001  || IKabs(evalcond[2]) > 0.000001  || IKabs(evalcond[3]) > 0.000001  || IKabs(evalcond[4]) > 0.000001  || IKabs(evalcond[5]) > 0.000001  )
{
continue;
}
}

{
std::vector<IkSingleDOFSolutionBase<IkReal> > vinfos(7);
vinfos[0].jointtype = 1;
vinfos[0].foffset = j0;
vinfos[0].indices[0] = _ij0[0];
vinfos[0].indices[1] = _ij0[1];
vinfos[0].maxsolutions = _nj0;
vinfos[1].jointtype = 1;
vinfos[1].foffset = j1;
vinfos[1].indices[0] = _ij1[0];
vinfos[1].indices[1] = _ij1[1];
vinfos[1].maxsolutions = _nj1;
vinfos[2].jointtype = 1;
vinfos[2].foffset = j2;
vinfos[2].indices[0] = _ij2[0];
vinfos[2].indices[1] = _ij2[1];
vinfos[2].maxsolutions = _nj2;
vinfos[3].jointtype = 1;
vinfos[3].foffset = j3;
vinfos[3].indices[0] = _ij3[0];
vinfos[3].indices[1] = _ij3[1];
vinfos[3].maxsolutions = _nj3;
vinfos[4].jointtype = 1;
vinfos[4].foffset = j4;
vinfos[4].indices[0] = _ij4[0];
vinfos[4].indices[1] = _ij4[1];
vinfos[4].maxsolutions = _nj4;
vinfos[5].jointtype = 1;
vinfos[5].foffset = j5;
vinfos[5].indices[0] = _ij5[0];
vinfos[5].indices[1] = _ij5[1];
vinfos[5].maxsolutions = _nj5;
vinfos[6].jointtype = 1;
vinfos[6].foffset = j6;
vinfos[6].indices[0] = _ij6[0];
vinfos[6].indices[1] = _ij6[1];
vinfos[6].maxsolutions = _nj6;
std::vector<int> vfree(0);
solutions.AddSolution(vinfos,vfree);
}
}
}

}

}

} else
{
if( 1 )
{
continue;

} else
{
}
}
}
}
}
}
}
}

} else
{
{
IkReal j3array[1], cj3array[1], sj3array[1];
bool j3valid[1]={false};
_nj3 = 1;
IkReal x13383=((IKabs(sj2) != 0)?((IkReal)1/(sj2)):(IkReal)1.0e30);
IkReal x13384=((sj5)*(sj6));
IkReal x13385=((r00)*(sj0));
IkReal x13386=((cj1)*(cj2));
IkReal x13387=((cj0)*(r10));
IkReal x13388=((cj6)*(sj5));
IkReal x13389=((r01)*(sj0));
IkReal x13390=((IkReal(1.00000000000000))*(cj0));
IkReal x13391=((cj5)*(r12));
IkReal x13392=((IkReal(1.00000000000000))*(cj5));
IkReal x13393=((r02)*(sj0));
if( IKabs(((x13383)*(((((x13384)*(x13385)))+(((cj0)*(x13391)))+(((IkReal(-1.00000000000000))*(r11)*(x13388)*(x13390)))+(((IkReal(-1.00000000000000))*(x13392)*(x13393)))+(((x13388)*(x13389)))+(((IkReal(-1.00000000000000))*(x13384)*(x13387))))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(((x13383)*(((IKabs(sj1) != 0)?((IkReal)1/(sj1)):(IkReal)1.0e30))*(((((IkReal(-1.00000000000000))*(x13386)*(x13388)*(x13389)))+(((IkReal(-1.00000000000000))*(x13386)*(x13390)*(x13391)))+(((IkReal(-1.00000000000000))*(x13384)*(x13385)*(x13386)))+(((cj0)*(r11)*(x13386)*(x13388)))+(((r20)*(sj2)*(x13384)))+(((IkReal(-1.00000000000000))*(r22)*(sj2)*(x13392)))+(((cj5)*(x13386)*(x13393)))+(((x13384)*(x13386)*(x13387)))+(((r21)*(sj2)*(x13388))))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(IKsqr(((x13383)*(((((x13384)*(x13385)))+(((cj0)*(x13391)))+(((IkReal(-1.00000000000000))*(r11)*(x13388)*(x13390)))+(((IkReal(-1.00000000000000))*(x13392)*(x13393)))+(((x13388)*(x13389)))+(((IkReal(-1.00000000000000))*(x13384)*(x13387)))))))+IKsqr(((x13383)*(((IKabs(sj1) != 0)?((IkReal)1/(sj1)):(IkReal)1.0e30))*(((((IkReal(-1.00000000000000))*(x13386)*(x13388)*(x13389)))+(((IkReal(-1.00000000000000))*(x13386)*(x13390)*(x13391)))+(((IkReal(-1.00000000000000))*(x13384)*(x13385)*(x13386)))+(((cj0)*(r11)*(x13386)*(x13388)))+(((r20)*(sj2)*(x13384)))+(((IkReal(-1.00000000000000))*(r22)*(sj2)*(x13392)))+(((cj5)*(x13386)*(x13393)))+(((x13384)*(x13386)*(x13387)))+(((r21)*(sj2)*(x13388)))))))-1) <= IKFAST_SINCOS_THRESH )
    continue;
j3array[0]=IKatan2(((x13383)*(((((x13384)*(x13385)))+(((cj0)*(x13391)))+(((IkReal(-1.00000000000000))*(r11)*(x13388)*(x13390)))+(((IkReal(-1.00000000000000))*(x13392)*(x13393)))+(((x13388)*(x13389)))+(((IkReal(-1.00000000000000))*(x13384)*(x13387)))))), ((x13383)*(((IKabs(sj1) != 0)?((IkReal)1/(sj1)):(IkReal)1.0e30))*(((((IkReal(-1.00000000000000))*(x13386)*(x13388)*(x13389)))+(((IkReal(-1.00000000000000))*(x13386)*(x13390)*(x13391)))+(((IkReal(-1.00000000000000))*(x13384)*(x13385)*(x13386)))+(((cj0)*(r11)*(x13386)*(x13388)))+(((r20)*(sj2)*(x13384)))+(((IkReal(-1.00000000000000))*(r22)*(sj2)*(x13392)))+(((cj5)*(x13386)*(x13393)))+(((x13384)*(x13386)*(x13387)))+(((r21)*(sj2)*(x13388)))))));
sj3array[0]=IKsin(j3array[0]);
cj3array[0]=IKcos(j3array[0]);
if( j3array[0] > IKPI )
{
    j3array[0]-=IK2PI;
}
else if( j3array[0] < -IKPI )
{    j3array[0]+=IK2PI;
}
j3valid[0] = true;
for(int ij3 = 0; ij3 < 1; ++ij3)
{
if( !j3valid[ij3] )
{
    continue;
}
_ij3[0] = ij3; _ij3[1] = -1;
for(int iij3 = ij3+1; iij3 < 1; ++iij3)
{
if( j3valid[iij3] && IKabs(cj3array[ij3]-cj3array[iij3]) < IKFAST_SOLUTION_THRESH && IKabs(sj3array[ij3]-sj3array[iij3]) < IKFAST_SOLUTION_THRESH )
{
    j3valid[iij3]=false; _ij3[1] = iij3; break; 
}
}
j3 = j3array[ij3]; cj3 = cj3array[ij3]; sj3 = sj3array[ij3];
{
IkReal evalcond[6];
IkReal x13394=IKcos(j3);
IkReal x13395=IKsin(j3);
IkReal x13396=((sj0)*(sj5));
IkReal x13397=((r00)*(sj6));
IkReal x13398=((IkReal(1.00000000000000))*(cj4));
IkReal x13399=((cj6)*(r01));
IkReal x13400=((cj0)*(cj5));
IkReal x13401=((cj5)*(sj0));
IkReal x13402=((cj6)*(r11));
IkReal x13403=((cj6)*(sj4));
IkReal x13404=((IkReal(1.00000000000000))*(cj1));
IkReal x13405=((cj4)*(cj5));
IkReal x13406=((cj6)*(r21));
IkReal x13407=((r20)*(sj6));
IkReal x13408=((r10)*(sj6));
IkReal x13409=((cj0)*(sj5));
IkReal x13410=((IkReal(1.00000000000000))*(cj0));
IkReal x13411=((IkReal(1.00000000000000))*(x13409));
IkReal x13412=((IkReal(1.00000000000000))*(x13395));
IkReal x13413=((cj0)*(sj4)*(sj6));
IkReal x13414=((cj2)*(x13395));
IkReal x13415=((sj0)*(sj4)*(sj6));
IkReal x13416=((IkReal(1.00000000000000))*(sj1)*(x13394));
evalcond[0]=((((IkReal(-1.00000000000000))*(x13404)*(x13414)))+(((IkReal(-1.00000000000000))*(x13416)))+(((sj5)*(x13406)))+(((sj5)*(x13407)))+(((IkReal(-1.00000000000000))*(cj5)*(r22))));
evalcond[1]=((((IkReal(-1.00000000000000))*(r21)*(sj4)*(sj6)))+(((x13405)*(x13407)))+(((cj4)*(r22)*(sj5)))+(((cj1)*(cj2)*(x13394)))+(((r20)*(x13403)))+(((IkReal(-1.00000000000000))*(sj1)*(x13412)))+(((x13405)*(x13406))));
evalcond[2]=((((x13396)*(x13399)))+(((r12)*(x13400)))+(((IkReal(-1.00000000000000))*(x13402)*(x13411)))+(((IkReal(-1.00000000000000))*(r02)*(x13401)))+(((IkReal(-1.00000000000000))*(x13408)*(x13411)))+(((x13396)*(x13397)))+(((IkReal(-1.00000000000000))*(sj2)*(x13412))));
evalcond[3]=((((IkReal(-1.00000000000000))*(x13396)*(x13402)))+(((IkReal(-1.00000000000000))*(x13394)*(x13404)))+(((r12)*(x13401)))+(((IkReal(-1.00000000000000))*(x13399)*(x13411)))+(((IkReal(-1.00000000000000))*(x13396)*(x13408)))+(((r02)*(x13400)))+(((IkReal(-1.00000000000000))*(x13397)*(x13411)))+(((sj1)*(x13414))));
evalcond[4]=((((IkReal(-1.00000000000000))*(x13398)*(x13400)*(x13402)))+(((cj4)*(x13399)*(x13401)))+(((cj4)*(r02)*(x13396)))+(((cj4)*(x13397)*(x13401)))+(((IkReal(-1.00000000000000))*(x13398)*(x13400)*(x13408)))+(((IkReal(-1.00000000000000))*(r01)*(x13415)))+(((sj2)*(x13394)))+(((IkReal(-1.00000000000000))*(r12)*(x13398)*(x13409)))+(((r00)*(sj0)*(x13403)))+(((IkReal(-1.00000000000000))*(r10)*(x13403)*(x13410)))+(((r11)*(x13413))));
evalcond[5]=((((IkReal(-1.00000000000000))*(x13398)*(x13401)*(x13402)))+(((IkReal(-1.00000000000000))*(x13398)*(x13401)*(x13408)))+(((IkReal(-1.00000000000000))*(r00)*(x13403)*(x13410)))+(((r01)*(x13413)))+(((IkReal(-1.00000000000000))*(cj2)*(x13416)))+(((IkReal(-1.00000000000000))*(r02)*(x13398)*(x13409)))+(((IkReal(-1.00000000000000))*(x13395)*(x13404)))+(((IkReal(-1.00000000000000))*(r12)*(x13396)*(x13398)))+(((IkReal(-1.00000000000000))*(x13397)*(x13398)*(x13400)))+(((IkReal(-1.00000000000000))*(r10)*(sj0)*(x13403)))+(((r11)*(x13415)))+(((IkReal(-1.00000000000000))*(x13398)*(x13399)*(x13400))));
if( IKabs(evalcond[0]) > 0.000001  || IKabs(evalcond[1]) > 0.000001  || IKabs(evalcond[2]) > 0.000001  || IKabs(evalcond[3]) > 0.000001  || IKabs(evalcond[4]) > 0.000001  || IKabs(evalcond[5]) > 0.000001  )
{
continue;
}
}

{
std::vector<IkSingleDOFSolutionBase<IkReal> > vinfos(7);
vinfos[0].jointtype = 1;
vinfos[0].foffset = j0;
vinfos[0].indices[0] = _ij0[0];
vinfos[0].indices[1] = _ij0[1];
vinfos[0].maxsolutions = _nj0;
vinfos[1].jointtype = 1;
vinfos[1].foffset = j1;
vinfos[1].indices[0] = _ij1[0];
vinfos[1].indices[1] = _ij1[1];
vinfos[1].maxsolutions = _nj1;
vinfos[2].jointtype = 1;
vinfos[2].foffset = j2;
vinfos[2].indices[0] = _ij2[0];
vinfos[2].indices[1] = _ij2[1];
vinfos[2].maxsolutions = _nj2;
vinfos[3].jointtype = 1;
vinfos[3].foffset = j3;
vinfos[3].indices[0] = _ij3[0];
vinfos[3].indices[1] = _ij3[1];
vinfos[3].maxsolutions = _nj3;
vinfos[4].jointtype = 1;
vinfos[4].foffset = j4;
vinfos[4].indices[0] = _ij4[0];
vinfos[4].indices[1] = _ij4[1];
vinfos[4].maxsolutions = _nj4;
vinfos[5].jointtype = 1;
vinfos[5].foffset = j5;
vinfos[5].indices[0] = _ij5[0];
vinfos[5].indices[1] = _ij5[1];
vinfos[5].maxsolutions = _nj5;
vinfos[6].jointtype = 1;
vinfos[6].foffset = j6;
vinfos[6].indices[0] = _ij6[0];
vinfos[6].indices[1] = _ij6[1];
vinfos[6].maxsolutions = _nj6;
std::vector<int> vfree(0);
solutions.AddSolution(vinfos,vfree);
}
}
}

}

}

} else
{
{
IkReal j3array[1], cj3array[1], sj3array[1];
bool j3valid[1]={false};
_nj3 = 1;
IkReal x13417=(cj1)*(cj1);
IkReal x13418=(sj1)*(sj1);
IkReal x13419=((r00)*(sj6));
IkReal x13420=((cj6)*(r01));
IkReal x13421=((IkReal(1.00000000000000))*(cj1));
IkReal x13422=((cj5)*(r22));
IkReal x13423=((sj5)*(sj6));
IkReal x13424=((r10)*(sj0));
IkReal x13425=((cj1)*(cj5));
IkReal x13426=((cj0)*(r02));
IkReal x13427=((r12)*(sj0));
IkReal x13428=((IkReal(1.00000000000000))*(sj1));
IkReal x13429=((cj6)*(sj5));
IkReal x13430=((cj0)*(sj5));
IkReal x13431=((r11)*(sj0));
IkReal x13432=((sj1)*(x13430));
if( IKabs(((((IKabs(((((cj2)*(x13418)))+(((cj2)*(x13417))))) != 0)?((IkReal)1/(((((cj2)*(x13418)))+(((cj2)*(x13417)))))):(IkReal)1.0e30))*(((((IkReal(-1.00000000000000))*(cj5)*(x13426)*(x13428)))+(((cj1)*(r21)*(x13429)))+(((x13420)*(x13432)))+(((sj1)*(x13429)*(x13431)))+(((IkReal(-1.00000000000000))*(x13421)*(x13422)))+(((sj1)*(x13423)*(x13424)))+(((cj1)*(r20)*(x13423)))+(((x13419)*(x13432)))+(((IkReal(-1.00000000000000))*(cj5)*(x13427)*(x13428))))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(((((IKabs(((x13417)+(x13418))) != 0)?((IkReal)1/(((x13417)+(x13418)))):(IkReal)1.0e30))*(((((IkReal(-1.00000000000000))*(x13419)*(x13421)*(x13430)))+(((r20)*(sj1)*(x13423)))+(((x13425)*(x13427)))+(((r21)*(sj1)*(x13429)))+(((IkReal(-1.00000000000000))*(x13421)*(x13429)*(x13431)))+(((IkReal(-1.00000000000000))*(x13420)*(x13421)*(x13430)))+(((x13425)*(x13426)))+(((IkReal(-1.00000000000000))*(x13421)*(x13423)*(x13424)))+(((IkReal(-1.00000000000000))*(x13422)*(x13428))))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(IKsqr(((((IKabs(((((cj2)*(x13418)))+(((cj2)*(x13417))))) != 0)?((IkReal)1/(((((cj2)*(x13418)))+(((cj2)*(x13417)))))):(IkReal)1.0e30))*(((((IkReal(-1.00000000000000))*(cj5)*(x13426)*(x13428)))+(((cj1)*(r21)*(x13429)))+(((x13420)*(x13432)))+(((sj1)*(x13429)*(x13431)))+(((IkReal(-1.00000000000000))*(x13421)*(x13422)))+(((sj1)*(x13423)*(x13424)))+(((cj1)*(r20)*(x13423)))+(((x13419)*(x13432)))+(((IkReal(-1.00000000000000))*(cj5)*(x13427)*(x13428)))))))+IKsqr(((((IKabs(((x13417)+(x13418))) != 0)?((IkReal)1/(((x13417)+(x13418)))):(IkReal)1.0e30))*(((((IkReal(-1.00000000000000))*(x13419)*(x13421)*(x13430)))+(((r20)*(sj1)*(x13423)))+(((x13425)*(x13427)))+(((r21)*(sj1)*(x13429)))+(((IkReal(-1.00000000000000))*(x13421)*(x13429)*(x13431)))+(((IkReal(-1.00000000000000))*(x13420)*(x13421)*(x13430)))+(((x13425)*(x13426)))+(((IkReal(-1.00000000000000))*(x13421)*(x13423)*(x13424)))+(((IkReal(-1.00000000000000))*(x13422)*(x13428)))))))-1) <= IKFAST_SINCOS_THRESH )
    continue;
j3array[0]=IKatan2(((((IKabs(((((cj2)*(x13418)))+(((cj2)*(x13417))))) != 0)?((IkReal)1/(((((cj2)*(x13418)))+(((cj2)*(x13417)))))):(IkReal)1.0e30))*(((((IkReal(-1.00000000000000))*(cj5)*(x13426)*(x13428)))+(((cj1)*(r21)*(x13429)))+(((x13420)*(x13432)))+(((sj1)*(x13429)*(x13431)))+(((IkReal(-1.00000000000000))*(x13421)*(x13422)))+(((sj1)*(x13423)*(x13424)))+(((cj1)*(r20)*(x13423)))+(((x13419)*(x13432)))+(((IkReal(-1.00000000000000))*(cj5)*(x13427)*(x13428)))))), ((((IKabs(((x13417)+(x13418))) != 0)?((IkReal)1/(((x13417)+(x13418)))):(IkReal)1.0e30))*(((((IkReal(-1.00000000000000))*(x13419)*(x13421)*(x13430)))+(((r20)*(sj1)*(x13423)))+(((x13425)*(x13427)))+(((r21)*(sj1)*(x13429)))+(((IkReal(-1.00000000000000))*(x13421)*(x13429)*(x13431)))+(((IkReal(-1.00000000000000))*(x13420)*(x13421)*(x13430)))+(((x13425)*(x13426)))+(((IkReal(-1.00000000000000))*(x13421)*(x13423)*(x13424)))+(((IkReal(-1.00000000000000))*(x13422)*(x13428)))))));
sj3array[0]=IKsin(j3array[0]);
cj3array[0]=IKcos(j3array[0]);
if( j3array[0] > IKPI )
{
    j3array[0]-=IK2PI;
}
else if( j3array[0] < -IKPI )
{    j3array[0]+=IK2PI;
}
j3valid[0] = true;
for(int ij3 = 0; ij3 < 1; ++ij3)
{
if( !j3valid[ij3] )
{
    continue;
}
_ij3[0] = ij3; _ij3[1] = -1;
for(int iij3 = ij3+1; iij3 < 1; ++iij3)
{
if( j3valid[iij3] && IKabs(cj3array[ij3]-cj3array[iij3]) < IKFAST_SOLUTION_THRESH && IKabs(sj3array[ij3]-sj3array[iij3]) < IKFAST_SOLUTION_THRESH )
{
    j3valid[iij3]=false; _ij3[1] = iij3; break; 
}
}
j3 = j3array[ij3]; cj3 = cj3array[ij3]; sj3 = sj3array[ij3];
{
IkReal evalcond[6];
IkReal x13433=IKcos(j3);
IkReal x13434=IKsin(j3);
IkReal x13435=((sj0)*(sj5));
IkReal x13436=((r00)*(sj6));
IkReal x13437=((IkReal(1.00000000000000))*(cj4));
IkReal x13438=((cj6)*(r01));
IkReal x13439=((cj0)*(cj5));
IkReal x13440=((cj5)*(sj0));
IkReal x13441=((cj6)*(r11));
IkReal x13442=((cj6)*(sj4));
IkReal x13443=((IkReal(1.00000000000000))*(cj1));
IkReal x13444=((cj4)*(cj5));
IkReal x13445=((cj6)*(r21));
IkReal x13446=((r20)*(sj6));
IkReal x13447=((r10)*(sj6));
IkReal x13448=((cj0)*(sj5));
IkReal x13449=((IkReal(1.00000000000000))*(cj0));
IkReal x13450=((IkReal(1.00000000000000))*(x13448));
IkReal x13451=((IkReal(1.00000000000000))*(x13434));
IkReal x13452=((cj0)*(sj4)*(sj6));
IkReal x13453=((cj2)*(x13434));
IkReal x13454=((sj0)*(sj4)*(sj6));
IkReal x13455=((IkReal(1.00000000000000))*(sj1)*(x13433));
evalcond[0]=((((IkReal(-1.00000000000000))*(x13455)))+(((sj5)*(x13445)))+(((IkReal(-1.00000000000000))*(cj5)*(r22)))+(((IkReal(-1.00000000000000))*(x13443)*(x13453)))+(((sj5)*(x13446))));
evalcond[1]=((((r20)*(x13442)))+(((IkReal(-1.00000000000000))*(r21)*(sj4)*(sj6)))+(((IkReal(-1.00000000000000))*(sj1)*(x13451)))+(((cj4)*(r22)*(sj5)))+(((cj1)*(cj2)*(x13433)))+(((x13444)*(x13446)))+(((x13444)*(x13445))));
evalcond[2]=((((IkReal(-1.00000000000000))*(r02)*(x13440)))+(((IkReal(-1.00000000000000))*(sj2)*(x13451)))+(((r12)*(x13439)))+(((IkReal(-1.00000000000000))*(x13447)*(x13450)))+(((IkReal(-1.00000000000000))*(x13441)*(x13450)))+(((x13435)*(x13436)))+(((x13435)*(x13438))));
evalcond[3]=((((sj1)*(x13453)))+(((IkReal(-1.00000000000000))*(x13438)*(x13450)))+(((r02)*(x13439)))+(((IkReal(-1.00000000000000))*(x13433)*(x13443)))+(((IkReal(-1.00000000000000))*(x13436)*(x13450)))+(((IkReal(-1.00000000000000))*(x13435)*(x13441)))+(((r12)*(x13440)))+(((IkReal(-1.00000000000000))*(x13435)*(x13447))));
evalcond[4]=((((IkReal(-1.00000000000000))*(r10)*(x13442)*(x13449)))+(((cj4)*(r02)*(x13435)))+(((sj2)*(x13433)))+(((r11)*(x13452)))+(((cj4)*(x13436)*(x13440)))+(((IkReal(-1.00000000000000))*(x13437)*(x13439)*(x13441)))+(((IkReal(-1.00000000000000))*(r01)*(x13454)))+(((r00)*(sj0)*(x13442)))+(((IkReal(-1.00000000000000))*(r12)*(x13437)*(x13448)))+(((cj4)*(x13438)*(x13440)))+(((IkReal(-1.00000000000000))*(x13437)*(x13439)*(x13447))));
evalcond[5]=((((IkReal(-1.00000000000000))*(r02)*(x13437)*(x13448)))+(((IkReal(-1.00000000000000))*(x13434)*(x13443)))+(((IkReal(-1.00000000000000))*(r12)*(x13435)*(x13437)))+(((IkReal(-1.00000000000000))*(x13436)*(x13437)*(x13439)))+(((IkReal(-1.00000000000000))*(r10)*(sj0)*(x13442)))+(((IkReal(-1.00000000000000))*(x13437)*(x13438)*(x13439)))+(((IkReal(-1.00000000000000))*(x13437)*(x13440)*(x13447)))+(((r01)*(x13452)))+(((IkReal(-1.00000000000000))*(cj2)*(x13455)))+(((IkReal(-1.00000000000000))*(r00)*(x13442)*(x13449)))+(((IkReal(-1.00000000000000))*(x13437)*(x13440)*(x13441)))+(((r11)*(x13454))));
if( IKabs(evalcond[0]) > 0.000001  || IKabs(evalcond[1]) > 0.000001  || IKabs(evalcond[2]) > 0.000001  || IKabs(evalcond[3]) > 0.000001  || IKabs(evalcond[4]) > 0.000001  || IKabs(evalcond[5]) > 0.000001  )
{
continue;
}
}

{
std::vector<IkSingleDOFSolutionBase<IkReal> > vinfos(7);
vinfos[0].jointtype = 1;
vinfos[0].foffset = j0;
vinfos[0].indices[0] = _ij0[0];
vinfos[0].indices[1] = _ij0[1];
vinfos[0].maxsolutions = _nj0;
vinfos[1].jointtype = 1;
vinfos[1].foffset = j1;
vinfos[1].indices[0] = _ij1[0];
vinfos[1].indices[1] = _ij1[1];
vinfos[1].maxsolutions = _nj1;
vinfos[2].jointtype = 1;
vinfos[2].foffset = j2;
vinfos[2].indices[0] = _ij2[0];
vinfos[2].indices[1] = _ij2[1];
vinfos[2].maxsolutions = _nj2;
vinfos[3].jointtype = 1;
vinfos[3].foffset = j3;
vinfos[3].indices[0] = _ij3[0];
vinfos[3].indices[1] = _ij3[1];
vinfos[3].maxsolutions = _nj3;
vinfos[4].jointtype = 1;
vinfos[4].foffset = j4;
vinfos[4].indices[0] = _ij4[0];
vinfos[4].indices[1] = _ij4[1];
vinfos[4].maxsolutions = _nj4;
vinfos[5].jointtype = 1;
vinfos[5].foffset = j5;
vinfos[5].indices[0] = _ij5[0];
vinfos[5].indices[1] = _ij5[1];
vinfos[5].maxsolutions = _nj5;
vinfos[6].jointtype = 1;
vinfos[6].foffset = j6;
vinfos[6].indices[0] = _ij6[0];
vinfos[6].indices[1] = _ij6[1];
vinfos[6].maxsolutions = _nj6;
std::vector<int> vfree(0);
solutions.AddSolution(vinfos,vfree);
}
}
}

}

}

} else
{
{
IkReal j3array[1], cj3array[1], sj3array[1];
bool j3valid[1]={false};
_nj3 = 1;
IkReal x13456=((sj1)*(sj6));
IkReal x13457=((r20)*(sj5));
IkReal x13458=((IkReal(1.00000000000000))*(r21));
IkReal x13459=((cj5)*(cj6));
IkReal x13460=((r22)*(sj5));
IkReal x13461=((cj4)*(sj1));
IkReal x13462=((cj1)*(cj2));
IkReal x13463=((cj5)*(r20));
IkReal x13464=((cj4)*(x13462));
IkReal x13465=((IkReal(1.00000000000000))*(cj5)*(r22));
IkReal x13466=((cj6)*(r20)*(sj4));
IkReal x13467=((cj6)*(r21)*(sj5));
if( IKabs(((gconst4)*(((((sj1)*(x13466)))+(((IkReal(-1.00000000000000))*(sj4)*(x13456)*(x13458)))+(((x13460)*(x13461)))+(((cj4)*(x13456)*(x13463)))+(((r21)*(x13459)*(x13461)))+(((x13462)*(x13467)))+(((IkReal(-1.00000000000000))*(x13462)*(x13465)))+(((sj6)*(x13457)*(x13462))))))) < IKFAST_ATAN2_MAGTHRESH && IKabs(((gconst4)*(((((sj1)*(x13467)))+(((IkReal(-1.00000000000000))*(x13460)*(x13464)))+(((x13456)*(x13457)))+(((IkReal(-1.00000000000000))*(x13458)*(x13459)*(x13464)))+(((IkReal(-1.00000000000000))*(sj6)*(x13463)*(x13464)))+(((IkReal(-1.00000000000000))*(x13462)*(x13466)))+(((IkReal(-1.00000000000000))*(sj1)*(x13465)))+(((r21)*(sj4)*(sj6)*(x13462))))))) < IKFAST_ATAN2_MAGTHRESH )
    continue;
j3array[0]=IKatan2(((gconst4)*(((((sj1)*(x13466)))+(((IkReal(-1.00000000000000))*(sj4)*(x13456)*(x13458)))+(((x13460)*(x13461)))+(((cj4)*(x13456)*(x13463)))+(((r21)*(x13459)*(x13461)))+(((x13462)*(x13467)))+(((IkReal(-1.00000000000000))*(x13462)*(x13465)))+(((sj6)*(x13457)*(x13462)))))), ((gconst4)*(((((sj1)*(x13467)))+(((IkReal(-1.00000000000000))*(x13460)*(x13464)))+(((x13456)*(x13457)))+(((IkReal(-1.00000000000000))*(x13458)*(x13459)*(x13464)))+(((IkReal(-1.00000000000000))*(sj6)*(x13463)*(x13464)))+(((IkReal(-1.00000000000000))*(x13462)*(x13466)))+(((IkReal(-1.00000000000000))*(sj1)*(x13465)))+(((r21)*(sj4)*(sj6)*(x13462)))))));
sj3array[0]=IKsin(j3array[0]);
cj3array[0]=IKcos(j3array[0]);
if( j3array[0] > IKPI )
{
    j3array[0]-=IK2PI;
}
else if( j3array[0] < -IKPI )
{    j3array[0]+=IK2PI;
}
j3valid[0] = true;
for(int ij3 = 0; ij3 < 1; ++ij3)
{
if( !j3valid[ij3] )
{
    continue;
}
_ij3[0] = ij3; _ij3[1] = -1;
for(int iij3 = ij3+1; iij3 < 1; ++iij3)
{
if( j3valid[iij3] && IKabs(cj3array[ij3]-cj3array[iij3]) < IKFAST_SOLUTION_THRESH && IKabs(sj3array[ij3]-sj3array[iij3]) < IKFAST_SOLUTION_THRESH )
{
    j3valid[iij3]=false; _ij3[1] = iij3; break; 
}
}
j3 = j3array[ij3]; cj3 = cj3array[ij3]; sj3 = sj3array[ij3];
{
IkReal evalcond[6];
IkReal x13468=IKcos(j3);
IkReal x13469=IKsin(j3);
IkReal x13470=((sj0)*(sj5));
IkReal x13471=((r00)*(sj6));
IkReal x13472=((IkReal(1.00000000000000))*(cj4));
IkReal x13473=((cj6)*(r01));
IkReal x13474=((cj0)*(cj5));
IkReal x13475=((cj5)*(sj0));
IkReal x13476=((cj6)*(r11));
IkReal x13477=((cj6)*(sj4));
IkReal x13478=((IkReal(1.00000000000000))*(cj1));
IkReal x13479=((cj4)*(cj5));
IkReal x13480=((cj6)*(r21));
IkReal x13481=((r20)*(sj6));
IkReal x13482=((r10)*(sj6));
IkReal x13483=((cj0)*(sj5));
IkReal x13484=((IkReal(1.00000000000000))*(cj0));
IkReal x13485=((IkReal(1.00000000000000))*(x13483));
IkReal x13486=((IkReal(1.00000000000000))*(x13469));
IkReal x13487=((cj0)*(sj4)*(sj6));
IkReal x13488=((cj2)*(x13469));
IkReal x13489=((sj0)*(sj4)*(sj6));
IkReal x13490=((IkReal(1.00000000000000))*(sj1)*(x13468));
evalcond[0]=((((IkReal(-1.00000000000000))*(x13490)))+(((sj5)*(x13480)))+(((IkReal(-1.00000000000000))*(cj5)*(r22)))+(((sj5)*(x13481)))+(((IkReal(-1.00000000000000))*(x13478)*(x13488))));
evalcond[1]=((((IkReal(-1.00000000000000))*(r21)*(sj4)*(sj6)))+(((x13479)*(x13480)))+(((cj1)*(cj2)*(x13468)))+(((IkReal(-1.00000000000000))*(sj1)*(x13486)))+(((cj4)*(r22)*(sj5)))+(((r20)*(x13477)))+(((x13479)*(x13481))));
evalcond[2]=((((x13470)*(x13471)))+(((IkReal(-1.00000000000000))*(x13482)*(x13485)))+(((x13470)*(x13473)))+(((IkReal(-1.00000000000000))*(sj2)*(x13486)))+(((r12)*(x13474)))+(((IkReal(-1.00000000000000))*(x13476)*(x13485)))+(((IkReal(-1.00000000000000))*(r02)*(x13475))));
evalcond[3]=((((sj1)*(x13488)))+(((IkReal(-1.00000000000000))*(x13470)*(x13476)))+(((IkReal(-1.00000000000000))*(x13468)*(x13478)))+(((r02)*(x13474)))+(((IkReal(-1.00000000000000))*(x13471)*(x13485)))+(((IkReal(-1.00000000000000))*(x13470)*(x13482)))+(((IkReal(-1.00000000000000))*(x13473)*(x13485)))+(((r12)*(x13475))));
evalcond[4]=((((IkReal(-1.00000000000000))*(r10)*(x13477)*(x13484)))+(((IkReal(-1.00000000000000))*(r12)*(x13472)*(x13483)))+(((cj4)*(x13471)*(x13475)))+(((IkReal(-1.00000000000000))*(x13472)*(x13474)*(x13476)))+(((IkReal(-1.00000000000000))*(x13472)*(x13474)*(x13482)))+(((r00)*(sj0)*(x13477)))+(((r11)*(x13487)))+(((sj2)*(x13468)))+(((cj4)*(x13473)*(x13475)))+(((IkReal(-1.00000000000000))*(r01)*(x13489)))+(((cj4)*(r02)*(x13470))));
evalcond[5]=((((IkReal(-1.00000000000000))*(x13471)*(x13472)*(x13474)))+(((IkReal(-1.00000000000000))*(cj2)*(x13490)))+(((r11)*(x13489)))+(((IkReal(-1.00000000000000))*(x13472)*(x13475)*(x13482)))+(((IkReal(-1.00000000000000))*(x13469)*(x13478)))+(((IkReal(-1.00000000000000))*(r10)*(sj0)*(x13477)))+(((IkReal(-1.00000000000000))*(r02)*(x13472)*(x13483)))+(((r01)*(x13487)))+(((IkReal(-1.00000000000000))*(x13472)*(x13475)*(x13476)))+(((IkReal(-1.00000000000000))*(r12)*(x13470)*(x13472)))+(((IkReal(-1.00000000000000))*(r00)*(x13477)*(x13484)))+(((IkReal(-1.00000000000000))*(x13472)*(x13473)*(x13474))));
if( IKabs(evalcond[0]) > 0.000001  || IKabs(evalcond[1]) > 0.000001  || IKabs(evalcond[2]) > 0.000001  || IKabs(evalcond[3]) > 0.000001  || IKabs(evalcond[4]) > 0.000001  || IKabs(evalcond[5]) > 0.000001  )
{
continue;
}
}

{
std::vector<IkSingleDOFSolutionBase<IkReal> > vinfos(7);
vinfos[0].jointtype = 1;
vinfos[0].foffset = j0;
vinfos[0].indices[0] = _ij0[0];
vinfos[0].indices[1] = _ij0[1];
vinfos[0].maxsolutions = _nj0;
vinfos[1].jointtype = 1;
vinfos[1].foffset = j1;
vinfos[1].indices[0] = _ij1[0];
vinfos[1].indices[1] = _ij1[1];
vinfos[1].maxsolutions = _nj1;
vinfos[2].jointtype = 1;
vinfos[2].foffset = j2;
vinfos[2].indices[0] = _ij2[0];
vinfos[2].indices[1] = _ij2[1];
vinfos[2].maxsolutions = _nj2;
vinfos[3].jointtype = 1;
vinfos[3].foffset = j3;
vinfos[3].indices[0] = _ij3[0];
vinfos[3].indices[1] = _ij3[1];
vinfos[3].maxsolutions = _nj3;
vinfos[4].jointtype = 1;
vinfos[4].foffset = j4;
vinfos[4].indices[0] = _ij4[0];
vinfos[4].indices[1] = _ij4[1];
vinfos[4].maxsolutions = _nj4;
vinfos[5].jointtype = 1;
vinfos[5].foffset = j5;
vinfos[5].indices[0] = _ij5[0];
vinfos[5].indices[1] = _ij5[1];
vinfos[5].maxsolutions = _nj5;
vinfos[6].jointtype = 1;
vinfos[6].foffset = j6;
vinfos[6].indices[0] = _ij6[0];
vinfos[6].indices[1] = _ij6[1];
vinfos[6].maxsolutions = _nj6;
std::vector<int> vfree(0);
solutions.AddSolution(vinfos,vfree);
}
}
}

}

}
}
}

}

}
}
}

}

}
    }
}
return solutions.GetNumSolutions()>0;
}

static inline bool checkconsistency8(const IkReal* Breal)
{
    IkReal norm = 0.1;
    for(int i = 0; i < 7; ++i) {
        norm += IKabs(Breal[i]);
    }
    IkReal tol = 1e-5*norm; // have to increase the threshold since many computations are involved
    return IKabs(Breal[0]*Breal[1]-Breal[2]) < tol && IKabs(Breal[1]*Breal[1]-Breal[3]) < tol && IKabs(Breal[0]*Breal[3]-Breal[4]) < tol && IKabs(Breal[1]*Breal[3]-Breal[5]) < tol && IKabs(Breal[0]*Breal[5]-Breal[6]) < tol;
}
/// \brief Solve the det Ax^2+Bx+C = 0 problem using the Manocha and Canny method (1994)
///
/// matcoeffs is of length 54*3, for 3 matrices
static inline void solvedialyticpoly8qep(const IkReal* matcoeffs, IkReal* rawroots, int& numroots)
{
    const IkReal tol = 128.0*std::numeric_limits<IkReal>::epsilon();
    IkReal IKFAST_ALIGNED16(M[16*16]) = {0};
    IkReal IKFAST_ALIGNED16(A[8*8]);
    IkReal IKFAST_ALIGNED16(work[16*16*15]);
    int ipiv[8];
    int info, coeffindex;
    const int worksize=16*16*15;
    const int matrixdim = 8;
    const int matrixdim2 = 16;
    numroots = 0;
    // first setup M = [0 I; -C -B] and A
    coeffindex = 0;
    for(int j = 0; j < 4; ++j) {
        for(int k = 0; k < 6; ++k) {
            M[matrixdim+(j+4)+2*matrixdim*k] = M[matrixdim+j+2*matrixdim*(k+2)] = -matcoeffs[coeffindex++];
        }
    }
    for(int j = 0; j < 4; ++j) {
        for(int k = 0; k < 6; ++k) {
            M[matrixdim+(j+4)+2*matrixdim*k+matrixdim*2*matrixdim] = M[matrixdim+j+2*matrixdim*(k+2)+matrixdim*2*matrixdim] = -matcoeffs[coeffindex++];
        }
    }
    for(int j = 0; j < 4; ++j) {
        for(int k = 0; k < 6; ++k) {
            A[(j+4)+matrixdim*k] = A[j+matrixdim*(k+2)] = matcoeffs[coeffindex++];
        }
        for(int k = 0; k < 2; ++k) {
            A[j+matrixdim*k] = A[(j+4)+matrixdim*(k+6)] = 0;
        }
    }
    const IkReal lfpossibilities[4][4] = {{1,-1,1,1},{1,0,-2,1},{1,1,2,0},{1,-1,4,1}};
    int lfindex = -1;
    bool bsingular = true;
    do {
        dgetrf_(&matrixdim,&matrixdim,A,&matrixdim,&ipiv[0],&info);
        if( info == 0 ) {
            bsingular = false;
            for(int j = 0; j < matrixdim; ++j) {
                if( IKabs(A[j*matrixdim+j]) < 100*tol ) {
                    bsingular = true;
                    break;
                }
            }
            if( !bsingular ) {
                break;
            }
        }
        if( lfindex == 3 ) {
            break;
        }
        // transform by the linear functional
        lfindex++;
        const IkReal* lf = lfpossibilities[lfindex];
        // have to reinitialize A
        coeffindex = 0;
        for(int j = 0; j < 4; ++j) {
            for(int k = 0; k < 6; ++k) {
                IkReal a = matcoeffs[coeffindex+48], b = matcoeffs[coeffindex+24], c = matcoeffs[coeffindex];
                A[(j+4)+matrixdim*k] = A[j+matrixdim*(k+2)] = lf[0]*lf[0]*a+lf[0]*lf[2]*b+lf[2]*lf[2]*c;
                M[matrixdim+(j+4)+2*matrixdim*k] = M[matrixdim+j+2*matrixdim*(k+2)] = -(lf[1]*lf[1]*a + lf[1]*lf[3]*b + lf[3]*lf[3]*c);
                M[matrixdim+(j+4)+2*matrixdim*k+matrixdim*2*matrixdim] = M[matrixdim+j+2*matrixdim*(k+2)+matrixdim*2*matrixdim] = -(2*lf[0]*lf[1]*a + (lf[0]*lf[3]+lf[1]*lf[2])*b + 2*lf[2]*lf[3]*c);
                coeffindex++;
            }
            for(int k = 0; k < 2; ++k) {
                A[j+matrixdim*k] = A[(j+4)+matrixdim*(k+6)] = 0;
            }
        }
    } while(lfindex<4);

    if( bsingular ) {
        return;
    }
    dgetrs_("No transpose", &matrixdim, &matrixdim2, A, &matrixdim, &ipiv[0], &M[matrixdim], &matrixdim2, &info);
    if( info != 0 ) {
        return;
    }

    // set identity in upper corner
    for(int j = 0; j < matrixdim; ++j) {
        M[matrixdim*2*matrixdim+j+matrixdim*2*j] = 1;
    }
    IkReal IKFAST_ALIGNED16(wr[16]);
    IkReal IKFAST_ALIGNED16(wi[16]);
    IkReal IKFAST_ALIGNED16(vr[16*16]);
    int one=1;
    dgeev_("N", "V", &matrixdim2, M, &matrixdim2, wr, wi,NULL, &one, vr, &matrixdim2, work, &worksize, &info);
    if( info != 0 ) {
        return;
    }
    IkReal Breal[matrixdim-1];
    for(int i = 0; i < matrixdim2; ++i) {
        if( IKabs(wi[i]) < tol*100 ) {
            IkReal* ev = vr+matrixdim2*i;
            if( IKabs(wr[i]) > 1 ) {
                ev += matrixdim;
            }
            // consistency has to be checked!!
            if( IKabs(ev[0]) < tol ) {
                continue;
            }
            IkReal iconst = 1/ev[0];
            for(int j = 1; j < matrixdim; ++j) {
                Breal[j-1] = ev[j]*iconst;
            }
            if( checkconsistency8(Breal) ) {
                if( lfindex >= 0 ) {
                    const IkReal* lf = lfpossibilities[lfindex];
                    rawroots[numroots++] = (wr[i]*lf[0]+lf[1])/(wr[i]*lf[2]+lf[3]);
                }
                else {
                    rawroots[numroots++] = wr[i];
                }
                bool bsmall0=IKabs(ev[0]) > IKabs(ev[2]);
                bool bsmall1=IKabs(ev[0]) > IKabs(ev[1]);
                if( bsmall0 && bsmall1 ) {
                    rawroots[numroots++] = ev[2]/ev[0];
                    rawroots[numroots++] = ev[1]/ev[0];
                }
                else if( bsmall0 && !bsmall1 ) {
                    rawroots[numroots++] = ev[3]/ev[1];
                    rawroots[numroots++] = ev[1]/ev[0];
                }
                else if( !bsmall0 && bsmall1 ) {
                    rawroots[numroots++] = ev[6]/ev[4];
                    rawroots[numroots++] = ev[7]/ev[6];
                }
                else if( !bsmall0 && !bsmall1 ) {
                    rawroots[numroots++] = ev[7]/ev[5];
                    rawroots[numroots++] = ev[7]/ev[6];
                }
            }
        }
    }
}};


/// solves the inverse kinematics equations.
/// \param pfree is an array specifying the free joints of the chain.
IKFAST_API bool ComputeIk(const IkReal* eetrans, const IkReal* eerot, const IkReal* pfree, IkSolutionListBase<IkReal>& solutions) {
IKSolver solver;
return solver.ComputeIk(eetrans,eerot,pfree,solutions);
}

IKFAST_API const char* GetKinematicsHash() { return "<robot:genericrobot - baxter (4d3b297e057bd5f20da8f53b5e6cc20b)>"; }

IKFAST_API const char* GetIkFastVersion() { return IKFAST_STRINGIZE(IKFAST_VERSION); }

#ifdef IKFAST_NAMESPACE
} // end namespace
#endif

#ifndef IKFAST_NO_MAIN
#include <stdio.h>
#include <stdlib.h>
#ifdef IKFAST_NAMESPACE
using namespace IKFAST_NAMESPACE;
#endif
int main(int argc, char** argv)
{
    if( argc != 12+GetNumFreeParameters()+1 ) {
        printf("\nUsage: ./ik r00 r01 r02 t0 r10 r11 r12 t1 r20 r21 r22 t2 free0 ...\n\n"
               "Returns the ik solutions given the transformation of the end effector specified by\n"
               "a 3x3 rotation R (rXX), and a 3x1 translation (tX).\n"
               "There are %d free parameters that have to be specified.\n\n",GetNumFreeParameters());
        return 1;
    }

    IkSolutionList<IkReal> solutions;
    std::vector<IkReal> vfree(GetNumFreeParameters());
    IkReal eerot[9],eetrans[3];
    eerot[0] = atof(argv[1]); eerot[1] = atof(argv[2]); eerot[2] = atof(argv[3]); eetrans[0] = atof(argv[4]);
    eerot[3] = atof(argv[5]); eerot[4] = atof(argv[6]); eerot[5] = atof(argv[7]); eetrans[1] = atof(argv[8]);
    eerot[6] = atof(argv[9]); eerot[7] = atof(argv[10]); eerot[8] = atof(argv[11]); eetrans[2] = atof(argv[12]);
    for(std::size_t i = 0; i < vfree.size(); ++i)
        vfree[i] = atof(argv[13+i]);
    bool bSuccess = ComputeIk(eetrans, eerot, vfree.size() > 0 ? &vfree[0] : NULL, solutions);

    if( !bSuccess ) {
        fprintf(stderr,"Failed to get ik solution\n");
        return -1;
    }

    printf("Found %d ik solutions:\n", (int)solutions.GetNumSolutions());
    std::vector<IkReal> solvalues(GetNumJoints());
    for(std::size_t i = 0; i < solutions.GetNumSolutions(); ++i) {
        const IkSolutionBase<IkReal>& sol = solutions.GetSolution(i);
        printf("sol%d (free=%d): ", (int)i, (int)sol.GetFree().size());
        std::vector<IkReal> vsolfree(sol.GetFree().size());
        sol.GetSolution(&solvalues[0],vsolfree.size()>0?&vsolfree[0]:NULL);
        for( std::size_t j = 0; j < solvalues.size(); ++j)
            printf("%.15f, ", solvalues[j]);
        printf("\n");
    }
    return 0;
}

#endif
